from typing import Optional
from botocore.client import BaseClient
from typing import Dict
from botocore.paginate import Paginator
from datetime import datetime
from botocore.waiter import Waiter
from typing import Union
from typing import List


class Client(BaseClient):
    def accept_reserved_instances_exchange_quote(self, ReservedInstanceIds: List, DryRun: bool = None, TargetConfigurations: List = None) -> Dict:
        """
        Accepts the Convertible Reserved Instance exchange quote described in the  GetReservedInstancesExchangeQuote call.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AcceptReservedInstancesExchangeQuote>`_
        
        **Request Syntax**
        ::
          response = client.accept_reserved_instances_exchange_quote(
              DryRun=True|False,
              ReservedInstanceIds=[
                  'string',
              ],
              TargetConfigurations=[
                  {
                      'InstanceCount': 123,
                      'OfferingId': 'string'
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ExchangeId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            The result of the exchange and whether it was ``successful`` .
            - **ExchangeId** *(string) --* 
              The ID of the successful exchange.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ReservedInstanceIds: list
        :param ReservedInstanceIds: **[REQUIRED]**
          The IDs of the Convertible Reserved Instances to exchange for another Convertible Reserved Instance of the same or higher value.
          - *(string) --*
        :type TargetConfigurations: list
        :param TargetConfigurations:
          The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances.
          - *(dict) --*
            Details about the target configuration.
            - **InstanceCount** *(integer) --*
              The number of instances the Covertible Reserved Instance offering can be applied to. This parameter is reserved and cannot be specified in a request
            - **OfferingId** *(string) --* **[REQUIRED]**
              The Convertible Reserved Instance offering ID.
        :rtype: dict
        :returns:
        """
        pass

    def accept_transit_gateway_vpc_attachment(self, TransitGatewayAttachmentId: str, DryRun: bool = None) -> Dict:
        """
        Accepts a request to attach a VPC to a transit gateway.
        The VPC attachment must be in the ``pendingAcceptance`` state. Use  DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use  RejectTransitGatewayVpcAttachment to reject a VPC attachment request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AcceptTransitGatewayVpcAttachment>`_
        
        **Request Syntax**
        ::
          response = client.accept_transit_gateway_vpc_attachment(
              TransitGatewayAttachmentId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayVpcAttachment': {
                    'TransitGatewayAttachmentId': 'string',
                    'TransitGatewayId': 'string',
                    'VpcId': 'string',
                    'VpcOwnerId': 'string',
                    'State': 'pendingAcceptance'|'rollingBack'|'pending'|'available'|'modifying'|'deleting'|'deleted'|'failed'|'rejected'|'rejecting'|'failing',
                    'SubnetIds': [
                        'string',
                    ],
                    'CreationTime': datetime(2015, 1, 1),
                    'Options': {
                        'DnsSupport': 'enable'|'disable',
                        'Ipv6Support': 'enable'|'disable'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayVpcAttachment** *(dict) --* 
              The VPC attachment.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **VpcOwnerId** *(string) --* 
                The ID of the AWS account that owns the VPC.
              - **State** *(string) --* 
                The state of the VPC attachment.
              - **SubnetIds** *(list) --* 
                The IDs of the subnets.
                - *(string) --* 
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Options** *(dict) --* 
                The VPC attachment options.
                - **DnsSupport** *(string) --* 
                  Indicates whether DNS support is enabled.
                - **Ipv6Support** *(string) --* 
                  Indicates whether IPv6 support is enabled.
              - **Tags** *(list) --* 
                The tags for the VPC attachment.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def accept_vpc_endpoint_connections(self, ServiceId: str, VpcEndpointIds: List, DryRun: bool = None) -> Dict:
        """
        Accepts one or more interface VPC endpoint connection requests to your VPC endpoint service.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AcceptVpcEndpointConnections>`_
        
        **Request Syntax**
        ::
          response = client.accept_vpc_endpoint_connections(
              DryRun=True|False,
              ServiceId='string',
              VpcEndpointIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Unsuccessful** *(list) --* 
              Information about the interface endpoints that were not accepted, if applicable.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceId: string
        :param ServiceId: **[REQUIRED]**
          The ID of the endpoint service.
        :type VpcEndpointIds: list
        :param VpcEndpointIds: **[REQUIRED]**
          The IDs of one or more interface VPC endpoints.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def accept_vpc_peering_connection(self, DryRun: bool = None, VpcPeeringConnectionId: str = None) -> Dict:
        """
        Accept a VPC peering connection request. To accept a request, the VPC peering connection must be in the ``pending-acceptance`` state, and you must be the owner of the peer VPC. Use  DescribeVpcPeeringConnections to view your outstanding VPC peering connection requests.
        For an inter-region VPC peering connection request, you must accept the VPC peering connection in the region of the accepter VPC.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AcceptVpcPeeringConnection>`_
        
        **Request Syntax**
        ::
          response = client.accept_vpc_peering_connection(
              DryRun=True|False,
              VpcPeeringConnectionId='string'
          )
        
        **Response Syntax**
        ::
            {
                'VpcPeeringConnection': {
                    'AccepterVpcInfo': {
                        'CidrBlock': 'string',
                        'Ipv6CidrBlockSet': [
                            {
                                'Ipv6CidrBlock': 'string'
                            },
                        ],
                        'CidrBlockSet': [
                            {
                                'CidrBlock': 'string'
                            },
                        ],
                        'OwnerId': 'string',
                        'PeeringOptions': {
                            'AllowDnsResolutionFromRemoteVpc': True|False,
                            'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                            'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                        },
                        'VpcId': 'string',
                        'Region': 'string'
                    },
                    'ExpirationTime': datetime(2015, 1, 1),
                    'RequesterVpcInfo': {
                        'CidrBlock': 'string',
                        'Ipv6CidrBlockSet': [
                            {
                                'Ipv6CidrBlock': 'string'
                            },
                        ],
                        'CidrBlockSet': [
                            {
                                'CidrBlock': 'string'
                            },
                        ],
                        'OwnerId': 'string',
                        'PeeringOptions': {
                            'AllowDnsResolutionFromRemoteVpc': True|False,
                            'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                            'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                        },
                        'VpcId': 'string',
                        'Region': 'string'
                    },
                    'Status': {
                        'Code': 'initiating-request'|'pending-acceptance'|'active'|'deleted'|'rejected'|'failed'|'expired'|'provisioning'|'deleting',
                        'Message': 'string'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'VpcPeeringConnectionId': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VpcPeeringConnection** *(dict) --* 
              Information about the VPC peering connection.
              - **AccepterVpcInfo** *(dict) --* 
                Information about the accepter VPC. CIDR block information is only returned when describing an active VPC peering connection.
                - **CidrBlock** *(string) --* 
                  The IPv4 CIDR block for the VPC.
                - **Ipv6CidrBlockSet** *(list) --* 
                  The IPv6 CIDR block for the VPC.
                  - *(dict) --* 
                    Describes an IPv6 CIDR block.
                    - **Ipv6CidrBlock** *(string) --* 
                      The IPv6 CIDR block.
                - **CidrBlockSet** *(list) --* 
                  Information about the IPv4 CIDR blocks for the VPC.
                  - *(dict) --* 
                    Describes an IPv4 CIDR block.
                    - **CidrBlock** *(string) --* 
                      The IPv4 CIDR block.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the VPC owner.
                - **PeeringOptions** *(dict) --* 
                  Information about the VPC peering connection options for the accepter or requester VPC.
                  - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                    Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
                  - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                    Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
                  - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                    Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
                - **Region** *(string) --* 
                  The region in which the VPC is located.
              - **ExpirationTime** *(datetime) --* 
                The time that an unaccepted VPC peering connection will expire.
              - **RequesterVpcInfo** *(dict) --* 
                Information about the requester VPC. CIDR block information is only returned when describing an active VPC peering connection.
                - **CidrBlock** *(string) --* 
                  The IPv4 CIDR block for the VPC.
                - **Ipv6CidrBlockSet** *(list) --* 
                  The IPv6 CIDR block for the VPC.
                  - *(dict) --* 
                    Describes an IPv6 CIDR block.
                    - **Ipv6CidrBlock** *(string) --* 
                      The IPv6 CIDR block.
                - **CidrBlockSet** *(list) --* 
                  Information about the IPv4 CIDR blocks for the VPC.
                  - *(dict) --* 
                    Describes an IPv4 CIDR block.
                    - **CidrBlock** *(string) --* 
                      The IPv4 CIDR block.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the VPC owner.
                - **PeeringOptions** *(dict) --* 
                  Information about the VPC peering connection options for the accepter or requester VPC.
                  - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                    Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
                  - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                    Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
                  - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                    Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
                - **Region** *(string) --* 
                  The region in which the VPC is located.
              - **Status** *(dict) --* 
                The status of the VPC peering connection.
                - **Code** *(string) --* 
                  The status of the VPC peering connection.
                - **Message** *(string) --* 
                  A message that provides more information about the status, if applicable.
              - **Tags** *(list) --* 
                Any tags assigned to the resource.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **VpcPeeringConnectionId** *(string) --* 
                The ID of the VPC peering connection.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcPeeringConnectionId: string
        :param VpcPeeringConnectionId:
          The ID of the VPC peering connection. You must specify this parameter in the request.
        :rtype: dict
        :returns:
        """
        pass

    def advertise_byoip_cidr(self, Cidr: str, DryRun: bool = None) -> Dict:
        """
        Advertises an IPv4 address range that is provisioned for use with your AWS resources through bring your own IP addresses (BYOIP).
        You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time.
        We recommend that you stop advertising the BYOIP CIDR from other locations when you advertise it from AWS. To minimize down time, you can configure your AWS resources to use an address from a BYOIP CIDR before it is advertised, and then simultaneously stop advertising it from the current location and start advertising it through AWS.
        It can take a few minutes before traffic to the specified addresses starts routing to AWS because of BGP propagation delays.
        To stop advertising the BYOIP CIDR, use  WithdrawByoipCidr .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AdvertiseByoipCidr>`_
        
        **Request Syntax**
        ::
          response = client.advertise_byoip_cidr(
              Cidr='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ByoipCidr': {
                    'Cidr': 'string',
                    'Description': 'string',
                    'StatusMessage': 'string',
                    'State': 'advertised'|'deprovisioned'|'failed-deprovision'|'failed-provision'|'pending-deprovision'|'pending-provision'|'provisioned'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ByoipCidr** *(dict) --* 
              Information about the address range.
              - **Cidr** *(string) --* 
                The public IPv4 address range, in CIDR notation.
              - **Description** *(string) --* 
                The description of the address range.
              - **StatusMessage** *(string) --* 
                Upon success, contains the ID of the address pool. Otherwise, contains an error message.
              - **State** *(string) --* 
                The state of the address pool.
        :type Cidr: string
        :param Cidr: **[REQUIRED]**
          The IPv4 address range, in CIDR notation. This must be the exact range that you provisioned. You can\'t advertise only a portion of the provisioned range.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def allocate_address(self, Domain: str = None, Address: str = None, PublicIpv4Pool: str = None, DryRun: bool = None) -> Dict:
        """
        Allocates an Elastic IP address to your AWS account. After you allocate the Elastic IP address you can associate it with an instance or network interface. After you release an Elastic IP address, it is released to the IP address pool and can be allocated to a different AWS account.
        You can allocate an Elastic IP address from an address pool owned by AWS or from an address pool created from a public IPv4 address range that you have brought to AWS for use with your AWS resources using bring your own IP addresses (BYOIP). For more information, see `Bring Your Own IP Addresses (BYOIP) <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        [EC2-VPC] If you release an Elastic IP address, you might be able to recover it. You cannot recover an Elastic IP address that you released after it is allocated to another AWS account. You cannot recover an Elastic IP address for EC2-Classic. To attempt to recover an Elastic IP address that you released, specify it in this operation.
        An Elastic IP address is for use either in the EC2-Classic platform or in a VPC. By default, you can allocate 5 Elastic IP addresses for EC2-Classic per region and 5 Elastic IP addresses for EC2-VPC per region.
        For more information, see `Elastic IP Addresses <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AllocateAddress>`_
        
        **Request Syntax**
        ::
          response = client.allocate_address(
              Domain='vpc'|'standard',
              Address='string',
              PublicIpv4Pool='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'PublicIp': 'string',
                'AllocationId': 'string',
                'PublicIpv4Pool': 'string',
                'Domain': 'vpc'|'standard'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **PublicIp** *(string) --* 
              The Elastic IP address.
            - **AllocationId** *(string) --* 
              [EC2-VPC] The ID that AWS assigns to represent the allocation of the Elastic IP address for use with instances in a VPC.
            - **PublicIpv4Pool** *(string) --* 
              The ID of an address pool.
            - **Domain** *(string) --* 
              Indicates whether this Elastic IP address is for use with instances in EC2-Classic (``standard`` ) or instances in a VPC (``vpc`` ).
        :type Domain: string
        :param Domain:
          Set to ``vpc`` to allocate the address for use with instances in a VPC.
          Default: The address is for use with instances in EC2-Classic.
        :type Address: string
        :param Address:
          [EC2-VPC] The Elastic IP address to recover or an IPv4 address from an address pool.
        :type PublicIpv4Pool: string
        :param PublicIpv4Pool:
          The ID of an address pool that you own. Use this parameter to let Amazon EC2 select an address from the address pool. To specify a specific address from the address pool, use the ``Address`` parameter instead.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def allocate_hosts(self, AvailabilityZone: str, InstanceType: str, Quantity: int, AutoPlacement: str = None, ClientToken: str = None, TagSpecifications: List = None) -> Dict:
        """
        Allocates a Dedicated Host to your account. At a minimum, specify the instance size type, Availability Zone, and quantity of hosts to allocate.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AllocateHosts>`_
        
        **Request Syntax**
        ::
          response = client.allocate_hosts(
              AutoPlacement='on'|'off',
              AvailabilityZone='string',
              ClientToken='string',
              InstanceType='string',
              Quantity=123,
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'HostIds': [
                    'string',
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of AllocateHosts.
            - **HostIds** *(list) --* 
              The ID of the allocated Dedicated Host. This is used to launch an instance onto a specific host.
              - *(string) --* 
        :type AutoPlacement: string
        :param AutoPlacement:
          Indicates whether the host accepts any untargeted instance launches that match its instance type configuration, or if it only accepts Host tenancy instance launches that specify its unique host ID. For more information, see `Understanding Instance Placement and Host Affinity <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/how-dedicated-hosts-work.html#dedicated-hosts-understanding>`__ in the *Amazon EC2 User Guide for Linux Instances* .
          Default: ``on``
        :type AvailabilityZone: string
        :param AvailabilityZone: **[REQUIRED]**
          The Availability Zone in which to allocate the Dedicated Host.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type InstanceType: string
        :param InstanceType: **[REQUIRED]**
          Specifies the instance type for which to configure your Dedicated Hosts. When you specify the instance type, that is the only instance type that you can launch onto that host.
        :type Quantity: integer
        :param Quantity: **[REQUIRED]**
          The number of Dedicated Hosts to allocate to your account with these parameters.
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the Dedicated Host during creation.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :rtype: dict
        :returns:
        """
        pass

    def apply_security_groups_to_client_vpn_target_network(self, ClientVpnEndpointId: str, VpcId: str, SecurityGroupIds: List, DryRun: bool = None) -> Dict:
        """
        Applies a security group to the association between the target network and the Client VPN endpoint. This action replaces the existing security groups with the specified security groups.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ApplySecurityGroupsToClientVpnTargetNetwork>`_
        
        **Request Syntax**
        ::
          response = client.apply_security_groups_to_client_vpn_target_network(
              ClientVpnEndpointId='string',
              VpcId='string',
              SecurityGroupIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'SecurityGroupIds': [
                    'string',
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **SecurityGroupIds** *(list) --* 
              The IDs of the applied security groups.
              - *(string) --* 
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC in which the associated target network is located.
        :type SecurityGroupIds: list
        :param SecurityGroupIds: **[REQUIRED]**
          The IDs of the security groups to apply to the associated target network. Up to 5 security groups can be applied to an associated target network.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def assign_ipv6_addresses(self, NetworkInterfaceId: str, Ipv6AddressCount: int = None, Ipv6Addresses: List = None) -> Dict:
        """
        Assigns one or more IPv6 addresses to the specified network interface. You can specify one or more specific IPv6 addresses, or you can specify the number of IPv6 addresses to be automatically assigned from within the subnet's IPv6 CIDR block range. You can assign as many IPv6 addresses to a network interface as you can assign private IPv4 addresses, and the limit varies per instance type. For information, see `IP Addresses Per Network Interface Per Instance Type <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssignIpv6Addresses>`_
        
        **Request Syntax**
        ::
          response = client.assign_ipv6_addresses(
              Ipv6AddressCount=123,
              Ipv6Addresses=[
                  'string',
              ],
              NetworkInterfaceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'AssignedIpv6Addresses': [
                    'string',
                ],
                'NetworkInterfaceId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AssignedIpv6Addresses** *(list) --* 
              The IPv6 addresses assigned to the network interface.
              - *(string) --* 
            - **NetworkInterfaceId** *(string) --* 
              The ID of the network interface.
        :type Ipv6AddressCount: integer
        :param Ipv6AddressCount:
          The number of IPv6 addresses to assign to the network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can\'t use this option if specifying specific IPv6 addresses.
        :type Ipv6Addresses: list
        :param Ipv6Addresses:
          One or more specific IPv6 addresses to be assigned to the network interface. You can\'t use this option if you\'re specifying a number of IPv6 addresses.
          - *(string) --*
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :rtype: dict
        :returns:
        """
        pass

    def assign_private_ip_addresses(self, NetworkInterfaceId: str, AllowReassignment: bool = None, PrivateIpAddresses: List = None, SecondaryPrivateIpAddressCount: int = None):
        """
        Assigns one or more secondary private IP addresses to the specified network interface.
        You can specify one or more specific secondary IP addresses, or you can specify the number of secondary IP addresses to be automatically assigned within the subnet's CIDR block range. The number of secondary IP addresses that you can assign to an instance varies by instance type. For information about instance types, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . For more information about Elastic IP addresses, see `Elastic IP Addresses <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        When you move a secondary private IP address to another network interface, any Elastic IP address that is associated with the IP address is also moved.
        Remapping an IP address is an asynchronous operation. When you move an IP address from one network interface to another, check ``network/interfaces/macs/mac/local-ipv4s`` in the instance metadata to confirm that the remapping is complete.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssignPrivateIpAddresses>`_
        
        **Request Syntax**
        ::
          response = client.assign_private_ip_addresses(
              AllowReassignment=True|False,
              NetworkInterfaceId='string',
              PrivateIpAddresses=[
                  'string',
              ],
              SecondaryPrivateIpAddressCount=123
          )
        :type AllowReassignment: boolean
        :param AllowReassignment:
          Indicates whether to allow an IP address that is already assigned to another network interface or instance to be reassigned to the specified network interface.
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :type PrivateIpAddresses: list
        :param PrivateIpAddresses:
          One or more IP addresses to be assigned as a secondary private IP address to the network interface. You can\'t specify this parameter when also specifying a number of secondary IP addresses.
          If you don\'t specify an IP address, Amazon EC2 automatically selects an IP address within the subnet range.
          - *(string) --*
        :type SecondaryPrivateIpAddressCount: integer
        :param SecondaryPrivateIpAddressCount:
          The number of secondary IP addresses to assign to the network interface. You can\'t specify this parameter when also specifying private IP addresses.
        :returns: None
        """
        pass

    def associate_address(self, AllocationId: str = None, InstanceId: str = None, PublicIp: str = None, AllowReassociation: bool = None, DryRun: bool = None, NetworkInterfaceId: str = None, PrivateIpAddress: str = None) -> Dict:
        """
        Associates an Elastic IP address with an instance or a network interface. Before you can use an Elastic IP address, you must allocate it to your account.
        An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see `Elastic IP Addresses <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        [EC2-Classic, VPC in an EC2-VPC-only account] If the Elastic IP address is already associated with a different instance, it is disassociated from that instance and associated with the specified instance. If you associate an Elastic IP address with an instance that has an existing Elastic IP address, the existing address is disassociated from the instance, but remains allocated to your account.
        [VPC in an EC2-Classic account] If you don't specify a private IP address, the Elastic IP address is associated with the primary IP address. If the Elastic IP address is already associated with a different instance or a network interface, you get an error unless you allow reassociation. You cannot associate an Elastic IP address with an instance or network interface that has an existing Elastic IP address.
        .. warning::
          This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error, and you may be charged for each time the Elastic IP address is remapped to the same instance. For more information, see the *Elastic IP Addresses* section of `Amazon EC2 Pricing <http://aws.amazon.com/ec2/pricing/>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateAddress>`_
        
        **Request Syntax**
        ::
          response = client.associate_address(
              AllocationId='string',
              InstanceId='string',
              PublicIp='string',
              AllowReassociation=True|False,
              DryRun=True|False,
              NetworkInterfaceId='string',
              PrivateIpAddress='string'
          )
        
        **Response Syntax**
        ::
            {
                'AssociationId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AssociationId** *(string) --* 
              [EC2-VPC] The ID that represents the association of the Elastic IP address with an instance.
        :type AllocationId: string
        :param AllocationId:
          [EC2-VPC] The allocation ID. This is required for EC2-VPC.
        :type InstanceId: string
        :param InstanceId:
          The ID of the instance. This is required for EC2-Classic. For EC2-VPC, you can specify either the instance ID or the network interface ID, but not both. The operation fails if you specify an instance ID unless exactly one network interface is attached.
        :type PublicIp: string
        :param PublicIp:
          The Elastic IP address to associate with the instance. This is required for EC2-Classic.
        :type AllowReassociation: boolean
        :param AllowReassociation:
          [EC2-VPC] For a VPC in an EC2-Classic account, specify true to allow an Elastic IP address that is already associated with an instance or network interface to be reassociated with the specified instance or network interface. Otherwise, the operation fails. In a VPC in an EC2-VPC-only account, reassociation is automatic, therefore you can specify false to ensure the operation fails if the Elastic IP address is already associated with another resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId:
          [EC2-VPC] The ID of the network interface. If the instance has more than one network interface, you must specify a network interface ID.
          For EC2-VPC, you can specify either the instance ID or the network interface ID, but not both.
        :type PrivateIpAddress: string
        :param PrivateIpAddress:
          [EC2-VPC] The primary or secondary private IP address to associate with the Elastic IP address. If no private IP address is specified, the Elastic IP address is associated with the primary private IP address.
        :rtype: dict
        :returns:
        """
        pass

    def associate_client_vpn_target_network(self, ClientVpnEndpointId: str, SubnetId: str, DryRun: bool = None) -> Dict:
        """
        Associates a target network with a Client VPN endpoint. A target network is a subnet in a VPC. You can associate multiple subnets from the same VPC with a Client VPN endpoint. You can associate only one subnet in each Availability Zone. We recommend that you associate at least two subnets to provide Availability Zone redundancy.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateClientVpnTargetNetwork>`_
        
        **Request Syntax**
        ::
          response = client.associate_client_vpn_target_network(
              ClientVpnEndpointId='string',
              SubnetId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'AssociationId': 'string',
                'Status': {
                    'Code': 'associating'|'associated'|'association-failed'|'disassociating'|'disassociated',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AssociationId** *(string) --* 
              The unique ID of the target network association.
            - **Status** *(dict) --* 
              The current state of the target network association.
              - **Code** *(string) --* 
                The state of the target network association.
              - **Message** *(string) --* 
                A message about the status of the target network association, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type SubnetId: string
        :param SubnetId: **[REQUIRED]**
          The ID of the subnet to associate with the Client VPN endpoint.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def associate_dhcp_options(self, DhcpOptionsId: str, VpcId: str, DryRun: bool = None):
        """
        Associates a set of DHCP options (that you've previously created) with the specified VPC, or associates no DHCP options with the VPC.
        After you associate the options with the VPC, any existing instances and all new instances that you launch in that VPC use the options. You don't need to restart or relaunch the instances. They automatically pick up the changes within a few hours, depending on how frequently the instance renews its DHCP lease. You can explicitly renew the lease using the operating system on the instance.
        For more information, see `DHCP Options Sets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_DHCP_Options.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateDhcpOptions>`_
        
        **Request Syntax**
        ::
          response = client.associate_dhcp_options(
              DhcpOptionsId='string',
              VpcId='string',
              DryRun=True|False
          )
        :type DhcpOptionsId: string
        :param DhcpOptionsId: **[REQUIRED]**
          The ID of the DHCP options set, or ``default`` to associate no DHCP options with the VPC.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def associate_iam_instance_profile(self, IamInstanceProfile: Dict, InstanceId: str) -> Dict:
        """
        Associates an IAM instance profile with a running or stopped instance. You cannot associate more than one IAM instance profile with an instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateIamInstanceProfile>`_
        
        **Request Syntax**
        ::
          response = client.associate_iam_instance_profile(
              IamInstanceProfile={
                  'Arn': 'string',
                  'Name': 'string'
              },
              InstanceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'IamInstanceProfileAssociation': {
                    'AssociationId': 'string',
                    'InstanceId': 'string',
                    'IamInstanceProfile': {
                        'Arn': 'string',
                        'Id': 'string'
                    },
                    'State': 'associating'|'associated'|'disassociating'|'disassociated',
                    'Timestamp': datetime(2015, 1, 1)
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **IamInstanceProfileAssociation** *(dict) --* 
              Information about the IAM instance profile association.
              - **AssociationId** *(string) --* 
                The ID of the association.
              - **InstanceId** *(string) --* 
                The ID of the instance.
              - **IamInstanceProfile** *(dict) --* 
                The IAM instance profile.
                - **Arn** *(string) --* 
                  The Amazon Resource Name (ARN) of the instance profile.
                - **Id** *(string) --* 
                  The ID of the instance profile.
              - **State** *(string) --* 
                The state of the association.
              - **Timestamp** *(datetime) --* 
                The time the IAM instance profile was associated with the instance.
        :type IamInstanceProfile: dict
        :param IamInstanceProfile: **[REQUIRED]**
          The IAM instance profile.
          - **Arn** *(string) --*
            The Amazon Resource Name (ARN) of the instance profile.
          - **Name** *(string) --*
            The name of the instance profile.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :rtype: dict
        :returns:
        """
        pass

    def associate_route_table(self, RouteTableId: str, SubnetId: str, DryRun: bool = None) -> Dict:
        """
        Associates a subnet with a route table. The subnet and route table must be in the same VPC. This association causes traffic originating from the subnet to be routed according to the routes in the route table. The action returns an association ID, which you need in order to disassociate the route table from the subnet later. A route table can be associated with multiple subnets.
        For more information, see `Route Tables <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.associate_route_table(
              DryRun=True|False,
              RouteTableId='string',
              SubnetId='string'
          )
        
        **Response Syntax**
        ::
            {
                'AssociationId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AssociationId** *(string) --* 
              The route table association ID. This ID is required for disassociating the route table.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the route table.
        :type SubnetId: string
        :param SubnetId: **[REQUIRED]**
          The ID of the subnet.
        :rtype: dict
        :returns:
        """
        pass

    def associate_subnet_cidr_block(self, Ipv6CidrBlock: str, SubnetId: str) -> Dict:
        """
        Associates a CIDR block with your subnet. You can only associate a single IPv6 CIDR block with your subnet. An IPv6 CIDR block must have a prefix length of /64.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateSubnetCidrBlock>`_
        
        **Request Syntax**
        ::
          response = client.associate_subnet_cidr_block(
              Ipv6CidrBlock='string',
              SubnetId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Ipv6CidrBlockAssociation': {
                    'AssociationId': 'string',
                    'Ipv6CidrBlock': 'string',
                    'Ipv6CidrBlockState': {
                        'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                        'StatusMessage': 'string'
                    }
                },
                'SubnetId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Ipv6CidrBlockAssociation** *(dict) --* 
              Information about the IPv6 CIDR block association.
              - **AssociationId** *(string) --* 
                The association ID for the CIDR block.
              - **Ipv6CidrBlock** *(string) --* 
                The IPv6 CIDR block.
              - **Ipv6CidrBlockState** *(dict) --* 
                Information about the state of the CIDR block.
                - **State** *(string) --* 
                  The state of a CIDR block.
                - **StatusMessage** *(string) --* 
                  A message about the status of the CIDR block, if applicable.
            - **SubnetId** *(string) --* 
              The ID of the subnet.
        :type Ipv6CidrBlock: string
        :param Ipv6CidrBlock: **[REQUIRED]**
          The IPv6 CIDR block for your subnet. The subnet must have a /64 prefix length.
        :type SubnetId: string
        :param SubnetId: **[REQUIRED]**
          The ID of your subnet.
        :rtype: dict
        :returns:
        """
        pass

    def associate_transit_gateway_route_table(self, TransitGatewayRouteTableId: str, TransitGatewayAttachmentId: str, DryRun: bool = None) -> Dict:
        """
        Associates the specified attachment with the specified transit gateway route table. You can associate only one route table with an attachment.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateTransitGatewayRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.associate_transit_gateway_route_table(
              TransitGatewayRouteTableId='string',
              TransitGatewayAttachmentId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Association': {
                    'TransitGatewayRouteTableId': 'string',
                    'TransitGatewayAttachmentId': 'string',
                    'ResourceId': 'string',
                    'ResourceType': 'vpc'|'vpn',
                    'State': 'associating'|'associated'|'disassociating'|'disassociated'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Association** *(dict) --* 
              The ID of the association.
              - **TransitGatewayRouteTableId** *(string) --* 
                The ID of the transit gateway route table.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **ResourceId** *(string) --* 
                The ID of the resource.
              - **ResourceType** *(string) --* 
                The resource type.
              - **State** *(string) --* 
                The state of the association.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def associate_vpc_cidr_block(self, VpcId: str, AmazonProvidedIpv6CidrBlock: bool = None, CidrBlock: str = None) -> Dict:
        """
        Associates a CIDR block with your VPC. You can associate a secondary IPv4 CIDR block, or you can associate an Amazon-provided IPv6 CIDR block. The IPv6 CIDR block size is fixed at /56.
        For more information about associating CIDR blocks with your VPC and applicable restrictions, see `VPC and Subnet Sizing <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Subnets.html#VPC_Sizing>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AssociateVpcCidrBlock>`_
        
        **Request Syntax**
        ::
          response = client.associate_vpc_cidr_block(
              AmazonProvidedIpv6CidrBlock=True|False,
              CidrBlock='string',
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Ipv6CidrBlockAssociation': {
                    'AssociationId': 'string',
                    'Ipv6CidrBlock': 'string',
                    'Ipv6CidrBlockState': {
                        'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                        'StatusMessage': 'string'
                    }
                },
                'CidrBlockAssociation': {
                    'AssociationId': 'string',
                    'CidrBlock': 'string',
                    'CidrBlockState': {
                        'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                        'StatusMessage': 'string'
                    }
                },
                'VpcId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Ipv6CidrBlockAssociation** *(dict) --* 
              Information about the IPv6 CIDR block association.
              - **AssociationId** *(string) --* 
                The association ID for the IPv6 CIDR block.
              - **Ipv6CidrBlock** *(string) --* 
                The IPv6 CIDR block.
              - **Ipv6CidrBlockState** *(dict) --* 
                Information about the state of the CIDR block.
                - **State** *(string) --* 
                  The state of the CIDR block.
                - **StatusMessage** *(string) --* 
                  A message about the status of the CIDR block, if applicable.
            - **CidrBlockAssociation** *(dict) --* 
              Information about the IPv4 CIDR block association.
              - **AssociationId** *(string) --* 
                The association ID for the IPv4 CIDR block.
              - **CidrBlock** *(string) --* 
                The IPv4 CIDR block.
              - **CidrBlockState** *(dict) --* 
                Information about the state of the CIDR block.
                - **State** *(string) --* 
                  The state of the CIDR block.
                - **StatusMessage** *(string) --* 
                  A message about the status of the CIDR block, if applicable.
            - **VpcId** *(string) --* 
              The ID of the VPC.
        :type AmazonProvidedIpv6CidrBlock: boolean
        :param AmazonProvidedIpv6CidrBlock:
          Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IPv6 addresses, or the size of the CIDR block.
        :type CidrBlock: string
        :param CidrBlock:
          An IPv4 CIDR block to associate with the VPC.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def attach_classic_link_vpc(self, Groups: List, InstanceId: str, VpcId: str, DryRun: bool = None) -> Dict:
        """
        Links an EC2-Classic instance to a ClassicLink-enabled VPC through one or more of the VPC's security groups. You cannot link an EC2-Classic instance to more than one VPC at a time. You can only link an instance that's in the ``running`` state. An instance is automatically unlinked from a VPC when it's stopped - you can link it to the VPC again when you restart it.
        After you've linked an instance, you cannot change the VPC security groups that are associated with it. To change the security groups, you must first unlink the instance, and then link it again.
        Linking your instance to a VPC is sometimes referred to as *attaching* your instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AttachClassicLinkVpc>`_
        
        **Request Syntax**
        ::
          response = client.attach_classic_link_vpc(
              DryRun=True|False,
              Groups=[
                  'string',
              ],
              InstanceId='string',
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Groups: list
        :param Groups: **[REQUIRED]**
          The ID of one or more of the VPC\'s security groups. You cannot specify security groups from a different VPC.
          - *(string) --*
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of an EC2-Classic instance to link to the ClassicLink-enabled VPC.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of a ClassicLink-enabled VPC.
        :rtype: dict
        :returns:
        """
        pass

    def attach_internet_gateway(self, InternetGatewayId: str, VpcId: str, DryRun: bool = None):
        """
        Attaches an internet gateway to a VPC, enabling connectivity between the internet and the VPC. For more information about your VPC and internet gateway, see the `Amazon Virtual Private Cloud User Guide <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AttachInternetGateway>`_
        
        **Request Syntax**
        ::
          response = client.attach_internet_gateway(
              DryRun=True|False,
              InternetGatewayId='string',
              VpcId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InternetGatewayId: string
        :param InternetGatewayId: **[REQUIRED]**
          The ID of the internet gateway.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :returns: None
        """
        pass

    def attach_network_interface(self, DeviceIndex: int, InstanceId: str, NetworkInterfaceId: str, DryRun: bool = None) -> Dict:
        """
        Attaches a network interface to an instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AttachNetworkInterface>`_
        
        **Request Syntax**
        ::
          response = client.attach_network_interface(
              DeviceIndex=123,
              DryRun=True|False,
              InstanceId='string',
              NetworkInterfaceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'AttachmentId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of AttachNetworkInterface.
            - **AttachmentId** *(string) --* 
              The ID of the network interface attachment.
        :type DeviceIndex: integer
        :param DeviceIndex: **[REQUIRED]**
          The index of the device for the network interface attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :rtype: dict
        :returns:
        """
        pass

    def attach_volume(self, Device: str, InstanceId: str, VolumeId: str, DryRun: bool = None) -> Dict:
        """
        Attaches an EBS volume to a running or stopped instance and exposes it to the instance with the specified device name.
        Encrypted EBS volumes may only be attached to instances that support Amazon EBS encryption. For more information, see `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        For a list of supported device names, see `Attaching an EBS Volume to an Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-attaching-volume.html>`__ . Any device names that aren't reserved for instance store volumes can be used for EBS volumes. For more information, see `Amazon EC2 Instance Store <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        If a volume has an AWS Marketplace product code:
        * The volume can be attached only to a stopped instance. 
        * AWS Marketplace product codes are copied from the volume to the instance. 
        * You must be subscribed to the product. 
        * The instance type and operating system of the instance must support the product. For example, you can't detach a volume from a Windows instance and attach it to a Linux instance. 
        For more information about EBS volumes, see `Attaching Amazon EBS Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-attaching-volume.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AttachVolume>`_
        
        **Request Syntax**
        ::
          response = client.attach_volume(
              Device='string',
              InstanceId='string',
              VolumeId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'AttachTime': datetime(2015, 1, 1),
                'Device': 'string',
                'InstanceId': 'string',
                'State': 'attaching'|'attached'|'detaching'|'detached'|'busy',
                'VolumeId': 'string',
                'DeleteOnTermination': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes volume attachment details.
            - **AttachTime** *(datetime) --* 
              The time stamp when the attachment initiated.
            - **Device** *(string) --* 
              The device name.
            - **InstanceId** *(string) --* 
              The ID of the instance.
            - **State** *(string) --* 
              The attachment state of the volume.
            - **VolumeId** *(string) --* 
              The ID of the volume.
            - **DeleteOnTermination** *(boolean) --* 
              Indicates whether the EBS volume is deleted on instance termination.
        :type Device: string
        :param Device: **[REQUIRED]**
          The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the EBS volume. The volume and instance must be within the same Availability Zone.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def attach_vpn_gateway(self, VpcId: str, VpnGatewayId: str, DryRun: bool = None) -> Dict:
        """
        Attaches a virtual private gateway to a VPC. You can attach one virtual private gateway to one VPC at a time.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AttachVpnGateway>`_
        
        **Request Syntax**
        ::
          response = client.attach_vpn_gateway(
              VpcId='string',
              VpnGatewayId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'VpcAttachment': {
                    'State': 'attaching'|'attached'|'detaching'|'detached',
                    'VpcId': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of AttachVpnGateway.
            - **VpcAttachment** *(dict) --* 
              Information about the attachment.
              - **State** *(string) --* 
                The current state of the attachment.
              - **VpcId** *(string) --* 
                The ID of the VPC.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type VpnGatewayId: string
        :param VpnGatewayId: **[REQUIRED]**
          The ID of the virtual private gateway.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def authorize_client_vpn_ingress(self, ClientVpnEndpointId: str, TargetNetworkCidr: str, AccessGroupId: str = None, AuthorizeAllGroups: bool = None, Description: str = None, DryRun: bool = None) -> Dict:
        """
        Adds an ingress authorization rule to a Client VPN endpoint. Ingress authorization rules act as firewall rules that grant access to networks. You must configure ingress authorization rules to enable clients to access resources in AWS or on-premises networks.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AuthorizeClientVpnIngress>`_
        
        **Request Syntax**
        ::
          response = client.authorize_client_vpn_ingress(
              ClientVpnEndpointId='string',
              TargetNetworkCidr='string',
              AccessGroupId='string',
              AuthorizeAllGroups=True|False,
              Description='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Status': {
                    'Code': 'authorizing'|'active'|'failed'|'revoking',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Status** *(dict) --* 
              The current state of the authorization rule.
              - **Code** *(string) --* 
                The state of the authorization rule.
              - **Message** *(string) --* 
                A message about the status of the authorization rule, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type TargetNetworkCidr: string
        :param TargetNetworkCidr: **[REQUIRED]**
          The IPv4 address range, in CIDR notation, of the network for which access is being authorized.
        :type AccessGroupId: string
        :param AccessGroupId:
          The ID of the Active Directory group to grant access.
        :type AuthorizeAllGroups: boolean
        :param AuthorizeAllGroups:
          Indicates whether to grant access to all clients. Use ``true`` to grant all clients who successfully establish a VPN connection access to the network.
        :type Description: string
        :param Description:
          A brief description of the authorization rule.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def authorize_security_group_egress(self, GroupId: str, DryRun: bool = None, IpPermissions: List = None, CidrIp: str = None, FromPort: int = None, IpProtocol: str = None, ToPort: int = None, SourceSecurityGroupName: str = None, SourceSecurityGroupOwnerId: str = None):
        """
        [VPC only] Adds the specified egress rules to a security group for use with a VPC.
        An outbound rule permits instances to send traffic to the specified destination IPv4 or IPv6 CIDR address ranges, or to the specified destination security groups for the same VPC.
        You specify a protocol for each rule (for example, TCP). For the TCP and UDP protocols, you must also specify the destination port or port range. For the ICMP protocol, you must also specify the ICMP type and code. You can use -1 for the type or code to mean all types or all codes.
        Rule changes are propagated to affected instances as quickly as possible. However, a small delay might occur.
        For more information about VPC security group limits, see `Amazon VPC Limits <https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AuthorizeSecurityGroupEgress>`_
        
        **Request Syntax**
        ::
          response = client.authorize_security_group_egress(
              DryRun=True|False,
              GroupId='string',
              IpPermissions=[
                  {
                      'FromPort': 123,
                      'IpProtocol': 'string',
                      'IpRanges': [
                          {
                              'CidrIp': 'string',
                              'Description': 'string'
                          },
                      ],
                      'Ipv6Ranges': [
                          {
                              'CidrIpv6': 'string',
                              'Description': 'string'
                          },
                      ],
                      'PrefixListIds': [
                          {
                              'Description': 'string',
                              'PrefixListId': 'string'
                          },
                      ],
                      'ToPort': 123,
                      'UserIdGroupPairs': [
                          {
                              'Description': 'string',
                              'GroupId': 'string',
                              'GroupName': 'string',
                              'PeeringStatus': 'string',
                              'UserId': 'string',
                              'VpcId': 'string',
                              'VpcPeeringConnectionId': 'string'
                          },
                      ]
                  },
              ],
              CidrIp='string',
              FromPort=123,
              IpProtocol='string',
              ToPort=123,
              SourceSecurityGroupName='string',
              SourceSecurityGroupOwnerId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupId: string
        :param GroupId: **[REQUIRED]**
          The ID of the security group.
        :type IpPermissions: list
        :param IpPermissions:
          The sets of IP permissions. You can\'t specify a destination security group and a CIDR IP address range in the same set of permissions.
          - *(dict) --*
            Describes a set of permissions for a security group rule.
            - **FromPort** *(integer) --*
              The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **IpProtocol** *(string) --*
              The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
              [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
            - **IpRanges** *(list) --*
              The IPv4 ranges.
              - *(dict) --*
                Describes an IPv4 range.
                - **CidrIp** *(string) --*
                  The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv4 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **Ipv6Ranges** *(list) --*
              [VPC only] The IPv6 ranges.
              - *(dict) --*
                [EC2-VPC only] Describes an IPv6 range.
                - **CidrIpv6** *(string) --*
                  The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv6 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **PrefixListIds** *(list) --*
              [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
              - *(dict) --*
                Describes a prefix list ID.
                - **Description** *(string) --*
                  A description for the security group rule that references this prefix list ID.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **PrefixListId** *(string) --*
                  The ID of the prefix.
            - **ToPort** *(integer) --*
              The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **UserIdGroupPairs** *(list) --*
              The security group and AWS account ID pairs.
              - *(dict) --*
                Describes a security group and AWS account ID pair.
                - **Description** *(string) --*
                  A description for the security group rule that references this user ID group pair.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **GroupId** *(string) --*
                  The ID of the security group.
                - **GroupName** *(string) --*
                  The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID.
                  For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                - **PeeringStatus** *(string) --*
                  The status of a VPC peering connection, if applicable.
                - **UserId** *(string) --*
                  The ID of an AWS account.
                  For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                  [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                - **VpcId** *(string) --*
                  The ID of the VPC for the referenced security group, if applicable.
                - **VpcPeeringConnectionId** *(string) --*
                  The ID of the VPC peering connection, if applicable.
        :type CidrIp: string
        :param CidrIp:
          Not supported. Use a set of IP permissions to specify the CIDR.
        :type FromPort: integer
        :param FromPort:
          Not supported. Use a set of IP permissions to specify the port.
        :type IpProtocol: string
        :param IpProtocol:
          Not supported. Use a set of IP permissions to specify the protocol name or number.
        :type ToPort: integer
        :param ToPort:
          Not supported. Use a set of IP permissions to specify the port.
        :type SourceSecurityGroupName: string
        :param SourceSecurityGroupName:
          Not supported. Use a set of IP permissions to specify a destination security group.
        :type SourceSecurityGroupOwnerId: string
        :param SourceSecurityGroupOwnerId:
          Not supported. Use a set of IP permissions to specify a destination security group.
        :returns: None
        """
        pass

    def authorize_security_group_ingress(self, CidrIp: str = None, FromPort: int = None, GroupId: str = None, GroupName: str = None, IpPermissions: List = None, IpProtocol: str = None, SourceSecurityGroupName: str = None, SourceSecurityGroupOwnerId: str = None, ToPort: int = None, DryRun: bool = None):
        """
        Adds the specified ingress rules to a security group.
        An inbound rule permits instances to receive traffic from the specified destination IPv4 or IPv6 CIDR address ranges, or from the specified destination security groups.
        You specify a protocol for each rule (for example, TCP). For TCP and UDP, you must also specify the destination port or port range. For ICMP/ICMPv6, you must also specify the ICMP/ICMPv6 type and code. You can use -1 to mean all types or all codes.
        Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.
        For more information about VPC security group limits, see `Amazon VPC Limits <https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/AuthorizeSecurityGroupIngress>`_
        
        **Request Syntax**
        ::
          response = client.authorize_security_group_ingress(
              CidrIp='string',
              FromPort=123,
              GroupId='string',
              GroupName='string',
              IpPermissions=[
                  {
                      'FromPort': 123,
                      'IpProtocol': 'string',
                      'IpRanges': [
                          {
                              'CidrIp': 'string',
                              'Description': 'string'
                          },
                      ],
                      'Ipv6Ranges': [
                          {
                              'CidrIpv6': 'string',
                              'Description': 'string'
                          },
                      ],
                      'PrefixListIds': [
                          {
                              'Description': 'string',
                              'PrefixListId': 'string'
                          },
                      ],
                      'ToPort': 123,
                      'UserIdGroupPairs': [
                          {
                              'Description': 'string',
                              'GroupId': 'string',
                              'GroupName': 'string',
                              'PeeringStatus': 'string',
                              'UserId': 'string',
                              'VpcId': 'string',
                              'VpcPeeringConnectionId': 'string'
                          },
                      ]
                  },
              ],
              IpProtocol='string',
              SourceSecurityGroupName='string',
              SourceSecurityGroupOwnerId='string',
              ToPort=123,
              DryRun=True|False
          )
        :type CidrIp: string
        :param CidrIp:
          The IPv4 address range, in CIDR format. You can\'t specify this parameter when specifying a source security group. To specify an IPv6 address range, use a set of IP permissions.
          Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
        :type FromPort: integer
        :param FromPort:
          The start of port range for the TCP and UDP protocols, or an ICMP type number. For the ICMP type number, use ``-1`` to specify all types. If you specify all ICMP types, you must specify all codes.
          Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
        :type GroupId: string
        :param GroupId:
          The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
        :type GroupName: string
        :param GroupName:
          [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request.
        :type IpPermissions: list
        :param IpPermissions:
          The sets of IP permissions.
          - *(dict) --*
            Describes a set of permissions for a security group rule.
            - **FromPort** *(integer) --*
              The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **IpProtocol** *(string) --*
              The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
              [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
            - **IpRanges** *(list) --*
              The IPv4 ranges.
              - *(dict) --*
                Describes an IPv4 range.
                - **CidrIp** *(string) --*
                  The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv4 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **Ipv6Ranges** *(list) --*
              [VPC only] The IPv6 ranges.
              - *(dict) --*
                [EC2-VPC only] Describes an IPv6 range.
                - **CidrIpv6** *(string) --*
                  The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv6 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **PrefixListIds** *(list) --*
              [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
              - *(dict) --*
                Describes a prefix list ID.
                - **Description** *(string) --*
                  A description for the security group rule that references this prefix list ID.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **PrefixListId** *(string) --*
                  The ID of the prefix.
            - **ToPort** *(integer) --*
              The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **UserIdGroupPairs** *(list) --*
              The security group and AWS account ID pairs.
              - *(dict) --*
                Describes a security group and AWS account ID pair.
                - **Description** *(string) --*
                  A description for the security group rule that references this user ID group pair.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **GroupId** *(string) --*
                  The ID of the security group.
                - **GroupName** *(string) --*
                  The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID.
                  For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                - **PeeringStatus** *(string) --*
                  The status of a VPC peering connection, if applicable.
                - **UserId** *(string) --*
                  The ID of an AWS account.
                  For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                  [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                - **VpcId** *(string) --*
                  The ID of the VPC for the referenced security group, if applicable.
                - **VpcPeeringConnectionId** *(string) --*
                  The ID of the VPC peering connection, if applicable.
        :type IpProtocol: string
        :param IpProtocol:
          The IP protocol name (``tcp`` , ``udp`` , ``icmp`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ). To specify ``icmpv6`` , use a set of IP permissions.
          [VPC only] Use ``-1`` to specify all protocols. If you specify ``-1`` or a protocol other than ``tcp`` , ``udp`` , or ``icmp`` , traffic on all ports is allowed, regardless of any ports you specify.
          Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
        :type SourceSecurityGroupName: string
        :param SourceSecurityGroupName:
          [EC2-Classic, default VPC] The name of the source security group. You can\'t specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. Creates rules that grant full ICMP, UDP, and TCP access. To create a rule with a specific IP protocol and port range, use a set of IP permissions instead. For EC2-VPC, the source security group must be in the same VPC.
        :type SourceSecurityGroupOwnerId: string
        :param SourceSecurityGroupOwnerId:
          [nondefault VPC] The AWS account ID for the source security group, if the source security group is in a different account. You can\'t specify this parameter in combination with the following parameters: the CIDR IP address range, the IP protocol, the start of the port range, and the end of the port range. Creates rules that grant full ICMP, UDP, and TCP access. To create a rule with a specific IP protocol and port range, use a set of IP permissions instead.
        :type ToPort: integer
        :param ToPort:
          The end of port range for the TCP and UDP protocols, or an ICMP code number. For the ICMP code number, use ``-1`` to specify all codes. If you specify all ICMP types, you must specify all codes.
          Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def bundle_instance(self, InstanceId: str, Storage: Dict, DryRun: bool = None) -> Dict:
        """
        Bundles an Amazon instance store-backed Windows instance.
        During bundling, only the root device volume (C:\) is bundled. Data on other instance store volumes is not preserved.
        .. note::
          This action is not applicable for Linux/Unix instances or Windows instances that are backed by Amazon EBS.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/BundleInstance>`_
        
        **Request Syntax**
        ::
          response = client.bundle_instance(
              InstanceId='string',
              Storage={
                  'S3': {
                      'AWSAccessKeyId': 'string',
                      'Bucket': 'string',
                      'Prefix': 'string',
                      'UploadPolicy': b'bytes',
                      'UploadPolicySignature': 'string'
                  }
              },
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'BundleTask': {
                    'BundleId': 'string',
                    'BundleTaskError': {
                        'Code': 'string',
                        'Message': 'string'
                    },
                    'InstanceId': 'string',
                    'Progress': 'string',
                    'StartTime': datetime(2015, 1, 1),
                    'State': 'pending'|'waiting-for-shutdown'|'bundling'|'storing'|'cancelling'|'complete'|'failed',
                    'Storage': {
                        'S3': {
                            'AWSAccessKeyId': 'string',
                            'Bucket': 'string',
                            'Prefix': 'string',
                            'UploadPolicy': b'bytes',
                            'UploadPolicySignature': 'string'
                        }
                    },
                    'UpdateTime': datetime(2015, 1, 1)
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of BundleInstance.
            - **BundleTask** *(dict) --* 
              Information about the bundle task.
              - **BundleId** *(string) --* 
                The ID of the bundle task.
              - **BundleTaskError** *(dict) --* 
                If the task fails, a description of the error.
                - **Code** *(string) --* 
                  The error code.
                - **Message** *(string) --* 
                  The error message.
              - **InstanceId** *(string) --* 
                The ID of the instance associated with this bundle task.
              - **Progress** *(string) --* 
                The level of task completion, as a percent (for example, 20%).
              - **StartTime** *(datetime) --* 
                The time this task started.
              - **State** *(string) --* 
                The state of the task.
              - **Storage** *(dict) --* 
                The Amazon S3 storage locations.
                - **S3** *(dict) --* 
                  An Amazon S3 storage location.
                  - **AWSAccessKeyId** *(string) --* 
                    The access key ID of the owner of the bucket. Before you specify a value for your access key ID, review and follow the guidance in `Best Practices for Managing AWS Access Keys <https://docs.aws.amazon.com/general/latest/gr/aws-access-keys-best-practices.html>`__ .
                  - **Bucket** *(string) --* 
                    The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
                  - **Prefix** *(string) --* 
                    The beginning of the file name of the AMI.
                  - **UploadPolicy** *(bytes) --* 
                    An Amazon S3 upload policy that gives Amazon EC2 permission to upload items into Amazon S3 on your behalf.
                  - **UploadPolicySignature** *(string) --* 
                    The signature of the JSON document.
              - **UpdateTime** *(datetime) --* 
                The time of the most recent update for the task.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance to bundle.
          Type: String
          Default: None
          Required: Yes
        :type Storage: dict
        :param Storage: **[REQUIRED]**
          The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
          - **S3** *(dict) --*
            An Amazon S3 storage location.
            - **AWSAccessKeyId** *(string) --*
              The access key ID of the owner of the bucket. Before you specify a value for your access key ID, review and follow the guidance in `Best Practices for Managing AWS Access Keys <https://docs.aws.amazon.com/general/latest/gr/aws-access-keys-best-practices.html>`__ .
            - **Bucket** *(string) --*
              The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
            - **Prefix** *(string) --*
              The beginning of the file name of the AMI.
            - **UploadPolicy** *(bytes) --*
              An Amazon S3 upload policy that gives Amazon EC2 permission to upload items into Amazon S3 on your behalf.
            - **UploadPolicySignature** *(string) --*
              The signature of the JSON document.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def can_paginate(self, operation_name: str = None):
        """
        Check if an operation can be paginated.
        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you\'d normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator(\"create_foo\")``.
        :return: ``True`` if the operation can be paginated,
            ``False`` otherwise.
        """
        pass

    def cancel_bundle_task(self, BundleId: str, DryRun: bool = None) -> Dict:
        """
        Cancels a bundling operation for an instance store-backed Windows instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelBundleTask>`_
        
        **Request Syntax**
        ::
          response = client.cancel_bundle_task(
              BundleId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'BundleTask': {
                    'BundleId': 'string',
                    'BundleTaskError': {
                        'Code': 'string',
                        'Message': 'string'
                    },
                    'InstanceId': 'string',
                    'Progress': 'string',
                    'StartTime': datetime(2015, 1, 1),
                    'State': 'pending'|'waiting-for-shutdown'|'bundling'|'storing'|'cancelling'|'complete'|'failed',
                    'Storage': {
                        'S3': {
                            'AWSAccessKeyId': 'string',
                            'Bucket': 'string',
                            'Prefix': 'string',
                            'UploadPolicy': b'bytes',
                            'UploadPolicySignature': 'string'
                        }
                    },
                    'UpdateTime': datetime(2015, 1, 1)
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CancelBundleTask.
            - **BundleTask** *(dict) --* 
              Information about the bundle task.
              - **BundleId** *(string) --* 
                The ID of the bundle task.
              - **BundleTaskError** *(dict) --* 
                If the task fails, a description of the error.
                - **Code** *(string) --* 
                  The error code.
                - **Message** *(string) --* 
                  The error message.
              - **InstanceId** *(string) --* 
                The ID of the instance associated with this bundle task.
              - **Progress** *(string) --* 
                The level of task completion, as a percent (for example, 20%).
              - **StartTime** *(datetime) --* 
                The time this task started.
              - **State** *(string) --* 
                The state of the task.
              - **Storage** *(dict) --* 
                The Amazon S3 storage locations.
                - **S3** *(dict) --* 
                  An Amazon S3 storage location.
                  - **AWSAccessKeyId** *(string) --* 
                    The access key ID of the owner of the bucket. Before you specify a value for your access key ID, review and follow the guidance in `Best Practices for Managing AWS Access Keys <https://docs.aws.amazon.com/general/latest/gr/aws-access-keys-best-practices.html>`__ .
                  - **Bucket** *(string) --* 
                    The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
                  - **Prefix** *(string) --* 
                    The beginning of the file name of the AMI.
                  - **UploadPolicy** *(bytes) --* 
                    An Amazon S3 upload policy that gives Amazon EC2 permission to upload items into Amazon S3 on your behalf.
                  - **UploadPolicySignature** *(string) --* 
                    The signature of the JSON document.
              - **UpdateTime** *(datetime) --* 
                The time of the most recent update for the task.
        :type BundleId: string
        :param BundleId: **[REQUIRED]**
          The ID of the bundle task.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def cancel_capacity_reservation(self, CapacityReservationId: str, DryRun: bool = None) -> Dict:
        """
        Cancels the specified Capacity Reservation, releases the reserved capacity, and changes the Capacity Reservation's state to ``cancelled`` .
        Instances running in the reserved capacity continue running until you stop them. Stopped instances that target the Capacity Reservation can no longer launch. Modify these instances to either target a different Capacity Reservation, launch On-Demand Instance capacity, or run in any open Capacity Reservation that has matching attributes and sufficient capacity.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelCapacityReservation>`_
        
        **Request Syntax**
        ::
          response = client.cancel_capacity_reservation(
              CapacityReservationId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type CapacityReservationId: string
        :param CapacityReservationId: **[REQUIRED]**
          The ID of the Capacity Reservation to be cancelled.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def cancel_conversion_task(self, ConversionTaskId: str, DryRun: bool = None, ReasonMessage: str = None):
        """
        Cancels an active conversion task. The task can be the import of an instance or volume. The action removes all artifacts of the conversion, including a partially uploaded volume or instance. If the conversion is complete or is in the process of transferring the final disk image, the command fails and returns an exception.
        For more information, see `Importing a Virtual Machine Using the Amazon EC2 CLI <https://docs.aws.amazon.com/AWSEC2/latest/CommandLineReference/ec2-cli-vmimport-export.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelConversionTask>`_
        
        **Request Syntax**
        ::
          response = client.cancel_conversion_task(
              ConversionTaskId='string',
              DryRun=True|False,
              ReasonMessage='string'
          )
        :type ConversionTaskId: string
        :param ConversionTaskId: **[REQUIRED]**
          The ID of the conversion task.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ReasonMessage: string
        :param ReasonMessage:
          The reason for canceling the conversion task.
        :returns: None
        """
        pass

    def cancel_export_task(self, ExportTaskId: str):
        """
        Cancels an active export task. The request removes all artifacts of the export, including any partially-created Amazon S3 objects. If the export task is complete or is in the process of transferring the final disk image, the command fails and returns an error.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelExportTask>`_
        
        **Request Syntax**
        ::
          response = client.cancel_export_task(
              ExportTaskId='string'
          )
        :type ExportTaskId: string
        :param ExportTaskId: **[REQUIRED]**
          The ID of the export task. This is the ID returned by ``CreateInstanceExportTask`` .
        :returns: None
        """
        pass

    def cancel_import_task(self, CancelReason: str = None, DryRun: bool = None, ImportTaskId: str = None) -> Dict:
        """
        Cancels an in-process import virtual machine or import snapshot task.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelImportTask>`_
        
        **Request Syntax**
        ::
          response = client.cancel_import_task(
              CancelReason='string',
              DryRun=True|False,
              ImportTaskId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ImportTaskId': 'string',
                'PreviousState': 'string',
                'State': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for CancelImportTask.
            - **ImportTaskId** *(string) --* 
              The ID of the task being canceled.
            - **PreviousState** *(string) --* 
              The current state of the task being canceled.
            - **State** *(string) --* 
              The current state of the task being canceled.
        :type CancelReason: string
        :param CancelReason:
          The reason for canceling the task.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ImportTaskId: string
        :param ImportTaskId:
          The ID of the import image or import snapshot task to be canceled.
        :rtype: dict
        :returns:
        """
        pass

    def cancel_reserved_instances_listing(self, ReservedInstancesListingId: str) -> Dict:
        """
        Cancels the specified Reserved Instance listing in the Reserved Instance Marketplace.
        For more information, see `Reserved Instance Marketplace <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelReservedInstancesListing>`_
        
        **Request Syntax**
        ::
          response = client.cancel_reserved_instances_listing(
              ReservedInstancesListingId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ReservedInstancesListings': [
                    {
                        'ClientToken': 'string',
                        'CreateDate': datetime(2015, 1, 1),
                        'InstanceCounts': [
                            {
                                'InstanceCount': 123,
                                'State': 'available'|'sold'|'cancelled'|'pending'
                            },
                        ],
                        'PriceSchedules': [
                            {
                                'Active': True|False,
                                'CurrencyCode': 'USD',
                                'Price': 123.0,
                                'Term': 123
                            },
                        ],
                        'ReservedInstancesId': 'string',
                        'ReservedInstancesListingId': 'string',
                        'Status': 'active'|'pending'|'cancelled'|'closed',
                        'StatusMessage': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'UpdateDate': datetime(2015, 1, 1)
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CancelReservedInstancesListing.
            - **ReservedInstancesListings** *(list) --* 
              The Reserved Instance listing.
              - *(dict) --* 
                Describes a Reserved Instance listing.
                - **ClientToken** *(string) --* 
                  A unique, case-sensitive key supplied by the client to ensure that the request is idempotent. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
                - **CreateDate** *(datetime) --* 
                  The time the listing was created.
                - **InstanceCounts** *(list) --* 
                  The number of instances in this state.
                  - *(dict) --* 
                    Describes a Reserved Instance listing state.
                    - **InstanceCount** *(integer) --* 
                      The number of listed Reserved Instances in the state specified by the ``state`` .
                    - **State** *(string) --* 
                      The states of the listed Reserved Instances.
                - **PriceSchedules** *(list) --* 
                  The price of the Reserved Instance listing.
                  - *(dict) --* 
                    Describes the price for a Reserved Instance.
                    - **Active** *(boolean) --* 
                      The current price schedule, as determined by the term remaining for the Reserved Instance in the listing.
                      A specific price schedule is always in effect, but only one price schedule can be active at any time. Take, for example, a Reserved Instance listing that has five months remaining in its term. When you specify price schedules for five months and two months, this means that schedule 1, covering the first three months of the remaining term, will be active during months 5, 4, and 3. Then schedule 2, covering the last two months of the term, will be active for months 2 and 1.
                    - **CurrencyCode** *(string) --* 
                      The currency for transacting the Reserved Instance resale. At this time, the only supported currency is ``USD`` .
                    - **Price** *(float) --* 
                      The fixed price for the term.
                    - **Term** *(integer) --* 
                      The number of months remaining in the reservation. For example, 2 is the second to the last month before the capacity reservation expires.
                - **ReservedInstancesId** *(string) --* 
                  The ID of the Reserved Instance.
                - **ReservedInstancesListingId** *(string) --* 
                  The ID of the Reserved Instance listing.
                - **Status** *(string) --* 
                  The status of the Reserved Instance listing.
                - **StatusMessage** *(string) --* 
                  The reason for the current status of the Reserved Instance listing. The response can be blank.
                - **Tags** *(list) --* 
                  Any tags assigned to the resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **UpdateDate** *(datetime) --* 
                  The last modified timestamp of the listing.
        :type ReservedInstancesListingId: string
        :param ReservedInstancesListingId: **[REQUIRED]**
          The ID of the Reserved Instance listing.
        :rtype: dict
        :returns:
        """
        pass

    def cancel_spot_fleet_requests(self, SpotFleetRequestIds: List, TerminateInstances: bool, DryRun: bool = None) -> Dict:
        """
        Cancels the specified Spot Fleet requests.
        After you cancel a Spot Fleet request, the Spot Fleet launches no new Spot Instances. You must specify whether the Spot Fleet should also terminate its Spot Instances. If you terminate the instances, the Spot Fleet request enters the ``cancelled_terminating`` state. Otherwise, the Spot Fleet request enters the ``cancelled_running`` state and the instances continue to run until they are interrupted or you terminate them manually.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelSpotFleetRequests>`_
        
        **Request Syntax**
        ::
          response = client.cancel_spot_fleet_requests(
              DryRun=True|False,
              SpotFleetRequestIds=[
                  'string',
              ],
              TerminateInstances=True|False
          )
        
        **Response Syntax**
        ::
            {
                'SuccessfulFleetRequests': [
                    {
                        'CurrentSpotFleetRequestState': 'submitted'|'active'|'cancelled'|'failed'|'cancelled_running'|'cancelled_terminating'|'modifying',
                        'PreviousSpotFleetRequestState': 'submitted'|'active'|'cancelled'|'failed'|'cancelled_running'|'cancelled_terminating'|'modifying',
                        'SpotFleetRequestId': 'string'
                    },
                ],
                'UnsuccessfulFleetRequests': [
                    {
                        'Error': {
                            'Code': 'fleetRequestIdDoesNotExist'|'fleetRequestIdMalformed'|'fleetRequestNotInCancellableState'|'unexpectedError',
                            'Message': 'string'
                        },
                        'SpotFleetRequestId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CancelSpotFleetRequests.
            - **SuccessfulFleetRequests** *(list) --* 
              Information about the Spot Fleet requests that are successfully canceled.
              - *(dict) --* 
                Describes a Spot Fleet request that was successfully canceled.
                - **CurrentSpotFleetRequestState** *(string) --* 
                  The current state of the Spot Fleet request.
                - **PreviousSpotFleetRequestState** *(string) --* 
                  The previous state of the Spot Fleet request.
                - **SpotFleetRequestId** *(string) --* 
                  The ID of the Spot Fleet request.
            - **UnsuccessfulFleetRequests** *(list) --* 
              Information about the Spot Fleet requests that are not successfully canceled.
              - *(dict) --* 
                Describes a Spot Fleet request that was not successfully canceled.
                - **Error** *(dict) --* 
                  The error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The description for the error code.
                - **SpotFleetRequestId** *(string) --* 
                  The ID of the Spot Fleet request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type SpotFleetRequestIds: list
        :param SpotFleetRequestIds: **[REQUIRED]**
          The IDs of the Spot Fleet requests.
          - *(string) --*
        :type TerminateInstances: boolean
        :param TerminateInstances: **[REQUIRED]**
          Indicates whether to terminate instances for a Spot Fleet request if it is canceled successfully.
        :rtype: dict
        :returns:
        """
        pass

    def cancel_spot_instance_requests(self, SpotInstanceRequestIds: List, DryRun: bool = None) -> Dict:
        """
        Cancels one or more Spot Instance requests.
        .. warning::
          Canceling a Spot Instance request does not terminate running Spot Instances associated with the request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CancelSpotInstanceRequests>`_
        
        **Request Syntax**
        ::
          response = client.cancel_spot_instance_requests(
              DryRun=True|False,
              SpotInstanceRequestIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'CancelledSpotInstanceRequests': [
                    {
                        'SpotInstanceRequestId': 'string',
                        'State': 'active'|'open'|'closed'|'cancelled'|'completed'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CancelSpotInstanceRequests.
            - **CancelledSpotInstanceRequests** *(list) --* 
              One or more Spot Instance requests.
              - *(dict) --* 
                Describes a request to cancel a Spot Instance.
                - **SpotInstanceRequestId** *(string) --* 
                  The ID of the Spot Instance request.
                - **State** *(string) --* 
                  The state of the Spot Instance request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type SpotInstanceRequestIds: list
        :param SpotInstanceRequestIds: **[REQUIRED]**
          One or more Spot Instance request IDs.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def confirm_product_instance(self, InstanceId: str, ProductCode: str, DryRun: bool = None) -> Dict:
        """
        Determines whether a product code is associated with an instance. This action can only be used by the owner of the product code. It is useful when a product code owner must verify whether another user's instance is eligible for support.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ConfirmProductInstance>`_
        
        **Request Syntax**
        ::
          response = client.confirm_product_instance(
              InstanceId='string',
              ProductCode='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'OwnerId': 'string',
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **OwnerId** *(string) --* 
              The AWS account ID of the instance owner. This is only present if the product code is attached to the instance.
            - **Return** *(boolean) --* 
              The return value of the request. Returns ``true`` if the specified product code is owned by the requester and associated with the specified instance.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type ProductCode: string
        :param ProductCode: **[REQUIRED]**
          The product code. This must be a product code that you own.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def copy_fpga_image(self, SourceFpgaImageId: str, SourceRegion: str, DryRun: bool = None, Description: str = None, Name: str = None, ClientToken: str = None) -> Dict:
        """
        Copies the specified Amazon FPGA Image (AFI) to the current region.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CopyFpgaImage>`_
        
        **Request Syntax**
        ::
          response = client.copy_fpga_image(
              DryRun=True|False,
              SourceFpgaImageId='string',
              Description='string',
              Name='string',
              SourceRegion='string',
              ClientToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'FpgaImageId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **FpgaImageId** *(string) --* 
              The ID of the new AFI.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type SourceFpgaImageId: string
        :param SourceFpgaImageId: **[REQUIRED]**
          The ID of the source AFI.
        :type Description: string
        :param Description:
          The description for the new AFI.
        :type Name: string
        :param Name:
          The name for the new AFI. The default is the name of the source AFI.
        :type SourceRegion: string
        :param SourceRegion: **[REQUIRED]**
          The region that contains the source AFI.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ .
        :rtype: dict
        :returns:
        """
        pass

    def copy_image(self, Name: str, SourceImageId: str, SourceRegion: str, ClientToken: str = None, Description: str = None, Encrypted: bool = None, KmsKeyId: str = None, DryRun: bool = None) -> Dict:
        """
        Initiates the copy of an AMI from the specified source region to the current region. You specify the destination region by using its endpoint when making the request.
        Copies of encrypted backing snapshots for the AMI are encrypted. Copies of unencrypted backing snapshots remain unencrypted, unless you set ``Encrypted`` during the copy operation. You cannot create an unencrypted copy of an encrypted backing snapshot.
        For more information about the prerequisites and limits when copying an AMI, see `Copying an AMI <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/CopyingAMIs.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CopyImage>`_
        
        **Request Syntax**
        ::
          response = client.copy_image(
              ClientToken='string',
              Description='string',
              Encrypted=True|False,
              KmsKeyId='string',
              Name='string',
              SourceImageId='string',
              SourceRegion='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ImageId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CopyImage.
            - **ImageId** *(string) --* 
              The ID of the new AMI.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type Description: string
        :param Description:
          A description for the new AMI in the destination region.
        :type Encrypted: boolean
        :param Encrypted:
          Specifies whether the destination snapshots of the copied image should be encrypted. You can encrypt a copy of an unencrypted snapshot, but you cannot create an unencrypted copy of an encrypted snapshot. The default CMK for EBS is used unless you specify a non-default AWS Key Management Service (AWS KMS) CMK using ``KmsKeyId`` . For more information, see `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type KmsKeyId: string
        :param KmsKeyId:
          An identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) to use when creating the encrypted volume. This parameter is only required if you want to use a non-default CMK; if this parameter is not specified, the default CMK for EBS is used. If a ``KmsKeyId`` is specified, the ``Encrypted`` flag must also be set.
          The CMK identifier may be provided in any of the following formats:
          * Key ID
          * Key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          * ARN using key ID. The ID ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``key`` namespace, and then the CMK ID. For example, arn:aws:kms:*us-east-1* :*012345678910* :key/*abcd1234-a123-456a-a12b-a123b4cd56ef* .
          * ARN using key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          AWS parses ``KmsKeyId`` asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. This action will eventually report failure.
          The specified CMK must exist in the region that the snapshot is being copied to.
        :type Name: string
        :param Name: **[REQUIRED]**
          The name of the new AMI in the destination region.
        :type SourceImageId: string
        :param SourceImageId: **[REQUIRED]**
          The ID of the AMI to copy.
        :type SourceRegion: string
        :param SourceRegion: **[REQUIRED]**
          The name of the region that contains the AMI to copy.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def copy_snapshot(self, SourceRegion: str, SourceSnapshotId: str, Description: str = None, DestinationRegion: str = None, Encrypted: bool = None, KmsKeyId: str = None, PresignedUrl: str = None, DryRun: bool = None) -> Dict:
        """
        Copies a point-in-time snapshot of an EBS volume and stores it in Amazon S3. You can copy the snapshot within the same Region or from one Region to another. You can use the snapshot to create EBS volumes or Amazon Machine Images (AMIs). The snapshot is copied to the regional endpoint that you send the HTTP request to.
        Copies of encrypted EBS snapshots remain encrypted. Copies of unencrypted snapshots remain unencrypted, unless the ``Encrypted`` flag is specified during the snapshot copy operation. By default, encrypted snapshot copies use the default AWS Key Management Service (AWS KMS) customer master key (CMK); however, you can specify a non-default CMK with the ``KmsKeyId`` parameter.
        To copy an encrypted snapshot that has been shared from another account, you must have permissions for the CMK used to encrypt the snapshot.
        Snapshots created by copying another snapshot have an arbitrary volume ID that should not be used for any purpose.
        For more information, see `Copying an Amazon EBS Snapshot <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-copy-snapshot.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CopySnapshot>`_
        
        **Request Syntax**
        ::
          response = client.copy_snapshot(
              Description='string',
              Encrypted=True|False,
              KmsKeyId='string',
              SourceRegion='string',
              SourceSnapshotId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'SnapshotId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CopySnapshot.
            - **SnapshotId** *(string) --* 
              The ID of the new snapshot.
        :type Description: string
        :param Description:
          A description for the EBS snapshot.
        :type DestinationRegion: string
        :param DestinationRegion:
          The destination Region to use in the ``PresignedUrl`` parameter of a snapshot copy operation. This parameter is only valid for specifying the destination Region in a ``PresignedUrl`` parameter, where it is required.
          The snapshot copy is sent to the regional endpoint that you sent the HTTP request to (for example, ``ec2.us-east-1.amazonaws.com`` ). With the AWS CLI, this is specified using the ``--region`` parameter or the default Region in your AWS configuration file.
            Please note that this parameter is automatically populated if it is not provided. Including this parameter is not required
        :type Encrypted: boolean
        :param Encrypted:
          Specifies whether the destination snapshot should be encrypted. You can encrypt a copy of an unencrypted snapshot, but you cannot use it to create an unencrypted copy of an encrypted snapshot. Your default CMK for EBS is used unless you specify a non-default AWS Key Management Service (AWS KMS) CMK using ``KmsKeyId`` . For more information, see `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type KmsKeyId: string
        :param KmsKeyId:
          An identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) to use when creating the encrypted volume. This parameter is only required if you want to use a non-default CMK; if this parameter is not specified, the default CMK for EBS is used. If a ``KmsKeyId`` is specified, the ``Encrypted`` flag must also be set.
          The CMK identifier may be provided in any of the following formats:
          * Key ID
          * Key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          * ARN using key ID. The ID ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``key`` namespace, and then the CMK ID. For example, arn:aws:kms:*us-east-1* :*012345678910* :key/*abcd1234-a123-456a-a12b-a123b4cd56ef* .
          * ARN using key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          AWS parses ``KmsKeyId`` asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. The action will eventually fail.
        :type PresignedUrl: string
        :param PresignedUrl:
          When you copy an encrypted source snapshot using the Amazon EC2 Query API, you must supply a pre-signed URL. This parameter is optional for unencrypted snapshots. For more information, see `Query Requests <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html>`__ .
          The ``PresignedUrl`` should use the snapshot source endpoint, the ``CopySnapshot`` action, and include the ``SourceRegion`` , ``SourceSnapshotId`` , and ``DestinationRegion`` parameters. The ``PresignedUrl`` must be signed using AWS Signature Version 4. Because EBS snapshots are stored in Amazon S3, the signing algorithm for this parameter uses the same logic that is described in `Authenticating Requests by Using Query Parameters (AWS Signature Version 4) <https://docs.aws.amazon.com/AmazonS3/latest/API/sigv4-query-string-auth.html>`__ in the *Amazon Simple Storage Service API Reference* . An invalid or improperly signed ``PresignedUrl`` will cause the copy operation to fail asynchronously, and the snapshot will move to an ``error`` state.
            Please note that this parameter is automatically populated if it is not provided. Including this parameter is not required
        :type SourceRegion: string
        :param SourceRegion: **[REQUIRED]**
          The ID of the Region that contains the snapshot to be copied.
        :type SourceSnapshotId: string
        :param SourceSnapshotId: **[REQUIRED]**
          The ID of the EBS snapshot to copy.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_capacity_reservation(self, InstanceType: str, InstancePlatform: str, AvailabilityZone: str, InstanceCount: int, ClientToken: str = None, Tenancy: str = None, EbsOptimized: bool = None, EphemeralStorage: bool = None, EndDate: datetime = None, EndDateType: str = None, InstanceMatchCriteria: str = None, TagSpecifications: List = None, DryRun: bool = None) -> Dict:
        """
        Creates a new Capacity Reservation with the specified attributes.
        Capacity Reservations enable you to reserve capacity for your Amazon EC2 instances in a specific Availability Zone for any duration. This gives you the flexibility to selectively add capacity reservations and still get the Regional RI discounts for that usage. By creating Capacity Reservations, you ensure that you always have access to Amazon EC2 capacity when you need it, for as long as you need it. For more information, see `Capacity Reservations <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-capacity-reservations.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        Your request to create a Capacity Reservation could fail if Amazon EC2 does not have sufficient capacity to fulfill the request. If your request fails due to Amazon EC2 capacity constraints, either try again at a later time, try in a different Availability Zone, or request a smaller capacity reservation. If your application is flexible across instance types and sizes, try to create a Capacity Reservation with different instance attributes.
        Your request could also fail if the requested quantity exceeds your On-Demand Instance limit for the selected instance type. If your request fails due to limit constraints, increase your On-Demand Instance limit for the required instance type and try again. For more information about increasing your instance limits, see `Amazon EC2 Service Limits <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-resource-limits.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateCapacityReservation>`_
        
        **Request Syntax**
        ::
          response = client.create_capacity_reservation(
              ClientToken='string',
              InstanceType='string',
              InstancePlatform='Linux/UNIX'|'Red Hat Enterprise Linux'|'SUSE Linux'|'Windows'|'Windows with SQL Server'|'Windows with SQL Server Enterprise'|'Windows with SQL Server Standard'|'Windows with SQL Server Web'|'Linux with SQL Server Standard'|'Linux with SQL Server Web'|'Linux with SQL Server Enterprise',
              AvailabilityZone='string',
              Tenancy='default'|'dedicated',
              InstanceCount=123,
              EbsOptimized=True|False,
              EphemeralStorage=True|False,
              EndDate=datetime(2015, 1, 1),
              EndDateType='unlimited'|'limited',
              InstanceMatchCriteria='open'|'targeted',
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'CapacityReservation': {
                    'CapacityReservationId': 'string',
                    'InstanceType': 'string',
                    'InstancePlatform': 'Linux/UNIX'|'Red Hat Enterprise Linux'|'SUSE Linux'|'Windows'|'Windows with SQL Server'|'Windows with SQL Server Enterprise'|'Windows with SQL Server Standard'|'Windows with SQL Server Web'|'Linux with SQL Server Standard'|'Linux with SQL Server Web'|'Linux with SQL Server Enterprise',
                    'AvailabilityZone': 'string',
                    'Tenancy': 'default'|'dedicated',
                    'TotalInstanceCount': 123,
                    'AvailableInstanceCount': 123,
                    'EbsOptimized': True|False,
                    'EphemeralStorage': True|False,
                    'State': 'active'|'expired'|'cancelled'|'pending'|'failed',
                    'EndDate': datetime(2015, 1, 1),
                    'EndDateType': 'unlimited'|'limited',
                    'InstanceMatchCriteria': 'open'|'targeted',
                    'CreateDate': datetime(2015, 1, 1),
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **CapacityReservation** *(dict) --* 
              Information about the Capacity Reservation.
              - **CapacityReservationId** *(string) --* 
                The ID of the Capacity Reservation.
              - **InstanceType** *(string) --* 
                The type of instance for which the Capacity Reservation reserves capacity.
              - **InstancePlatform** *(string) --* 
                The type of operating system for which the Capacity Reservation reserves capacity.
              - **AvailabilityZone** *(string) --* 
                The Availability Zone in which the capacity is reserved.
              - **Tenancy** *(string) --* 
                Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:
                * ``default`` - The Capacity Reservation is created on hardware that is shared with other AWS accounts. 
                * ``dedicated`` - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single AWS account. 
              - **TotalInstanceCount** *(integer) --* 
                The number of instances for which the Capacity Reservation reserves capacity.
              - **AvailableInstanceCount** *(integer) --* 
                The remaining capacity. Indicates the number of instances that can be launched in the Capacity Reservation.
              - **EbsOptimized** *(boolean) --* 
                Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS- optimized instance.
              - **EphemeralStorage** *(boolean) --* 
                Indicates whether the Capacity Reservation supports instances with temporary, block-level storage.
              - **State** *(string) --* 
                The current state of the Capacity Reservation. A Capacity Reservation can be in one of the following states:
                * ``active`` - The Capacity Reservation is active and the capacity is available for your use. 
                * ``cancelled`` - The Capacity Reservation expired automatically at the date and time specified in your request. The reserved capacity is no longer available for your use. 
                * ``expired`` - The Capacity Reservation was manually cancelled. The reserved capacity is no longer available for your use. 
                * ``pending`` - The Capacity Reservation request was successful but the capacity provisioning is still pending. 
                * ``failed`` - The Capacity Reservation request has failed. A request might fail due to invalid request parameters, capacity constraints, or instance limit constraints. Failed requests are retained for 60 minutes. 
              - **EndDate** *(datetime) --* 
                The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to ``expired`` when it reaches its end date and time.
              - **EndDateType** *(string) --* 
                Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:
                * ``unlimited`` - The Capacity Reservation remains active until you explicitly cancel it. 
                * ``limited`` - The Capacity Reservation expires automatically at a specified date and time. 
              - **InstanceMatchCriteria** *(string) --* 
                Indicates the type of instance launches that the Capacity Reservation accepts. The options include:
                * ``open`` - The Capacity Reservation accepts all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes launch into the Capacity Reservation automatically without specifying any additional parameters. 
                * ``targeted`` - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.  
              - **CreateDate** *(datetime) --* 
                The date and time at which the Capacity Reservation was created.
              - **Tags** *(list) --* 
                Any tags assigned to the Capacity Reservation.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          Constraint: Maximum 64 ASCII characters.
        :type InstanceType: string
        :param InstanceType: **[REQUIRED]**
          The instance type for which to reserve capacity. For more information, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type InstancePlatform: string
        :param InstancePlatform: **[REQUIRED]**
          The type of operating system for which to reserve capacity.
        :type AvailabilityZone: string
        :param AvailabilityZone: **[REQUIRED]**
          The Availability Zone in which to create the Capacity Reservation.
        :type Tenancy: string
        :param Tenancy:
          Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:
          * ``default`` - The Capacity Reservation is created on hardware that is shared with other AWS accounts.
          * ``dedicated`` - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single AWS account.
        :type InstanceCount: integer
        :param InstanceCount: **[REQUIRED]**
          The number of instances for which to reserve capacity.
        :type EbsOptimized: boolean
        :param EbsOptimized:
          Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS- optimized instance.
        :type EphemeralStorage: boolean
        :param EphemeralStorage:
          Indicates whether the Capacity Reservation supports instances with temporary, block-level storage.
        :type EndDate: datetime
        :param EndDate:
          The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation\'s state changes to ``expired`` when it reaches its end date and time.
          You must provide an ``EndDate`` value if ``EndDateType`` is ``limited`` . Omit ``EndDate`` if ``EndDateType`` is ``unlimited`` .
          If the ``EndDateType`` is ``limited`` , the Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019.
        :type EndDateType: string
        :param EndDateType:
          Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:
          * ``unlimited`` - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an ``EndDate`` if the ``EndDateType`` is ``unlimited`` .
          * ``limited`` - The Capacity Reservation expires automatically at a specified date and time. You must provide an ``EndDate`` value if the ``EndDateType`` value is ``limited`` .
        :type InstanceMatchCriteria: string
        :param InstanceMatchCriteria:
          Indicates the type of instance launches that the Capacity Reservation accepts. The options include:
          * ``open`` - The Capacity Reservation automatically matches all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes run in the Capacity Reservation automatically without specifying any additional parameters.
          * ``targeted`` - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.
          Default: ``open``
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the Capacity Reservation during launch.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_client_vpn_endpoint(self, ClientCidrBlock: str, ServerCertificateArn: str, AuthenticationOptions: List, ConnectionLogOptions: Dict, DnsServers: List = None, TransportProtocol: str = None, Description: str = None, DryRun: bool = None, ClientToken: str = None, TagSpecifications: List = None) -> Dict:
        """
        Creates a Client VPN endpoint. A Client VPN endpoint is the resource you create and configure to enable and manage client VPN sessions. It is the destination endpoint at which all client VPN sessions are terminated.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateClientVpnEndpoint>`_
        
        **Request Syntax**
        ::
          response = client.create_client_vpn_endpoint(
              ClientCidrBlock='string',
              ServerCertificateArn='string',
              AuthenticationOptions=[
                  {
                      'Type': 'certificate-authentication'|'directory-service-authentication',
                      'ActiveDirectory': {
                          'DirectoryId': 'string'
                      },
                      'MutualAuthentication': {
                          'ClientRootCertificateChainArn': 'string'
                      }
                  },
              ],
              ConnectionLogOptions={
                  'Enabled': True|False,
                  'CloudwatchLogGroup': 'string',
                  'CloudwatchLogStream': 'string'
              },
              DnsServers=[
                  'string',
              ],
              TransportProtocol='tcp'|'udp',
              Description='string',
              DryRun=True|False,
              ClientToken='string',
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ClientVpnEndpointId': 'string',
                'Status': {
                    'Code': 'pending-associate'|'available'|'deleting'|'deleted',
                    'Message': 'string'
                },
                'DnsName': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientVpnEndpointId** *(string) --* 
              The ID of the Client VPN endpoint.
            - **Status** *(dict) --* 
              The current state of the Client VPN endpoint.
              - **Code** *(string) --* 
                The state of the Client VPN endpoint. Possible states include:
                * ``pending-associate`` - The Client VPN endpoint has been created but no target networks have been associated. The Client VPN endpoint cannot accept connections. 
                * ``available`` - The Client VPN endpoint has been created and a target network has been associated. The Client VPN endpoint can accept connections. 
                * ``deleting`` - The Client VPN endpoint is being deleted. The Client VPN endpoint cannot accept connections. 
                * ``deleted`` - The Client VPN endpoint has been deleted. The Client VPN endpoint cannot accept connections. 
              - **Message** *(string) --* 
                A message about the status of the Client VPN endpoint.
            - **DnsName** *(string) --* 
              The DNS name to be used by clients when establishing their VPN session.
        :type ClientCidrBlock: string
        :param ClientCidrBlock: **[REQUIRED]**
          The IPv4 address range, in CIDR notation, from which to assign client IP addresses. The address range cannot overlap with the local CIDR of the VPC in which the associated subnet is located, or the routes that you add manually. The address range cannot be changed after the Client VPN endpoint has been created. The CIDR block should be /22 or greater.
        :type ServerCertificateArn: string
        :param ServerCertificateArn: **[REQUIRED]**
          The ARN of the server certificate. For more information, see the `AWS Certificate Manager User Guide <https://docs.aws.amazon.com/acm/latest/userguide/>`__ .
        :type AuthenticationOptions: list
        :param AuthenticationOptions: **[REQUIRED]**
          Information about the authentication method to be used to authenticate clients.
          - *(dict) --*
            Describes the authentication method to be used by a Client VPN endpoint. Client VPN supports Active Directory and mutual authentication. For more information, see `Authentication <https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/authentication-authrization.html#client-authentication>`__ in the *AWS Client VPN Administrator Guide* .
            - **Type** *(string) --*
              The type of client authentication to be used. Specify ``certificate-authentication`` to use certificate-based authentication, or ``directory-service-authentication`` to use Active Directory authentication.
            - **ActiveDirectory** *(dict) --*
              Information about the Active Directory to be used, if applicable. You must provide this information if **Type** is ``directory-service-authentication`` .
              - **DirectoryId** *(string) --*
                The ID of the Active Directory to be used for authentication.
            - **MutualAuthentication** *(dict) --*
              Information about the authentication certificates to be used, if applicable. You must provide this information if **Type** is ``certificate-authentication`` .
              - **ClientRootCertificateChainArn** *(string) --*
                The ARN of the client certificate. The certificate must be signed by a certificate authority (CA) and it must be provisioned in AWS Certificate Manager (ACM).
        :type ConnectionLogOptions: dict
        :param ConnectionLogOptions: **[REQUIRED]**
          Information about the client connection logging options.
          If you enable client connection logging, data about client connections is sent to a Cloudwatch Logs log stream. The following information is logged:
          * Client connection requests
          * Client connection results (successful and unsuccessful)
          * Reasons for unsuccessful client connection requests
          * Client connection termination time
          - **Enabled** *(boolean) --*
            Indicates whether connection logging is enabled.
          - **CloudwatchLogGroup** *(string) --*
            The name of the CloudWatch Logs log group.
          - **CloudwatchLogStream** *(string) --*
            The name of the CloudWatch Logs log stream to which the connection data is published.
        :type DnsServers: list
        :param DnsServers:
          Information about the DNS servers to be used for DNS resolution. A Client VPN endpoint can have up to two DNS servers. If no DNS server is specified, the DNS address of the VPC that is to be associated with Client VPN endpoint is used as the DNS server.
          - *(string) --*
        :type TransportProtocol: string
        :param TransportProtocol:
          The transport protocol to be used by the VPN session.
          Default value: ``udp``
        :type Description: string
        :param Description:
          A brief description of the Client VPN endpoint.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ .
          This field is autopopulated if not provided.
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the Client VPN endpoint during creation.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :rtype: dict
        :returns:
        """
        pass

    def create_client_vpn_route(self, ClientVpnEndpointId: str, DestinationCidrBlock: str, TargetVpcSubnetId: str, Description: str = None, DryRun: bool = None) -> Dict:
        """
        Adds a route to a network to a Client VPN endpoint. Each Client VPN endpoint has a route table that describes the available destination network routes. Each route in the route table specifies the path for traﬃc to speciﬁc resources or networks.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateClientVpnRoute>`_
        
        **Request Syntax**
        ::
          response = client.create_client_vpn_route(
              ClientVpnEndpointId='string',
              DestinationCidrBlock='string',
              TargetVpcSubnetId='string',
              Description='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Status': {
                    'Code': 'creating'|'active'|'failed'|'deleting',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Status** *(dict) --* 
              The current state of the route.
              - **Code** *(string) --* 
                The state of the Client VPN endpoint route.
              - **Message** *(string) --* 
                A message about the status of the Client VPN endpoint route, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint to which to add the route.
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock: **[REQUIRED]**
          The IPv4 address range, in CIDR notation, of the route destination. For example:
          * To add a route for Internet access, enter ``0.0.0.0/0``
          * To add a route for a peered VPC, enter the peered VPC\'s IPv4 CIDR range
          * To add a route for an on-premises network, enter the AWS Site-to-Site VPN connection\'s IPv4 CIDR range
          Route address ranges cannot overlap with the CIDR range specified for client allocation.
        :type TargetVpcSubnetId: string
        :param TargetVpcSubnetId: **[REQUIRED]**
          The ID of the subnet through which you want to route traffic. The specified subnet must be an existing target network of the Client VPN endpoint.
        :type Description: string
        :param Description:
          A brief description of the route.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_customer_gateway(self, BgpAsn: int, PublicIp: str, Type: str, DryRun: bool = None) -> Dict:
        """
        Provides information to AWS about your VPN customer gateway device. The customer gateway is the appliance at your end of the VPN connection. (The device on the AWS side of the VPN connection is the virtual private gateway.) You must provide the Internet-routable IP address of the customer gateway's external interface. The IP address must be static and may be behind a device performing network address translation (NAT).
        For devices that use Border Gateway Protocol (BGP), you can also provide the device's BGP Autonomous System Number (ASN). You can use an existing ASN assigned to your network. If you don't have an ASN already, you can use a private ASN (in the 64512 - 65534 range).
        .. note::
          Amazon EC2 supports all 2-byte ASN numbers in the range of 1 - 65534, with the exception of 7224, which is reserved in the ``us-east-1`` region, and 9059, which is reserved in the ``eu-west-1`` region.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        .. warning::
          You cannot create more than one customer gateway with the same VPN type, IP address, and BGP ASN parameter values. If you run an identical request more than one time, the first request creates the customer gateway, and subsequent requests return information about the existing customer gateway. The subsequent requests do not create new customer gateway resources.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateCustomerGateway>`_
        
        **Request Syntax**
        ::
          response = client.create_customer_gateway(
              BgpAsn=123,
              PublicIp='string',
              Type='ipsec.1',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'CustomerGateway': {
                    'BgpAsn': 'string',
                    'CustomerGatewayId': 'string',
                    'IpAddress': 'string',
                    'State': 'string',
                    'Type': 'string',
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateCustomerGateway.
            - **CustomerGateway** *(dict) --* 
              Information about the customer gateway.
              - **BgpAsn** *(string) --* 
                The customer gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).
              - **CustomerGatewayId** *(string) --* 
                The ID of the customer gateway.
              - **IpAddress** *(string) --* 
                The Internet-routable IP address of the customer gateway's outside interface.
              - **State** *(string) --* 
                The current state of the customer gateway (``pending | available | deleting | deleted`` ).
              - **Type** *(string) --* 
                The type of VPN connection the customer gateway supports (``ipsec.1`` ).
              - **Tags** *(list) --* 
                Any tags assigned to the customer gateway.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type BgpAsn: integer
        :param BgpAsn: **[REQUIRED]**
          For devices that support BGP, the customer gateway\'s BGP ASN.
          Default: 65000
        :type PublicIp: string
        :param PublicIp: **[REQUIRED]**
          The Internet-routable IP address for the customer gateway\'s outside interface. The address must be static.
        :type Type: string
        :param Type: **[REQUIRED]**
          The type of VPN connection that this customer gateway supports (``ipsec.1`` ).
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_default_subnet(self, AvailabilityZone: str, DryRun: bool = None) -> Dict:
        """
        Creates a default subnet with a size ``/20`` IPv4 CIDR block in the specified Availability Zone in your default VPC. You can have only one default subnet per Availability Zone. For more information, see `Creating a Default Subnet <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/default-vpc.html#create-default-subnet>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateDefaultSubnet>`_
        
        **Request Syntax**
        ::
          response = client.create_default_subnet(
              AvailabilityZone='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Subnet': {
                    'AvailabilityZone': 'string',
                    'AvailabilityZoneId': 'string',
                    'AvailableIpAddressCount': 123,
                    'CidrBlock': 'string',
                    'DefaultForAz': True|False,
                    'MapPublicIpOnLaunch': True|False,
                    'State': 'pending'|'available',
                    'SubnetId': 'string',
                    'VpcId': 'string',
                    'OwnerId': 'string',
                    'AssignIpv6AddressOnCreation': True|False,
                    'Ipv6CidrBlockAssociationSet': [
                        {
                            'AssociationId': 'string',
                            'Ipv6CidrBlock': 'string',
                            'Ipv6CidrBlockState': {
                                'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                'StatusMessage': 'string'
                            }
                        },
                    ],
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'SubnetArn': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Subnet** *(dict) --* 
              Information about the subnet.
              - **AvailabilityZone** *(string) --* 
                The Availability Zone of the subnet.
              - **AvailabilityZoneId** *(string) --* 
                The AZ ID of the subnet.
              - **AvailableIpAddressCount** *(integer) --* 
                The number of unused private IPv4 addresses in the subnet. The IPv4 addresses for any stopped instances are considered unavailable.
              - **CidrBlock** *(string) --* 
                The IPv4 CIDR block assigned to the subnet.
              - **DefaultForAz** *(boolean) --* 
                Indicates whether this is the default subnet for the Availability Zone.
              - **MapPublicIpOnLaunch** *(boolean) --* 
                Indicates whether instances launched in this subnet receive a public IPv4 address.
              - **State** *(string) --* 
                The current state of the subnet.
              - **SubnetId** *(string) --* 
                The ID of the subnet.
              - **VpcId** *(string) --* 
                The ID of the VPC the subnet is in.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the subnet.
              - **AssignIpv6AddressOnCreation** *(boolean) --* 
                Indicates whether a network interface created in this subnet (including a network interface created by  RunInstances ) receives an IPv6 address.
              - **Ipv6CidrBlockAssociationSet** *(list) --* 
                Information about the IPv6 CIDR blocks associated with the subnet.
                - *(dict) --* 
                  Describes an IPv6 CIDR block associated with a subnet.
                  - **AssociationId** *(string) --* 
                    The association ID for the CIDR block.
                  - **Ipv6CidrBlock** *(string) --* 
                    The IPv6 CIDR block.
                  - **Ipv6CidrBlockState** *(dict) --* 
                    Information about the state of the CIDR block.
                    - **State** *(string) --* 
                      The state of a CIDR block.
                    - **StatusMessage** *(string) --* 
                      A message about the status of the CIDR block, if applicable.
              - **Tags** *(list) --* 
                Any tags assigned to the subnet.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **SubnetArn** *(string) --* 
                The Amazon Resource Name (ARN) of the subnet.
        :type AvailabilityZone: string
        :param AvailabilityZone: **[REQUIRED]**
          The Availability Zone in which to create the default subnet.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_default_vpc(self, DryRun: bool = None) -> Dict:
        """
        Creates a default VPC with a size ``/16`` IPv4 CIDR block and a default subnet in each Availability Zone. For more information about the components of a default VPC, see `Default VPC and Default Subnets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/default-vpc.html>`__ in the *Amazon Virtual Private Cloud User Guide* . You cannot specify the components of the default VPC yourself.
        If you deleted your previous default VPC, you can create a default VPC. You cannot have more than one default VPC per Region.
        If your account supports EC2-Classic, you cannot use this action to create a default VPC in a Region that supports EC2-Classic. If you want a default VPC in a Region that supports EC2-Classic, see "I really want a default VPC for my existing EC2 account. Is that possible?" in the `Default VPCs FAQ <http://aws.amazon.com/vpc/faqs/#Default_VPCs>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateDefaultVpc>`_
        
        **Request Syntax**
        ::
          response = client.create_default_vpc(
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Vpc': {
                    'CidrBlock': 'string',
                    'DhcpOptionsId': 'string',
                    'State': 'pending'|'available',
                    'VpcId': 'string',
                    'OwnerId': 'string',
                    'InstanceTenancy': 'default'|'dedicated'|'host',
                    'Ipv6CidrBlockAssociationSet': [
                        {
                            'AssociationId': 'string',
                            'Ipv6CidrBlock': 'string',
                            'Ipv6CidrBlockState': {
                                'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                'StatusMessage': 'string'
                            }
                        },
                    ],
                    'CidrBlockAssociationSet': [
                        {
                            'AssociationId': 'string',
                            'CidrBlock': 'string',
                            'CidrBlockState': {
                                'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                'StatusMessage': 'string'
                            }
                        },
                    ],
                    'IsDefault': True|False,
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Vpc** *(dict) --* 
              Information about the VPC.
              - **CidrBlock** *(string) --* 
                The primary IPv4 CIDR block for the VPC.
              - **DhcpOptionsId** *(string) --* 
                The ID of the set of DHCP options you've associated with the VPC (or ``default`` if the default options are associated with the VPC).
              - **State** *(string) --* 
                The current state of the VPC.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the VPC.
              - **InstanceTenancy** *(string) --* 
                The allowed tenancy of instances launched into the VPC.
              - **Ipv6CidrBlockAssociationSet** *(list) --* 
                Information about the IPv6 CIDR blocks associated with the VPC.
                - *(dict) --* 
                  Describes an IPv6 CIDR block associated with a VPC.
                  - **AssociationId** *(string) --* 
                    The association ID for the IPv6 CIDR block.
                  - **Ipv6CidrBlock** *(string) --* 
                    The IPv6 CIDR block.
                  - **Ipv6CidrBlockState** *(dict) --* 
                    Information about the state of the CIDR block.
                    - **State** *(string) --* 
                      The state of the CIDR block.
                    - **StatusMessage** *(string) --* 
                      A message about the status of the CIDR block, if applicable.
              - **CidrBlockAssociationSet** *(list) --* 
                Information about the IPv4 CIDR blocks associated with the VPC.
                - *(dict) --* 
                  Describes an IPv4 CIDR block associated with a VPC.
                  - **AssociationId** *(string) --* 
                    The association ID for the IPv4 CIDR block.
                  - **CidrBlock** *(string) --* 
                    The IPv4 CIDR block.
                  - **CidrBlockState** *(dict) --* 
                    Information about the state of the CIDR block.
                    - **State** *(string) --* 
                      The state of the CIDR block.
                    - **StatusMessage** *(string) --* 
                      A message about the status of the CIDR block, if applicable.
              - **IsDefault** *(boolean) --* 
                Indicates whether the VPC is the default VPC.
              - **Tags** *(list) --* 
                Any tags assigned to the VPC.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_dhcp_options(self, DhcpConfigurations: List, DryRun: bool = None) -> Dict:
        """
        Creates a set of DHCP options for your VPC. After creating the set, you must associate it with the VPC, causing all existing and new instances that you launch in the VPC to use this set of DHCP options. The following are the individual DHCP options you can specify. For more information about the options, see `RFC 2132 <http://www.ietf.org/rfc/rfc2132.txt>`__ .
        * ``domain-name-servers`` - The IP addresses of up to four domain name servers, or AmazonProvidedDNS. The default DHCP option set specifies AmazonProvidedDNS. If specifying more than one domain name server, specify the IP addresses in a single parameter, separated by commas. ITo have your instance to receive a custom DNS hostname as specified in ``domain-name`` , you must set ``domain-name-servers`` to a custom DNS server. 
        * ``domain-name`` - If you're using AmazonProvidedDNS in ``us-east-1`` , specify ``ec2.internal`` . If you're using AmazonProvidedDNS in another region, specify ``region.compute.internal`` (for example, ``ap-northeast-1.compute.internal`` ). Otherwise, specify a domain name (for example, ``MyCompany.com`` ). This value is used to complete unqualified DNS hostnames. **Important** : Some Linux operating systems accept multiple domain names separated by spaces. However, Windows and other Linux operating systems treat the value as a single domain, which results in unexpected behavior. If your DHCP options set is associated with a VPC that has instances with multiple operating systems, specify only one domain name. 
        * ``ntp-servers`` - The IP addresses of up to four Network Time Protocol (NTP) servers. 
        * ``netbios-name-servers`` - The IP addresses of up to four NetBIOS name servers. 
        * ``netbios-node-type`` - The NetBIOS node type (1, 2, 4, or 8). We recommend that you specify 2 (broadcast and multicast are not currently supported). For more information about these node types, see `RFC 2132 <http://www.ietf.org/rfc/rfc2132.txt>`__ . 
        Your VPC automatically starts out with a set of DHCP options that includes only a DNS server that we provide (AmazonProvidedDNS). If you create a set of options, and if your VPC has an internet gateway, make sure to set the ``domain-name-servers`` option either to ``AmazonProvidedDNS`` or to a domain name server of your choice. For more information, see `DHCP Options Sets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_DHCP_Options.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateDhcpOptions>`_
        
        **Request Syntax**
        ::
          response = client.create_dhcp_options(
              DhcpConfigurations=[
                  {
                      'Key': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'DhcpOptions': {
                    'DhcpConfigurations': [
                        {
                            'Key': 'string',
                            'Values': [
                                {
                                    'Value': 'string'
                                },
                            ]
                        },
                    ],
                    'DhcpOptionsId': 'string',
                    'OwnerId': 'string',
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **DhcpOptions** *(dict) --* 
              A set of DHCP options.
              - **DhcpConfigurations** *(list) --* 
                One or more DHCP options in the set.
                - *(dict) --* 
                  Describes a DHCP configuration option.
                  - **Key** *(string) --* 
                    The name of a DHCP option.
                  - **Values** *(list) --* 
                    One or more values for the DHCP option.
                    - *(dict) --* 
                      Describes a value for a resource attribute that is a String.
                      - **Value** *(string) --* 
                        The attribute value. The value is case-sensitive.
              - **DhcpOptionsId** *(string) --* 
                The ID of the set of DHCP options.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the DHCP options set.
              - **Tags** *(list) --* 
                Any tags assigned to the DHCP options set.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DhcpConfigurations: list
        :param DhcpConfigurations: **[REQUIRED]**
          A DHCP configuration option.
          - *(dict) --*
            - **Key** *(string) --*
            - **Values** *(list) --*
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_egress_only_internet_gateway(self, VpcId: str, ClientToken: str = None, DryRun: bool = None) -> Dict:
        """
        [IPv6 only] Creates an egress-only internet gateway for your VPC. An egress-only internet gateway is used to enable outbound communication over IPv6 from instances in your VPC to the internet, and prevents hosts outside of your VPC from initiating an IPv6 connection with your instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateEgressOnlyInternetGateway>`_
        
        **Request Syntax**
        ::
          response = client.create_egress_only_internet_gateway(
              ClientToken='string',
              DryRun=True|False,
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ClientToken': 'string',
                'EgressOnlyInternetGateway': {
                    'Attachments': [
                        {
                            'State': 'attaching'|'attached'|'detaching'|'detached',
                            'VpcId': 'string'
                        },
                    ],
                    'EgressOnlyInternetGatewayId': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientToken** *(string) --* 
              Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
            - **EgressOnlyInternetGateway** *(dict) --* 
              Information about the egress-only internet gateway.
              - **Attachments** *(list) --* 
                Information about the attachment of the egress-only internet gateway.
                - *(dict) --* 
                  Describes the attachment of a VPC to an internet gateway or an egress-only internet gateway.
                  - **State** *(string) --* 
                    The current state of the attachment. For an internet gateway, the state is ``available`` when attached to a VPC; otherwise, this value is not returned.
                  - **VpcId** *(string) --* 
                    The ID of the VPC.
              - **EgressOnlyInternetGatewayId** *(string) --* 
                The ID of the egress-only internet gateway.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC for which to create the egress-only internet gateway.
        :rtype: dict
        :returns:
        """
        pass

    def create_fleet(self, LaunchTemplateConfigs: List, TargetCapacitySpecification: Dict, DryRun: bool = None, ClientToken: str = None, SpotOptions: Dict = None, OnDemandOptions: Dict = None, ExcessCapacityTerminationPolicy: str = None, TerminateInstancesWithExpiration: bool = None, Type: str = None, ValidFrom: datetime = None, ValidUntil: datetime = None, ReplaceUnhealthyInstances: bool = None, TagSpecifications: List = None) -> Dict:
        """
        Launches an EC2 Fleet.
        You can create a single EC2 Fleet that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet.
        For more information, see `Launching an EC2 Fleet <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateFleet>`_
        
        **Request Syntax**
        ::
          response = client.create_fleet(
              DryRun=True|False,
              ClientToken='string',
              SpotOptions={
                  'AllocationStrategy': 'lowest-price'|'diversified',
                  'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate',
                  'InstancePoolsToUseCount': 123,
                  'SingleInstanceType': True|False,
                  'SingleAvailabilityZone': True|False,
                  'MinTargetCapacity': 123
              },
              OnDemandOptions={
                  'AllocationStrategy': 'lowest-price'|'prioritized',
                  'SingleInstanceType': True|False,
                  'SingleAvailabilityZone': True|False,
                  'MinTargetCapacity': 123
              },
              ExcessCapacityTerminationPolicy='no-termination'|'termination',
              LaunchTemplateConfigs=[
                  {
                      'LaunchTemplateSpecification': {
                          'LaunchTemplateId': 'string',
                          'LaunchTemplateName': 'string',
                          'Version': 'string'
                      },
                      'Overrides': [
                          {
                              'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                              'MaxPrice': 'string',
                              'SubnetId': 'string',
                              'AvailabilityZone': 'string',
                              'WeightedCapacity': 123.0,
                              'Priority': 123.0,
                              'Placement': {
                                  'AvailabilityZone': 'string',
                                  'Affinity': 'string',
                                  'GroupName': 'string',
                                  'PartitionNumber': 123,
                                  'HostId': 'string',
                                  'Tenancy': 'default'|'dedicated'|'host',
                                  'SpreadDomain': 'string'
                              }
                          },
                      ]
                  },
              ],
              TargetCapacitySpecification={
                  'TotalTargetCapacity': 123,
                  'OnDemandTargetCapacity': 123,
                  'SpotTargetCapacity': 123,
                  'DefaultTargetCapacityType': 'spot'|'on-demand'
              },
              TerminateInstancesWithExpiration=True|False,
              Type='request'|'maintain'|'instant',
              ValidFrom=datetime(2015, 1, 1),
              ValidUntil=datetime(2015, 1, 1),
              ReplaceUnhealthyInstances=True|False,
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'FleetId': 'string',
                'Errors': [
                    {
                        'LaunchTemplateAndOverrides': {
                            'LaunchTemplateSpecification': {
                                'LaunchTemplateId': 'string',
                                'LaunchTemplateName': 'string',
                                'Version': 'string'
                            },
                            'Overrides': {
                                'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                'MaxPrice': 'string',
                                'SubnetId': 'string',
                                'AvailabilityZone': 'string',
                                'WeightedCapacity': 123.0,
                                'Priority': 123.0,
                                'Placement': {
                                    'GroupName': 'string'
                                }
                            }
                        },
                        'Lifecycle': 'spot'|'on-demand',
                        'ErrorCode': 'string',
                        'ErrorMessage': 'string'
                    },
                ],
                'Instances': [
                    {
                        'LaunchTemplateAndOverrides': {
                            'LaunchTemplateSpecification': {
                                'LaunchTemplateId': 'string',
                                'LaunchTemplateName': 'string',
                                'Version': 'string'
                            },
                            'Overrides': {
                                'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                'MaxPrice': 'string',
                                'SubnetId': 'string',
                                'AvailabilityZone': 'string',
                                'WeightedCapacity': 123.0,
                                'Priority': 123.0,
                                'Placement': {
                                    'GroupName': 'string'
                                }
                            }
                        },
                        'Lifecycle': 'spot'|'on-demand',
                        'InstanceIds': [
                            'string',
                        ],
                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                        'Platform': 'Windows'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **FleetId** *(string) --* 
              The ID of the EC2 Fleet.
            - **Errors** *(list) --* 
              Information about the instances that could not be launched by the fleet. Valid only when **Type** is set to ``instant`` .
              - *(dict) --* 
                Describes the instances that could not be launched by the fleet.
                - **LaunchTemplateAndOverrides** *(dict) --* 
                  The launch templates and overrides that were used for launching the instances. Any parameters that you specify in the Overrides override the same parameters in the launch template.
                  - **LaunchTemplateSpecification** *(dict) --* 
                    The launch template.
                    - **LaunchTemplateId** *(string) --* 
                      The ID of the launch template. You must specify either a template ID or a template name.
                    - **LaunchTemplateName** *(string) --* 
                      The name of the launch template. You must specify either a template name or a template ID.
                    - **Version** *(string) --* 
                      The version number of the launch template. You must specify a version number.
                  - **Overrides** *(dict) --* 
                    Any parameters that you specify override the same parameters in the launch template.
                    - **InstanceType** *(string) --* 
                      The instance type.
                    - **MaxPrice** *(string) --* 
                      The maximum price per unit hour that you are willing to pay for a Spot Instance.
                    - **SubnetId** *(string) --* 
                      The ID of the subnet in which to launch the instances.
                    - **AvailabilityZone** *(string) --* 
                      The Availability Zone in which to launch the instances.
                    - **WeightedCapacity** *(float) --* 
                      The number of units provided by the specified instance type.
                    - **Priority** *(float) --* 
                      The priority for the launch template override. If **AllocationStrategy** is set to ``prioritized`` , EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the override has the lowest priority.
                    - **Placement** *(dict) --* 
                      The location where the instance launched, if applicable.
                      - **GroupName** *(string) --* 
                        The name of the placement group the instance is in.
                - **Lifecycle** *(string) --* 
                  Indicates if the instance that could not be launched was a Spot Instance or On-Demand Instance.
                - **ErrorCode** *(string) --* 
                  The error code that indicates why the instance could not be launched. For more information about error codes, see `Error Codes <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html>`__ .
                - **ErrorMessage** *(string) --* 
                  The error message that describes why the instance could not be launched. For more information about error messages, see ee `Error Codes <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html>`__ .
            - **Instances** *(list) --* 
              Information about the instances that were launched by the fleet. Valid only when **Type** is set to ``instant`` .
              - *(dict) --* 
                Describes the instances that were launched by the fleet.
                - **LaunchTemplateAndOverrides** *(dict) --* 
                  The launch templates and overrides that were used for launching the instances. Any parameters that you specify in the Overrides override the same parameters in the launch template.
                  - **LaunchTemplateSpecification** *(dict) --* 
                    The launch template.
                    - **LaunchTemplateId** *(string) --* 
                      The ID of the launch template. You must specify either a template ID or a template name.
                    - **LaunchTemplateName** *(string) --* 
                      The name of the launch template. You must specify either a template name or a template ID.
                    - **Version** *(string) --* 
                      The version number of the launch template. You must specify a version number.
                  - **Overrides** *(dict) --* 
                    Any parameters that you specify override the same parameters in the launch template.
                    - **InstanceType** *(string) --* 
                      The instance type.
                    - **MaxPrice** *(string) --* 
                      The maximum price per unit hour that you are willing to pay for a Spot Instance.
                    - **SubnetId** *(string) --* 
                      The ID of the subnet in which to launch the instances.
                    - **AvailabilityZone** *(string) --* 
                      The Availability Zone in which to launch the instances.
                    - **WeightedCapacity** *(float) --* 
                      The number of units provided by the specified instance type.
                    - **Priority** *(float) --* 
                      The priority for the launch template override. If **AllocationStrategy** is set to ``prioritized`` , EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the override has the lowest priority.
                    - **Placement** *(dict) --* 
                      The location where the instance launched, if applicable.
                      - **GroupName** *(string) --* 
                        The name of the placement group the instance is in.
                - **Lifecycle** *(string) --* 
                  Indicates if the instance that was launched is a Spot Instance or On-Demand Instance.
                - **InstanceIds** *(list) --* 
                  The IDs of the instances.
                  - *(string) --* 
                - **InstanceType** *(string) --* 
                  The instance type.
                - **Platform** *(string) --* 
                  The value is ``Windows`` for Windows instances; otherwise blank.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
        :type SpotOptions: dict
        :param SpotOptions:
          Describes the configuration of Spot Instances in an EC2 Fleet.
          - **AllocationStrategy** *(string) --*
            Indicates how to allocate the target capacity across the Spot pools specified by the Spot Fleet request. The default is ``lowestPrice`` .
          - **InstanceInterruptionBehavior** *(string) --*
            The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
          - **InstancePoolsToUseCount** *(integer) --*
            The number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot **AllocationStrategy** is set to ``lowest-price`` . EC2 Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify.
          - **SingleInstanceType** *(boolean) --*
            Indicates that the fleet uses a single instance type to launch all Spot Instances in the fleet.
          - **SingleAvailabilityZone** *(boolean) --*
            Indicates that the fleet launches all Spot Instances into a single Availability Zone.
          - **MinTargetCapacity** *(integer) --*
            The minimum target capacity for Spot Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances.
        :type OnDemandOptions: dict
        :param OnDemandOptions:
          The allocation strategy of On-Demand Instances in an EC2 Fleet.
          - **AllocationStrategy** *(string) --*
            The order of the launch template overrides to use in fulfilling On-Demand capacity. If you specify ``lowest-price`` , EC2 Fleet uses price to determine the order, launching the lowest price first. If you specify ``prioritized`` , EC2 Fleet uses the priority that you assigned to each launch template override, launching the highest priority first. If you do not specify a value, EC2 Fleet defaults to ``lowest-price`` .
          - **SingleInstanceType** *(boolean) --*
            Indicates that the fleet uses a single instance type to launch all On-Demand Instances in the fleet.
          - **SingleAvailabilityZone** *(boolean) --*
            Indicates that the fleet launches all On-Demand Instances into a single Availability Zone.
          - **MinTargetCapacity** *(integer) --*
            The minimum target capacity for On-Demand Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances.
        :type ExcessCapacityTerminationPolicy: string
        :param ExcessCapacityTerminationPolicy:
          Indicates whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet.
        :type LaunchTemplateConfigs: list
        :param LaunchTemplateConfigs: **[REQUIRED]**
          The configuration for the EC2 Fleet.
          - *(dict) --*
            Describes a launch template and overrides.
            - **LaunchTemplateSpecification** *(dict) --*
              The launch template to use. You must specify either the launch template ID or launch template name in the request.
              - **LaunchTemplateId** *(string) --*
                The ID of the launch template.
              - **LaunchTemplateName** *(string) --*
                The name of the launch template.
              - **Version** *(string) --*
                The version number of the launch template.
            - **Overrides** *(list) --*
              Any parameters that you specify override the same parameters in the launch template.
              - *(dict) --*
                Describes overrides for a launch template.
                - **InstanceType** *(string) --*
                  The instance type.
                - **MaxPrice** *(string) --*
                  The maximum price per unit hour that you are willing to pay for a Spot Instance.
                - **SubnetId** *(string) --*
                  The ID of the subnet in which to launch the instances.
                - **AvailabilityZone** *(string) --*
                  The Availability Zone in which to launch the instances.
                - **WeightedCapacity** *(float) --*
                  The number of units provided by the specified instance type.
                - **Priority** *(float) --*
                  The priority for the launch template override. If **AllocationStrategy** is set to ``prioritized`` , EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority.
                - **Placement** *(dict) --*
                  The location where the instance launched, if applicable.
                  - **AvailabilityZone** *(string) --*
                    The Availability Zone of the instance.
                    If not specified, an Availability Zone will be automatically chosen for you based on the load balancing criteria for the region.
                  - **Affinity** *(string) --*
                    The affinity setting for the instance on the Dedicated Host. This parameter is not supported for the  ImportInstance command.
                  - **GroupName** *(string) --*
                    The name of the placement group the instance is in.
                  - **PartitionNumber** *(integer) --*
                    The number of the partition the instance is in. Valid only if the placement group strategy is set to ``partition`` .
                  - **HostId** *(string) --*
                    The ID of the Dedicated Host on which the instance resides. This parameter is not supported for the  ImportInstance command.
                  - **Tenancy** *(string) --*
                    The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for the  ImportInstance command.
                  - **SpreadDomain** *(string) --*
                    Reserved for future use.
        :type TargetCapacitySpecification: dict
        :param TargetCapacitySpecification: **[REQUIRED]**
          The ``TotalTargetCapacity`` , ``OnDemandTargetCapacity`` , ``SpotTargetCapacity`` , and ``DefaultCapacityType`` structure.
          - **TotalTargetCapacity** *(integer) --* **[REQUIRED]**
            The number of units to request, filled using ``DefaultTargetCapacityType`` .
          - **OnDemandTargetCapacity** *(integer) --*
            The number of On-Demand units to request.
          - **SpotTargetCapacity** *(integer) --*
            The number of Spot units to request.
          - **DefaultTargetCapacityType** *(string) --*
            The default ``TotalTargetCapacity`` , which is either ``Spot`` or ``On-Demand`` .
        :type TerminateInstancesWithExpiration: boolean
        :param TerminateInstancesWithExpiration:
          Indicates whether running instances should be terminated when the EC2 Fleet expires.
        :type Type: string
        :param Type:
          The type of the request. By default, the EC2 Fleet places an asynchronous request for your desired capacity, and maintains it by replenishing interrupted Spot Instances (``maintain`` ). A value of ``instant`` places a synchronous one-time request, and returns errors for any instances that could not be launched. A value of ``request`` places an asynchronous one-time request without maintaining capacity or submitting requests in alternative capacity pools if capacity is unavailable. For more information, see `EC2 Fleet Request Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-configuration-strategies.html#ec2-fleet-request-type>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type ValidFrom: datetime
        :param ValidFrom:
          The start date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). The default is to start fulfilling the request immediately.
        :type ValidUntil: datetime
        :param ValidUntil:
          The end date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). At this point, no new EC2 Fleet requests are placed or able to fulfill the request. If no value is specified, the request remains until you cancel it.
        :type ReplaceUnhealthyInstances: boolean
        :param ReplaceUnhealthyInstances:
          Indicates whether EC2 Fleet should replace unhealthy instances.
        :type TagSpecifications: list
        :param TagSpecifications:
          The key-value pair for tagging the EC2 Fleet request on creation. The value for ``ResourceType`` must be ``fleet`` , otherwise the fleet request fails. To tag instances at launch, specify the tags in the `launch template <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template>`__ . For information about tagging after launch, see `Tagging Your Resources <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources>`__ .
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :rtype: dict
        :returns:
        """
        pass

    def create_flow_logs(self, ResourceIds: List, ResourceType: str, TrafficType: str, DryRun: bool = None, ClientToken: str = None, DeliverLogsPermissionArn: str = None, LogGroupName: str = None, LogDestinationType: str = None, LogDestination: str = None) -> Dict:
        """
        Creates one or more flow logs to capture information about IP traffic for a specific network interface, subnet, or VPC. 
        Flow log data for a monitored network interface is recorded as flow log records, which are log events consisting of fields that describe the traffic flow. For more information, see `Flow Log Records <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/flow-logs.html#flow-log-records>`__ in the *Amazon Virtual Private Cloud User Guide* .
        When publishing to CloudWatch Logs, flow log records are published to a log group, and each network interface has a unique log stream in the log group. When publishing to Amazon S3, flow log records for all of the monitored network interfaces are published to a single log file object that is stored in the specified bucket.
        For more information, see `VPC Flow Logs <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/flow-logs.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateFlowLogs>`_
        
        **Request Syntax**
        ::
          response = client.create_flow_logs(
              DryRun=True|False,
              ClientToken='string',
              DeliverLogsPermissionArn='string',
              LogGroupName='string',
              ResourceIds=[
                  'string',
              ],
              ResourceType='VPC'|'Subnet'|'NetworkInterface',
              TrafficType='ACCEPT'|'REJECT'|'ALL',
              LogDestinationType='cloud-watch-logs'|'s3',
              LogDestination='string'
          )
        
        **Response Syntax**
        ::
            {
                'ClientToken': 'string',
                'FlowLogIds': [
                    'string',
                ],
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientToken** *(string) --* 
              Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
            - **FlowLogIds** *(list) --* 
              The IDs of the flow logs.
              - *(string) --* 
            - **Unsuccessful** *(list) --* 
              Information about the flow logs that could not be created successfully.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ .
        :type DeliverLogsPermissionArn: string
        :param DeliverLogsPermissionArn:
          The ARN for the IAM role that permits Amazon EC2 to publish flow logs to a CloudWatch Logs log group in your account.
          If you specify ``LogDestinationType`` as ``s3`` , do not specify ``DeliverLogsPermissionArn`` or ``LogGroupName`` .
        :type LogGroupName: string
        :param LogGroupName:
          The name of a new or existing CloudWatch Logs log group where Amazon EC2 publishes your flow logs.
          If you specify ``LogDestinationType`` as ``s3`` , do not specify ``DeliverLogsPermissionArn`` or ``LogGroupName`` .
        :type ResourceIds: list
        :param ResourceIds: **[REQUIRED]**
          The ID of the subnet, network interface, or VPC for which you want to create a flow log.
          Constraints: Maximum of 1000 resources
          - *(string) --*
        :type ResourceType: string
        :param ResourceType: **[REQUIRED]**
          The type of resource for which to create the flow log. For example, if you specified a VPC ID for the ``ResourceId`` property, specify ``VPC`` for this property.
        :type TrafficType: string
        :param TrafficType: **[REQUIRED]**
          The type of traffic to log. You can log traffic that the resource accepts or rejects, or all traffic.
        :type LogDestinationType: string
        :param LogDestinationType:
          Specifies the type of destination to which the flow log data is to be published. Flow log data can be published to CloudWatch Logs or Amazon S3. To publish flow log data to CloudWatch Logs, specify ``cloud-watch-logs`` . To publish flow log data to Amazon S3, specify ``s3`` .
          If you specify ``LogDestinationType`` as ``s3`` , do not specify ``DeliverLogsPermissionArn`` or ``LogGroupName`` .
          Default: ``cloud-watch-logs``
        :type LogDestination: string
        :param LogDestination:
          Specifies the destination to which the flow log data is to be published. Flow log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket. The value specified for this parameter depends on the value specified for ``LogDestinationType`` .
          If LogDestinationType is not specified or ``cloud-watch-logs`` , specify the Amazon Resource Name (ARN) of the CloudWatch Logs log group.
          If LogDestinationType is ``s3`` , specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the bucket. To specify a subfolder in the bucket, use the following ARN format: ``bucket_ARN/subfolder_name/`` . For example, to specify a subfolder named ``my-logs`` in a bucket named ``my-bucket`` , use the following ARN: ``arn:aws:s3:::my-bucket/my-logs/`` . You cannot use ``AWSLogs`` as a subfolder name. This is a reserved term.
        :rtype: dict
        :returns:
        """
        pass

    def create_fpga_image(self, InputStorageLocation: Dict, DryRun: bool = None, LogsStorageLocation: Dict = None, Description: str = None, Name: str = None, ClientToken: str = None) -> Dict:
        """
        Creates an Amazon FPGA Image (AFI) from the specified design checkpoint (DCP).
        The create operation is asynchronous. To verify that the AFI is ready for use, check the output logs.
        An AFI contains the FPGA bitstream that is ready to download to an FPGA. You can securely deploy an AFI on multiple FPGA-accelerated instances. For more information, see the `AWS FPGA Hardware Development Kit <https://github.com/aws/aws-fpga/>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateFpgaImage>`_
        
        **Request Syntax**
        ::
          response = client.create_fpga_image(
              DryRun=True|False,
              InputStorageLocation={
                  'Bucket': 'string',
                  'Key': 'string'
              },
              LogsStorageLocation={
                  'Bucket': 'string',
                  'Key': 'string'
              },
              Description='string',
              Name='string',
              ClientToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'FpgaImageId': 'string',
                'FpgaImageGlobalId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **FpgaImageId** *(string) --* 
              The FPGA image identifier (AFI ID).
            - **FpgaImageGlobalId** *(string) --* 
              The global FPGA image identifier (AGFI ID).
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InputStorageLocation: dict
        :param InputStorageLocation: **[REQUIRED]**
          The location of the encrypted design checkpoint in Amazon S3. The input must be a tarball.
          - **Bucket** *(string) --*
            The name of the S3 bucket.
          - **Key** *(string) --*
            The key.
        :type LogsStorageLocation: dict
        :param LogsStorageLocation:
          The location in Amazon S3 for the output logs.
          - **Bucket** *(string) --*
            The name of the S3 bucket.
          - **Key** *(string) --*
            The key.
        :type Description: string
        :param Description:
          A description for the AFI.
        :type Name: string
        :param Name:
          A name for the AFI.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ .
        :rtype: dict
        :returns:
        """
        pass

    def create_image(self, InstanceId: str, Name: str, BlockDeviceMappings: List = None, Description: str = None, DryRun: bool = None, NoReboot: bool = None) -> Dict:
        """
        Creates an Amazon EBS-backed AMI from an Amazon EBS-backed instance that is either running or stopped.
        If you customized your instance with instance store volumes or EBS volumes in addition to the root device volume, the new AMI contains block device mapping information for those volumes. When you launch an instance from this new AMI, the instance automatically launches with those additional volumes.
        For more information, see `Creating Amazon EBS-Backed Linux AMIs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/creating-an-ami-ebs.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateImage>`_
        
        **Request Syntax**
        ::
          response = client.create_image(
              BlockDeviceMappings=[
                  {
                      'DeviceName': 'string',
                      'VirtualName': 'string',
                      'Ebs': {
                          'DeleteOnTermination': True|False,
                          'Iops': 123,
                          'SnapshotId': 'string',
                          'VolumeSize': 123,
                          'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                          'Encrypted': True|False,
                          'KmsKeyId': 'string'
                      },
                      'NoDevice': 'string'
                  },
              ],
              Description='string',
              DryRun=True|False,
              InstanceId='string',
              Name='string',
              NoReboot=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ImageId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ImageId** *(string) --* 
              The ID of the new AMI.
        :type BlockDeviceMappings: list
        :param BlockDeviceMappings:
          Tthe block device mappings. This parameter cannot be used to modify the encryption status of existing volumes or snapshots. To create an AMI with encrypted snapshots, use the  CopyImage action.
          - *(dict) --*
            Describes a block device mapping.
            - **DeviceName** *(string) --*
              The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
            - **VirtualName** *(string) --*
              The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
              NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
              Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
            - **Ebs** *(dict) --*
              Parameters used to automatically set up EBS volumes when the instance is launched.
              - **DeleteOnTermination** *(boolean) --*
                Indicates whether the EBS volume is deleted on instance termination.
              - **Iops** *(integer) --*
                The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
              - **SnapshotId** *(string) --*
                The ID of the snapshot.
              - **VolumeSize** *(integer) --*
                The size of the volume, in GiB.
                Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
              - **VolumeType** *(string) --*
                The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                Default: ``standard``
              - **Encrypted** *(boolean) --*
                Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
              - **KmsKeyId** *(string) --*
                Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
            - **NoDevice** *(string) --*
              Suppresses the specified device included in the block device mapping of the AMI.
        :type Description: string
        :param Description:
          A description for the new image.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type Name: string
        :param Name: **[REQUIRED]**
          A name for the new image.
          Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes (\'), at-signs (@), or underscores(_)
        :type NoReboot: boolean
        :param NoReboot:
          By default, Amazon EC2 attempts to shut down and reboot the instance before creating the image. If the \'No Reboot\' option is set, Amazon EC2 doesn\'t shut down the instance before creating the image. When this option is used, file system integrity on the created image can\'t be guaranteed.
        :rtype: dict
        :returns:
        """
        pass

    def create_instance_export_task(self, InstanceId: str, Description: str = None, ExportToS3Task: Dict = None, TargetEnvironment: str = None) -> Dict:
        """
        Exports a running or stopped instance to an S3 bucket.
        For information about the supported operating systems, image formats, and known limitations for the types of instances you can export, see `Exporting an Instance as a VM Using VM Import/Export <https://docs.aws.amazon.com/vm-import/latest/userguide/vmexport.html>`__ in the *VM Import/Export User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateInstanceExportTask>`_
        
        **Request Syntax**
        ::
          response = client.create_instance_export_task(
              Description='string',
              ExportToS3Task={
                  'ContainerFormat': 'ova',
                  'DiskImageFormat': 'VMDK'|'RAW'|'VHD',
                  'S3Bucket': 'string',
                  'S3Prefix': 'string'
              },
              InstanceId='string',
              TargetEnvironment='citrix'|'vmware'|'microsoft'
          )
        
        **Response Syntax**
        ::
            {
                'ExportTask': {
                    'Description': 'string',
                    'ExportTaskId': 'string',
                    'ExportToS3Task': {
                        'ContainerFormat': 'ova',
                        'DiskImageFormat': 'VMDK'|'RAW'|'VHD',
                        'S3Bucket': 'string',
                        'S3Key': 'string'
                    },
                    'InstanceExportDetails': {
                        'InstanceId': 'string',
                        'TargetEnvironment': 'citrix'|'vmware'|'microsoft'
                    },
                    'State': 'active'|'cancelling'|'cancelled'|'completed',
                    'StatusMessage': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for CreateInstanceExportTask.
            - **ExportTask** *(dict) --* 
              Information about the instance export task.
              - **Description** *(string) --* 
                A description of the resource being exported.
              - **ExportTaskId** *(string) --* 
                The ID of the export task.
              - **ExportToS3Task** *(dict) --* 
                Information about the export task.
                - **ContainerFormat** *(string) --* 
                  The container format used to combine disk images with metadata (such as OVF). If absent, only the disk image is exported.
                - **DiskImageFormat** *(string) --* 
                  The format for the exported image.
                - **S3Bucket** *(string) --* 
                  The S3 bucket for the destination image. The destination bucket must exist and grant WRITE and READ_ACP permissions to the AWS account ``vm-import-export@amazon.com`` .
                - **S3Key** *(string) --* 
                  The encryption key for your S3 bucket.
              - **InstanceExportDetails** *(dict) --* 
                Information about the instance to export.
                - **InstanceId** *(string) --* 
                  The ID of the resource being exported.
                - **TargetEnvironment** *(string) --* 
                  The target virtualization environment.
              - **State** *(string) --* 
                The state of the export task.
              - **StatusMessage** *(string) --* 
                The status message related to the export task.
        :type Description: string
        :param Description:
          A description for the conversion task or the resource being exported. The maximum length is 255 bytes.
        :type ExportToS3Task: dict
        :param ExportToS3Task:
          The format and location for an instance export task.
          - **ContainerFormat** *(string) --*
            The container format used to combine disk images with metadata (such as OVF). If absent, only the disk image is exported.
          - **DiskImageFormat** *(string) --*
            The format for the exported image.
          - **S3Bucket** *(string) --*
            The S3 bucket for the destination image. The destination bucket must exist and grant WRITE and READ_ACP permissions to the AWS account ``vm-import-export@amazon.com`` .
          - **S3Prefix** *(string) --*
            The image is written to a single object in the S3 bucket at the S3 key s3prefix + exportTaskId + \'.\' + diskImageFormat.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type TargetEnvironment: string
        :param TargetEnvironment:
          The target virtualization environment.
        :rtype: dict
        :returns:
        """
        pass

    def create_internet_gateway(self, DryRun: bool = None) -> Dict:
        """
        Creates an internet gateway for use with a VPC. After creating the internet gateway, you attach it to a VPC using  AttachInternetGateway .
        For more information about your VPC and internet gateway, see the `Amazon Virtual Private Cloud User Guide <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateInternetGateway>`_
        
        **Request Syntax**
        ::
          response = client.create_internet_gateway(
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'InternetGateway': {
                    'Attachments': [
                        {
                            'State': 'attaching'|'attached'|'detaching'|'detached',
                            'VpcId': 'string'
                        },
                    ],
                    'InternetGatewayId': 'string',
                    'OwnerId': 'string',
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InternetGateway** *(dict) --* 
              Information about the internet gateway.
              - **Attachments** *(list) --* 
                Any VPCs attached to the internet gateway.
                - *(dict) --* 
                  Describes the attachment of a VPC to an internet gateway or an egress-only internet gateway.
                  - **State** *(string) --* 
                    The current state of the attachment. For an internet gateway, the state is ``available`` when attached to a VPC; otherwise, this value is not returned.
                  - **VpcId** *(string) --* 
                    The ID of the VPC.
              - **InternetGatewayId** *(string) --* 
                The ID of the internet gateway.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the internet gateway.
              - **Tags** *(list) --* 
                Any tags assigned to the internet gateway.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_key_pair(self, KeyName: str, DryRun: bool = None) -> Dict:
        """
        Creates a 2048-bit RSA key pair with the specified name. Amazon EC2 stores the public key and displays the private key for you to save to a file. The private key is returned as an unencrypted PEM encoded PKCS#1 private key. If a key with the specified name already exists, Amazon EC2 returns an error.
        You can have up to five thousand key pairs per region.
        The key pair returned to you is available only in the region in which you create it. If you prefer, you can create your own key pair using a third-party tool and upload it to any region using  ImportKeyPair .
        For more information, see `Key Pairs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateKeyPair>`_
        
        **Request Syntax**
        ::
          response = client.create_key_pair(
              KeyName='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'KeyFingerprint': 'string',
                'KeyMaterial': 'string',
                'KeyName': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes a key pair.
            - **KeyFingerprint** *(string) --* 
              The SHA-1 digest of the DER encoded private key.
            - **KeyMaterial** *(string) --* 
              An unencrypted PEM encoded RSA private key.
            - **KeyName** *(string) --* 
              The name of the key pair.
        :type KeyName: string
        :param KeyName: **[REQUIRED]**
          A unique name for the key pair.
          Constraints: Up to 255 ASCII characters
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_launch_template(self, LaunchTemplateName: str, LaunchTemplateData: Dict, DryRun: bool = None, ClientToken: str = None, VersionDescription: str = None) -> Dict:
        """
        Creates a launch template. A launch template contains the parameters to launch an instance. When you launch an instance using  RunInstances , you can specify a launch template instead of providing the launch parameters in the request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateLaunchTemplate>`_
        
        **Request Syntax**
        ::
          response = client.create_launch_template(
              DryRun=True|False,
              ClientToken='string',
              LaunchTemplateName='string',
              VersionDescription='string',
              LaunchTemplateData={
                  'KernelId': 'string',
                  'EbsOptimized': True|False,
                  'IamInstanceProfile': {
                      'Arn': 'string',
                      'Name': 'string'
                  },
                  'BlockDeviceMappings': [
                      {
                          'DeviceName': 'string',
                          'VirtualName': 'string',
                          'Ebs': {
                              'Encrypted': True|False,
                              'DeleteOnTermination': True|False,
                              'Iops': 123,
                              'KmsKeyId': 'string',
                              'SnapshotId': 'string',
                              'VolumeSize': 123,
                              'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1'
                          },
                          'NoDevice': 'string'
                      },
                  ],
                  'NetworkInterfaces': [
                      {
                          'AssociatePublicIpAddress': True|False,
                          'DeleteOnTermination': True|False,
                          'Description': 'string',
                          'DeviceIndex': 123,
                          'Groups': [
                              'string',
                          ],
                          'InterfaceType': 'string',
                          'Ipv6AddressCount': 123,
                          'Ipv6Addresses': [
                              {
                                  'Ipv6Address': 'string'
                              },
                          ],
                          'NetworkInterfaceId': 'string',
                          'PrivateIpAddress': 'string',
                          'PrivateIpAddresses': [
                              {
                                  'Primary': True|False,
                                  'PrivateIpAddress': 'string'
                              },
                          ],
                          'SecondaryPrivateIpAddressCount': 123,
                          'SubnetId': 'string'
                      },
                  ],
                  'ImageId': 'string',
                  'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                  'KeyName': 'string',
                  'Monitoring': {
                      'Enabled': True|False
                  },
                  'Placement': {
                      'AvailabilityZone': 'string',
                      'Affinity': 'string',
                      'GroupName': 'string',
                      'HostId': 'string',
                      'Tenancy': 'default'|'dedicated'|'host',
                      'SpreadDomain': 'string'
                  },
                  'RamDiskId': 'string',
                  'DisableApiTermination': True|False,
                  'InstanceInitiatedShutdownBehavior': 'stop'|'terminate',
                  'UserData': 'string',
                  'TagSpecifications': [
                      {
                          'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                          'Tags': [
                              {
                                  'Key': 'string',
                                  'Value': 'string'
                              },
                          ]
                      },
                  ],
                  'ElasticGpuSpecifications': [
                      {
                          'Type': 'string'
                      },
                  ],
                  'ElasticInferenceAccelerators': [
                      {
                          'Type': 'string'
                      },
                  ],
                  'SecurityGroupIds': [
                      'string',
                  ],
                  'SecurityGroups': [
                      'string',
                  ],
                  'InstanceMarketOptions': {
                      'MarketType': 'spot',
                      'SpotOptions': {
                          'MaxPrice': 'string',
                          'SpotInstanceType': 'one-time'|'persistent',
                          'BlockDurationMinutes': 123,
                          'ValidUntil': datetime(2015, 1, 1),
                          'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                      }
                  },
                  'CreditSpecification': {
                      'CpuCredits': 'string'
                  },
                  'CpuOptions': {
                      'CoreCount': 123,
                      'ThreadsPerCore': 123
                  },
                  'CapacityReservationSpecification': {
                      'CapacityReservationPreference': 'open'|'none',
                      'CapacityReservationTarget': {
                          'CapacityReservationId': 'string'
                      }
                  },
                  'LicenseSpecifications': [
                      {
                          'LicenseConfigurationArn': 'string'
                      },
                  ],
                  'HibernationOptions': {
                      'Configured': True|False
                  }
              }
          )
        
        **Response Syntax**
        ::
            {
                'LaunchTemplate': {
                    'LaunchTemplateId': 'string',
                    'LaunchTemplateName': 'string',
                    'CreateTime': datetime(2015, 1, 1),
                    'CreatedBy': 'string',
                    'DefaultVersionNumber': 123,
                    'LatestVersionNumber': 123,
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **LaunchTemplate** *(dict) --* 
              Information about the launch template.
              - **LaunchTemplateId** *(string) --* 
                The ID of the launch template.
              - **LaunchTemplateName** *(string) --* 
                The name of the launch template.
              - **CreateTime** *(datetime) --* 
                The time launch template was created.
              - **CreatedBy** *(string) --* 
                The principal that created the launch template. 
              - **DefaultVersionNumber** *(integer) --* 
                The version number of the default version of the launch template.
              - **LatestVersionNumber** *(integer) --* 
                The version number of the latest version of the launch template.
              - **Tags** *(list) --* 
                The tags for the launch template.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          Constraint: Maximum 128 ASCII characters.
        :type LaunchTemplateName: string
        :param LaunchTemplateName: **[REQUIRED]**
          A name for the launch template.
        :type VersionDescription: string
        :param VersionDescription:
          A description for the first version of the launch template.
        :type LaunchTemplateData: dict
        :param LaunchTemplateData: **[REQUIRED]**
          The information for the launch template.
          - **KernelId** *(string) --*
            The ID of the kernel.
            .. warning::
              We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `User Provided Kernels <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **EbsOptimized** *(boolean) --*
            Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal Amazon EBS I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS-optimized instance.
          - **IamInstanceProfile** *(dict) --*
            The IAM instance profile.
            - **Arn** *(string) --*
              The Amazon Resource Name (ARN) of the instance profile.
            - **Name** *(string) --*
              The name of the instance profile.
          - **BlockDeviceMappings** *(list) --*
            The block device mapping.
            .. warning::
              Supplying both a snapshot ID and an encryption value as arguments for block-device mapping results in an error. This is because only blank volumes can be encrypted on start, and these are not created from a snapshot. If a snapshot is the basis for the volume, it contains data by definition and its encryption status cannot be changed using this action.
            - *(dict) --*
              Describes a block device mapping.
              - **DeviceName** *(string) --*
                The device name (for example, /dev/sdh or xvdh).
              - **VirtualName** *(string) --*
                The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
              - **Ebs** *(dict) --*
                Parameters used to automatically set up EBS volumes when the instance is launched.
                - **Encrypted** *(boolean) --*
                  Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption. If you are creating a volume from a snapshot, you can\'t specify an encryption value.
                - **DeleteOnTermination** *(boolean) --*
                  Indicates whether the EBS volume is deleted on instance termination.
                - **Iops** *(integer) --*
                  The number of I/O operations per second (IOPS) that the volume supports. For io1, this represents the number of IOPS that are provisioned for the volume. For gp2, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information about General Purpose SSD baseline performance, I/O credits, and bursting, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                  Condition: This parameter is required for requests to create io1 volumes; it is not used in requests to create gp2, st1, sc1, or standard volumes.
                - **KmsKeyId** *(string) --*
                  The ARN of the AWS Key Management Service (AWS KMS) CMK used for encryption.
                - **SnapshotId** *(string) --*
                  The ID of the snapshot.
                - **VolumeSize** *(integer) --*
                  The size of the volume, in GiB.
                  Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                - **VolumeType** *(string) --*
                  The volume type.
              - **NoDevice** *(string) --*
                Suppresses the specified device included in the block device mapping of the AMI.
          - **NetworkInterfaces** *(list) --*
            One or more network interfaces.
            - *(dict) --*
              The parameters for a network interface.
              - **AssociatePublicIpAddress** *(boolean) --*
                Associates a public IPv4 address with eth0 for a new network interface.
              - **DeleteOnTermination** *(boolean) --*
                Indicates whether the network interface is deleted when the instance is terminated.
              - **Description** *(string) --*
                A description for the network interface.
              - **DeviceIndex** *(integer) --*
                The device index for the network interface attachment.
              - **Groups** *(list) --*
                The IDs of one or more security groups.
                - *(string) --*
              - **InterfaceType** *(string) --*
                The type of networking interface.
              - **Ipv6AddressCount** *(integer) --*
                The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can\'t use this option if specifying specific IPv6 addresses.
              - **Ipv6Addresses** *(list) --*
                One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can\'t use this option if you\'re specifying a number of IPv6 addresses.
                - *(dict) --*
                  Describes an IPv6 address.
                  - **Ipv6Address** *(string) --*
                    The IPv6 address.
              - **NetworkInterfaceId** *(string) --*
                The ID of the network interface.
              - **PrivateIpAddress** *(string) --*
                The primary private IPv4 address of the network interface.
              - **PrivateIpAddresses** *(list) --*
                One or more private IPv4 addresses.
                - *(dict) --*
                  Describes a secondary private IPv4 address for a network interface.
                  - **Primary** *(boolean) --*
                    Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                  - **PrivateIpAddress** *(string) --*
                    The private IPv4 addresses.
              - **SecondaryPrivateIpAddressCount** *(integer) --*
                The number of secondary private IPv4 addresses to assign to a network interface.
              - **SubnetId** *(string) --*
                The ID of the subnet for the network interface.
          - **ImageId** *(string) --*
            The ID of the AMI, which you can get by using `DescribeImages <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImages.html>`__ .
          - **InstanceType** *(string) --*
            The instance type. For more information, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **KeyName** *(string) --*
            The name of the key pair. You can create a key pair using `CreateKeyPair <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateKeyPair.html>`__ or `ImportKeyPair <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportKeyPair.html>`__ .
            .. warning::
              If you do not specify a key pair, you can\'t connect to the instance unless you choose an AMI that is configured to allow users another way to log in.
          - **Monitoring** *(dict) --*
            The monitoring for the instance.
            - **Enabled** *(boolean) --*
              Specify ``true`` to enable detailed monitoring. Otherwise, basic monitoring is enabled.
          - **Placement** *(dict) --*
            The placement for the instance.
            - **AvailabilityZone** *(string) --*
              The Availability Zone for the instance.
            - **Affinity** *(string) --*
              The affinity setting for an instance on a Dedicated Host.
            - **GroupName** *(string) --*
              The name of the placement group for the instance.
            - **HostId** *(string) --*
              The ID of the Dedicated Host for the instance.
            - **Tenancy** *(string) --*
              The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware.
            - **SpreadDomain** *(string) --*
              Reserved for future use.
          - **RamDiskId** *(string) --*
            The ID of the RAM disk.
            .. warning::
              We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `User Provided Kernels <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **DisableApiTermination** *(boolean) --*
            If set to ``true`` , you can\'t terminate the instance using the Amazon EC2 console, CLI, or API. To change this attribute to ``false`` after launch, use `ModifyInstanceAttribute <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceAttribute.html>`__ .
          - **InstanceInitiatedShutdownBehavior** *(string) --*
            Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
            Default: ``stop``
          - **UserData** *(string) --*
            The Base64-encoded user data to make available to the instance. For more information, see `Running Commands on Your Linux Instance at Launch <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/user-data.html>`__ (Linux) and `Adding User Data <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2-instance-metadata.html#instancedata-add-user-data>`__ (Windows).
          - **TagSpecifications** *(list) --*
            The tags to apply to the resources during launch. You can only tag instances and volumes on launch. The specified tags are applied to all instances or volumes that are created during launch. To tag a resource after it has been created, see  CreateTags .
            - *(dict) --*
              The tags specification for the launch template.
              - **ResourceType** *(string) --*
                The type of resource to tag. Currently, the resource types that support tagging on creation are ``instance`` and ``volume`` . To tag a resource after it has been created, see  CreateTags .
              - **Tags** *(list) --*
                The tags to apply to the resource.
                - *(dict) --*
                  Describes a tag.
                  - **Key** *(string) --*
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --*
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
          - **ElasticGpuSpecifications** *(list) --*
            An elastic GPU to associate with the instance.
            - *(dict) --*
              A specification for an Elastic Graphics accelerator.
              - **Type** *(string) --* **[REQUIRED]**
                The type of Elastic Graphics accelerator.
          - **ElasticInferenceAccelerators** *(list) --*
            The elastic inference accelerator for the instance.
            - *(dict) --*
              Describes an elastic inference accelerator.
              - **Type** *(string) --* **[REQUIRED]**
                The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge.
          - **SecurityGroupIds** *(list) --*
            One or more security group IDs. You can create a security group using  CreateSecurityGroup . You cannot specify both a security group ID and security name in the same request.
            - *(string) --*
          - **SecurityGroups** *(list) --*
            [EC2-Classic, default VPC] One or more security group names. For a nondefault VPC, you must use security group IDs instead. You cannot specify both a security group ID and security name in the same request.
            - *(string) --*
          - **InstanceMarketOptions** *(dict) --*
            The market (purchasing) option for the instances.
            - **MarketType** *(string) --*
              The market type.
            - **SpotOptions** *(dict) --*
              The options for Spot Instances.
              - **MaxPrice** *(string) --*
                The maximum hourly price you\'re willing to pay for the Spot Instances.
              - **SpotInstanceType** *(string) --*
                The Spot Instance request type.
              - **BlockDurationMinutes** *(integer) --*
                The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
              - **ValidUntil** *(datetime) --*
                The end date of the request. For a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date and time is reached. The default end date is 7 days from the current date.
              - **InstanceInterruptionBehavior** *(string) --*
                The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
          - **CreditSpecification** *(dict) --*
            The credit option for CPU usage of the instance. Valid for T2 or T3 instances only.
            - **CpuCredits** *(string) --* **[REQUIRED]**
              The credit option for CPU usage of a T2 or T3 instance. Valid values are ``standard`` and ``unlimited`` .
          - **CpuOptions** *(dict) --*
            The CPU options for the instance. For more information, see `Optimizing CPU Options <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
            - **CoreCount** *(integer) --*
              The number of CPU cores for the instance.
            - **ThreadsPerCore** *(integer) --*
              The number of threads per CPU core. To disable Intel Hyper-Threading Technology for the instance, specify a value of 1. Otherwise, specify the default value of 2.
          - **CapacityReservationSpecification** *(dict) --*
            The Capacity Reservation targeting option. If you do not specify this parameter, the instance\'s Capacity Reservation preference defaults to ``open`` , which enables it to run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
            - **CapacityReservationPreference** *(string) --*
              Indicates the instance\'s Capacity Reservation preferences. Possible preferences include:
              * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
              * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity.
            - **CapacityReservationTarget** *(dict) --*
              Information about the target Capacity Reservation.
              - **CapacityReservationId** *(string) --*
                The ID of the Capacity Reservation.
          - **LicenseSpecifications** *(list) --*
            The license configurations.
            - *(dict) --*
              Describes a license configuration.
              - **LicenseConfigurationArn** *(string) --*
                The Amazon Resource Name (ARN) of the license configuration.
          - **HibernationOptions** *(dict) --*
            Indicates whether an instance is enabled for hibernation. This parameter is valid only if the instance meets the `hibernation prerequisites <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html#hibernating-prerequisites>`__ . Hibernation is currently supported only for Amazon Linux. For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
            - **Configured** *(boolean) --*
              If you set this parameter to ``true`` , the instance is enabled for hibernation.
              Default: ``false``
        :rtype: dict
        :returns:
        """
        pass

    def create_launch_template_version(self, LaunchTemplateData: Dict, DryRun: bool = None, ClientToken: str = None, LaunchTemplateId: str = None, LaunchTemplateName: str = None, SourceVersion: str = None, VersionDescription: str = None) -> Dict:
        """
        Creates a new version for a launch template. You can specify an existing version of launch template from which to base the new version.
        Launch template versions are numbered in the order in which they are created. You cannot specify, change, or replace the numbering of launch template versions.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateLaunchTemplateVersion>`_
        
        **Request Syntax**
        ::
          response = client.create_launch_template_version(
              DryRun=True|False,
              ClientToken='string',
              LaunchTemplateId='string',
              LaunchTemplateName='string',
              SourceVersion='string',
              VersionDescription='string',
              LaunchTemplateData={
                  'KernelId': 'string',
                  'EbsOptimized': True|False,
                  'IamInstanceProfile': {
                      'Arn': 'string',
                      'Name': 'string'
                  },
                  'BlockDeviceMappings': [
                      {
                          'DeviceName': 'string',
                          'VirtualName': 'string',
                          'Ebs': {
                              'Encrypted': True|False,
                              'DeleteOnTermination': True|False,
                              'Iops': 123,
                              'KmsKeyId': 'string',
                              'SnapshotId': 'string',
                              'VolumeSize': 123,
                              'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1'
                          },
                          'NoDevice': 'string'
                      },
                  ],
                  'NetworkInterfaces': [
                      {
                          'AssociatePublicIpAddress': True|False,
                          'DeleteOnTermination': True|False,
                          'Description': 'string',
                          'DeviceIndex': 123,
                          'Groups': [
                              'string',
                          ],
                          'InterfaceType': 'string',
                          'Ipv6AddressCount': 123,
                          'Ipv6Addresses': [
                              {
                                  'Ipv6Address': 'string'
                              },
                          ],
                          'NetworkInterfaceId': 'string',
                          'PrivateIpAddress': 'string',
                          'PrivateIpAddresses': [
                              {
                                  'Primary': True|False,
                                  'PrivateIpAddress': 'string'
                              },
                          ],
                          'SecondaryPrivateIpAddressCount': 123,
                          'SubnetId': 'string'
                      },
                  ],
                  'ImageId': 'string',
                  'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                  'KeyName': 'string',
                  'Monitoring': {
                      'Enabled': True|False
                  },
                  'Placement': {
                      'AvailabilityZone': 'string',
                      'Affinity': 'string',
                      'GroupName': 'string',
                      'HostId': 'string',
                      'Tenancy': 'default'|'dedicated'|'host',
                      'SpreadDomain': 'string'
                  },
                  'RamDiskId': 'string',
                  'DisableApiTermination': True|False,
                  'InstanceInitiatedShutdownBehavior': 'stop'|'terminate',
                  'UserData': 'string',
                  'TagSpecifications': [
                      {
                          'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                          'Tags': [
                              {
                                  'Key': 'string',
                                  'Value': 'string'
                              },
                          ]
                      },
                  ],
                  'ElasticGpuSpecifications': [
                      {
                          'Type': 'string'
                      },
                  ],
                  'ElasticInferenceAccelerators': [
                      {
                          'Type': 'string'
                      },
                  ],
                  'SecurityGroupIds': [
                      'string',
                  ],
                  'SecurityGroups': [
                      'string',
                  ],
                  'InstanceMarketOptions': {
                      'MarketType': 'spot',
                      'SpotOptions': {
                          'MaxPrice': 'string',
                          'SpotInstanceType': 'one-time'|'persistent',
                          'BlockDurationMinutes': 123,
                          'ValidUntil': datetime(2015, 1, 1),
                          'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                      }
                  },
                  'CreditSpecification': {
                      'CpuCredits': 'string'
                  },
                  'CpuOptions': {
                      'CoreCount': 123,
                      'ThreadsPerCore': 123
                  },
                  'CapacityReservationSpecification': {
                      'CapacityReservationPreference': 'open'|'none',
                      'CapacityReservationTarget': {
                          'CapacityReservationId': 'string'
                      }
                  },
                  'LicenseSpecifications': [
                      {
                          'LicenseConfigurationArn': 'string'
                      },
                  ],
                  'HibernationOptions': {
                      'Configured': True|False
                  }
              }
          )
        
        **Response Syntax**
        ::
            {
                'LaunchTemplateVersion': {
                    'LaunchTemplateId': 'string',
                    'LaunchTemplateName': 'string',
                    'VersionNumber': 123,
                    'VersionDescription': 'string',
                    'CreateTime': datetime(2015, 1, 1),
                    'CreatedBy': 'string',
                    'DefaultVersion': True|False,
                    'LaunchTemplateData': {
                        'KernelId': 'string',
                        'EbsOptimized': True|False,
                        'IamInstanceProfile': {
                            'Arn': 'string',
                            'Name': 'string'
                        },
                        'BlockDeviceMappings': [
                            {
                                'DeviceName': 'string',
                                'VirtualName': 'string',
                                'Ebs': {
                                    'Encrypted': True|False,
                                    'DeleteOnTermination': True|False,
                                    'Iops': 123,
                                    'KmsKeyId': 'string',
                                    'SnapshotId': 'string',
                                    'VolumeSize': 123,
                                    'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1'
                                },
                                'NoDevice': 'string'
                            },
                        ],
                        'NetworkInterfaces': [
                            {
                                'AssociatePublicIpAddress': True|False,
                                'DeleteOnTermination': True|False,
                                'Description': 'string',
                                'DeviceIndex': 123,
                                'Groups': [
                                    'string',
                                ],
                                'InterfaceType': 'string',
                                'Ipv6AddressCount': 123,
                                'Ipv6Addresses': [
                                    {
                                        'Ipv6Address': 'string'
                                    },
                                ],
                                'NetworkInterfaceId': 'string',
                                'PrivateIpAddress': 'string',
                                'PrivateIpAddresses': [
                                    {
                                        'Primary': True|False,
                                        'PrivateIpAddress': 'string'
                                    },
                                ],
                                'SecondaryPrivateIpAddressCount': 123,
                                'SubnetId': 'string'
                            },
                        ],
                        'ImageId': 'string',
                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                        'KeyName': 'string',
                        'Monitoring': {
                            'Enabled': True|False
                        },
                        'Placement': {
                            'AvailabilityZone': 'string',
                            'Affinity': 'string',
                            'GroupName': 'string',
                            'HostId': 'string',
                            'Tenancy': 'default'|'dedicated'|'host',
                            'SpreadDomain': 'string'
                        },
                        'RamDiskId': 'string',
                        'DisableApiTermination': True|False,
                        'InstanceInitiatedShutdownBehavior': 'stop'|'terminate',
                        'UserData': 'string',
                        'TagSpecifications': [
                            {
                                'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                                'Tags': [
                                    {
                                        'Key': 'string',
                                        'Value': 'string'
                                    },
                                ]
                            },
                        ],
                        'ElasticGpuSpecifications': [
                            {
                                'Type': 'string'
                            },
                        ],
                        'ElasticInferenceAccelerators': [
                            {
                                'Type': 'string'
                            },
                        ],
                        'SecurityGroupIds': [
                            'string',
                        ],
                        'SecurityGroups': [
                            'string',
                        ],
                        'InstanceMarketOptions': {
                            'MarketType': 'spot',
                            'SpotOptions': {
                                'MaxPrice': 'string',
                                'SpotInstanceType': 'one-time'|'persistent',
                                'BlockDurationMinutes': 123,
                                'ValidUntil': datetime(2015, 1, 1),
                                'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                            }
                        },
                        'CreditSpecification': {
                            'CpuCredits': 'string'
                        },
                        'CpuOptions': {
                            'CoreCount': 123,
                            'ThreadsPerCore': 123
                        },
                        'CapacityReservationSpecification': {
                            'CapacityReservationPreference': 'open'|'none',
                            'CapacityReservationTarget': {
                                'CapacityReservationId': 'string'
                            }
                        },
                        'LicenseSpecifications': [
                            {
                                'LicenseConfigurationArn': 'string'
                            },
                        ],
                        'HibernationOptions': {
                            'Configured': True|False
                        }
                    }
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **LaunchTemplateVersion** *(dict) --* 
              Information about the launch template version.
              - **LaunchTemplateId** *(string) --* 
                The ID of the launch template.
              - **LaunchTemplateName** *(string) --* 
                The name of the launch template.
              - **VersionNumber** *(integer) --* 
                The version number.
              - **VersionDescription** *(string) --* 
                The description for the version.
              - **CreateTime** *(datetime) --* 
                The time the version was created.
              - **CreatedBy** *(string) --* 
                The principal that created the version.
              - **DefaultVersion** *(boolean) --* 
                Indicates whether the version is the default version.
              - **LaunchTemplateData** *(dict) --* 
                Information about the launch template.
                - **KernelId** *(string) --* 
                  The ID of the kernel, if applicable.
                - **EbsOptimized** *(boolean) --* 
                  Indicates whether the instance is optimized for Amazon EBS I/O. 
                - **IamInstanceProfile** *(dict) --* 
                  The IAM instance profile.
                  - **Arn** *(string) --* 
                    The Amazon Resource Name (ARN) of the instance profile.
                  - **Name** *(string) --* 
                    The name of the instance profile.
                - **BlockDeviceMappings** *(list) --* 
                  The block device mappings.
                  - *(dict) --* 
                    Describes a block device mapping.
                    - **DeviceName** *(string) --* 
                      The device name.
                    - **VirtualName** *(string) --* 
                      The virtual device name (ephemeralN).
                    - **Ebs** *(dict) --* 
                      Information about the block device for an EBS volume.
                      - **Encrypted** *(boolean) --* 
                        Indicates whether the EBS volume is encrypted.
                      - **DeleteOnTermination** *(boolean) --* 
                        Indicates whether the EBS volume is deleted on instance termination.
                      - **Iops** *(integer) --* 
                        The number of I/O operations per second (IOPS) that the volume supports. 
                      - **KmsKeyId** *(string) --* 
                        The ARN of the AWS Key Management Service (AWS KMS) CMK used for encryption.
                      - **SnapshotId** *(string) --* 
                        The ID of the snapshot.
                      - **VolumeSize** *(integer) --* 
                        The size of the volume, in GiB.
                      - **VolumeType** *(string) --* 
                        The volume type.
                    - **NoDevice** *(string) --* 
                      Suppresses the specified device included in the block device mapping of the AMI.
                - **NetworkInterfaces** *(list) --* 
                  The network interfaces.
                  - *(dict) --* 
                    Describes a network interface.
                    - **AssociatePublicIpAddress** *(boolean) --* 
                      Indicates whether to associate a public IPv4 address with eth0 for a new network interface.
                    - **DeleteOnTermination** *(boolean) --* 
                      Indicates whether the network interface is deleted when the instance is terminated.
                    - **Description** *(string) --* 
                      A description for the network interface.
                    - **DeviceIndex** *(integer) --* 
                      The device index for the network interface attachment.
                    - **Groups** *(list) --* 
                      The IDs of one or more security groups.
                      - *(string) --* 
                    - **InterfaceType** *(string) --* 
                      The type of network interface.
                    - **Ipv6AddressCount** *(integer) --* 
                      The number of IPv6 addresses for the network interface.
                    - **Ipv6Addresses** *(list) --* 
                      The IPv6 addresses for the network interface.
                      - *(dict) --* 
                        Describes an IPv6 address.
                        - **Ipv6Address** *(string) --* 
                          The IPv6 address.
                    - **NetworkInterfaceId** *(string) --* 
                      The ID of the network interface.
                    - **PrivateIpAddress** *(string) --* 
                      The primary private IPv4 address of the network interface.
                    - **PrivateIpAddresses** *(list) --* 
                      One or more private IPv4 addresses.
                      - *(dict) --* 
                        Describes a secondary private IPv4 address for a network interface.
                        - **Primary** *(boolean) --* 
                          Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                        - **PrivateIpAddress** *(string) --* 
                          The private IPv4 addresses.
                    - **SecondaryPrivateIpAddressCount** *(integer) --* 
                      The number of secondary private IPv4 addresses for the network interface.
                    - **SubnetId** *(string) --* 
                      The ID of the subnet for the network interface.
                - **ImageId** *(string) --* 
                  The ID of the AMI that was used to launch the instance.
                - **InstanceType** *(string) --* 
                  The instance type.
                - **KeyName** *(string) --* 
                  The name of the key pair.
                - **Monitoring** *(dict) --* 
                  The monitoring for the instance.
                  - **Enabled** *(boolean) --* 
                    Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
                - **Placement** *(dict) --* 
                  The placement of the instance.
                  - **AvailabilityZone** *(string) --* 
                    The Availability Zone of the instance.
                  - **Affinity** *(string) --* 
                    The affinity setting for the instance on the Dedicated Host.
                  - **GroupName** *(string) --* 
                    The name of the placement group for the instance.
                  - **HostId** *(string) --* 
                    The ID of the Dedicated Host for the instance.
                  - **Tenancy** *(string) --* 
                    The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. 
                  - **SpreadDomain** *(string) --* 
                    Reserved for future use.
                - **RamDiskId** *(string) --* 
                  The ID of the RAM disk, if applicable.
                - **DisableApiTermination** *(boolean) --* 
                  If set to ``true`` , indicates that the instance cannot be terminated using the Amazon EC2 console, command line tool, or API.
                - **InstanceInitiatedShutdownBehavior** *(string) --* 
                  Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
                - **UserData** *(string) --* 
                  The user data for the instance. 
                - **TagSpecifications** *(list) --* 
                  The tags.
                  - *(dict) --* 
                    The tag specification for the launch template.
                    - **ResourceType** *(string) --* 
                      The type of resource.
                    - **Tags** *(list) --* 
                      The tags for the resource.
                      - *(dict) --* 
                        Describes a tag.
                        - **Key** *(string) --* 
                          The key of the tag.
                          Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                        - **Value** *(string) --* 
                          The value of the tag.
                          Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **ElasticGpuSpecifications** *(list) --* 
                  The elastic GPU specification.
                  - *(dict) --* 
                    Describes an elastic GPU.
                    - **Type** *(string) --* 
                      The elastic GPU type.
                - **ElasticInferenceAccelerators** *(list) --* 
                  The elastic inference accelerator for the instance. 
                  - *(dict) --* 
                    Describes an elastic inference accelerator. 
                    - **Type** *(string) --* 
                      The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge. 
                - **SecurityGroupIds** *(list) --* 
                  The security group IDs.
                  - *(string) --* 
                - **SecurityGroups** *(list) --* 
                  The security group names.
                  - *(string) --* 
                - **InstanceMarketOptions** *(dict) --* 
                  The market (purchasing) option for the instances.
                  - **MarketType** *(string) --* 
                    The market type.
                  - **SpotOptions** *(dict) --* 
                    The options for Spot Instances.
                    - **MaxPrice** *(string) --* 
                      The maximum hourly price you're willing to pay for the Spot Instances.
                    - **SpotInstanceType** *(string) --* 
                      The Spot Instance request type.
                    - **BlockDurationMinutes** *(integer) --* 
                      The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
                    - **ValidUntil** *(datetime) --* 
                      The end date of the request. For a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date and time is reached.
                    - **InstanceInterruptionBehavior** *(string) --* 
                      The behavior when a Spot Instance is interrupted.
                - **CreditSpecification** *(dict) --* 
                  The credit option for CPU usage of the instance.
                  - **CpuCredits** *(string) --* 
                    The credit option for CPU usage of a T2 or T3 instance. Valid values are ``standard`` and ``unlimited`` .
                - **CpuOptions** *(dict) --* 
                  The CPU options for the instance. For more information, see `Optimizing CPU Options <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                  - **CoreCount** *(integer) --* 
                    The number of CPU cores for the instance.
                  - **ThreadsPerCore** *(integer) --* 
                    The number of threads per CPU core.
                - **CapacityReservationSpecification** *(dict) --* 
                  Information about the Capacity Reservation targeting option.
                  - **CapacityReservationPreference** *(string) --* 
                    Indicates the instance's Capacity Reservation preferences. Possible preferences include:
                    * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone). 
                    * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity. 
                  - **CapacityReservationTarget** *(dict) --* 
                    Information about the target Capacity Reservation.
                    - **CapacityReservationId** *(string) --* 
                      The ID of the Capacity Reservation.
                - **LicenseSpecifications** *(list) --* 
                  The license configurations.
                  - *(dict) --* 
                    Describes a license configuration.
                    - **LicenseConfigurationArn** *(string) --* 
                      The Amazon Resource Name (ARN) of the license configuration.
                - **HibernationOptions** *(dict) --* 
                  Indicates whether an instance is configured for hibernation. For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                  - **Configured** *(boolean) --* 
                    If this parameter is set to ``true`` , the instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          Constraint: Maximum 128 ASCII characters.
        :type LaunchTemplateId: string
        :param LaunchTemplateId:
          The ID of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type LaunchTemplateName: string
        :param LaunchTemplateName:
          The name of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type SourceVersion: string
        :param SourceVersion:
          The version number of the launch template version on which to base the new version. The new version inherits the same launch parameters as the source version, except for parameters that you specify in LaunchTemplateData.
        :type VersionDescription: string
        :param VersionDescription:
          A description for the version of the launch template.
        :type LaunchTemplateData: dict
        :param LaunchTemplateData: **[REQUIRED]**
          The information for the launch template.
          - **KernelId** *(string) --*
            The ID of the kernel.
            .. warning::
              We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `User Provided Kernels <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **EbsOptimized** *(boolean) --*
            Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal Amazon EBS I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS-optimized instance.
          - **IamInstanceProfile** *(dict) --*
            The IAM instance profile.
            - **Arn** *(string) --*
              The Amazon Resource Name (ARN) of the instance profile.
            - **Name** *(string) --*
              The name of the instance profile.
          - **BlockDeviceMappings** *(list) --*
            The block device mapping.
            .. warning::
              Supplying both a snapshot ID and an encryption value as arguments for block-device mapping results in an error. This is because only blank volumes can be encrypted on start, and these are not created from a snapshot. If a snapshot is the basis for the volume, it contains data by definition and its encryption status cannot be changed using this action.
            - *(dict) --*
              Describes a block device mapping.
              - **DeviceName** *(string) --*
                The device name (for example, /dev/sdh or xvdh).
              - **VirtualName** *(string) --*
                The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
              - **Ebs** *(dict) --*
                Parameters used to automatically set up EBS volumes when the instance is launched.
                - **Encrypted** *(boolean) --*
                  Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption. If you are creating a volume from a snapshot, you can\'t specify an encryption value.
                - **DeleteOnTermination** *(boolean) --*
                  Indicates whether the EBS volume is deleted on instance termination.
                - **Iops** *(integer) --*
                  The number of I/O operations per second (IOPS) that the volume supports. For io1, this represents the number of IOPS that are provisioned for the volume. For gp2, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information about General Purpose SSD baseline performance, I/O credits, and bursting, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                  Condition: This parameter is required for requests to create io1 volumes; it is not used in requests to create gp2, st1, sc1, or standard volumes.
                - **KmsKeyId** *(string) --*
                  The ARN of the AWS Key Management Service (AWS KMS) CMK used for encryption.
                - **SnapshotId** *(string) --*
                  The ID of the snapshot.
                - **VolumeSize** *(integer) --*
                  The size of the volume, in GiB.
                  Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                - **VolumeType** *(string) --*
                  The volume type.
              - **NoDevice** *(string) --*
                Suppresses the specified device included in the block device mapping of the AMI.
          - **NetworkInterfaces** *(list) --*
            One or more network interfaces.
            - *(dict) --*
              The parameters for a network interface.
              - **AssociatePublicIpAddress** *(boolean) --*
                Associates a public IPv4 address with eth0 for a new network interface.
              - **DeleteOnTermination** *(boolean) --*
                Indicates whether the network interface is deleted when the instance is terminated.
              - **Description** *(string) --*
                A description for the network interface.
              - **DeviceIndex** *(integer) --*
                The device index for the network interface attachment.
              - **Groups** *(list) --*
                The IDs of one or more security groups.
                - *(string) --*
              - **InterfaceType** *(string) --*
                The type of networking interface.
              - **Ipv6AddressCount** *(integer) --*
                The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can\'t use this option if specifying specific IPv6 addresses.
              - **Ipv6Addresses** *(list) --*
                One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can\'t use this option if you\'re specifying a number of IPv6 addresses.
                - *(dict) --*
                  Describes an IPv6 address.
                  - **Ipv6Address** *(string) --*
                    The IPv6 address.
              - **NetworkInterfaceId** *(string) --*
                The ID of the network interface.
              - **PrivateIpAddress** *(string) --*
                The primary private IPv4 address of the network interface.
              - **PrivateIpAddresses** *(list) --*
                One or more private IPv4 addresses.
                - *(dict) --*
                  Describes a secondary private IPv4 address for a network interface.
                  - **Primary** *(boolean) --*
                    Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                  - **PrivateIpAddress** *(string) --*
                    The private IPv4 addresses.
              - **SecondaryPrivateIpAddressCount** *(integer) --*
                The number of secondary private IPv4 addresses to assign to a network interface.
              - **SubnetId** *(string) --*
                The ID of the subnet for the network interface.
          - **ImageId** *(string) --*
            The ID of the AMI, which you can get by using `DescribeImages <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImages.html>`__ .
          - **InstanceType** *(string) --*
            The instance type. For more information, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **KeyName** *(string) --*
            The name of the key pair. You can create a key pair using `CreateKeyPair <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateKeyPair.html>`__ or `ImportKeyPair <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportKeyPair.html>`__ .
            .. warning::
              If you do not specify a key pair, you can\'t connect to the instance unless you choose an AMI that is configured to allow users another way to log in.
          - **Monitoring** *(dict) --*
            The monitoring for the instance.
            - **Enabled** *(boolean) --*
              Specify ``true`` to enable detailed monitoring. Otherwise, basic monitoring is enabled.
          - **Placement** *(dict) --*
            The placement for the instance.
            - **AvailabilityZone** *(string) --*
              The Availability Zone for the instance.
            - **Affinity** *(string) --*
              The affinity setting for an instance on a Dedicated Host.
            - **GroupName** *(string) --*
              The name of the placement group for the instance.
            - **HostId** *(string) --*
              The ID of the Dedicated Host for the instance.
            - **Tenancy** *(string) --*
              The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware.
            - **SpreadDomain** *(string) --*
              Reserved for future use.
          - **RamDiskId** *(string) --*
            The ID of the RAM disk.
            .. warning::
              We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `User Provided Kernels <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **DisableApiTermination** *(boolean) --*
            If set to ``true`` , you can\'t terminate the instance using the Amazon EC2 console, CLI, or API. To change this attribute to ``false`` after launch, use `ModifyInstanceAttribute <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceAttribute.html>`__ .
          - **InstanceInitiatedShutdownBehavior** *(string) --*
            Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
            Default: ``stop``
          - **UserData** *(string) --*
            The Base64-encoded user data to make available to the instance. For more information, see `Running Commands on Your Linux Instance at Launch <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/user-data.html>`__ (Linux) and `Adding User Data <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2-instance-metadata.html#instancedata-add-user-data>`__ (Windows).
          - **TagSpecifications** *(list) --*
            The tags to apply to the resources during launch. You can only tag instances and volumes on launch. The specified tags are applied to all instances or volumes that are created during launch. To tag a resource after it has been created, see  CreateTags .
            - *(dict) --*
              The tags specification for the launch template.
              - **ResourceType** *(string) --*
                The type of resource to tag. Currently, the resource types that support tagging on creation are ``instance`` and ``volume`` . To tag a resource after it has been created, see  CreateTags .
              - **Tags** *(list) --*
                The tags to apply to the resource.
                - *(dict) --*
                  Describes a tag.
                  - **Key** *(string) --*
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --*
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
          - **ElasticGpuSpecifications** *(list) --*
            An elastic GPU to associate with the instance.
            - *(dict) --*
              A specification for an Elastic Graphics accelerator.
              - **Type** *(string) --* **[REQUIRED]**
                The type of Elastic Graphics accelerator.
          - **ElasticInferenceAccelerators** *(list) --*
            The elastic inference accelerator for the instance.
            - *(dict) --*
              Describes an elastic inference accelerator.
              - **Type** *(string) --* **[REQUIRED]**
                The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge.
          - **SecurityGroupIds** *(list) --*
            One or more security group IDs. You can create a security group using  CreateSecurityGroup . You cannot specify both a security group ID and security name in the same request.
            - *(string) --*
          - **SecurityGroups** *(list) --*
            [EC2-Classic, default VPC] One or more security group names. For a nondefault VPC, you must use security group IDs instead. You cannot specify both a security group ID and security name in the same request.
            - *(string) --*
          - **InstanceMarketOptions** *(dict) --*
            The market (purchasing) option for the instances.
            - **MarketType** *(string) --*
              The market type.
            - **SpotOptions** *(dict) --*
              The options for Spot Instances.
              - **MaxPrice** *(string) --*
                The maximum hourly price you\'re willing to pay for the Spot Instances.
              - **SpotInstanceType** *(string) --*
                The Spot Instance request type.
              - **BlockDurationMinutes** *(integer) --*
                The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
              - **ValidUntil** *(datetime) --*
                The end date of the request. For a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date and time is reached. The default end date is 7 days from the current date.
              - **InstanceInterruptionBehavior** *(string) --*
                The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
          - **CreditSpecification** *(dict) --*
            The credit option for CPU usage of the instance. Valid for T2 or T3 instances only.
            - **CpuCredits** *(string) --* **[REQUIRED]**
              The credit option for CPU usage of a T2 or T3 instance. Valid values are ``standard`` and ``unlimited`` .
          - **CpuOptions** *(dict) --*
            The CPU options for the instance. For more information, see `Optimizing CPU Options <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
            - **CoreCount** *(integer) --*
              The number of CPU cores for the instance.
            - **ThreadsPerCore** *(integer) --*
              The number of threads per CPU core. To disable Intel Hyper-Threading Technology for the instance, specify a value of 1. Otherwise, specify the default value of 2.
          - **CapacityReservationSpecification** *(dict) --*
            The Capacity Reservation targeting option. If you do not specify this parameter, the instance\'s Capacity Reservation preference defaults to ``open`` , which enables it to run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
            - **CapacityReservationPreference** *(string) --*
              Indicates the instance\'s Capacity Reservation preferences. Possible preferences include:
              * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
              * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity.
            - **CapacityReservationTarget** *(dict) --*
              Information about the target Capacity Reservation.
              - **CapacityReservationId** *(string) --*
                The ID of the Capacity Reservation.
          - **LicenseSpecifications** *(list) --*
            The license configurations.
            - *(dict) --*
              Describes a license configuration.
              - **LicenseConfigurationArn** *(string) --*
                The Amazon Resource Name (ARN) of the license configuration.
          - **HibernationOptions** *(dict) --*
            Indicates whether an instance is enabled for hibernation. This parameter is valid only if the instance meets the `hibernation prerequisites <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html#hibernating-prerequisites>`__ . Hibernation is currently supported only for Amazon Linux. For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
            - **Configured** *(boolean) --*
              If you set this parameter to ``true`` , the instance is enabled for hibernation.
              Default: ``false``
        :rtype: dict
        :returns:
        """
        pass

    def create_nat_gateway(self, AllocationId: str, SubnetId: str, ClientToken: str = None) -> Dict:
        """
        Creates a NAT gateway in the specified public subnet. This action creates a network interface in the specified subnet with a private IP address from the IP address range of the subnet. Internet-bound traffic from a private subnet can be routed to the NAT gateway, therefore enabling instances in the private subnet to connect to the internet. For more information, see `NAT Gateways <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateNatGateway>`_
        
        **Request Syntax**
        ::
          response = client.create_nat_gateway(
              AllocationId='string',
              ClientToken='string',
              SubnetId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ClientToken': 'string',
                'NatGateway': {
                    'CreateTime': datetime(2015, 1, 1),
                    'DeleteTime': datetime(2015, 1, 1),
                    'FailureCode': 'string',
                    'FailureMessage': 'string',
                    'NatGatewayAddresses': [
                        {
                            'AllocationId': 'string',
                            'NetworkInterfaceId': 'string',
                            'PrivateIp': 'string',
                            'PublicIp': 'string'
                        },
                    ],
                    'NatGatewayId': 'string',
                    'ProvisionedBandwidth': {
                        'ProvisionTime': datetime(2015, 1, 1),
                        'Provisioned': 'string',
                        'RequestTime': datetime(2015, 1, 1),
                        'Requested': 'string',
                        'Status': 'string'
                    },
                    'State': 'pending'|'failed'|'available'|'deleting'|'deleted',
                    'SubnetId': 'string',
                    'VpcId': 'string',
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientToken** *(string) --* 
              Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
            - **NatGateway** *(dict) --* 
              Information about the NAT gateway.
              - **CreateTime** *(datetime) --* 
                The date and time the NAT gateway was created.
              - **DeleteTime** *(datetime) --* 
                The date and time the NAT gateway was deleted, if applicable.
              - **FailureCode** *(string) --* 
                If the NAT gateway could not be created, specifies the error code for the failure. (``InsufficientFreeAddressesInSubnet`` | ``Gateway.NotAttached`` | ``InvalidAllocationID.NotFound`` | ``Resource.AlreadyAssociated`` | ``InternalError`` | ``InvalidSubnetID.NotFound`` )
              - **FailureMessage** *(string) --* 
                If the NAT gateway could not be created, specifies the error message for the failure, that corresponds to the error code.
                * For InsufficientFreeAddressesInSubnet: "Subnet has insufficient free addresses to create this NAT gateway" 
                * For Gateway.NotAttached: "Network vpc-xxxxxxxx has no Internet gateway attached" 
                * For InvalidAllocationID.NotFound: "Elastic IP address eipalloc-xxxxxxxx could not be associated with this NAT gateway" 
                * For Resource.AlreadyAssociated: "Elastic IP address eipalloc-xxxxxxxx is already associated" 
                * For InternalError: "Network interface eni-xxxxxxxx, created and used internally by this NAT gateway is in an invalid state. Please try again." 
                * For InvalidSubnetID.NotFound: "The specified subnet subnet-xxxxxxxx does not exist or could not be found." 
              - **NatGatewayAddresses** *(list) --* 
                Information about the IP addresses and network interface associated with the NAT gateway.
                - *(dict) --* 
                  Describes the IP addresses and network interface associated with a NAT gateway.
                  - **AllocationId** *(string) --* 
                    The allocation ID of the Elastic IP address that's associated with the NAT gateway.
                  - **NetworkInterfaceId** *(string) --* 
                    The ID of the network interface associated with the NAT gateway.
                  - **PrivateIp** *(string) --* 
                    The private IP address associated with the Elastic IP address.
                  - **PublicIp** *(string) --* 
                    The Elastic IP address associated with the NAT gateway.
              - **NatGatewayId** *(string) --* 
                The ID of the NAT gateway.
              - **ProvisionedBandwidth** *(dict) --* 
                Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                - **ProvisionTime** *(datetime) --* 
                  Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                - **Provisioned** *(string) --* 
                  Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                - **RequestTime** *(datetime) --* 
                  Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                - **Requested** *(string) --* 
                  Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                - **Status** *(string) --* 
                  Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
              - **State** *(string) --* 
                The state of the NAT gateway.
                * ``pending`` : The NAT gateway is being created and is not ready to process traffic. 
                * ``failed`` : The NAT gateway could not be created. Check the ``failureCode`` and ``failureMessage`` fields for the reason. 
                * ``available`` : The NAT gateway is able to process traffic. This status remains until you delete the NAT gateway, and does not indicate the health of the NAT gateway. 
                * ``deleting`` : The NAT gateway is in the process of being terminated and may still be processing traffic. 
                * ``deleted`` : The NAT gateway has been terminated and is no longer processing traffic. 
              - **SubnetId** *(string) --* 
                The ID of the subnet in which the NAT gateway is located.
              - **VpcId** *(string) --* 
                The ID of the VPC in which the NAT gateway is located.
              - **Tags** *(list) --* 
                The tags for the NAT gateway.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type AllocationId: string
        :param AllocationId: **[REQUIRED]**
          The allocation ID of an Elastic IP address to associate with the NAT gateway. If the Elastic IP address is associated with another resource, you must first disassociate it.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          Constraint: Maximum 64 ASCII characters.
        :type SubnetId: string
        :param SubnetId: **[REQUIRED]**
          The subnet in which to create the NAT gateway.
        :rtype: dict
        :returns:
        """
        pass

    def create_network_acl(self, VpcId: str, DryRun: bool = None) -> Dict:
        """
        Creates a network ACL in a VPC. Network ACLs provide an optional layer of security (in addition to security groups) for the instances in your VPC.
        For more information, see `Network ACLs <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_ACLs.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateNetworkAcl>`_
        
        **Request Syntax**
        ::
          response = client.create_network_acl(
              DryRun=True|False,
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NetworkAcl': {
                    'Associations': [
                        {
                            'NetworkAclAssociationId': 'string',
                            'NetworkAclId': 'string',
                            'SubnetId': 'string'
                        },
                    ],
                    'Entries': [
                        {
                            'CidrBlock': 'string',
                            'Egress': True|False,
                            'IcmpTypeCode': {
                                'Code': 123,
                                'Type': 123
                            },
                            'Ipv6CidrBlock': 'string',
                            'PortRange': {
                                'From': 123,
                                'To': 123
                            },
                            'Protocol': 'string',
                            'RuleAction': 'allow'|'deny',
                            'RuleNumber': 123
                        },
                    ],
                    'IsDefault': True|False,
                    'NetworkAclId': 'string',
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'VpcId': 'string',
                    'OwnerId': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NetworkAcl** *(dict) --* 
              Information about the network ACL.
              - **Associations** *(list) --* 
                Any associations between the network ACL and one or more subnets
                - *(dict) --* 
                  Describes an association between a network ACL and a subnet.
                  - **NetworkAclAssociationId** *(string) --* 
                    The ID of the association between a network ACL and a subnet.
                  - **NetworkAclId** *(string) --* 
                    The ID of the network ACL.
                  - **SubnetId** *(string) --* 
                    The ID of the subnet.
              - **Entries** *(list) --* 
                One or more entries (rules) in the network ACL.
                - *(dict) --* 
                  Describes an entry in a network ACL.
                  - **CidrBlock** *(string) --* 
                    The IPv4 network range to allow or deny, in CIDR notation.
                  - **Egress** *(boolean) --* 
                    Indicates whether the rule is an egress rule (applied to traffic leaving the subnet).
                  - **IcmpTypeCode** *(dict) --* 
                    ICMP protocol: The ICMP type and code.
                    - **Code** *(integer) --* 
                      The ICMP code. A value of -1 means all codes for the specified ICMP type.
                    - **Type** *(integer) --* 
                      The ICMP type. A value of -1 means all types.
                  - **Ipv6CidrBlock** *(string) --* 
                    The IPv6 network range to allow or deny, in CIDR notation.
                  - **PortRange** *(dict) --* 
                    TCP or UDP protocols: The range of ports the rule applies to.
                    - **From** *(integer) --* 
                      The first port in the range.
                    - **To** *(integer) --* 
                      The last port in the range.
                  - **Protocol** *(string) --* 
                    The protocol number. A value of "-1" means all protocols.
                  - **RuleAction** *(string) --* 
                    Indicates whether to allow or deny the traffic that matches the rule.
                  - **RuleNumber** *(integer) --* 
                    The rule number for the entry. ACL entries are processed in ascending order by rule number.
              - **IsDefault** *(boolean) --* 
                Indicates whether this is the default network ACL for the VPC.
              - **NetworkAclId** *(string) --* 
                The ID of the network ACL.
              - **Tags** *(list) --* 
                Any tags assigned to the network ACL.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **VpcId** *(string) --* 
                The ID of the VPC for the network ACL.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the network ACL.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def create_network_acl_entry(self, Egress: bool, NetworkAclId: str, Protocol: str, RuleAction: str, RuleNumber: int, CidrBlock: str = None, DryRun: bool = None, IcmpTypeCode: Dict = None, Ipv6CidrBlock: str = None, PortRange: Dict = None):
        """
        Creates an entry (a rule) in a network ACL with the specified rule number. Each network ACL has a set of numbered ingress rules and a separate set of numbered egress rules. When determining whether a packet should be allowed in or out of a subnet associated with the ACL, we process the entries in the ACL according to the rule numbers, in ascending order. Each network ACL has a set of ingress rules and a separate set of egress rules.
        We recommend that you leave room between the rule numbers (for example, 100, 110, 120, ...), and not number them one right after the other (for example, 101, 102, 103, ...). This makes it easier to add a rule between existing ones without having to renumber the rules.
        After you add an entry, you can't modify it; you must either replace it, or create an entry and delete the old one.
        For more information about network ACLs, see `Network ACLs <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_ACLs.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateNetworkAclEntry>`_
        
        **Request Syntax**
        ::
          response = client.create_network_acl_entry(
              CidrBlock='string',
              DryRun=True|False,
              Egress=True|False,
              IcmpTypeCode={
                  'Code': 123,
                  'Type': 123
              },
              Ipv6CidrBlock='string',
              NetworkAclId='string',
              PortRange={
                  'From': 123,
                  'To': 123
              },
              Protocol='string',
              RuleAction='allow'|'deny',
              RuleNumber=123
          )
        :type CidrBlock: string
        :param CidrBlock:
          The IPv4 network range to allow or deny, in CIDR notation (for example ``172.16.0.0/24`` ).
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Egress: boolean
        :param Egress: **[REQUIRED]**
          Indicates whether this is an egress rule (rule is applied to traffic leaving the subnet).
        :type IcmpTypeCode: dict
        :param IcmpTypeCode:
          ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.
          - **Code** *(integer) --*
            The ICMP code. A value of -1 means all codes for the specified ICMP type.
          - **Type** *(integer) --*
            The ICMP type. A value of -1 means all types.
        :type Ipv6CidrBlock: string
        :param Ipv6CidrBlock:
          The IPv6 network range to allow or deny, in CIDR notation (for example ``2001:db8:1234:1a00::/64`` ).
        :type NetworkAclId: string
        :param NetworkAclId: **[REQUIRED]**
          The ID of the network ACL.
        :type PortRange: dict
        :param PortRange:
          TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).
          - **From** *(integer) --*
            The first port in the range.
          - **To** *(integer) --*
            The last port in the range.
        :type Protocol: string
        :param Protocol: **[REQUIRED]**
          The protocol number. A value of \"-1\" means all protocols. If you specify \"-1\" or a protocol number other than \"6\" (TCP), \"17\" (UDP), or \"1\" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol \"58\" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol \"58\" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.
        :type RuleAction: string
        :param RuleAction: **[REQUIRED]**
          Indicates whether to allow or deny the traffic that matches the rule.
        :type RuleNumber: integer
        :param RuleNumber: **[REQUIRED]**
          The rule number for the entry (for example, 100). ACL entries are processed in ascending order by rule number.
          Constraints: Positive integer from 1 to 32766. The range 32767 to 65535 is reserved for internal use.
        :returns: None
        """
        pass

    def create_network_interface(self, SubnetId: str, Description: str = None, DryRun: bool = None, Groups: List = None, Ipv6AddressCount: int = None, Ipv6Addresses: List = None, PrivateIpAddress: str = None, PrivateIpAddresses: List = None, SecondaryPrivateIpAddressCount: int = None, InterfaceType: str = None) -> Dict:
        """
        Creates a network interface in the specified subnet.
        For more information about network interfaces, see `Elastic Network Interfaces <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateNetworkInterface>`_
        
        **Request Syntax**
        ::
          response = client.create_network_interface(
              Description='string',
              DryRun=True|False,
              Groups=[
                  'string',
              ],
              Ipv6AddressCount=123,
              Ipv6Addresses=[
                  {
                      'Ipv6Address': 'string'
                  },
              ],
              PrivateIpAddress='string',
              PrivateIpAddresses=[
                  {
                      'Primary': True|False,
                      'PrivateIpAddress': 'string'
                  },
              ],
              SecondaryPrivateIpAddressCount=123,
              InterfaceType='efa',
              SubnetId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NetworkInterface': {
                    'Association': {
                        'AllocationId': 'string',
                        'AssociationId': 'string',
                        'IpOwnerId': 'string',
                        'PublicDnsName': 'string',
                        'PublicIp': 'string'
                    },
                    'Attachment': {
                        'AttachTime': datetime(2015, 1, 1),
                        'AttachmentId': 'string',
                        'DeleteOnTermination': True|False,
                        'DeviceIndex': 123,
                        'InstanceId': 'string',
                        'InstanceOwnerId': 'string',
                        'Status': 'attaching'|'attached'|'detaching'|'detached'
                    },
                    'AvailabilityZone': 'string',
                    'Description': 'string',
                    'Groups': [
                        {
                            'GroupName': 'string',
                            'GroupId': 'string'
                        },
                    ],
                    'InterfaceType': 'interface'|'natGateway'|'efa',
                    'Ipv6Addresses': [
                        {
                            'Ipv6Address': 'string'
                        },
                    ],
                    'MacAddress': 'string',
                    'NetworkInterfaceId': 'string',
                    'OwnerId': 'string',
                    'PrivateDnsName': 'string',
                    'PrivateIpAddress': 'string',
                    'PrivateIpAddresses': [
                        {
                            'Association': {
                                'AllocationId': 'string',
                                'AssociationId': 'string',
                                'IpOwnerId': 'string',
                                'PublicDnsName': 'string',
                                'PublicIp': 'string'
                            },
                            'Primary': True|False,
                            'PrivateDnsName': 'string',
                            'PrivateIpAddress': 'string'
                        },
                    ],
                    'RequesterId': 'string',
                    'RequesterManaged': True|False,
                    'SourceDestCheck': True|False,
                    'Status': 'available'|'associated'|'attaching'|'in-use'|'detaching',
                    'SubnetId': 'string',
                    'TagSet': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'VpcId': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateNetworkInterface.
            - **NetworkInterface** *(dict) --* 
              Information about the network interface.
              - **Association** *(dict) --* 
                The association information for an Elastic IP address (IPv4) associated with the network interface.
                - **AllocationId** *(string) --* 
                  The allocation ID.
                - **AssociationId** *(string) --* 
                  The association ID.
                - **IpOwnerId** *(string) --* 
                  The ID of the Elastic IP address owner.
                - **PublicDnsName** *(string) --* 
                  The public DNS name.
                - **PublicIp** *(string) --* 
                  The address of the Elastic IP address bound to the network interface.
              - **Attachment** *(dict) --* 
                The network interface attachment.
                - **AttachTime** *(datetime) --* 
                  The timestamp indicating when the attachment initiated.
                - **AttachmentId** *(string) --* 
                  The ID of the network interface attachment.
                - **DeleteOnTermination** *(boolean) --* 
                  Indicates whether the network interface is deleted when the instance is terminated.
                - **DeviceIndex** *(integer) --* 
                  The device index of the network interface attachment on the instance.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **InstanceOwnerId** *(string) --* 
                  The AWS account ID of the owner of the instance.
                - **Status** *(string) --* 
                  The attachment state.
              - **AvailabilityZone** *(string) --* 
                The Availability Zone.
              - **Description** *(string) --* 
                A description.
              - **Groups** *(list) --* 
                Any security groups for the network interface.
                - *(dict) --* 
                  Describes a security group.
                  - **GroupName** *(string) --* 
                    The name of the security group.
                  - **GroupId** *(string) --* 
                    The ID of the security group.
              - **InterfaceType** *(string) --* 
                The type of network interface.
              - **Ipv6Addresses** *(list) --* 
                The IPv6 addresses associated with the network interface.
                - *(dict) --* 
                  Describes an IPv6 address associated with a network interface.
                  - **Ipv6Address** *(string) --* 
                    The IPv6 address.
              - **MacAddress** *(string) --* 
                The MAC address.
              - **NetworkInterfaceId** *(string) --* 
                The ID of the network interface.
              - **OwnerId** *(string) --* 
                The AWS account ID of the owner of the network interface.
              - **PrivateDnsName** *(string) --* 
                The private DNS name.
              - **PrivateIpAddress** *(string) --* 
                The IPv4 address of the network interface within the subnet.
              - **PrivateIpAddresses** *(list) --* 
                The private IPv4 addresses associated with the network interface.
                - *(dict) --* 
                  Describes the private IPv4 address of a network interface.
                  - **Association** *(dict) --* 
                    The association information for an Elastic IP address (IPv4) associated with the network interface.
                    - **AllocationId** *(string) --* 
                      The allocation ID.
                    - **AssociationId** *(string) --* 
                      The association ID.
                    - **IpOwnerId** *(string) --* 
                      The ID of the Elastic IP address owner.
                    - **PublicDnsName** *(string) --* 
                      The public DNS name.
                    - **PublicIp** *(string) --* 
                      The address of the Elastic IP address bound to the network interface.
                  - **Primary** *(boolean) --* 
                    Indicates whether this IPv4 address is the primary private IPv4 address of the network interface.
                  - **PrivateDnsName** *(string) --* 
                    The private DNS name.
                  - **PrivateIpAddress** *(string) --* 
                    The private IPv4 address.
              - **RequesterId** *(string) --* 
                The ID of the entity that launched the instance on your behalf (for example, AWS Management Console or Auto Scaling).
              - **RequesterManaged** *(boolean) --* 
                Indicates whether the network interface is being managed by AWS.
              - **SourceDestCheck** *(boolean) --* 
                Indicates whether traffic to or from the instance is validated.
              - **Status** *(string) --* 
                The status of the network interface.
              - **SubnetId** *(string) --* 
                The ID of the subnet.
              - **TagSet** *(list) --* 
                Any tags assigned to the network interface.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **VpcId** *(string) --* 
                The ID of the VPC.
        :type Description: string
        :param Description:
          A description for the network interface.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Groups: list
        :param Groups:
          The IDs of one or more security groups.
          - *(string) --*
        :type Ipv6AddressCount: integer
        :param Ipv6AddressCount:
          The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can\'t use this option if specifying specific IPv6 addresses. If your subnet has the ``AssignIpv6AddressOnCreation`` attribute set to ``true`` , you can specify ``0`` to override this setting.
        :type Ipv6Addresses: list
        :param Ipv6Addresses:
          One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can\'t use this option if you\'re specifying a number of IPv6 addresses.
          - *(dict) --*
            Describes an IPv6 address.
            - **Ipv6Address** *(string) --*
              The IPv6 address.
        :type PrivateIpAddress: string
        :param PrivateIpAddress:
          The primary private IPv4 address of the network interface. If you don\'t specify an IPv4 address, Amazon EC2 selects one for you from the subnet\'s IPv4 CIDR range. If you specify an IP address, you cannot indicate any IP addresses specified in ``privateIpAddresses`` as primary (only one IP address can be designated as primary).
        :type PrivateIpAddresses: list
        :param PrivateIpAddresses:
          One or more private IPv4 addresses.
          - *(dict) --*
            Describes a secondary private IPv4 address for a network interface.
            - **Primary** *(boolean) --*
              Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
            - **PrivateIpAddress** *(string) --*
              The private IPv4 addresses.
        :type SecondaryPrivateIpAddressCount: integer
        :param SecondaryPrivateIpAddressCount:
          The number of secondary private IPv4 addresses to assign to a network interface. When you specify a number of secondary IPv4 addresses, Amazon EC2 selects these IP addresses within the subnet\'s IPv4 CIDR range. You can\'t specify this option and specify more than one private IP address using ``privateIpAddresses`` .
          The number of IP addresses you can assign to a network interface varies by instance type. For more information, see `IP Addresses Per ENI Per Instance Type <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI>`__ in the *Amazon Virtual Private Cloud User Guide* .
        :type InterfaceType: string
        :param InterfaceType:
          Indicates whether the network interface is an Elastic Fabric Adapter (EFA). Only specify this parameter to create an EFA. For more information, see `Elastic Fabric Adapter <AWSEC2/latest/UserGuide/efa.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          If you are not creating an EFA ENI, omit this parameter.
        :type SubnetId: string
        :param SubnetId: **[REQUIRED]**
          The ID of the subnet to associate with the network interface.
        :rtype: dict
        :returns:
        """
        pass

    def create_network_interface_permission(self, NetworkInterfaceId: str, Permission: str, AwsAccountId: str = None, AwsService: str = None, DryRun: bool = None) -> Dict:
        """
        Grants an AWS-authorized account permission to attach the specified network interface to an instance in their account.
        You can grant permission to a single AWS account only, and only one account at a time.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateNetworkInterfacePermission>`_
        
        **Request Syntax**
        ::
          response = client.create_network_interface_permission(
              NetworkInterfaceId='string',
              AwsAccountId='string',
              AwsService='string',
              Permission='INSTANCE-ATTACH'|'EIP-ASSOCIATE',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'InterfacePermission': {
                    'NetworkInterfacePermissionId': 'string',
                    'NetworkInterfaceId': 'string',
                    'AwsAccountId': 'string',
                    'AwsService': 'string',
                    'Permission': 'INSTANCE-ATTACH'|'EIP-ASSOCIATE',
                    'PermissionState': {
                        'State': 'pending'|'granted'|'revoking'|'revoked',
                        'StatusMessage': 'string'
                    }
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateNetworkInterfacePermission.
            - **InterfacePermission** *(dict) --* 
              Information about the permission for the network interface.
              - **NetworkInterfacePermissionId** *(string) --* 
                The ID of the network interface permission.
              - **NetworkInterfaceId** *(string) --* 
                The ID of the network interface.
              - **AwsAccountId** *(string) --* 
                The AWS account ID.
              - **AwsService** *(string) --* 
                The AWS service.
              - **Permission** *(string) --* 
                The type of permission.
              - **PermissionState** *(dict) --* 
                Information about the state of the permission.
                - **State** *(string) --* 
                  The state of the permission.
                - **StatusMessage** *(string) --* 
                  A status message, if applicable.
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :type AwsAccountId: string
        :param AwsAccountId:
          The AWS account ID.
        :type AwsService: string
        :param AwsService:
          The AWS service. Currently not supported.
        :type Permission: string
        :param Permission: **[REQUIRED]**
          The type of permission to grant.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_placement_group(self, DryRun: bool = None, GroupName: str = None, Strategy: str = None, PartitionCount: int = None):
        """
        Creates a placement group in which to launch instances. The strategy of the placement group determines how the instances are organized within the group. 
        A ``cluster`` placement group is a logical grouping of instances within a single Availability Zone that benefit from low network latency, high network throughput. A ``spread`` placement group places instances on distinct hardware. A ``partition`` placement group places groups of instances in different partitions, where instances in one partition do not share the same hardware with instances in another partition.
        For more information, see `Placement Groups <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreatePlacementGroup>`_
        
        **Request Syntax**
        ::
          response = client.create_placement_group(
              DryRun=True|False,
              GroupName='string',
              Strategy='cluster'|'spread'|'partition',
              PartitionCount=123
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupName: string
        :param GroupName:
          A name for the placement group. Must be unique within the scope of your account for the Region.
          Constraints: Up to 255 ASCII characters
        :type Strategy: string
        :param Strategy:
          The placement strategy.
        :type PartitionCount: integer
        :param PartitionCount:
          The number of partitions. Valid only when **Strategy** is set to ``partition`` .
        :returns: None
        """
        pass

    def create_reserved_instances_listing(self, ClientToken: str, InstanceCount: int, PriceSchedules: List, ReservedInstancesId: str) -> Dict:
        """
        Creates a listing for Amazon EC2 Standard Reserved Instances to be sold in the Reserved Instance Marketplace. You can submit one Standard Reserved Instance listing at a time. To get a list of your Standard Reserved Instances, you can use the  DescribeReservedInstances operation.
        .. note::
          Only Standard Reserved Instances can be sold in the Reserved Instance Marketplace. Convertible Reserved Instances cannot be sold.
        The Reserved Instance Marketplace matches sellers who want to resell Standard Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances.
        To sell your Standard Reserved Instances, you must first register as a seller in the Reserved Instance Marketplace. After completing the registration process, you can create a Reserved Instance Marketplace listing of some or all of your Standard Reserved Instances, and specify the upfront price to receive for them. Your Standard Reserved Instance listings then become available for purchase. To view the details of your Standard Reserved Instance listing, you can use the  DescribeReservedInstancesListings operation.
        For more information, see `Reserved Instance Marketplace <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateReservedInstancesListing>`_
        
        **Request Syntax**
        ::
          response = client.create_reserved_instances_listing(
              ClientToken='string',
              InstanceCount=123,
              PriceSchedules=[
                  {
                      'CurrencyCode': 'USD',
                      'Price': 123.0,
                      'Term': 123
                  },
              ],
              ReservedInstancesId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ReservedInstancesListings': [
                    {
                        'ClientToken': 'string',
                        'CreateDate': datetime(2015, 1, 1),
                        'InstanceCounts': [
                            {
                                'InstanceCount': 123,
                                'State': 'available'|'sold'|'cancelled'|'pending'
                            },
                        ],
                        'PriceSchedules': [
                            {
                                'Active': True|False,
                                'CurrencyCode': 'USD',
                                'Price': 123.0,
                                'Term': 123
                            },
                        ],
                        'ReservedInstancesId': 'string',
                        'ReservedInstancesListingId': 'string',
                        'Status': 'active'|'pending'|'cancelled'|'closed',
                        'StatusMessage': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'UpdateDate': datetime(2015, 1, 1)
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateReservedInstancesListing.
            - **ReservedInstancesListings** *(list) --* 
              Information about the Standard Reserved Instance listing.
              - *(dict) --* 
                Describes a Reserved Instance listing.
                - **ClientToken** *(string) --* 
                  A unique, case-sensitive key supplied by the client to ensure that the request is idempotent. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
                - **CreateDate** *(datetime) --* 
                  The time the listing was created.
                - **InstanceCounts** *(list) --* 
                  The number of instances in this state.
                  - *(dict) --* 
                    Describes a Reserved Instance listing state.
                    - **InstanceCount** *(integer) --* 
                      The number of listed Reserved Instances in the state specified by the ``state`` .
                    - **State** *(string) --* 
                      The states of the listed Reserved Instances.
                - **PriceSchedules** *(list) --* 
                  The price of the Reserved Instance listing.
                  - *(dict) --* 
                    Describes the price for a Reserved Instance.
                    - **Active** *(boolean) --* 
                      The current price schedule, as determined by the term remaining for the Reserved Instance in the listing.
                      A specific price schedule is always in effect, but only one price schedule can be active at any time. Take, for example, a Reserved Instance listing that has five months remaining in its term. When you specify price schedules for five months and two months, this means that schedule 1, covering the first three months of the remaining term, will be active during months 5, 4, and 3. Then schedule 2, covering the last two months of the term, will be active for months 2 and 1.
                    - **CurrencyCode** *(string) --* 
                      The currency for transacting the Reserved Instance resale. At this time, the only supported currency is ``USD`` .
                    - **Price** *(float) --* 
                      The fixed price for the term.
                    - **Term** *(integer) --* 
                      The number of months remaining in the reservation. For example, 2 is the second to the last month before the capacity reservation expires.
                - **ReservedInstancesId** *(string) --* 
                  The ID of the Reserved Instance.
                - **ReservedInstancesListingId** *(string) --* 
                  The ID of the Reserved Instance listing.
                - **Status** *(string) --* 
                  The status of the Reserved Instance listing.
                - **StatusMessage** *(string) --* 
                  The reason for the current status of the Reserved Instance listing. The response can be blank.
                - **Tags** *(list) --* 
                  Any tags assigned to the resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **UpdateDate** *(datetime) --* 
                  The last modified timestamp of the listing.
        :type ClientToken: string
        :param ClientToken: **[REQUIRED]**
          Unique, case-sensitive identifier you provide to ensure idempotency of your listings. This helps avoid duplicate listings. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
        :type InstanceCount: integer
        :param InstanceCount: **[REQUIRED]**
          The number of instances that are a part of a Reserved Instance account to be listed in the Reserved Instance Marketplace. This number should be less than or equal to the instance count associated with the Reserved Instance ID specified in this call.
        :type PriceSchedules: list
        :param PriceSchedules: **[REQUIRED]**
          A list specifying the price of the Standard Reserved Instance for each month remaining in the Reserved Instance term.
          - *(dict) --*
            Describes the price for a Reserved Instance.
            - **CurrencyCode** *(string) --*
              The currency for transacting the Reserved Instance resale. At this time, the only supported currency is ``USD`` .
            - **Price** *(float) --*
              The fixed price for the term.
            - **Term** *(integer) --*
              The number of months remaining in the reservation. For example, 2 is the second to the last month before the capacity reservation expires.
        :type ReservedInstancesId: string
        :param ReservedInstancesId: **[REQUIRED]**
          The ID of the active Standard Reserved Instance.
        :rtype: dict
        :returns:
        """
        pass

    def create_route(self, RouteTableId: str, DestinationCidrBlock: str = None, DestinationIpv6CidrBlock: str = None, DryRun: bool = None, EgressOnlyInternetGatewayId: str = None, GatewayId: str = None, InstanceId: str = None, NatGatewayId: str = None, TransitGatewayId: str = None, NetworkInterfaceId: str = None, VpcPeeringConnectionId: str = None) -> Dict:
        """
        Creates a route in a route table within a VPC.
        You must specify one of the following targets: internet gateway or virtual private gateway, NAT instance, NAT gateway, VPC peering connection, network interface, or egress-only internet gateway.
        When determining how to route traffic, we use the route with the most specific match. For example, traffic is destined for the IPv4 address ``192.0.2.3`` , and the route table includes the following two IPv4 routes:
        * ``192.0.2.0/24`` (goes to some target A) 
        * ``192.0.2.0/28`` (goes to some target B) 
        Both routes apply to the traffic destined for ``192.0.2.3`` . However, the second route in the list covers a smaller number of IP addresses and is therefore more specific, so we use that route to determine where to target the traffic.
        For more information about route tables, see `Route Tables <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateRoute>`_
        
        **Request Syntax**
        ::
          response = client.create_route(
              DestinationCidrBlock='string',
              DestinationIpv6CidrBlock='string',
              DryRun=True|False,
              EgressOnlyInternetGatewayId='string',
              GatewayId='string',
              InstanceId='string',
              NatGatewayId='string',
              TransitGatewayId='string',
              NetworkInterfaceId='string',
              RouteTableId='string',
              VpcPeeringConnectionId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock:
          The IPv4 CIDR address block used for the destination match. Routing decisions are based on the most specific match.
        :type DestinationIpv6CidrBlock: string
        :param DestinationIpv6CidrBlock:
          The IPv6 CIDR block used for the destination match. Routing decisions are based on the most specific match.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EgressOnlyInternetGatewayId: string
        :param EgressOnlyInternetGatewayId:
          [IPv6 traffic only] The ID of an egress-only internet gateway.
        :type GatewayId: string
        :param GatewayId:
          The ID of an internet gateway or virtual private gateway attached to your VPC.
        :type InstanceId: string
        :param InstanceId:
          The ID of a NAT instance in your VPC. The operation fails if you specify an instance ID unless exactly one network interface is attached.
        :type NatGatewayId: string
        :param NatGatewayId:
          [IPv4 traffic only] The ID of a NAT gateway.
        :type TransitGatewayId: string
        :param TransitGatewayId:
          The ID of a transit gateway.
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId:
          The ID of a network interface.
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the route table for the route.
        :type VpcPeeringConnectionId: string
        :param VpcPeeringConnectionId:
          The ID of a VPC peering connection.
        :rtype: dict
        :returns:
        """
        pass

    def create_route_table(self, VpcId: str, DryRun: bool = None) -> Dict:
        """
        Creates a route table for the specified VPC. After you create a route table, you can add routes and associate the table with a subnet.
        For more information, see `Route Tables <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.create_route_table(
              DryRun=True|False,
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'RouteTable': {
                    'Associations': [
                        {
                            'Main': True|False,
                            'RouteTableAssociationId': 'string',
                            'RouteTableId': 'string',
                            'SubnetId': 'string'
                        },
                    ],
                    'PropagatingVgws': [
                        {
                            'GatewayId': 'string'
                        },
                    ],
                    'RouteTableId': 'string',
                    'Routes': [
                        {
                            'DestinationCidrBlock': 'string',
                            'DestinationIpv6CidrBlock': 'string',
                            'DestinationPrefixListId': 'string',
                            'EgressOnlyInternetGatewayId': 'string',
                            'GatewayId': 'string',
                            'InstanceId': 'string',
                            'InstanceOwnerId': 'string',
                            'NatGatewayId': 'string',
                            'TransitGatewayId': 'string',
                            'NetworkInterfaceId': 'string',
                            'Origin': 'CreateRouteTable'|'CreateRoute'|'EnableVgwRoutePropagation',
                            'State': 'active'|'blackhole',
                            'VpcPeeringConnectionId': 'string'
                        },
                    ],
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'VpcId': 'string',
                    'OwnerId': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **RouteTable** *(dict) --* 
              Information about the route table.
              - **Associations** *(list) --* 
                The associations between the route table and one or more subnets.
                - *(dict) --* 
                  Describes an association between a route table and a subnet.
                  - **Main** *(boolean) --* 
                    Indicates whether this is the main route table.
                  - **RouteTableAssociationId** *(string) --* 
                    The ID of the association between a route table and a subnet.
                  - **RouteTableId** *(string) --* 
                    The ID of the route table.
                  - **SubnetId** *(string) --* 
                    The ID of the subnet. A subnet ID is not returned for an implicit association.
              - **PropagatingVgws** *(list) --* 
                Any virtual private gateway (VGW) propagating routes.
                - *(dict) --* 
                  Describes a virtual private gateway propagating route.
                  - **GatewayId** *(string) --* 
                    The ID of the virtual private gateway.
              - **RouteTableId** *(string) --* 
                The ID of the route table.
              - **Routes** *(list) --* 
                The routes in the route table.
                - *(dict) --* 
                  Describes a route in a route table.
                  - **DestinationCidrBlock** *(string) --* 
                    The IPv4 CIDR block used for the destination match.
                  - **DestinationIpv6CidrBlock** *(string) --* 
                    The IPv6 CIDR block used for the destination match.
                  - **DestinationPrefixListId** *(string) --* 
                    The prefix of the AWS service.
                  - **EgressOnlyInternetGatewayId** *(string) --* 
                    The ID of the egress-only internet gateway.
                  - **GatewayId** *(string) --* 
                    The ID of a gateway attached to your VPC.
                  - **InstanceId** *(string) --* 
                    The ID of a NAT instance in your VPC.
                  - **InstanceOwnerId** *(string) --* 
                    The AWS account ID of the owner of the instance.
                  - **NatGatewayId** *(string) --* 
                    The ID of a NAT gateway.
                  - **TransitGatewayId** *(string) --* 
                    The ID of a transit gateway.
                  - **NetworkInterfaceId** *(string) --* 
                    The ID of the network interface.
                  - **Origin** *(string) --* 
                    Describes how the route was created.
                    * ``CreateRouteTable`` - The route was automatically created when the route table was created. 
                    * ``CreateRoute`` - The route was manually added to the route table. 
                    * ``EnableVgwRoutePropagation`` - The route was propagated by route propagation. 
                  - **State** *(string) --* 
                    The state of the route. The ``blackhole`` state indicates that the route's target isn't available (for example, the specified gateway isn't attached to the VPC, or the specified NAT instance has been terminated).
                  - **VpcPeeringConnectionId** *(string) --* 
                    The ID of a VPC peering connection.
              - **Tags** *(list) --* 
                Any tags assigned to the route table.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the route table.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def create_security_group(self, Description: str, GroupName: str, VpcId: str = None, DryRun: bool = None) -> Dict:
        """
        Creates a security group.
        A security group acts as a virtual firewall for your instance to control inbound and outbound traffic. For more information, see `Amazon EC2 Security Groups <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-network-security.html>`__ in the *Amazon Elastic Compute Cloud User Guide* and `Security Groups for Your VPC <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_SecurityGroups.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        When you create a security group, you specify a friendly name of your choice. You can have a security group for use in EC2-Classic with the same name as a security group for use in a VPC. However, you can't have two security groups for use in EC2-Classic with the same name or two security groups for use in a VPC with the same name.
        You have a default security group for use in EC2-Classic and a default security group for use in your VPC. If you don't specify a security group when you launch an instance, the instance is launched into the appropriate default security group. A default security group includes a default rule that grants instances unrestricted network access to each other.
        You can add or remove rules from your security groups using  AuthorizeSecurityGroupIngress ,  AuthorizeSecurityGroupEgress ,  RevokeSecurityGroupIngress , and  RevokeSecurityGroupEgress .
        For more information about VPC security group limits, see `Amazon VPC Limits <https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateSecurityGroup>`_
        
        **Request Syntax**
        ::
          response = client.create_security_group(
              Description='string',
              GroupName='string',
              VpcId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'GroupId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **GroupId** *(string) --* 
              The ID of the security group.
        :type Description: string
        :param Description: **[REQUIRED]**
          A description for the security group. This is informational only.
          Constraints: Up to 255 characters in length
          Constraints for EC2-Classic: ASCII characters
          Constraints for EC2-VPC: a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&;{}!$*
        :type GroupName: string
        :param GroupName: **[REQUIRED]**
          The name of the security group.
          Constraints: Up to 255 characters in length. Cannot start with ``sg-`` .
          Constraints for EC2-Classic: ASCII characters
          Constraints for EC2-VPC: a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&;{}!$*
        :type VpcId: string
        :param VpcId:
          [EC2-VPC] The ID of the VPC. Required for EC2-VPC.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_snapshot(self, VolumeId: str, Description: str = None, TagSpecifications: List = None, DryRun: bool = None) -> Dict:
        """
        Creates a snapshot of an EBS volume and stores it in Amazon S3. You can use snapshots for backups, to make copies of EBS volumes, and to save data before shutting down an instance.
        When a snapshot is created, any AWS Marketplace product codes that are associated with the source volume are propagated to the snapshot.
        You can take a snapshot of an attached volume that is in use. However, snapshots only capture data that has been written to your EBS volume at the time the snapshot command is issued; this may exclude any data that has been cached by any applications or the operating system. If you can pause any file systems on the volume long enough to take a snapshot, your snapshot should be complete. However, if you cannot pause all file writes to the volume, you should unmount the volume from within the instance, issue the snapshot command, and then remount the volume to ensure a consistent and complete snapshot. You may remount and use your volume while the snapshot status is ``pending`` .
        To create a snapshot for EBS volumes that serve as root devices, you should stop the instance before taking the snapshot.
        Snapshots that are taken from encrypted volumes are automatically encrypted. Volumes that are created from encrypted snapshots are also automatically encrypted. Your encrypted volumes and any associated snapshots always remain protected.
        You can tag your snapshots during creation. For more information, see `Tagging Your Amazon EC2 Resources <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        For more information, see `Amazon Elastic Block Store <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/AmazonEBS.html>`__ and `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateSnapshot>`_
        
        **Request Syntax**
        ::
          response = client.create_snapshot(
              Description='string',
              VolumeId='string',
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'DataEncryptionKeyId': 'string',
                'Description': 'string',
                'Encrypted': True|False,
                'KmsKeyId': 'string',
                'OwnerId': 'string',
                'Progress': 'string',
                'SnapshotId': 'string',
                'StartTime': datetime(2015, 1, 1),
                'State': 'pending'|'completed'|'error',
                'StateMessage': 'string',
                'VolumeId': 'string',
                'VolumeSize': 123,
                'OwnerAlias': 'string',
                'Tags': [
                    {
                        'Key': 'string',
                        'Value': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes a snapshot.
            - **DataEncryptionKeyId** *(string) --* 
              The data encryption key identifier for the snapshot. This value is a unique identifier that corresponds to the data encryption key that was used to encrypt the original volume or snapshot copy. Because data encryption keys are inherited by volumes created from snapshots, and vice versa, if snapshots share the same data encryption key identifier, then they belong to the same volume/snapshot lineage. This parameter is only returned by the  DescribeSnapshots API operation.
            - **Description** *(string) --* 
              The description for the snapshot.
            - **Encrypted** *(boolean) --* 
              Indicates whether the snapshot is encrypted.
            - **KmsKeyId** *(string) --* 
              The full ARN of the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to protect the volume encryption key for the parent volume.
            - **OwnerId** *(string) --* 
              The AWS account ID of the EBS snapshot owner.
            - **Progress** *(string) --* 
              The progress of the snapshot, as a percentage.
            - **SnapshotId** *(string) --* 
              The ID of the snapshot. Each snapshot receives a unique identifier when it is created.
            - **StartTime** *(datetime) --* 
              The time stamp when the snapshot was initiated.
            - **State** *(string) --* 
              The snapshot state.
            - **StateMessage** *(string) --* 
              Encrypted Amazon EBS snapshots are copied asynchronously. If a snapshot copy operation fails (for example, if the proper AWS Key Management Service (AWS KMS) permissions are not obtained) this field displays error state details to help you diagnose why the error occurred. This parameter is only returned by the  DescribeSnapshots API operation.
            - **VolumeId** *(string) --* 
              The ID of the volume that was used to create the snapshot. Snapshots created by the  CopySnapshot action have an arbitrary volume ID that should not be used for any purpose.
            - **VolumeSize** *(integer) --* 
              The size of the volume, in GiB.
            - **OwnerAlias** *(string) --* 
              Value from an Amazon-maintained list (``amazon`` | ``self`` | ``all`` | ``aws-marketplace`` | ``microsoft`` ) of snapshot owners. Not to be confused with the user-configured AWS account alias, which is set from the IAM console. 
            - **Tags** *(list) --* 
              Any tags assigned to the snapshot.
              - *(dict) --* 
                Describes a tag.
                - **Key** *(string) --* 
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --* 
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type Description: string
        :param Description:
          A description for the snapshot.
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the EBS volume.
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the snapshot during creation.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_spot_datafeed_subscription(self, Bucket: str, DryRun: bool = None, Prefix: str = None) -> Dict:
        """
        Creates a data feed for Spot Instances, enabling you to view Spot Instance usage logs. You can create one data feed per AWS account. For more information, see `Spot Instance Data Feed <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-data-feeds.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateSpotDatafeedSubscription>`_
        
        **Request Syntax**
        ::
          response = client.create_spot_datafeed_subscription(
              Bucket='string',
              DryRun=True|False,
              Prefix='string'
          )
        
        **Response Syntax**
        ::
            {
                'SpotDatafeedSubscription': {
                    'Bucket': 'string',
                    'Fault': {
                        'Code': 'string',
                        'Message': 'string'
                    },
                    'OwnerId': 'string',
                    'Prefix': 'string',
                    'State': 'Active'|'Inactive'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateSpotDatafeedSubscription.
            - **SpotDatafeedSubscription** *(dict) --* 
              The Spot Instance data feed subscription.
              - **Bucket** *(string) --* 
                The Amazon S3 bucket where the Spot Instance data feed is located.
              - **Fault** *(dict) --* 
                The fault codes for the Spot Instance request, if any.
                - **Code** *(string) --* 
                  The reason code for the Spot Instance state change.
                - **Message** *(string) --* 
                  The message for the Spot Instance state change.
              - **OwnerId** *(string) --* 
                The AWS account ID of the account.
              - **Prefix** *(string) --* 
                The prefix that is prepended to data feed files.
              - **State** *(string) --* 
                The state of the Spot Instance data feed subscription.
        :type Bucket: string
        :param Bucket: **[REQUIRED]**
          The Amazon S3 bucket in which to store the Spot Instance data feed.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Prefix: string
        :param Prefix:
          A prefix for the data feed file names.
        :rtype: dict
        :returns:
        """
        pass

    def create_subnet(self, CidrBlock: str, VpcId: str, AvailabilityZone: str = None, AvailabilityZoneId: str = None, Ipv6CidrBlock: str = None, DryRun: bool = None) -> Dict:
        """
        Creates a subnet in an existing VPC.
        When you create each subnet, you provide the VPC ID and IPv4 CIDR block for the subnet. After you create a subnet, you can't change its CIDR block. The size of the subnet's IPv4 CIDR block can be the same as a VPC's IPv4 CIDR block, or a subset of a VPC's IPv4 CIDR block. If you create more than one subnet in a VPC, the subnets' CIDR blocks must not overlap. The smallest IPv4 subnet (and VPC) you can create uses a /28 netmask (16 IPv4 addresses), and the largest uses a /16 netmask (65,536 IPv4 addresses).
        If you've associated an IPv6 CIDR block with your VPC, you can create a subnet with an IPv6 CIDR block that uses a /64 prefix length. 
        .. warning::
          AWS reserves both the first four and the last IPv4 address in each subnet's CIDR block. They're not available for use.
        If you add more than one subnet to a VPC, they're set up in a star topology with a logical router in the middle.
        If you launch an instance in a VPC using an Amazon EBS-backed AMI, the IP address doesn't change if you stop and restart the instance (unlike a similar instance launched outside a VPC, which gets a new IP address when restarted). It's therefore possible to have a subnet with no running instances (they're all stopped), but no remaining IP addresses available.
        For more information about subnets, see `Your VPC and Subnets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Subnets.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateSubnet>`_
        
        **Request Syntax**
        ::
          response = client.create_subnet(
              AvailabilityZone='string',
              AvailabilityZoneId='string',
              CidrBlock='string',
              Ipv6CidrBlock='string',
              VpcId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Subnet': {
                    'AvailabilityZone': 'string',
                    'AvailabilityZoneId': 'string',
                    'AvailableIpAddressCount': 123,
                    'CidrBlock': 'string',
                    'DefaultForAz': True|False,
                    'MapPublicIpOnLaunch': True|False,
                    'State': 'pending'|'available',
                    'SubnetId': 'string',
                    'VpcId': 'string',
                    'OwnerId': 'string',
                    'AssignIpv6AddressOnCreation': True|False,
                    'Ipv6CidrBlockAssociationSet': [
                        {
                            'AssociationId': 'string',
                            'Ipv6CidrBlock': 'string',
                            'Ipv6CidrBlockState': {
                                'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                'StatusMessage': 'string'
                            }
                        },
                    ],
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'SubnetArn': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Subnet** *(dict) --* 
              Information about the subnet.
              - **AvailabilityZone** *(string) --* 
                The Availability Zone of the subnet.
              - **AvailabilityZoneId** *(string) --* 
                The AZ ID of the subnet.
              - **AvailableIpAddressCount** *(integer) --* 
                The number of unused private IPv4 addresses in the subnet. The IPv4 addresses for any stopped instances are considered unavailable.
              - **CidrBlock** *(string) --* 
                The IPv4 CIDR block assigned to the subnet.
              - **DefaultForAz** *(boolean) --* 
                Indicates whether this is the default subnet for the Availability Zone.
              - **MapPublicIpOnLaunch** *(boolean) --* 
                Indicates whether instances launched in this subnet receive a public IPv4 address.
              - **State** *(string) --* 
                The current state of the subnet.
              - **SubnetId** *(string) --* 
                The ID of the subnet.
              - **VpcId** *(string) --* 
                The ID of the VPC the subnet is in.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the subnet.
              - **AssignIpv6AddressOnCreation** *(boolean) --* 
                Indicates whether a network interface created in this subnet (including a network interface created by  RunInstances ) receives an IPv6 address.
              - **Ipv6CidrBlockAssociationSet** *(list) --* 
                Information about the IPv6 CIDR blocks associated with the subnet.
                - *(dict) --* 
                  Describes an IPv6 CIDR block associated with a subnet.
                  - **AssociationId** *(string) --* 
                    The association ID for the CIDR block.
                  - **Ipv6CidrBlock** *(string) --* 
                    The IPv6 CIDR block.
                  - **Ipv6CidrBlockState** *(dict) --* 
                    Information about the state of the CIDR block.
                    - **State** *(string) --* 
                      The state of a CIDR block.
                    - **StatusMessage** *(string) --* 
                      A message about the status of the CIDR block, if applicable.
              - **Tags** *(list) --* 
                Any tags assigned to the subnet.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **SubnetArn** *(string) --* 
                The Amazon Resource Name (ARN) of the subnet.
        :type AvailabilityZone: string
        :param AvailabilityZone:
          The Availability Zone for the subnet.
          Default: AWS selects one for you. If you create more than one subnet in your VPC, we may not necessarily select a different zone for each subnet.
        :type AvailabilityZoneId: string
        :param AvailabilityZoneId:
          The AZ ID of the subnet.
        :type CidrBlock: string
        :param CidrBlock: **[REQUIRED]**
          The IPv4 network range for the subnet, in CIDR notation. For example, ``10.0.0.0/24`` .
        :type Ipv6CidrBlock: string
        :param Ipv6CidrBlock:
          The IPv6 network range for the subnet, in CIDR notation. The subnet size must use a /64 prefix length.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_tags(self, Resources: List, Tags: List, DryRun: bool = None):
        """
        Adds or overwrites the specified tags for the specified Amazon EC2 resource or resources. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique per resource.
        For more information about tags, see `Tagging Your Resources <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . For more information about creating IAM policies that control users' access to resources based on tags, see `Supported Resource-Level Permissions for Amazon EC2 API Actions <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-supported-iam-actions-resources.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateTags>`_
        
        **Request Syntax**
        ::
          response = client.create_tags(
              DryRun=True|False,
              Resources=[
                  'string',
              ],
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Resources: list
        :param Resources: **[REQUIRED]**
          The IDs of the resources, separated by spaces.
          Constraints: Up to 1000 resource IDs. We recommend breaking up this request into smaller batches.
          - *(string) --*
        :type Tags: list
        :param Tags: **[REQUIRED]**
          The tags. The ``value`` parameter is required, but if you don\'t want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.
          - *(dict) --*
            Describes a tag.
            - **Key** *(string) --*
              The key of the tag.
              Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
            - **Value** *(string) --*
              The value of the tag.
              Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :returns: None
        """
        pass

    def create_transit_gateway(self, Description: str = None, Options: Dict = None, TagSpecifications: List = None, DryRun: bool = None) -> Dict:
        """
        Creates a transit gateway.
        You can use a transit gateway to interconnect your virtual private clouds (VPC) and on-premises networks. After the transit gateway enters the ``available`` state, you can attach your VPCs and VPN connections to the transit gateway.
        To attach your VPCs, use  CreateTransitGatewayVpcAttachment .
        To attach a VPN connection, use  CreateCustomerGateway to create a customer gateway and specify the ID of the customer gateway and the ID of the transit gateway in a call to  CreateVpnConnection .
        When you create a transit gateway, we create a default transit gateway route table and use it as the default association route table and the default propagation route table. You can use  CreateTransitGatewayRouteTable to create additional transit gateway route tables. If you disable automatic route propagation, we do not create a default transit gateway route table. You can use  EnableTransitGatewayRouteTablePropagation to propagate routes from a resource attachment to a transit gateway route table. If you disable automatic associations, you can use  AssociateTransitGatewayRouteTable to associate a resource attachment with a transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateTransitGateway>`_
        
        **Request Syntax**
        ::
          response = client.create_transit_gateway(
              Description='string',
              Options={
                  'AmazonSideAsn': 123,
                  'AutoAcceptSharedAttachments': 'enable'|'disable',
                  'DefaultRouteTableAssociation': 'enable'|'disable',
                  'DefaultRouteTablePropagation': 'enable'|'disable',
                  'VpnEcmpSupport': 'enable'|'disable',
                  'DnsSupport': 'enable'|'disable'
              },
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGateway': {
                    'TransitGatewayId': 'string',
                    'TransitGatewayArn': 'string',
                    'State': 'pending'|'available'|'modifying'|'deleting'|'deleted',
                    'OwnerId': 'string',
                    'Description': 'string',
                    'CreationTime': datetime(2015, 1, 1),
                    'Options': {
                        'AmazonSideAsn': 123,
                        'AutoAcceptSharedAttachments': 'enable'|'disable',
                        'DefaultRouteTableAssociation': 'enable'|'disable',
                        'AssociationDefaultRouteTableId': 'string',
                        'DefaultRouteTablePropagation': 'enable'|'disable',
                        'PropagationDefaultRouteTableId': 'string',
                        'VpnEcmpSupport': 'enable'|'disable',
                        'DnsSupport': 'enable'|'disable'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGateway** *(dict) --* 
              Information about the transit gateway.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **TransitGatewayArn** *(string) --* 
                The Amazon Resource Name (ARN) of the transit gateway.
              - **State** *(string) --* 
                The state of the transit gateway.
              - **OwnerId** *(string) --* 
                The ID of the AWS account ID that owns the transit gateway.
              - **Description** *(string) --* 
                The description of the transit gateway.
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Options** *(dict) --* 
                The transit gateway options.
                - **AmazonSideAsn** *(integer) --* 
                  A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.
                - **AutoAcceptSharedAttachments** *(string) --* 
                  Indicates whether attachment requests are automatically accepted.
                - **DefaultRouteTableAssociation** *(string) --* 
                  Indicates whether resource attachments are automatically associated with the default association route table.
                - **AssociationDefaultRouteTableId** *(string) --* 
                  The ID of the default association route table.
                - **DefaultRouteTablePropagation** *(string) --* 
                  Indicates whether resource attachments automatically propagate routes to the default propagation route table.
                - **PropagationDefaultRouteTableId** *(string) --* 
                  The ID of the default propagation route table.
                - **VpnEcmpSupport** *(string) --* 
                  Indicates whether Equal Cost Multipath Protocol support is enabled.
                - **DnsSupport** *(string) --* 
                  Indicates whether DNS support is enabled.
              - **Tags** *(list) --* 
                The tags for the transit gateway.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type Description: string
        :param Description:
          A description of the transit gateway.
        :type Options: dict
        :param Options:
          The transit gateway options.
          - **AmazonSideAsn** *(integer) --*
            A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.
          - **AutoAcceptSharedAttachments** *(string) --*
            Enable or disable automatic acceptance of attachment requests. The default is ``disable`` .
          - **DefaultRouteTableAssociation** *(string) --*
            Enable or disable automatic association with the default association route table. The default is ``enable`` .
          - **DefaultRouteTablePropagation** *(string) --*
            Enable or disable automatic propagation of routes to the default propagation route table. The default is ``enable`` .
          - **VpnEcmpSupport** *(string) --*
            Enable or disable Equal Cost Multipath Protocol support.
          - **DnsSupport** *(string) --*
            Enable or disable DNS support.
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the transit gateway.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_transit_gateway_route(self, DestinationCidrBlock: str, TransitGatewayRouteTableId: str, TransitGatewayAttachmentId: str = None, Blackhole: bool = None, DryRun: bool = None) -> Dict:
        """
        Creates a static route for the specified transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateTransitGatewayRoute>`_
        
        **Request Syntax**
        ::
          response = client.create_transit_gateway_route(
              DestinationCidrBlock='string',
              TransitGatewayRouteTableId='string',
              TransitGatewayAttachmentId='string',
              Blackhole=True|False,
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Route': {
                    'DestinationCidrBlock': 'string',
                    'TransitGatewayAttachments': [
                        {
                            'ResourceId': 'string',
                            'TransitGatewayAttachmentId': 'string',
                            'ResourceType': 'vpc'|'vpn'
                        },
                    ],
                    'Type': 'static'|'propagated',
                    'State': 'pending'|'active'|'blackhole'|'deleting'|'deleted'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Route** *(dict) --* 
              Information about the route.
              - **DestinationCidrBlock** *(string) --* 
                The CIDR block used for destination matches.
              - **TransitGatewayAttachments** *(list) --* 
                The attachments.
                - *(dict) --* 
                  Describes a route attachment.
                  - **ResourceId** *(string) --* 
                    The ID of the resource.
                  - **TransitGatewayAttachmentId** *(string) --* 
                    The ID of the attachment.
                  - **ResourceType** *(string) --* 
                    The resource type.
              - **Type** *(string) --* 
                The route type.
              - **State** *(string) --* 
                The state of the route.
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock: **[REQUIRED]**
          The CIDR range used for destination matches. Routing decisions are based on the most specific match.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId:
          The ID of the attachment.
        :type Blackhole: boolean
        :param Blackhole:
          Indicates whether to drop traffic if the target isn\'t available.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_transit_gateway_route_table(self, TransitGatewayId: str, TagSpecifications: List = None, DryRun: bool = None) -> Dict:
        """
        Creates a route table for the specified transit gateway.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateTransitGatewayRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.create_transit_gateway_route_table(
              TransitGatewayId='string',
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayRouteTable': {
                    'TransitGatewayRouteTableId': 'string',
                    'TransitGatewayId': 'string',
                    'State': 'pending'|'available'|'deleting'|'deleted',
                    'DefaultAssociationRouteTable': True|False,
                    'DefaultPropagationRouteTable': True|False,
                    'CreationTime': datetime(2015, 1, 1),
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayRouteTable** *(dict) --* 
              Information about the transit gateway route table.
              - **TransitGatewayRouteTableId** *(string) --* 
                The ID of the transit gateway route table.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **State** *(string) --* 
                The state of the transit gateway route table.
              - **DefaultAssociationRouteTable** *(boolean) --* 
                Indicates whether this is the default association route table for the transit gateway.
              - **DefaultPropagationRouteTable** *(boolean) --* 
                Indicates whether this is the default propagation route table for the transit gateway.
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Tags** *(list) --* 
                Any tags assigned to the route table.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayId: string
        :param TransitGatewayId: **[REQUIRED]**
          The ID of the transit gateway.
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the transit gateway route table.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_transit_gateway_vpc_attachment(self, TransitGatewayId: str, VpcId: str, SubnetIds: List, Options: Dict = None, TagSpecifications: List = None, DryRun: bool = None) -> Dict:
        """
        Attaches the specified VPC to the specified transit gateway.
        If you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC that is already attached, the new VPC CIDR range is not propagated to the default propagation route table.
        To send VPC traffic to an attached transit gateway, add a route to the VPC route table using  CreateRoute .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateTransitGatewayVpcAttachment>`_
        
        **Request Syntax**
        ::
          response = client.create_transit_gateway_vpc_attachment(
              TransitGatewayId='string',
              VpcId='string',
              SubnetIds=[
                  'string',
              ],
              Options={
                  'DnsSupport': 'enable'|'disable',
                  'Ipv6Support': 'enable'|'disable'
              },
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayVpcAttachment': {
                    'TransitGatewayAttachmentId': 'string',
                    'TransitGatewayId': 'string',
                    'VpcId': 'string',
                    'VpcOwnerId': 'string',
                    'State': 'pendingAcceptance'|'rollingBack'|'pending'|'available'|'modifying'|'deleting'|'deleted'|'failed'|'rejected'|'rejecting'|'failing',
                    'SubnetIds': [
                        'string',
                    ],
                    'CreationTime': datetime(2015, 1, 1),
                    'Options': {
                        'DnsSupport': 'enable'|'disable',
                        'Ipv6Support': 'enable'|'disable'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayVpcAttachment** *(dict) --* 
              Information about the VPC attachment.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **VpcOwnerId** *(string) --* 
                The ID of the AWS account that owns the VPC.
              - **State** *(string) --* 
                The state of the VPC attachment.
              - **SubnetIds** *(list) --* 
                The IDs of the subnets.
                - *(string) --* 
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Options** *(dict) --* 
                The VPC attachment options.
                - **DnsSupport** *(string) --* 
                  Indicates whether DNS support is enabled.
                - **Ipv6Support** *(string) --* 
                  Indicates whether IPv6 support is enabled.
              - **Tags** *(list) --* 
                The tags for the VPC attachment.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayId: string
        :param TransitGatewayId: **[REQUIRED]**
          The ID of the transit gateway.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type SubnetIds: list
        :param SubnetIds: **[REQUIRED]**
          The IDs of one or more subnets. You can specify only one subnet per Availability Zone. You must specify at least one subnet, but we recommend that you specify two subnets for better availability. The transit gateway uses one IP address from each specified subnet.
          - *(string) --*
        :type Options: dict
        :param Options:
          The VPC attachment options.
          - **DnsSupport** *(string) --*
            Enable or disable DNS support. The default is ``enable`` .
          - **Ipv6Support** *(string) --*
            Enable or disable IPv6 support. The default is ``enable`` .
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the VPC attachment.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def create_volume(self, AvailabilityZone: str, Encrypted: bool = None, Iops: int = None, KmsKeyId: str = None, Size: int = None, SnapshotId: str = None, VolumeType: str = None, DryRun: bool = None, TagSpecifications: List = None) -> Dict:
        """
        Creates an EBS volume that can be attached to an instance in the same Availability Zone. The volume is created in the regional endpoint that you send the HTTP request to. For more information see `Regions and Endpoints <https://docs.aws.amazon.com/general/latest/gr/rande.html>`__ .
        You can create a new empty volume or restore a volume from an EBS snapshot. Any AWS Marketplace product codes from the snapshot are propagated to the volume.
        You can create encrypted volumes with the ``Encrypted`` parameter. Encrypted volumes may only be attached to instances that support Amazon EBS encryption. Volumes that are created from encrypted snapshots are also automatically encrypted. For more information, see `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        You can tag your volumes during creation. For more information, see `Tagging Your Amazon EC2 Resources <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        For more information, see `Creating an Amazon EBS Volume <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-creating-volume.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVolume>`_
        
        **Request Syntax**
        ::
          response = client.create_volume(
              AvailabilityZone='string',
              Encrypted=True|False,
              Iops=123,
              KmsKeyId='string',
              Size=123,
              SnapshotId='string',
              VolumeType='standard'|'io1'|'gp2'|'sc1'|'st1',
              DryRun=True|False,
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Attachments': [
                    {
                        'AttachTime': datetime(2015, 1, 1),
                        'Device': 'string',
                        'InstanceId': 'string',
                        'State': 'attaching'|'attached'|'detaching'|'detached'|'busy',
                        'VolumeId': 'string',
                        'DeleteOnTermination': True|False
                    },
                ],
                'AvailabilityZone': 'string',
                'CreateTime': datetime(2015, 1, 1),
                'Encrypted': True|False,
                'KmsKeyId': 'string',
                'Size': 123,
                'SnapshotId': 'string',
                'State': 'creating'|'available'|'in-use'|'deleting'|'deleted'|'error',
                'VolumeId': 'string',
                'Iops': 123,
                'Tags': [
                    {
                        'Key': 'string',
                        'Value': 'string'
                    },
                ],
                'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1'
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes a volume.
            - **Attachments** *(list) --* 
              Information about the volume attachments.
              - *(dict) --* 
                Describes volume attachment details.
                - **AttachTime** *(datetime) --* 
                  The time stamp when the attachment initiated.
                - **Device** *(string) --* 
                  The device name.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **State** *(string) --* 
                  The attachment state of the volume.
                - **VolumeId** *(string) --* 
                  The ID of the volume.
                - **DeleteOnTermination** *(boolean) --* 
                  Indicates whether the EBS volume is deleted on instance termination.
            - **AvailabilityZone** *(string) --* 
              The Availability Zone for the volume.
            - **CreateTime** *(datetime) --* 
              The time stamp when volume creation was initiated.
            - **Encrypted** *(boolean) --* 
              Indicates whether the volume will be encrypted.
            - **KmsKeyId** *(string) --* 
              The full ARN of the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to protect the volume encryption key for the volume.
            - **Size** *(integer) --* 
              The size of the volume, in GiBs.
            - **SnapshotId** *(string) --* 
              The snapshot from which the volume was created, if applicable.
            - **State** *(string) --* 
              The volume state.
            - **VolumeId** *(string) --* 
              The ID of the volume.
            - **Iops** *(integer) --* 
              The number of I/O operations per second (IOPS) that the volume supports. For Provisioned IOPS SSD volumes, this represents the number of IOPS that are provisioned for the volume. For General Purpose SSD volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
              Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
              Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
            - **Tags** *(list) --* 
              Any tags assigned to the volume.
              - *(dict) --* 
                Describes a tag.
                - **Key** *(string) --* 
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --* 
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **VolumeType** *(string) --* 
              The volume type. This can be ``gp2`` for General Purpose SSD, ``io1`` for Provisioned IOPS SSD, ``st1`` for Throughput Optimized HDD, ``sc1`` for Cold HDD, or ``standard`` for Magnetic volumes.
        :type AvailabilityZone: string
        :param AvailabilityZone: **[REQUIRED]**
          The Availability Zone in which to create the volume. Use  DescribeAvailabilityZones to list the Availability Zones that are currently available to you.
        :type Encrypted: boolean
        :param Encrypted:
          Specifies whether the volume should be encrypted. Encrypted Amazon EBS volumes may only be attached to instances that support Amazon EBS encryption. Volumes that are created from encrypted snapshots are automatically encrypted. There is no way to create an encrypted volume from an unencrypted snapshot or vice versa. If your AMI uses encrypted volumes, you can only launch it on supported instance types. For more information, see `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type Iops: integer
        :param Iops:
          The number of I/O operations per second (IOPS) to provision for the volume, with a maximum ratio of 50 IOPS/GiB. Range is 100 to 64,000 IOPS for volumes in most Regions. Maximum IOPS of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          This parameter is valid only for Provisioned IOPS SSD (io1) volumes.
        :type KmsKeyId: string
        :param KmsKeyId:
          An identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) to use when creating the encrypted volume. This parameter is only required if you want to use a non-default CMK; if this parameter is not specified, the default CMK for EBS is used. If a ``KmsKeyId`` is specified, the ``Encrypted`` flag must also be set.
          The CMK identifier may be provided in any of the following formats:
          * Key ID
          * Key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          * ARN using key ID. The ID ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``key`` namespace, and then the CMK ID. For example, arn:aws:kms:*us-east-1* :*012345678910* :key/*abcd1234-a123-456a-a12b-a123b4cd56ef* .
          * ARN using key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          AWS parses ``KmsKeyId`` asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. The action will eventually fail.
        :type Size: integer
        :param Size:
          The size of the volume, in GiBs.
          Constraints: 1-16,384 for ``gp2`` , 4-16,384 for ``io1`` , 500-16,384 for ``st1`` , 500-16,384 for ``sc1`` , and 1-1,024 for ``standard`` . If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
          Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
          .. note::
            At least one of Size or SnapshotId are required.
        :type SnapshotId: string
        :param SnapshotId:
          The snapshot from which to create the volume.
          .. note::
            At least one of Size or SnapshotId are required.
        :type VolumeType: string
        :param VolumeType:
          The volume type. This can be ``gp2`` for General Purpose SSD, ``io1`` for Provisioned IOPS SSD, ``st1`` for Throughput Optimized HDD, ``sc1`` for Cold HDD, or ``standard`` for Magnetic volumes.
          Defaults: If no volume type is specified, the default is ``standard`` in us-east-1, eu-west-1, eu-central-1, us-west-2, us-west-1, sa-east-1, ap-northeast-1, ap-northeast-2, ap-southeast-1, ap-southeast-2, ap-south-1, us-gov-west-1, and cn-north-1. In all other Regions, EBS defaults to ``gp2`` .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the volume during creation.
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :rtype: dict
        :returns:
        """
        pass

    def create_vpc(self, CidrBlock: str, AmazonProvidedIpv6CidrBlock: bool = None, DryRun: bool = None, InstanceTenancy: str = None) -> Dict:
        """
        Creates a VPC with the specified IPv4 CIDR block. The smallest VPC you can create uses a /28 netmask (16 IPv4 addresses), and the largest uses a /16 netmask (65,536 IPv4 addresses). For more information about how large to make your VPC, see `Your VPC and Subnets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Subnets.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        You can optionally request an Amazon-provided IPv6 CIDR block for the VPC. The IPv6 CIDR block uses a /56 prefix length, and is allocated from Amazon's pool of IPv6 addresses. You cannot choose the IPv6 range for your VPC.
        By default, each instance you launch in the VPC has the default DHCP options, which include only a default DNS server that we provide (AmazonProvidedDNS). For more information, see `DHCP Options Sets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_DHCP_Options.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        You can specify the instance tenancy value for the VPC when you create it. You can't change this value for the VPC after you create it. For more information, see `Dedicated Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-instance.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpc>`_
        
        **Request Syntax**
        ::
          response = client.create_vpc(
              CidrBlock='string',
              AmazonProvidedIpv6CidrBlock=True|False,
              DryRun=True|False,
              InstanceTenancy='default'|'dedicated'|'host'
          )
        
        **Response Syntax**
        ::
            {
                'Vpc': {
                    'CidrBlock': 'string',
                    'DhcpOptionsId': 'string',
                    'State': 'pending'|'available',
                    'VpcId': 'string',
                    'OwnerId': 'string',
                    'InstanceTenancy': 'default'|'dedicated'|'host',
                    'Ipv6CidrBlockAssociationSet': [
                        {
                            'AssociationId': 'string',
                            'Ipv6CidrBlock': 'string',
                            'Ipv6CidrBlockState': {
                                'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                'StatusMessage': 'string'
                            }
                        },
                    ],
                    'CidrBlockAssociationSet': [
                        {
                            'AssociationId': 'string',
                            'CidrBlock': 'string',
                            'CidrBlockState': {
                                'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                'StatusMessage': 'string'
                            }
                        },
                    ],
                    'IsDefault': True|False,
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Vpc** *(dict) --* 
              Information about the VPC.
              - **CidrBlock** *(string) --* 
                The primary IPv4 CIDR block for the VPC.
              - **DhcpOptionsId** *(string) --* 
                The ID of the set of DHCP options you've associated with the VPC (or ``default`` if the default options are associated with the VPC).
              - **State** *(string) --* 
                The current state of the VPC.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **OwnerId** *(string) --* 
                The ID of the AWS account that owns the VPC.
              - **InstanceTenancy** *(string) --* 
                The allowed tenancy of instances launched into the VPC.
              - **Ipv6CidrBlockAssociationSet** *(list) --* 
                Information about the IPv6 CIDR blocks associated with the VPC.
                - *(dict) --* 
                  Describes an IPv6 CIDR block associated with a VPC.
                  - **AssociationId** *(string) --* 
                    The association ID for the IPv6 CIDR block.
                  - **Ipv6CidrBlock** *(string) --* 
                    The IPv6 CIDR block.
                  - **Ipv6CidrBlockState** *(dict) --* 
                    Information about the state of the CIDR block.
                    - **State** *(string) --* 
                      The state of the CIDR block.
                    - **StatusMessage** *(string) --* 
                      A message about the status of the CIDR block, if applicable.
              - **CidrBlockAssociationSet** *(list) --* 
                Information about the IPv4 CIDR blocks associated with the VPC.
                - *(dict) --* 
                  Describes an IPv4 CIDR block associated with a VPC.
                  - **AssociationId** *(string) --* 
                    The association ID for the IPv4 CIDR block.
                  - **CidrBlock** *(string) --* 
                    The IPv4 CIDR block.
                  - **CidrBlockState** *(dict) --* 
                    Information about the state of the CIDR block.
                    - **State** *(string) --* 
                      The state of the CIDR block.
                    - **StatusMessage** *(string) --* 
                      A message about the status of the CIDR block, if applicable.
              - **IsDefault** *(boolean) --* 
                Indicates whether the VPC is the default VPC.
              - **Tags** *(list) --* 
                Any tags assigned to the VPC.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type CidrBlock: string
        :param CidrBlock: **[REQUIRED]**
          The IPv4 network range for the VPC, in CIDR notation. For example, ``10.0.0.0/16`` .
        :type AmazonProvidedIpv6CidrBlock: boolean
        :param AmazonProvidedIpv6CidrBlock:
          Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IP addresses, or the size of the CIDR block.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceTenancy: string
        :param InstanceTenancy:
          The tenancy options for instances launched into the VPC. For ``default`` , instances are launched with shared tenancy by default. You can launch instances with any tenancy into a shared tenancy VPC. For ``dedicated`` , instances are launched as dedicated tenancy instances by default. You can only launch instances with a tenancy of ``dedicated`` or ``host`` into a dedicated tenancy VPC.
           **Important:** The ``host`` value cannot be used with this parameter. Use the ``default`` or ``dedicated`` values only.
          Default: ``default``
        :rtype: dict
        :returns:
        """
        pass

    def create_vpc_endpoint(self, VpcId: str, ServiceName: str, DryRun: bool = None, VpcEndpointType: str = None, PolicyDocument: str = None, RouteTableIds: List = None, SubnetIds: List = None, SecurityGroupIds: List = None, ClientToken: str = None, PrivateDnsEnabled: bool = None) -> Dict:
        """
        Creates a VPC endpoint for a specified service. An endpoint enables you to create a private connection between your VPC and the service. The service may be provided by AWS, an AWS Marketplace partner, or another AWS account. For more information, see `VPC Endpoints <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-endpoints.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        A ``gateway`` endpoint serves as a target for a route in your route table for traffic destined for the AWS service. You can specify an endpoint policy to attach to the endpoint that will control access to the service from your VPC. You can also specify the VPC route tables that use the endpoint.
        An ``interface`` endpoint is a network interface in your subnet that serves as an endpoint for communicating with the specified service. You can specify the subnets in which to create an endpoint, and the security groups to associate with the endpoint network interface.
        Use  DescribeVpcEndpointServices to get a list of supported services.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpcEndpoint>`_
        
        **Request Syntax**
        ::
          response = client.create_vpc_endpoint(
              DryRun=True|False,
              VpcEndpointType='Interface'|'Gateway',
              VpcId='string',
              ServiceName='string',
              PolicyDocument='string',
              RouteTableIds=[
                  'string',
              ],
              SubnetIds=[
                  'string',
              ],
              SecurityGroupIds=[
                  'string',
              ],
              ClientToken='string',
              PrivateDnsEnabled=True|False
          )
        
        **Response Syntax**
        ::
            {
                'VpcEndpoint': {
                    'VpcEndpointId': 'string',
                    'VpcEndpointType': 'Interface'|'Gateway',
                    'VpcId': 'string',
                    'ServiceName': 'string',
                    'State': 'PendingAcceptance'|'Pending'|'Available'|'Deleting'|'Deleted'|'Rejected'|'Failed'|'Expired',
                    'PolicyDocument': 'string',
                    'RouteTableIds': [
                        'string',
                    ],
                    'SubnetIds': [
                        'string',
                    ],
                    'Groups': [
                        {
                            'GroupId': 'string',
                            'GroupName': 'string'
                        },
                    ],
                    'PrivateDnsEnabled': True|False,
                    'RequesterManaged': True|False,
                    'NetworkInterfaceIds': [
                        'string',
                    ],
                    'DnsEntries': [
                        {
                            'DnsName': 'string',
                            'HostedZoneId': 'string'
                        },
                    ],
                    'CreationTimestamp': datetime(2015, 1, 1)
                },
                'ClientToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateVpcEndpoint.
            - **VpcEndpoint** *(dict) --* 
              Information about the endpoint.
              - **VpcEndpointId** *(string) --* 
                The ID of the VPC endpoint.
              - **VpcEndpointType** *(string) --* 
                The type of endpoint.
              - **VpcId** *(string) --* 
                The ID of the VPC to which the endpoint is associated.
              - **ServiceName** *(string) --* 
                The name of the service to which the endpoint is associated.
              - **State** *(string) --* 
                The state of the VPC endpoint.
              - **PolicyDocument** *(string) --* 
                The policy document associated with the endpoint, if applicable.
              - **RouteTableIds** *(list) --* 
                (Gateway endpoint) One or more route tables associated with the endpoint.
                - *(string) --* 
              - **SubnetIds** *(list) --* 
                (Interface endpoint) One or more subnets in which the endpoint is located.
                - *(string) --* 
              - **Groups** *(list) --* 
                (Interface endpoint) Information about the security groups associated with the network interface.
                - *(dict) --* 
                  Describes a security group.
                  - **GroupId** *(string) --* 
                    The ID of the security group.
                  - **GroupName** *(string) --* 
                    The name of the security group.
              - **PrivateDnsEnabled** *(boolean) --* 
                (Interface endpoint) Indicates whether the VPC is associated with a private hosted zone.
              - **RequesterManaged** *(boolean) --* 
                Indicates whether the VPC endpoint is being managed by its service.
              - **NetworkInterfaceIds** *(list) --* 
                (Interface endpoint) One or more network interfaces for the endpoint.
                - *(string) --* 
              - **DnsEntries** *(list) --* 
                (Interface endpoint) The DNS entries for the endpoint.
                - *(dict) --* 
                  Describes a DNS entry.
                  - **DnsName** *(string) --* 
                    The DNS name.
                  - **HostedZoneId** *(string) --* 
                    The ID of the private hosted zone.
              - **CreationTimestamp** *(datetime) --* 
                The date and time the VPC endpoint was created.
            - **ClientToken** *(string) --* 
              Unique, case-sensitive identifier you provide to ensure the idempotency of the request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcEndpointType: string
        :param VpcEndpointType:
          The type of endpoint.
          Default: Gateway
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC in which the endpoint will be used.
        :type ServiceName: string
        :param ServiceName: **[REQUIRED]**
          The service name. To get a list of available services, use the  DescribeVpcEndpointServices request, or get the name from the service provider.
        :type PolicyDocument: string
        :param PolicyDocument:
          A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format. If this parameter is not specified, we attach a default policy that allows full access to the service.
        :type RouteTableIds: list
        :param RouteTableIds:
          (Gateway endpoint) One or more route table IDs.
          - *(string) --*
        :type SubnetIds: list
        :param SubnetIds:
          (Interface endpoint) The ID of one or more subnets in which to create an endpoint network interface.
          - *(string) --*
        :type SecurityGroupIds: list
        :param SecurityGroupIds:
          (Interface endpoint) The ID of one or more security groups to associate with the endpoint network interface.
          - *(string) --*
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
        :type PrivateDnsEnabled: boolean
        :param PrivateDnsEnabled:
          (Interface endpoint) Indicate whether to associate a private hosted zone with the specified VPC. The private hosted zone contains a record set for the default public DNS name for the service for the region (for example, ``kinesis.us-east-1.amazonaws.com`` ) which resolves to the private IP addresses of the endpoint network interfaces in the VPC. This enables you to make requests to the default public DNS name for the service instead of the public DNS names that are automatically generated by the VPC endpoint service.
          To use a private hosted zone, you must set the following VPC attributes to ``true`` : ``enableDnsHostnames`` and ``enableDnsSupport`` . Use  ModifyVpcAttribute to set the VPC attributes.
          Default: ``false``
        :rtype: dict
        :returns:
        """
        pass

    def create_vpc_endpoint_connection_notification(self, ConnectionNotificationArn: str, ConnectionEvents: List, DryRun: bool = None, ServiceId: str = None, VpcEndpointId: str = None, ClientToken: str = None) -> Dict:
        """
        Creates a connection notification for a specified VPC endpoint or VPC endpoint service. A connection notification notifies you of specific endpoint events. You must create an SNS topic to receive notifications. For more information, see `Create a Topic <https://docs.aws.amazon.com/sns/latest/dg/CreateTopic.html>`__ in the *Amazon Simple Notification Service Developer Guide* .
        You can create a connection notification for interface endpoints only.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpcEndpointConnectionNotification>`_
        
        **Request Syntax**
        ::
          response = client.create_vpc_endpoint_connection_notification(
              DryRun=True|False,
              ServiceId='string',
              VpcEndpointId='string',
              ConnectionNotificationArn='string',
              ConnectionEvents=[
                  'string',
              ],
              ClientToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ConnectionNotification': {
                    'ConnectionNotificationId': 'string',
                    'ServiceId': 'string',
                    'VpcEndpointId': 'string',
                    'ConnectionNotificationType': 'Topic',
                    'ConnectionNotificationArn': 'string',
                    'ConnectionEvents': [
                        'string',
                    ],
                    'ConnectionNotificationState': 'Enabled'|'Disabled'
                },
                'ClientToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ConnectionNotification** *(dict) --* 
              Information about the notification.
              - **ConnectionNotificationId** *(string) --* 
                The ID of the notification.
              - **ServiceId** *(string) --* 
                The ID of the endpoint service.
              - **VpcEndpointId** *(string) --* 
                The ID of the VPC endpoint.
              - **ConnectionNotificationType** *(string) --* 
                The type of notification.
              - **ConnectionNotificationArn** *(string) --* 
                The ARN of the SNS topic for the notification.
              - **ConnectionEvents** *(list) --* 
                The events for the notification. Valid values are ``Accept`` , ``Connect`` , ``Delete`` , and ``Reject`` .
                - *(string) --* 
              - **ConnectionNotificationState** *(string) --* 
                The state of the notification.
            - **ClientToken** *(string) --* 
              Unique, case-sensitive identifier you provide to ensure the idempotency of the request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceId: string
        :param ServiceId:
          The ID of the endpoint service.
        :type VpcEndpointId: string
        :param VpcEndpointId:
          The ID of the endpoint.
        :type ConnectionNotificationArn: string
        :param ConnectionNotificationArn: **[REQUIRED]**
          The ARN of the SNS topic for the notifications.
        :type ConnectionEvents: list
        :param ConnectionEvents: **[REQUIRED]**
          One or more endpoint events for which to receive notifications. Valid values are ``Accept`` , ``Connect`` , ``Delete`` , and ``Reject`` .
          - *(string) --*
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
        :rtype: dict
        :returns:
        """
        pass

    def create_vpc_endpoint_service_configuration(self, NetworkLoadBalancerArns: List, DryRun: bool = None, AcceptanceRequired: bool = None, ClientToken: str = None) -> Dict:
        """
        Creates a VPC endpoint service configuration to which service consumers (AWS accounts, IAM users, and IAM roles) can connect. Service consumers can create an interface VPC endpoint to connect to your service.
        To create an endpoint service configuration, you must first create a Network Load Balancer for your service. For more information, see `VPC Endpoint Services <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/endpoint-service.html>`__ in the *Amazon Virtual Private Cloud User Guide* . 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpcEndpointServiceConfiguration>`_
        
        **Request Syntax**
        ::
          response = client.create_vpc_endpoint_service_configuration(
              DryRun=True|False,
              AcceptanceRequired=True|False,
              NetworkLoadBalancerArns=[
                  'string',
              ],
              ClientToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ServiceConfiguration': {
                    'ServiceType': [
                        {
                            'ServiceType': 'Interface'|'Gateway'
                        },
                    ],
                    'ServiceId': 'string',
                    'ServiceName': 'string',
                    'ServiceState': 'Pending'|'Available'|'Deleting'|'Deleted'|'Failed',
                    'AvailabilityZones': [
                        'string',
                    ],
                    'AcceptanceRequired': True|False,
                    'ManagesVpcEndpoints': True|False,
                    'NetworkLoadBalancerArns': [
                        'string',
                    ],
                    'BaseEndpointDnsNames': [
                        'string',
                    ],
                    'PrivateDnsName': 'string'
                },
                'ClientToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ServiceConfiguration** *(dict) --* 
              Information about the service configuration.
              - **ServiceType** *(list) --* 
                The type of service.
                - *(dict) --* 
                  Describes the type of service for a VPC endpoint.
                  - **ServiceType** *(string) --* 
                    The type of service.
              - **ServiceId** *(string) --* 
                The ID of the service.
              - **ServiceName** *(string) --* 
                The name of the service.
              - **ServiceState** *(string) --* 
                The service state.
              - **AvailabilityZones** *(list) --* 
                In the Availability Zones in which the service is available.
                - *(string) --* 
              - **AcceptanceRequired** *(boolean) --* 
                Indicates whether requests from other AWS accounts to create an endpoint to the service must first be accepted.
              - **ManagesVpcEndpoints** *(boolean) --* 
                Indicates whether the service manages it's VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.
              - **NetworkLoadBalancerArns** *(list) --* 
                The Amazon Resource Names (ARNs) of the Network Load Balancers for the service.
                - *(string) --* 
              - **BaseEndpointDnsNames** *(list) --* 
                The DNS names for the service.
                - *(string) --* 
              - **PrivateDnsName** *(string) --* 
                The private DNS name for the service.
            - **ClientToken** *(string) --* 
              Unique, case-sensitive identifier you provide to ensure the idempotency of the request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type AcceptanceRequired: boolean
        :param AcceptanceRequired:
          Indicate whether requests from service consumers to create an endpoint to your service must be accepted. To accept a request, use  AcceptVpcEndpointConnections .
        :type NetworkLoadBalancerArns: list
        :param NetworkLoadBalancerArns: **[REQUIRED]**
          The Amazon Resource Names (ARNs) of one or more Network Load Balancers for your service.
          - *(string) --*
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ .
        :rtype: dict
        :returns:
        """
        pass

    def create_vpc_peering_connection(self, DryRun: bool = None, PeerOwnerId: str = None, PeerVpcId: str = None, VpcId: str = None, PeerRegion: str = None) -> Dict:
        """
        Requests a VPC peering connection between two VPCs: a requester VPC that you own and an accepter VPC with which to create the connection. The accepter VPC can belong to another AWS account and can be in a different Region to the requester VPC. The requester VPC and accepter VPC cannot have overlapping CIDR blocks.
        .. note::
          Limitations and rules apply to a VPC peering connection. For more information, see the `limitations <https://docs.aws.amazon.com/AmazonVPC/latest/PeeringGuide/vpc-peering-basics.html#vpc-peering-limitations>`__ section in the *VPC Peering Guide* .
        The owner of the accepter VPC must accept the peering request to activate the peering connection. The VPC peering connection request expires after 7 days, after which it cannot be accepted or rejected.
        If you create a VPC peering connection request between VPCs with overlapping CIDR blocks, the VPC peering connection has a status of ``failed`` .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpcPeeringConnection>`_
        
        **Request Syntax**
        ::
          response = client.create_vpc_peering_connection(
              DryRun=True|False,
              PeerOwnerId='string',
              PeerVpcId='string',
              VpcId='string',
              PeerRegion='string'
          )
        
        **Response Syntax**
        ::
            {
                'VpcPeeringConnection': {
                    'AccepterVpcInfo': {
                        'CidrBlock': 'string',
                        'Ipv6CidrBlockSet': [
                            {
                                'Ipv6CidrBlock': 'string'
                            },
                        ],
                        'CidrBlockSet': [
                            {
                                'CidrBlock': 'string'
                            },
                        ],
                        'OwnerId': 'string',
                        'PeeringOptions': {
                            'AllowDnsResolutionFromRemoteVpc': True|False,
                            'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                            'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                        },
                        'VpcId': 'string',
                        'Region': 'string'
                    },
                    'ExpirationTime': datetime(2015, 1, 1),
                    'RequesterVpcInfo': {
                        'CidrBlock': 'string',
                        'Ipv6CidrBlockSet': [
                            {
                                'Ipv6CidrBlock': 'string'
                            },
                        ],
                        'CidrBlockSet': [
                            {
                                'CidrBlock': 'string'
                            },
                        ],
                        'OwnerId': 'string',
                        'PeeringOptions': {
                            'AllowDnsResolutionFromRemoteVpc': True|False,
                            'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                            'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                        },
                        'VpcId': 'string',
                        'Region': 'string'
                    },
                    'Status': {
                        'Code': 'initiating-request'|'pending-acceptance'|'active'|'deleted'|'rejected'|'failed'|'expired'|'provisioning'|'deleting',
                        'Message': 'string'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'VpcPeeringConnectionId': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VpcPeeringConnection** *(dict) --* 
              Information about the VPC peering connection.
              - **AccepterVpcInfo** *(dict) --* 
                Information about the accepter VPC. CIDR block information is only returned when describing an active VPC peering connection.
                - **CidrBlock** *(string) --* 
                  The IPv4 CIDR block for the VPC.
                - **Ipv6CidrBlockSet** *(list) --* 
                  The IPv6 CIDR block for the VPC.
                  - *(dict) --* 
                    Describes an IPv6 CIDR block.
                    - **Ipv6CidrBlock** *(string) --* 
                      The IPv6 CIDR block.
                - **CidrBlockSet** *(list) --* 
                  Information about the IPv4 CIDR blocks for the VPC.
                  - *(dict) --* 
                    Describes an IPv4 CIDR block.
                    - **CidrBlock** *(string) --* 
                      The IPv4 CIDR block.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the VPC owner.
                - **PeeringOptions** *(dict) --* 
                  Information about the VPC peering connection options for the accepter or requester VPC.
                  - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                    Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
                  - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                    Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
                  - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                    Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
                - **Region** *(string) --* 
                  The region in which the VPC is located.
              - **ExpirationTime** *(datetime) --* 
                The time that an unaccepted VPC peering connection will expire.
              - **RequesterVpcInfo** *(dict) --* 
                Information about the requester VPC. CIDR block information is only returned when describing an active VPC peering connection.
                - **CidrBlock** *(string) --* 
                  The IPv4 CIDR block for the VPC.
                - **Ipv6CidrBlockSet** *(list) --* 
                  The IPv6 CIDR block for the VPC.
                  - *(dict) --* 
                    Describes an IPv6 CIDR block.
                    - **Ipv6CidrBlock** *(string) --* 
                      The IPv6 CIDR block.
                - **CidrBlockSet** *(list) --* 
                  Information about the IPv4 CIDR blocks for the VPC.
                  - *(dict) --* 
                    Describes an IPv4 CIDR block.
                    - **CidrBlock** *(string) --* 
                      The IPv4 CIDR block.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the VPC owner.
                - **PeeringOptions** *(dict) --* 
                  Information about the VPC peering connection options for the accepter or requester VPC.
                  - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                    Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
                  - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                    Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
                  - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                    Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
                - **Region** *(string) --* 
                  The region in which the VPC is located.
              - **Status** *(dict) --* 
                The status of the VPC peering connection.
                - **Code** *(string) --* 
                  The status of the VPC peering connection.
                - **Message** *(string) --* 
                  A message that provides more information about the status, if applicable.
              - **Tags** *(list) --* 
                Any tags assigned to the resource.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **VpcPeeringConnectionId** *(string) --* 
                The ID of the VPC peering connection.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type PeerOwnerId: string
        :param PeerOwnerId:
          The AWS account ID of the owner of the accepter VPC.
          Default: Your AWS account ID
        :type PeerVpcId: string
        :param PeerVpcId:
          The ID of the VPC with which you are creating the VPC peering connection. You must specify this parameter in the request.
        :type VpcId: string
        :param VpcId:
          The ID of the requester VPC. You must specify this parameter in the request.
        :type PeerRegion: string
        :param PeerRegion:
          The region code for the accepter VPC, if the accepter VPC is located in a region other than the region in which you make the request.
          Default: The region in which you make the request.
        :rtype: dict
        :returns:
        """
        pass

    def create_vpn_connection(self, CustomerGatewayId: str, Type: str, VpnGatewayId: str = None, TransitGatewayId: str = None, DryRun: bool = None, Options: Dict = None) -> Dict:
        """
        Creates a VPN connection between an existing virtual private gateway and a VPN customer gateway. The only supported connection type is ``ipsec.1`` .
        The response includes information that you need to give to your network administrator to configure your customer gateway.
        .. warning::
          We strongly recommend that you use HTTPS when calling this operation because the response contains sensitive cryptographic information for configuring your customer gateway.
        If you decide to shut down your VPN connection for any reason and later create a new VPN connection, you must reconfigure your customer gateway with the new information returned from this call.
        This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpnConnection>`_
        
        **Request Syntax**
        ::
          response = client.create_vpn_connection(
              CustomerGatewayId='string',
              Type='string',
              VpnGatewayId='string',
              TransitGatewayId='string',
              DryRun=True|False,
              Options={
                  'StaticRoutesOnly': True|False,
                  'TunnelOptions': [
                      {
                          'TunnelInsideCidr': 'string',
                          'PreSharedKey': 'string'
                      },
                  ]
              }
          )
        
        **Response Syntax**
        ::
            {
                'VpnConnection': {
                    'CustomerGatewayConfiguration': 'string',
                    'CustomerGatewayId': 'string',
                    'Category': 'string',
                    'State': 'pending'|'available'|'deleting'|'deleted',
                    'Type': 'ipsec.1',
                    'VpnConnectionId': 'string',
                    'VpnGatewayId': 'string',
                    'TransitGatewayId': 'string',
                    'Options': {
                        'StaticRoutesOnly': True|False
                    },
                    'Routes': [
                        {
                            'DestinationCidrBlock': 'string',
                            'Source': 'Static',
                            'State': 'pending'|'available'|'deleting'|'deleted'
                        },
                    ],
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'VgwTelemetry': [
                        {
                            'AcceptedRouteCount': 123,
                            'LastStatusChange': datetime(2015, 1, 1),
                            'OutsideIpAddress': 'string',
                            'Status': 'UP'|'DOWN',
                            'StatusMessage': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateVpnConnection.
            - **VpnConnection** *(dict) --* 
              Information about the VPN connection.
              - **CustomerGatewayConfiguration** *(string) --* 
                The configuration information for the VPN connection's customer gateway (in the native XML format). This element is always present in the  CreateVpnConnection response; however, it's present in the  DescribeVpnConnections response only if the VPN connection is in the ``pending`` or ``available`` state.
              - **CustomerGatewayId** *(string) --* 
                The ID of the customer gateway at your end of the VPN connection.
              - **Category** *(string) --* 
                The category of the VPN connection. A value of ``VPN`` indicates an AWS VPN connection. A value of ``VPN-Classic`` indicates an AWS Classic VPN connection.
              - **State** *(string) --* 
                The current state of the VPN connection.
              - **Type** *(string) --* 
                The type of VPN connection.
              - **VpnConnectionId** *(string) --* 
                The ID of the VPN connection.
              - **VpnGatewayId** *(string) --* 
                The ID of the virtual private gateway at the AWS side of the VPN connection.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway associated with the VPN connection.
              - **Options** *(dict) --* 
                The VPN connection options.
                - **StaticRoutesOnly** *(boolean) --* 
                  Indicates whether the VPN connection uses static routes only. Static routes must be used for devices that don't support BGP.
              - **Routes** *(list) --* 
                The static routes associated with the VPN connection.
                - *(dict) --* 
                  Describes a static route for a VPN connection.
                  - **DestinationCidrBlock** *(string) --* 
                    The CIDR block associated with the local subnet of the customer data center.
                  - **Source** *(string) --* 
                    Indicates how the routes were provided.
                  - **State** *(string) --* 
                    The current state of the static route.
              - **Tags** *(list) --* 
                Any tags assigned to the VPN connection.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **VgwTelemetry** *(list) --* 
                Information about the VPN tunnel.
                - *(dict) --* 
                  Describes telemetry for a VPN tunnel.
                  - **AcceptedRouteCount** *(integer) --* 
                    The number of accepted routes.
                  - **LastStatusChange** *(datetime) --* 
                    The date and time of the last change in status.
                  - **OutsideIpAddress** *(string) --* 
                    The Internet-routable IP address of the virtual private gateway's outside interface.
                  - **Status** *(string) --* 
                    The status of the VPN tunnel.
                  - **StatusMessage** *(string) --* 
                    If an error occurs, a description of the error.
        :type CustomerGatewayId: string
        :param CustomerGatewayId: **[REQUIRED]**
          The ID of the customer gateway.
        :type Type: string
        :param Type: **[REQUIRED]**
          The type of VPN connection (``ipsec.1`` ).
        :type VpnGatewayId: string
        :param VpnGatewayId:
          The ID of the virtual private gateway. If you specify a virtual private gateway, you cannot specify a transit gateway.
        :type TransitGatewayId: string
        :param TransitGatewayId:
          The ID of the transit gateway. If you specify a transit gateway, you cannot specify a virtual private gateway.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Options: dict
        :param Options:
          The options for the VPN connection.
          - **StaticRoutesOnly** *(boolean) --*
            Indicate whether the VPN connection uses static routes only. If you are creating a VPN connection for a device that does not support BGP, you must specify ``true`` . Use  CreateVpnConnectionRoute to create a static route.
            Default: ``false``
          - **TunnelOptions** *(list) --*
            The tunnel options for the VPN connection.
            - *(dict) --*
              The tunnel options for a VPN connection.
              - **TunnelInsideCidr** *(string) --*
                The range of inside IP addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same virtual private gateway.
                Constraints: A size /30 CIDR block from the ``169.254.0.0/16`` range. The following CIDR blocks are reserved and cannot be used:
                * ``169.254.0.0/30``
                * ``169.254.1.0/30``
                * ``169.254.2.0/30``
                * ``169.254.3.0/30``
                * ``169.254.4.0/30``
                * ``169.254.5.0/30``
                * ``169.254.169.252/30``
              - **PreSharedKey** *(string) --*
                The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and customer gateway.
                Constraints: Allowed characters are alphanumeric characters and ._. Must be between 8 and 64 characters in length and cannot start with zero (0).
        :rtype: dict
        :returns:
        """
        pass

    def create_vpn_connection_route(self, DestinationCidrBlock: str, VpnConnectionId: str):
        """
        Creates a static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpnConnectionRoute>`_
        
        **Request Syntax**
        ::
          response = client.create_vpn_connection_route(
              DestinationCidrBlock='string',
              VpnConnectionId='string'
          )
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock: **[REQUIRED]**
          The CIDR block associated with the local subnet of the customer network.
        :type VpnConnectionId: string
        :param VpnConnectionId: **[REQUIRED]**
          The ID of the VPN connection.
        :returns: None
        """
        pass

    def create_vpn_gateway(self, Type: str, AvailabilityZone: str = None, AmazonSideAsn: int = None, DryRun: bool = None) -> Dict:
        """
        Creates a virtual private gateway. A virtual private gateway is the endpoint on the VPC side of your VPN connection. You can create a virtual private gateway before creating the VPC itself.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/CreateVpnGateway>`_
        
        **Request Syntax**
        ::
          response = client.create_vpn_gateway(
              AvailabilityZone='string',
              Type='ipsec.1',
              AmazonSideAsn=123,
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'VpnGateway': {
                    'AvailabilityZone': 'string',
                    'State': 'pending'|'available'|'deleting'|'deleted',
                    'Type': 'ipsec.1',
                    'VpcAttachments': [
                        {
                            'State': 'attaching'|'attached'|'detaching'|'detached',
                            'VpcId': 'string'
                        },
                    ],
                    'VpnGatewayId': 'string',
                    'AmazonSideAsn': 123,
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of CreateVpnGateway.
            - **VpnGateway** *(dict) --* 
              Information about the virtual private gateway.
              - **AvailabilityZone** *(string) --* 
                The Availability Zone where the virtual private gateway was created, if applicable. This field may be empty or not returned.
              - **State** *(string) --* 
                The current state of the virtual private gateway.
              - **Type** *(string) --* 
                The type of VPN connection the virtual private gateway supports.
              - **VpcAttachments** *(list) --* 
                Any VPCs attached to the virtual private gateway.
                - *(dict) --* 
                  Describes an attachment between a virtual private gateway and a VPC.
                  - **State** *(string) --* 
                    The current state of the attachment.
                  - **VpcId** *(string) --* 
                    The ID of the VPC.
              - **VpnGatewayId** *(string) --* 
                The ID of the virtual private gateway.
              - **AmazonSideAsn** *(integer) --* 
                The private Autonomous System Number (ASN) for the Amazon side of a BGP session.
              - **Tags** *(list) --* 
                Any tags assigned to the virtual private gateway.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type AvailabilityZone: string
        :param AvailabilityZone:
          The Availability Zone for the virtual private gateway.
        :type Type: string
        :param Type: **[REQUIRED]**
          The type of VPN connection this virtual private gateway supports.
        :type AmazonSideAsn: integer
        :param AmazonSideAsn:
          A private Autonomous System Number (ASN) for the Amazon side of a BGP session. If you\'re using a 16-bit ASN, it must be in the 64512 to 65534 range. If you\'re using a 32-bit ASN, it must be in the 4200000000 to 4294967294 range.
          Default: 64512
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_client_vpn_endpoint(self, ClientVpnEndpointId: str, DryRun: bool = None) -> Dict:
        """
        Deletes the specified Client VPN endpoint. You must disassociate all target networks before you can delete a Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteClientVpnEndpoint>`_
        
        **Request Syntax**
        ::
          response = client.delete_client_vpn_endpoint(
              ClientVpnEndpointId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Status': {
                    'Code': 'pending-associate'|'available'|'deleting'|'deleted',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Status** *(dict) --* 
              The current state of the Client VPN endpoint.
              - **Code** *(string) --* 
                The state of the Client VPN endpoint. Possible states include:
                * ``pending-associate`` - The Client VPN endpoint has been created but no target networks have been associated. The Client VPN endpoint cannot accept connections. 
                * ``available`` - The Client VPN endpoint has been created and a target network has been associated. The Client VPN endpoint can accept connections. 
                * ``deleting`` - The Client VPN endpoint is being deleted. The Client VPN endpoint cannot accept connections. 
                * ``deleted`` - The Client VPN endpoint has been deleted. The Client VPN endpoint cannot accept connections. 
              - **Message** *(string) --* 
                A message about the status of the Client VPN endpoint.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN to be deleted.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_client_vpn_route(self, ClientVpnEndpointId: str, DestinationCidrBlock: str, TargetVpcSubnetId: str = None, DryRun: bool = None) -> Dict:
        """
        Deletes a route from a Client VPN endpoint. You can only delete routes that you manually added using the **CreateClientVpnRoute** action. You cannot delete routes that were automatically added when associating a subnet. To remove routes that have been automatically added, disassociate the target subnet from the Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteClientVpnRoute>`_
        
        **Request Syntax**
        ::
          response = client.delete_client_vpn_route(
              ClientVpnEndpointId='string',
              TargetVpcSubnetId='string',
              DestinationCidrBlock='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Status': {
                    'Code': 'creating'|'active'|'failed'|'deleting',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Status** *(dict) --* 
              The current state of the route.
              - **Code** *(string) --* 
                The state of the Client VPN endpoint route.
              - **Message** *(string) --* 
                A message about the status of the Client VPN endpoint route, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint from which the route is to be deleted.
        :type TargetVpcSubnetId: string
        :param TargetVpcSubnetId:
          The ID of the target subnet used by the route.
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock: **[REQUIRED]**
          The IPv4 address range, in CIDR notation, of the route to be deleted.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_customer_gateway(self, CustomerGatewayId: str, DryRun: bool = None):
        """
        Deletes the specified customer gateway. You must delete the VPN connection before you can delete the customer gateway.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteCustomerGateway>`_
        
        **Request Syntax**
        ::
          response = client.delete_customer_gateway(
              CustomerGatewayId='string',
              DryRun=True|False
          )
        :type CustomerGatewayId: string
        :param CustomerGatewayId: **[REQUIRED]**
          The ID of the customer gateway.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_dhcp_options(self, DhcpOptionsId: str, DryRun: bool = None):
        """
        Deletes the specified set of DHCP options. You must disassociate the set of DHCP options before you can delete it. You can disassociate the set of DHCP options by associating either a new set of options or the default set of options with the VPC.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteDhcpOptions>`_
        
        **Request Syntax**
        ::
          response = client.delete_dhcp_options(
              DhcpOptionsId='string',
              DryRun=True|False
          )
        :type DhcpOptionsId: string
        :param DhcpOptionsId: **[REQUIRED]**
          The ID of the DHCP options set.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_egress_only_internet_gateway(self, EgressOnlyInternetGatewayId: str, DryRun: bool = None) -> Dict:
        """
        Deletes an egress-only internet gateway.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteEgressOnlyInternetGateway>`_
        
        **Request Syntax**
        ::
          response = client.delete_egress_only_internet_gateway(
              DryRun=True|False,
              EgressOnlyInternetGatewayId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ReturnCode': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ReturnCode** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EgressOnlyInternetGatewayId: string
        :param EgressOnlyInternetGatewayId: **[REQUIRED]**
          The ID of the egress-only internet gateway.
        :rtype: dict
        :returns:
        """
        pass

    def delete_fleets(self, FleetIds: List, TerminateInstances: bool, DryRun: bool = None) -> Dict:
        """
        Deletes the specified EC2 Fleet.
        After you delete an EC2 Fleet, it launches no new instances. You must specify whether an EC2 Fleet should also terminate its instances. If you terminate the instances, the EC2 Fleet enters the ``deleted_terminating`` state. Otherwise, the EC2 Fleet enters the ``deleted_running`` state, and the instances continue to run until they are interrupted or you terminate them manually. 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteFleets>`_
        
        **Request Syntax**
        ::
          response = client.delete_fleets(
              DryRun=True|False,
              FleetIds=[
                  'string',
              ],
              TerminateInstances=True|False
          )
        
        **Response Syntax**
        ::
            {
                'SuccessfulFleetDeletions': [
                    {
                        'CurrentFleetState': 'submitted'|'active'|'deleted'|'failed'|'deleted-running'|'deleted-terminating'|'modifying',
                        'PreviousFleetState': 'submitted'|'active'|'deleted'|'failed'|'deleted-running'|'deleted-terminating'|'modifying',
                        'FleetId': 'string'
                    },
                ],
                'UnsuccessfulFleetDeletions': [
                    {
                        'Error': {
                            'Code': 'fleetIdDoesNotExist'|'fleetIdMalformed'|'fleetNotInDeletableState'|'unexpectedError',
                            'Message': 'string'
                        },
                        'FleetId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **SuccessfulFleetDeletions** *(list) --* 
              Information about the EC2 Fleets that are successfully deleted.
              - *(dict) --* 
                Describes an EC2 Fleet that was successfully deleted.
                - **CurrentFleetState** *(string) --* 
                  The current state of the EC2 Fleet.
                - **PreviousFleetState** *(string) --* 
                  The previous state of the EC2 Fleet.
                - **FleetId** *(string) --* 
                  The ID of the EC2 Fleet.
            - **UnsuccessfulFleetDeletions** *(list) --* 
              Information about the EC2 Fleets that are not successfully deleted.
              - *(dict) --* 
                Describes an EC2 Fleet that was not successfully deleted.
                - **Error** *(dict) --* 
                  The error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The description for the error code.
                - **FleetId** *(string) --* 
                  The ID of the EC2 Fleet.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type FleetIds: list
        :param FleetIds: **[REQUIRED]**
          The IDs of the EC2 Fleets.
          - *(string) --*
        :type TerminateInstances: boolean
        :param TerminateInstances: **[REQUIRED]**
          Indicates whether to terminate instances for an EC2 Fleet if it is deleted successfully.
        :rtype: dict
        :returns:
        """
        pass

    def delete_flow_logs(self, FlowLogIds: List, DryRun: bool = None) -> Dict:
        """
        Deletes one or more flow logs.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteFlowLogs>`_
        
        **Request Syntax**
        ::
          response = client.delete_flow_logs(
              DryRun=True|False,
              FlowLogIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Unsuccessful** *(list) --* 
              Information about the flow logs that could not be deleted successfully.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type FlowLogIds: list
        :param FlowLogIds: **[REQUIRED]**
          One or more flow log IDs.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def delete_fpga_image(self, FpgaImageId: str, DryRun: bool = None) -> Dict:
        """
        Deletes the specified Amazon FPGA Image (AFI).
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteFpgaImage>`_
        
        **Request Syntax**
        ::
          response = client.delete_fpga_image(
              DryRun=True|False,
              FpgaImageId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Is ``true`` if the request succeeds, and an error otherwise.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type FpgaImageId: string
        :param FpgaImageId: **[REQUIRED]**
          The ID of the AFI.
        :rtype: dict
        :returns:
        """
        pass

    def delete_internet_gateway(self, InternetGatewayId: str, DryRun: bool = None):
        """
        Deletes the specified internet gateway. You must detach the internet gateway from the VPC before you can delete it.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteInternetGateway>`_
        
        **Request Syntax**
        ::
          response = client.delete_internet_gateway(
              DryRun=True|False,
              InternetGatewayId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InternetGatewayId: string
        :param InternetGatewayId: **[REQUIRED]**
          The ID of the internet gateway.
        :returns: None
        """
        pass

    def delete_key_pair(self, KeyName: str, DryRun: bool = None):
        """
        Deletes the specified key pair, by removing the public key from Amazon EC2.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteKeyPair>`_
        
        **Request Syntax**
        ::
          response = client.delete_key_pair(
              KeyName='string',
              DryRun=True|False
          )
        :type KeyName: string
        :param KeyName: **[REQUIRED]**
          The name of the key pair.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_launch_template(self, DryRun: bool = None, LaunchTemplateId: str = None, LaunchTemplateName: str = None) -> Dict:
        """
        Deletes a launch template. Deleting a launch template deletes all of its versions.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteLaunchTemplate>`_
        
        **Request Syntax**
        ::
          response = client.delete_launch_template(
              DryRun=True|False,
              LaunchTemplateId='string',
              LaunchTemplateName='string'
          )
        
        **Response Syntax**
        ::
            {
                'LaunchTemplate': {
                    'LaunchTemplateId': 'string',
                    'LaunchTemplateName': 'string',
                    'CreateTime': datetime(2015, 1, 1),
                    'CreatedBy': 'string',
                    'DefaultVersionNumber': 123,
                    'LatestVersionNumber': 123,
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **LaunchTemplate** *(dict) --* 
              Information about the launch template.
              - **LaunchTemplateId** *(string) --* 
                The ID of the launch template.
              - **LaunchTemplateName** *(string) --* 
                The name of the launch template.
              - **CreateTime** *(datetime) --* 
                The time launch template was created.
              - **CreatedBy** *(string) --* 
                The principal that created the launch template. 
              - **DefaultVersionNumber** *(integer) --* 
                The version number of the default version of the launch template.
              - **LatestVersionNumber** *(integer) --* 
                The version number of the latest version of the launch template.
              - **Tags** *(list) --* 
                The tags for the launch template.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type LaunchTemplateId: string
        :param LaunchTemplateId:
          The ID of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type LaunchTemplateName: string
        :param LaunchTemplateName:
          The name of the launch template. You must specify either the launch template ID or launch template name in the request.
        :rtype: dict
        :returns:
        """
        pass

    def delete_launch_template_versions(self, Versions: List, DryRun: bool = None, LaunchTemplateId: str = None, LaunchTemplateName: str = None) -> Dict:
        """
        Deletes one or more versions of a launch template. You cannot delete the default version of a launch template; you must first assign a different version as the default. If the default version is the only version for the launch template, you must delete the entire launch template using  DeleteLaunchTemplate .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteLaunchTemplateVersions>`_
        
        **Request Syntax**
        ::
          response = client.delete_launch_template_versions(
              DryRun=True|False,
              LaunchTemplateId='string',
              LaunchTemplateName='string',
              Versions=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'SuccessfullyDeletedLaunchTemplateVersions': [
                    {
                        'LaunchTemplateId': 'string',
                        'LaunchTemplateName': 'string',
                        'VersionNumber': 123
                    },
                ],
                'UnsuccessfullyDeletedLaunchTemplateVersions': [
                    {
                        'LaunchTemplateId': 'string',
                        'LaunchTemplateName': 'string',
                        'VersionNumber': 123,
                        'ResponseError': {
                            'Code': 'launchTemplateIdDoesNotExist'|'launchTemplateIdMalformed'|'launchTemplateNameDoesNotExist'|'launchTemplateNameMalformed'|'launchTemplateVersionDoesNotExist'|'unexpectedError',
                            'Message': 'string'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **SuccessfullyDeletedLaunchTemplateVersions** *(list) --* 
              Information about the launch template versions that were successfully deleted.
              - *(dict) --* 
                Describes a launch template version that was successfully deleted.
                - **LaunchTemplateId** *(string) --* 
                  The ID of the launch template.
                - **LaunchTemplateName** *(string) --* 
                  The name of the launch template.
                - **VersionNumber** *(integer) --* 
                  The version number of the launch template.
            - **UnsuccessfullyDeletedLaunchTemplateVersions** *(list) --* 
              Information about the launch template versions that could not be deleted.
              - *(dict) --* 
                Describes a launch template version that could not be deleted.
                - **LaunchTemplateId** *(string) --* 
                  The ID of the launch template.
                - **LaunchTemplateName** *(string) --* 
                  The name of the launch template.
                - **VersionNumber** *(integer) --* 
                  The version number of the launch template.
                - **ResponseError** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message, if applicable.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type LaunchTemplateId: string
        :param LaunchTemplateId:
          The ID of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type LaunchTemplateName: string
        :param LaunchTemplateName:
          The name of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type Versions: list
        :param Versions: **[REQUIRED]**
          The version numbers of one or more launch template versions to delete.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def delete_nat_gateway(self, NatGatewayId: str) -> Dict:
        """
        Deletes the specified NAT gateway. Deleting a NAT gateway disassociates its Elastic IP address, but does not release the address from your account. Deleting a NAT gateway does not delete any NAT gateway routes in your route tables.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteNatGateway>`_
        
        **Request Syntax**
        ::
          response = client.delete_nat_gateway(
              NatGatewayId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NatGatewayId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NatGatewayId** *(string) --* 
              The ID of the NAT gateway.
        :type NatGatewayId: string
        :param NatGatewayId: **[REQUIRED]**
          The ID of the NAT gateway.
        :rtype: dict
        :returns:
        """
        pass

    def delete_network_acl(self, NetworkAclId: str, DryRun: bool = None):
        """
        Deletes the specified network ACL. You can't delete the ACL if it's associated with any subnets. You can't delete the default network ACL.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteNetworkAcl>`_
        
        **Request Syntax**
        ::
          response = client.delete_network_acl(
              DryRun=True|False,
              NetworkAclId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkAclId: string
        :param NetworkAclId: **[REQUIRED]**
          The ID of the network ACL.
        :returns: None
        """
        pass

    def delete_network_acl_entry(self, Egress: bool, NetworkAclId: str, RuleNumber: int, DryRun: bool = None):
        """
        Deletes the specified ingress or egress entry (rule) from the specified network ACL.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteNetworkAclEntry>`_
        
        **Request Syntax**
        ::
          response = client.delete_network_acl_entry(
              DryRun=True|False,
              Egress=True|False,
              NetworkAclId='string',
              RuleNumber=123
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Egress: boolean
        :param Egress: **[REQUIRED]**
          Indicates whether the rule is an egress rule.
        :type NetworkAclId: string
        :param NetworkAclId: **[REQUIRED]**
          The ID of the network ACL.
        :type RuleNumber: integer
        :param RuleNumber: **[REQUIRED]**
          The rule number of the entry to delete.
        :returns: None
        """
        pass

    def delete_network_interface(self, NetworkInterfaceId: str, DryRun: bool = None):
        """
        Deletes the specified network interface. You must detach the network interface before you can delete it.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteNetworkInterface>`_
        
        **Request Syntax**
        ::
          response = client.delete_network_interface(
              DryRun=True|False,
              NetworkInterfaceId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :returns: None
        """
        pass

    def delete_network_interface_permission(self, NetworkInterfacePermissionId: str, Force: bool = None, DryRun: bool = None) -> Dict:
        """
        Deletes a permission for a network interface. By default, you cannot delete the permission if the account for which you're removing the permission has attached the network interface to an instance. However, you can force delete the permission, regardless of any attachment.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteNetworkInterfacePermission>`_
        
        **Request Syntax**
        ::
          response = client.delete_network_interface_permission(
              NetworkInterfacePermissionId='string',
              Force=True|False,
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for DeleteNetworkInterfacePermission.
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds, otherwise returns an error.
        :type NetworkInterfacePermissionId: string
        :param NetworkInterfacePermissionId: **[REQUIRED]**
          The ID of the network interface permission.
        :type Force: boolean
        :param Force:
          Specify ``true`` to remove the permission even if the network interface is attached to an instance.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_placement_group(self, GroupName: str, DryRun: bool = None):
        """
        Deletes the specified placement group. You must terminate all instances in the placement group before you can delete the placement group. For more information, see `Placement Groups <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeletePlacementGroup>`_
        
        **Request Syntax**
        ::
          response = client.delete_placement_group(
              DryRun=True|False,
              GroupName='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupName: string
        :param GroupName: **[REQUIRED]**
          The name of the placement group.
        :returns: None
        """
        pass

    def delete_route(self, RouteTableId: str, DestinationCidrBlock: str = None, DestinationIpv6CidrBlock: str = None, DryRun: bool = None):
        """
        Deletes the specified route from the specified route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteRoute>`_
        
        **Request Syntax**
        ::
          response = client.delete_route(
              DestinationCidrBlock='string',
              DestinationIpv6CidrBlock='string',
              DryRun=True|False,
              RouteTableId='string'
          )
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock:
          The IPv4 CIDR range for the route. The value you specify must match the CIDR for the route exactly.
        :type DestinationIpv6CidrBlock: string
        :param DestinationIpv6CidrBlock:
          The IPv6 CIDR range for the route. The value you specify must match the CIDR for the route exactly.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the route table.
        :returns: None
        """
        pass

    def delete_route_table(self, RouteTableId: str, DryRun: bool = None):
        """
        Deletes the specified route table. You must disassociate the route table from any subnets before you can delete it. You can't delete the main route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.delete_route_table(
              DryRun=True|False,
              RouteTableId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the route table.
        :returns: None
        """
        pass

    def delete_security_group(self, GroupId: str = None, GroupName: str = None, DryRun: bool = None):
        """
        Deletes a security group.
        If you attempt to delete a security group that is associated with an instance, or is referenced by another security group, the operation fails with ``InvalidGroup.InUse`` in EC2-Classic or ``DependencyViolation`` in EC2-VPC.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteSecurityGroup>`_
        
        **Request Syntax**
        ::
          response = client.delete_security_group(
              GroupId='string',
              GroupName='string',
              DryRun=True|False
          )
        :type GroupId: string
        :param GroupId:
          The ID of the security group. Required for a nondefault VPC.
        :type GroupName: string
        :param GroupName:
          [EC2-Classic, default VPC] The name of the security group. You can specify either the security group name or the security group ID.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_snapshot(self, SnapshotId: str, DryRun: bool = None):
        """
        Deletes the specified snapshot.
        When you make periodic snapshots of a volume, the snapshots are incremental, and only the blocks on the device that have changed since your last snapshot are saved in the new snapshot. When you delete a snapshot, only the data not needed for any other snapshot is removed. So regardless of which prior snapshots have been deleted, all active snapshots will have access to all the information needed to restore the volume.
        You cannot delete a snapshot of the root device of an EBS volume used by a registered AMI. You must first de-register the AMI before you can delete the snapshot.
        For more information, see `Deleting an Amazon EBS Snapshot <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-deleting-snapshot.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteSnapshot>`_
        
        **Request Syntax**
        ::
          response = client.delete_snapshot(
              SnapshotId='string',
              DryRun=True|False
          )
        :type SnapshotId: string
        :param SnapshotId: **[REQUIRED]**
          The ID of the EBS snapshot.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_spot_datafeed_subscription(self, DryRun: bool = None):
        """
        Deletes the data feed for Spot Instances.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteSpotDatafeedSubscription>`_
        
        **Request Syntax**
        ::
          response = client.delete_spot_datafeed_subscription(
              DryRun=True|False
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_subnet(self, SubnetId: str, DryRun: bool = None):
        """
        Deletes the specified subnet. You must terminate all running instances in the subnet before you can delete the subnet.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteSubnet>`_
        
        **Request Syntax**
        ::
          response = client.delete_subnet(
              SubnetId='string',
              DryRun=True|False
          )
        :type SubnetId: string
        :param SubnetId: **[REQUIRED]**
          The ID of the subnet.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_tags(self, Resources: List, DryRun: bool = None, Tags: List = None):
        """
        Deletes the specified set of tags from the specified set of resources.
        To list the current tags, use  DescribeTags . For more information about tags, see `Tagging Your Resources <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteTags>`_
        
        **Request Syntax**
        ::
          response = client.delete_tags(
              DryRun=True|False,
              Resources=[
                  'string',
              ],
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Resources: list
        :param Resources: **[REQUIRED]**
          The IDs of the resources, separated by spaces.
          Constraints: Up to 1000 resource IDs. We recommend breaking up this request into smaller batches.
          - *(string) --*
        :type Tags: list
        :param Tags:
          The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string.
          If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete AWS-generated tags (tags that have the ``aws:`` prefix).
          - *(dict) --*
            Describes a tag.
            - **Key** *(string) --*
              The key of the tag.
              Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
            - **Value** *(string) --*
              The value of the tag.
              Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :returns: None
        """
        pass

    def delete_transit_gateway(self, TransitGatewayId: str, DryRun: bool = None) -> Dict:
        """
        Deletes the specified transit gateway.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteTransitGateway>`_
        
        **Request Syntax**
        ::
          response = client.delete_transit_gateway(
              TransitGatewayId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGateway': {
                    'TransitGatewayId': 'string',
                    'TransitGatewayArn': 'string',
                    'State': 'pending'|'available'|'modifying'|'deleting'|'deleted',
                    'OwnerId': 'string',
                    'Description': 'string',
                    'CreationTime': datetime(2015, 1, 1),
                    'Options': {
                        'AmazonSideAsn': 123,
                        'AutoAcceptSharedAttachments': 'enable'|'disable',
                        'DefaultRouteTableAssociation': 'enable'|'disable',
                        'AssociationDefaultRouteTableId': 'string',
                        'DefaultRouteTablePropagation': 'enable'|'disable',
                        'PropagationDefaultRouteTableId': 'string',
                        'VpnEcmpSupport': 'enable'|'disable',
                        'DnsSupport': 'enable'|'disable'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGateway** *(dict) --* 
              Information about the deleted transit gateway.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **TransitGatewayArn** *(string) --* 
                The Amazon Resource Name (ARN) of the transit gateway.
              - **State** *(string) --* 
                The state of the transit gateway.
              - **OwnerId** *(string) --* 
                The ID of the AWS account ID that owns the transit gateway.
              - **Description** *(string) --* 
                The description of the transit gateway.
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Options** *(dict) --* 
                The transit gateway options.
                - **AmazonSideAsn** *(integer) --* 
                  A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.
                - **AutoAcceptSharedAttachments** *(string) --* 
                  Indicates whether attachment requests are automatically accepted.
                - **DefaultRouteTableAssociation** *(string) --* 
                  Indicates whether resource attachments are automatically associated with the default association route table.
                - **AssociationDefaultRouteTableId** *(string) --* 
                  The ID of the default association route table.
                - **DefaultRouteTablePropagation** *(string) --* 
                  Indicates whether resource attachments automatically propagate routes to the default propagation route table.
                - **PropagationDefaultRouteTableId** *(string) --* 
                  The ID of the default propagation route table.
                - **VpnEcmpSupport** *(string) --* 
                  Indicates whether Equal Cost Multipath Protocol support is enabled.
                - **DnsSupport** *(string) --* 
                  Indicates whether DNS support is enabled.
              - **Tags** *(list) --* 
                The tags for the transit gateway.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayId: string
        :param TransitGatewayId: **[REQUIRED]**
          The ID of the transit gateway.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_transit_gateway_route(self, TransitGatewayRouteTableId: str, DestinationCidrBlock: str, DryRun: bool = None) -> Dict:
        """
        Deletes the specified route from the specified transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteTransitGatewayRoute>`_
        
        **Request Syntax**
        ::
          response = client.delete_transit_gateway_route(
              TransitGatewayRouteTableId='string',
              DestinationCidrBlock='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Route': {
                    'DestinationCidrBlock': 'string',
                    'TransitGatewayAttachments': [
                        {
                            'ResourceId': 'string',
                            'TransitGatewayAttachmentId': 'string',
                            'ResourceType': 'vpc'|'vpn'
                        },
                    ],
                    'Type': 'static'|'propagated',
                    'State': 'pending'|'active'|'blackhole'|'deleting'|'deleted'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Route** *(dict) --* 
              Information about the route.
              - **DestinationCidrBlock** *(string) --* 
                The CIDR block used for destination matches.
              - **TransitGatewayAttachments** *(list) --* 
                The attachments.
                - *(dict) --* 
                  Describes a route attachment.
                  - **ResourceId** *(string) --* 
                    The ID of the resource.
                  - **TransitGatewayAttachmentId** *(string) --* 
                    The ID of the attachment.
                  - **ResourceType** *(string) --* 
                    The resource type.
              - **Type** *(string) --* 
                The route type.
              - **State** *(string) --* 
                The state of the route.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock: **[REQUIRED]**
          The CIDR range for the route. This must match the CIDR for the route exactly.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_transit_gateway_route_table(self, TransitGatewayRouteTableId: str, DryRun: bool = None) -> Dict:
        """
        Deletes the specified transit gateway route table. You must disassociate the route table from any transit gateway route tables before you can delete it.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteTransitGatewayRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.delete_transit_gateway_route_table(
              TransitGatewayRouteTableId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayRouteTable': {
                    'TransitGatewayRouteTableId': 'string',
                    'TransitGatewayId': 'string',
                    'State': 'pending'|'available'|'deleting'|'deleted',
                    'DefaultAssociationRouteTable': True|False,
                    'DefaultPropagationRouteTable': True|False,
                    'CreationTime': datetime(2015, 1, 1),
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayRouteTable** *(dict) --* 
              Information about the deleted transit gateway route table.
              - **TransitGatewayRouteTableId** *(string) --* 
                The ID of the transit gateway route table.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **State** *(string) --* 
                The state of the transit gateway route table.
              - **DefaultAssociationRouteTable** *(boolean) --* 
                Indicates whether this is the default association route table for the transit gateway.
              - **DefaultPropagationRouteTable** *(boolean) --* 
                Indicates whether this is the default propagation route table for the transit gateway.
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Tags** *(list) --* 
                Any tags assigned to the route table.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_transit_gateway_vpc_attachment(self, TransitGatewayAttachmentId: str, DryRun: bool = None) -> Dict:
        """
        Deletes the specified VPC attachment.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteTransitGatewayVpcAttachment>`_
        
        **Request Syntax**
        ::
          response = client.delete_transit_gateway_vpc_attachment(
              TransitGatewayAttachmentId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayVpcAttachment': {
                    'TransitGatewayAttachmentId': 'string',
                    'TransitGatewayId': 'string',
                    'VpcId': 'string',
                    'VpcOwnerId': 'string',
                    'State': 'pendingAcceptance'|'rollingBack'|'pending'|'available'|'modifying'|'deleting'|'deleted'|'failed'|'rejected'|'rejecting'|'failing',
                    'SubnetIds': [
                        'string',
                    ],
                    'CreationTime': datetime(2015, 1, 1),
                    'Options': {
                        'DnsSupport': 'enable'|'disable',
                        'Ipv6Support': 'enable'|'disable'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayVpcAttachment** *(dict) --* 
              Information about the deleted VPC attachment.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **VpcOwnerId** *(string) --* 
                The ID of the AWS account that owns the VPC.
              - **State** *(string) --* 
                The state of the VPC attachment.
              - **SubnetIds** *(list) --* 
                The IDs of the subnets.
                - *(string) --* 
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Options** *(dict) --* 
                The VPC attachment options.
                - **DnsSupport** *(string) --* 
                  Indicates whether DNS support is enabled.
                - **Ipv6Support** *(string) --* 
                  Indicates whether IPv6 support is enabled.
              - **Tags** *(list) --* 
                The tags for the VPC attachment.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def delete_volume(self, VolumeId: str, DryRun: bool = None):
        """
        Deletes the specified EBS volume. The volume must be in the ``available`` state (not attached to an instance).
        The volume can remain in the ``deleting`` state for several minutes.
        For more information, see `Deleting an Amazon EBS Volume <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-deleting-volume.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVolume>`_
        
        **Request Syntax**
        ::
          response = client.delete_volume(
              VolumeId='string',
              DryRun=True|False
          )
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the volume.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_vpc(self, VpcId: str, DryRun: bool = None):
        """
        Deletes the specified VPC. You must detach or delete all gateways and resources that are associated with the VPC before you can delete it. For example, you must terminate all instances running in the VPC, delete all security groups associated with the VPC (except the default one), delete all route tables associated with the VPC (except the default one), and so on.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpc>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpc(
              VpcId='string',
              DryRun=True|False
          )
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_vpc_endpoint_connection_notifications(self, ConnectionNotificationIds: List, DryRun: bool = None) -> Dict:
        """
        Deletes one or more VPC endpoint connection notifications.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpcEndpointConnectionNotifications>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpc_endpoint_connection_notifications(
              DryRun=True|False,
              ConnectionNotificationIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Unsuccessful** *(list) --* 
              Information about the notifications that could not be deleted successfully.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ConnectionNotificationIds: list
        :param ConnectionNotificationIds: **[REQUIRED]**
          One or more notification IDs.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def delete_vpc_endpoint_service_configurations(self, ServiceIds: List, DryRun: bool = None) -> Dict:
        """
        Deletes one or more VPC endpoint service configurations in your account. Before you delete the endpoint service configuration, you must reject any ``Available`` or ``PendingAcceptance`` interface endpoint connections that are attached to the service.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpcEndpointServiceConfigurations>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpc_endpoint_service_configurations(
              DryRun=True|False,
              ServiceIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Unsuccessful** *(list) --* 
              Information about the service configurations that were not deleted, if applicable.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceIds: list
        :param ServiceIds: **[REQUIRED]**
          The IDs of one or more services.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def delete_vpc_endpoints(self, VpcEndpointIds: List, DryRun: bool = None) -> Dict:
        """
        Deletes one or more specified VPC endpoints. Deleting a gateway endpoint also deletes the endpoint routes in the route tables that were associated with the endpoint. Deleting an interface endpoint deletes the endpoint network interfaces.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpcEndpoints>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpc_endpoints(
              DryRun=True|False,
              VpcEndpointIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DeleteVpcEndpoints.
            - **Unsuccessful** *(list) --* 
              Information about the VPC endpoints that were not successfully deleted.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcEndpointIds: list
        :param VpcEndpointIds: **[REQUIRED]**
          One or more VPC endpoint IDs.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def delete_vpc_peering_connection(self, VpcPeeringConnectionId: str, DryRun: bool = None) -> Dict:
        """
        Deletes a VPC peering connection. Either the owner of the requester VPC or the owner of the accepter VPC can delete the VPC peering connection if it's in the ``active`` state. The owner of the requester VPC can delete a VPC peering connection in the ``pending-acceptance`` state. You cannot delete a VPC peering connection that's in the ``failed`` state.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpcPeeringConnection>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpc_peering_connection(
              DryRun=True|False,
              VpcPeeringConnectionId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcPeeringConnectionId: string
        :param VpcPeeringConnectionId: **[REQUIRED]**
          The ID of the VPC peering connection.
        :rtype: dict
        :returns:
        """
        pass

    def delete_vpn_connection(self, VpnConnectionId: str, DryRun: bool = None):
        """
        Deletes the specified VPN connection.
        If you're deleting the VPC and its associated components, we recommend that you detach the virtual private gateway from the VPC and delete the VPC before deleting the VPN connection. If you believe that the tunnel credentials for your VPN connection have been compromised, you can delete the VPN connection and create a new one that has new keys, without needing to delete the VPC or virtual private gateway. If you create a new VPN connection, you must reconfigure the customer gateway using the new configuration information returned with the new VPN connection ID.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpnConnection>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpn_connection(
              VpnConnectionId='string',
              DryRun=True|False
          )
        :type VpnConnectionId: string
        :param VpnConnectionId: **[REQUIRED]**
          The ID of the VPN connection.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def delete_vpn_connection_route(self, DestinationCidrBlock: str, VpnConnectionId: str):
        """
        Deletes the specified static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpnConnectionRoute>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpn_connection_route(
              DestinationCidrBlock='string',
              VpnConnectionId='string'
          )
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock: **[REQUIRED]**
          The CIDR block associated with the local subnet of the customer network.
        :type VpnConnectionId: string
        :param VpnConnectionId: **[REQUIRED]**
          The ID of the VPN connection.
        :returns: None
        """
        pass

    def delete_vpn_gateway(self, VpnGatewayId: str, DryRun: bool = None):
        """
        Deletes the specified virtual private gateway. We recommend that before you delete a virtual private gateway, you detach it from the VPC and delete the VPN connection. Note that you don't need to delete the virtual private gateway if you plan to delete and recreate the VPN connection between your VPC and your network.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeleteVpnGateway>`_
        
        **Request Syntax**
        ::
          response = client.delete_vpn_gateway(
              VpnGatewayId='string',
              DryRun=True|False
          )
        :type VpnGatewayId: string
        :param VpnGatewayId: **[REQUIRED]**
          The ID of the virtual private gateway.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def deprovision_byoip_cidr(self, Cidr: str, DryRun: bool = None) -> Dict:
        """
        Releases the specified address range that you provisioned for use with your AWS resources through bring your own IP addresses (BYOIP) and deletes the corresponding address pool.
        Before you can release an address range, you must stop advertising it using  WithdrawByoipCidr and you must not have any IP addresses allocated from its address range.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeprovisionByoipCidr>`_
        
        **Request Syntax**
        ::
          response = client.deprovision_byoip_cidr(
              Cidr='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ByoipCidr': {
                    'Cidr': 'string',
                    'Description': 'string',
                    'StatusMessage': 'string',
                    'State': 'advertised'|'deprovisioned'|'failed-deprovision'|'failed-provision'|'pending-deprovision'|'pending-provision'|'provisioned'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ByoipCidr** *(dict) --* 
              Information about the address range.
              - **Cidr** *(string) --* 
                The public IPv4 address range, in CIDR notation.
              - **Description** *(string) --* 
                The description of the address range.
              - **StatusMessage** *(string) --* 
                Upon success, contains the ID of the address pool. Otherwise, contains an error message.
              - **State** *(string) --* 
                The state of the address pool.
        :type Cidr: string
        :param Cidr: **[REQUIRED]**
          The public IPv4 address range, in CIDR notation. The prefix must be the same prefix that you specified when you provisioned the address range.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def deregister_image(self, ImageId: str, DryRun: bool = None):
        """
        Deregisters the specified AMI. After you deregister an AMI, it can't be used to launch new instances; however, it doesn't affect any instances that you've already launched from the AMI. You'll continue to incur usage costs for those instances until you terminate them.
        When you deregister an Amazon EBS-backed AMI, it doesn't affect the snapshot that was created for the root volume of the instance during the AMI creation process. When you deregister an instance store-backed AMI, it doesn't affect the files that you uploaded to Amazon S3 when you created the AMI.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DeregisterImage>`_
        
        **Request Syntax**
        ::
          response = client.deregister_image(
              ImageId='string',
              DryRun=True|False
          )
        :type ImageId: string
        :param ImageId: **[REQUIRED]**
          The ID of the AMI.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def describe_account_attributes(self, AttributeNames: List = None, DryRun: bool = None) -> Dict:
        """
        Describes attributes of your AWS account. The following are the supported account attributes:
        * ``supported-platforms`` : Indicates whether your account can launch instances into EC2-Classic and EC2-VPC, or only into EC2-VPC. 
        * ``default-vpc`` : The ID of the default VPC for your account, or ``none`` . 
        * ``max-instances`` : The maximum number of On-Demand Instances that you can run. 
        * ``vpc-max-security-groups-per-interface`` : The maximum number of security groups that you can assign to a network interface. 
        * ``max-elastic-ips`` : The maximum number of Elastic IP addresses that you can allocate for use with EC2-Classic.  
        * ``vpc-max-elastic-ips`` : The maximum number of Elastic IP addresses that you can allocate for use with EC2-VPC. 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeAccountAttributes>`_
        
        **Request Syntax**
        ::
          response = client.describe_account_attributes(
              AttributeNames=[
                  'supported-platforms'|'default-vpc',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'AccountAttributes': [
                    {
                        'AttributeName': 'string',
                        'AttributeValues': [
                            {
                                'AttributeValue': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AccountAttributes** *(list) --* 
              Information about the account attributes.
              - *(dict) --* 
                Describes an account attribute.
                - **AttributeName** *(string) --* 
                  The name of the account attribute.
                - **AttributeValues** *(list) --* 
                  The values for the account attribute.
                  - *(dict) --* 
                    Describes a value of an account attribute.
                    - **AttributeValue** *(string) --* 
                      The value of the attribute.
        :type AttributeNames: list
        :param AttributeNames:
          The account attribute names.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_addresses(self, Filters: List = None, PublicIps: List = None, AllocationIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the specified Elastic IP addresses or all of your Elastic IP addresses.
        An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see `Elastic IP Addresses <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeAddresses>`_
        
        **Request Syntax**
        ::
          response = client.describe_addresses(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              PublicIps=[
                  'string',
              ],
              AllocationIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Addresses': [
                    {
                        'InstanceId': 'string',
                        'PublicIp': 'string',
                        'AllocationId': 'string',
                        'AssociationId': 'string',
                        'Domain': 'vpc'|'standard',
                        'NetworkInterfaceId': 'string',
                        'NetworkInterfaceOwnerId': 'string',
                        'PrivateIpAddress': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'PublicIpv4Pool': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Addresses** *(list) --* 
              Information about the Elastic IP addresses.
              - *(dict) --* 
                Describes an Elastic IP address.
                - **InstanceId** *(string) --* 
                  The ID of the instance that the address is associated with (if any).
                - **PublicIp** *(string) --* 
                  The Elastic IP address.
                - **AllocationId** *(string) --* 
                  The ID representing the allocation of the address for use with EC2-VPC.
                - **AssociationId** *(string) --* 
                  The ID representing the association of the address with an instance in a VPC.
                - **Domain** *(string) --* 
                  Indicates whether this Elastic IP address is for use with instances in EC2-Classic (``standard`` ) or instances in a VPC (``vpc`` ).
                - **NetworkInterfaceId** *(string) --* 
                  The ID of the network interface.
                - **NetworkInterfaceOwnerId** *(string) --* 
                  The ID of the AWS account that owns the network interface.
                - **PrivateIpAddress** *(string) --* 
                  The private IP address associated with the Elastic IP address.
                - **Tags** *(list) --* 
                  Any tags assigned to the Elastic IP address.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **PublicIpv4Pool** *(string) --* 
                  The ID of an address pool.
        :type Filters: list
        :param Filters:
          One or more filters. Filter names and values are case-sensitive.
          * ``allocation-id`` - [EC2-VPC] The allocation ID for the address.
          * ``association-id`` - [EC2-VPC] The association ID for the address.
          * ``domain`` - Indicates whether the address is for use in EC2-Classic (``standard`` ) or in a VPC (``vpc`` ).
          * ``instance-id`` - The ID of the instance the address is associated with, if any.
          * ``network-interface-id`` - [EC2-VPC] The ID of the network interface that the address is associated with, if any.
          * ``network-interface-owner-id`` - The AWS account ID of the owner.
          * ``private-ip-address`` - [EC2-VPC] The private IP address associated with the Elastic IP address.
          * ``public-ip`` - The Elastic IP address.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type PublicIps: list
        :param PublicIps:
          One or more Elastic IP addresses.
          Default: Describes all your Elastic IP addresses.
          - *(string) --*
        :type AllocationIds: list
        :param AllocationIds:
          [EC2-VPC] Information about the allocation IDs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_aggregate_id_format(self, DryRun: bool = None) -> Dict:
        """
        Describes the longer ID format settings for all resource types in a specific region. This request is useful for performing a quick audit to determine whether a specific region is fully opted in for longer IDs (17-character IDs).
        This request only returns information about resource types that support longer IDs.
        The following resource types support longer IDs: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``instance`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``reservation`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``snapshot`` | ``subnet`` | ``subnet-cidr-block-association`` | ``volume`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeAggregateIdFormat>`_
        
        **Request Syntax**
        ::
          response = client.describe_aggregate_id_format(
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'UseLongIdsAggregated': True|False,
                'Statuses': [
                    {
                        'Deadline': datetime(2015, 1, 1),
                        'Resource': 'string',
                        'UseLongIds': True|False
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **UseLongIdsAggregated** *(boolean) --* 
              Indicates whether all resource types in the region are configured to use longer IDs. This value is only ``true`` if all users are configured to use longer IDs for all resources types in the region.
            - **Statuses** *(list) --* 
              Information about each resource's ID format.
              - *(dict) --* 
                Describes the ID format for a resource.
                - **Deadline** *(datetime) --* 
                  The date in UTC at which you are permanently switched over to using longer IDs. If a deadline is not yet available for this resource type, this field is not returned.
                - **Resource** *(string) --* 
                  The type of resource.
                - **UseLongIds** *(boolean) --* 
                  Indicates whether longer IDs (17-character IDs) are enabled for the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_availability_zones(self, Filters: List = None, ZoneNames: List = None, ZoneIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the Availability Zones that are available to you. The results include zones only for the region you're currently using. If there is an event impacting an Availability Zone, you can use this request to view the state and any provided message for that Availability Zone.
        For more information, see `Regions and Availability Zones <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-regions-availability-zones.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeAvailabilityZones>`_
        
        **Request Syntax**
        ::
          response = client.describe_availability_zones(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              ZoneNames=[
                  'string',
              ],
              ZoneIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'AvailabilityZones': [
                    {
                        'State': 'available'|'information'|'impaired'|'unavailable',
                        'Messages': [
                            {
                                'Message': 'string'
                            },
                        ],
                        'RegionName': 'string',
                        'ZoneName': 'string',
                        'ZoneId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AvailabilityZones** *(list) --* 
              Information about the Availability Zones.
              - *(dict) --* 
                Describes an Availability Zone.
                - **State** *(string) --* 
                  The state of the Availability Zone.
                - **Messages** *(list) --* 
                  Any messages about the Availability Zone.
                  - *(dict) --* 
                    Describes a message about an Availability Zone.
                    - **Message** *(string) --* 
                      The message about the Availability Zone.
                - **RegionName** *(string) --* 
                  The name of the region.
                - **ZoneName** *(string) --* 
                  The name of the Availability Zone.
                - **ZoneId** *(string) --* 
                  The ID of the Availability Zone.
        :type Filters: list
        :param Filters:
          The filters.
          * ``message`` - Information about the Availability Zone.
          * ``region-name`` - The name of the region for the Availability Zone (for example, ``us-east-1`` ).
          * ``state`` - The state of the Availability Zone (``available`` | ``information`` | ``impaired`` | ``unavailable`` ).
          * ``zone-id`` - The ID of the Availability Zone (for example, ``use1-az1`` ).
          * ``zone-name`` - The name of the Availability Zone (for example, ``us-east-1a`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type ZoneNames: list
        :param ZoneNames:
          The names of the Availability Zones.
          - *(string) --*
        :type ZoneIds: list
        :param ZoneIds:
          The IDs of the Availability Zones.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_bundle_tasks(self, BundleIds: List = None, Filters: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the specified bundle tasks or all of your bundle tasks.
        .. note::
          Completed bundle tasks are listed for only a limited time. If your bundle task is no longer in the list, you can still register an AMI from it. Just use ``RegisterImage`` with the Amazon S3 bucket name and image manifest name you provided to the bundle task.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeBundleTasks>`_
        
        **Request Syntax**
        ::
          response = client.describe_bundle_tasks(
              BundleIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'BundleTasks': [
                    {
                        'BundleId': 'string',
                        'BundleTaskError': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'InstanceId': 'string',
                        'Progress': 'string',
                        'StartTime': datetime(2015, 1, 1),
                        'State': 'pending'|'waiting-for-shutdown'|'bundling'|'storing'|'cancelling'|'complete'|'failed',
                        'Storage': {
                            'S3': {
                                'AWSAccessKeyId': 'string',
                                'Bucket': 'string',
                                'Prefix': 'string',
                                'UploadPolicy': b'bytes',
                                'UploadPolicySignature': 'string'
                            }
                        },
                        'UpdateTime': datetime(2015, 1, 1)
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **BundleTasks** *(list) --* 
              Information about the bundle tasks.
              - *(dict) --* 
                Describes a bundle task.
                - **BundleId** *(string) --* 
                  The ID of the bundle task.
                - **BundleTaskError** *(dict) --* 
                  If the task fails, a description of the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message.
                - **InstanceId** *(string) --* 
                  The ID of the instance associated with this bundle task.
                - **Progress** *(string) --* 
                  The level of task completion, as a percent (for example, 20%).
                - **StartTime** *(datetime) --* 
                  The time this task started.
                - **State** *(string) --* 
                  The state of the task.
                - **Storage** *(dict) --* 
                  The Amazon S3 storage locations.
                  - **S3** *(dict) --* 
                    An Amazon S3 storage location.
                    - **AWSAccessKeyId** *(string) --* 
                      The access key ID of the owner of the bucket. Before you specify a value for your access key ID, review and follow the guidance in `Best Practices for Managing AWS Access Keys <https://docs.aws.amazon.com/general/latest/gr/aws-access-keys-best-practices.html>`__ .
                    - **Bucket** *(string) --* 
                      The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
                    - **Prefix** *(string) --* 
                      The beginning of the file name of the AMI.
                    - **UploadPolicy** *(bytes) --* 
                      An Amazon S3 upload policy that gives Amazon EC2 permission to upload items into Amazon S3 on your behalf.
                    - **UploadPolicySignature** *(string) --* 
                      The signature of the JSON document.
                - **UpdateTime** *(datetime) --* 
                  The time of the most recent update for the task.
        :type BundleIds: list
        :param BundleIds:
          The bundle task IDs.
          Default: Describes all your bundle tasks.
          - *(string) --*
        :type Filters: list
        :param Filters:
          The filters.
          * ``bundle-id`` - The ID of the bundle task.
          * ``error-code`` - If the task failed, the error code returned.
          * ``error-message`` - If the task failed, the error message returned.
          * ``instance-id`` - The ID of the instance.
          * ``progress`` - The level of task completion, as a percentage (for example, 20%).
          * ``s3-bucket`` - The Amazon S3 bucket to store the AMI.
          * ``s3-prefix`` - The beginning of the AMI name.
          * ``start-time`` - The time the task started (for example, 2013-09-15T17:15:20.000Z).
          * ``state`` - The state of the task (``pending`` | ``waiting-for-shutdown`` | ``bundling`` | ``storing`` | ``cancelling`` | ``complete`` | ``failed`` ).
          * ``update-time`` - The time of the most recent update for the task.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_byoip_cidrs(self, MaxResults: int, DryRun: bool = None, NextToken: str = None) -> Dict:
        """
        Describes the IP address ranges that were specified in calls to  ProvisionByoipCidr .
        To describe the address pools that were created when you provisioned the address ranges, use  DescribePublicIpv4Pools .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeByoipCidrs>`_
        
        **Request Syntax**
        ::
          response = client.describe_byoip_cidrs(
              DryRun=True|False,
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ByoipCidrs': [
                    {
                        'Cidr': 'string',
                        'Description': 'string',
                        'StatusMessage': 'string',
                        'State': 'advertised'|'deprovisioned'|'failed-deprovision'|'failed-provision'|'pending-deprovision'|'pending-provision'|'provisioned'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ByoipCidrs** *(list) --* 
              Information about your address ranges.
              - *(dict) --* 
                Information about an address range that is provisioned for use with your AWS resources through bring your own IP addresses (BYOIP).
                - **Cidr** *(string) --* 
                  The public IPv4 address range, in CIDR notation.
                - **Description** *(string) --* 
                  The description of the address range.
                - **StatusMessage** *(string) --* 
                  Upon success, contains the ID of the address pool. Otherwise, contains an error message.
                - **State** *(string) --* 
                  The state of the address pool.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults: **[REQUIRED]**
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_capacity_reservations(self, CapacityReservationIds: List = None, NextToken: str = None, MaxResults: int = None, Filters: List = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more of your Capacity Reservations. The results describe only the Capacity Reservations in the AWS Region that you're currently using.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeCapacityReservations>`_
        
        **Request Syntax**
        ::
          response = client.describe_capacity_reservations(
              CapacityReservationIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'CapacityReservations': [
                    {
                        'CapacityReservationId': 'string',
                        'InstanceType': 'string',
                        'InstancePlatform': 'Linux/UNIX'|'Red Hat Enterprise Linux'|'SUSE Linux'|'Windows'|'Windows with SQL Server'|'Windows with SQL Server Enterprise'|'Windows with SQL Server Standard'|'Windows with SQL Server Web'|'Linux with SQL Server Standard'|'Linux with SQL Server Web'|'Linux with SQL Server Enterprise',
                        'AvailabilityZone': 'string',
                        'Tenancy': 'default'|'dedicated',
                        'TotalInstanceCount': 123,
                        'AvailableInstanceCount': 123,
                        'EbsOptimized': True|False,
                        'EphemeralStorage': True|False,
                        'State': 'active'|'expired'|'cancelled'|'pending'|'failed',
                        'EndDate': datetime(2015, 1, 1),
                        'EndDateType': 'unlimited'|'limited',
                        'InstanceMatchCriteria': 'open'|'targeted',
                        'CreateDate': datetime(2015, 1, 1),
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
            - **CapacityReservations** *(list) --* 
              Information about the Capacity Reservations.
              - *(dict) --* 
                Describes a Capacity Reservation.
                - **CapacityReservationId** *(string) --* 
                  The ID of the Capacity Reservation.
                - **InstanceType** *(string) --* 
                  The type of instance for which the Capacity Reservation reserves capacity.
                - **InstancePlatform** *(string) --* 
                  The type of operating system for which the Capacity Reservation reserves capacity.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone in which the capacity is reserved.
                - **Tenancy** *(string) --* 
                  Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:
                  * ``default`` - The Capacity Reservation is created on hardware that is shared with other AWS accounts. 
                  * ``dedicated`` - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single AWS account. 
                - **TotalInstanceCount** *(integer) --* 
                  The number of instances for which the Capacity Reservation reserves capacity.
                - **AvailableInstanceCount** *(integer) --* 
                  The remaining capacity. Indicates the number of instances that can be launched in the Capacity Reservation.
                - **EbsOptimized** *(boolean) --* 
                  Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS- optimized instance.
                - **EphemeralStorage** *(boolean) --* 
                  Indicates whether the Capacity Reservation supports instances with temporary, block-level storage.
                - **State** *(string) --* 
                  The current state of the Capacity Reservation. A Capacity Reservation can be in one of the following states:
                  * ``active`` - The Capacity Reservation is active and the capacity is available for your use. 
                  * ``cancelled`` - The Capacity Reservation expired automatically at the date and time specified in your request. The reserved capacity is no longer available for your use. 
                  * ``expired`` - The Capacity Reservation was manually cancelled. The reserved capacity is no longer available for your use. 
                  * ``pending`` - The Capacity Reservation request was successful but the capacity provisioning is still pending. 
                  * ``failed`` - The Capacity Reservation request has failed. A request might fail due to invalid request parameters, capacity constraints, or instance limit constraints. Failed requests are retained for 60 minutes. 
                - **EndDate** *(datetime) --* 
                  The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to ``expired`` when it reaches its end date and time.
                - **EndDateType** *(string) --* 
                  Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:
                  * ``unlimited`` - The Capacity Reservation remains active until you explicitly cancel it. 
                  * ``limited`` - The Capacity Reservation expires automatically at a specified date and time. 
                - **InstanceMatchCriteria** *(string) --* 
                  Indicates the type of instance launches that the Capacity Reservation accepts. The options include:
                  * ``open`` - The Capacity Reservation accepts all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes launch into the Capacity Reservation automatically without specifying any additional parameters. 
                  * ``targeted`` - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.  
                - **CreateDate** *(datetime) --* 
                  The date and time at which the Capacity Reservation was created.
                - **Tags** *(list) --* 
                  Any tags assigned to the Capacity Reservation.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type CapacityReservationIds: list
        :param CapacityReservationIds:
          The ID of the Capacity Reservation.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value.
        :type Filters: list
        :param Filters:
          One or more filters.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_classic_link_instances(self, Filters: List = None, DryRun: bool = None, InstanceIds: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes one or more of your linked EC2-Classic instances. This request only returns information about EC2-Classic instances linked to a VPC through ClassicLink. You cannot use this request to return information about other instances.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeClassicLinkInstances>`_
        
        **Request Syntax**
        ::
          response = client.describe_classic_link_instances(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              InstanceIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'Instances': [
                    {
                        'Groups': [
                            {
                                'GroupName': 'string',
                                'GroupId': 'string'
                            },
                        ],
                        'InstanceId': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VpcId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Instances** *(list) --* 
              Information about one or more linked EC2-Classic instances.
              - *(dict) --* 
                Describes a linked EC2-Classic instance.
                - **Groups** *(list) --* 
                  A list of security groups.
                  - *(dict) --* 
                    Describes a security group.
                    - **GroupName** *(string) --* 
                      The name of the security group.
                    - **GroupId** *(string) --* 
                      The ID of the security group.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **Tags** *(list) --* 
                  Any tags assigned to the instance.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``group-id`` - The ID of a VPC security group that\'s associated with the instance.
          * ``instance-id`` - The ID of the instance.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-id`` - The ID of the VPC to which the instance is linked.  ``vpc-id`` - The ID of the VPC that the instance is linked to.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceIds: list
        :param InstanceIds:
          One or more instance IDs. Must be instances linked to a VPC through ClassicLink.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
          Constraint: If the value is greater than 1000, we return only 1000 items.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_client_vpn_authorization_rules(self, ClientVpnEndpointId: str, DryRun: bool = None, NextToken: str = None, Filters: List = None, MaxResults: int = None) -> Dict:
        """
        Describes the authorization rules for a specified Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeClientVpnAuthorizationRules>`_
        
        **Request Syntax**
        ::
          response = client.describe_client_vpn_authorization_rules(
              ClientVpnEndpointId='string',
              DryRun=True|False,
              NextToken='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'AuthorizationRules': [
                    {
                        'ClientVpnEndpointId': 'string',
                        'Description': 'string',
                        'GroupId': 'string',
                        'AccessAll': True|False,
                        'DestinationCidr': 'string',
                        'Status': {
                            'Code': 'authorizing'|'active'|'failed'|'revoking',
                            'Message': 'string'
                        }
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AuthorizationRules** *(list) --* 
              Information about the authorization rules.
              - *(dict) --* 
                Information about an authorization rule.
                - **ClientVpnEndpointId** *(string) --* 
                  The ID of the Client VPN endpoint with which the authorization rule is associated.
                - **Description** *(string) --* 
                  A brief description of the authorization rule.
                - **GroupId** *(string) --* 
                  The ID of the Active Directory group to which the authorization rule grants access.
                - **AccessAll** *(boolean) --* 
                  Indicates whether the authorization rule grants access to all clients.
                - **DestinationCidr** *(string) --* 
                  The IPv4 address range, in CIDR notation, of the network to which the authorization rule applies.
                - **Status** *(dict) --* 
                  The current state of the authorization rule.
                  - **Code** *(string) --* 
                    The state of the authorization rule.
                  - **Message** *(string) --* 
                    A message about the status of the authorization rule, if applicable.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type Filters: list
        :param Filters:
          One or more filters. Filter names and values are case-sensitive.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_client_vpn_connections(self, ClientVpnEndpointId: str, Filters: List = None, NextToken: str = None, MaxResults: int = None, DryRun: bool = None) -> Dict:
        """
        Describes active client connections and connections that have been terminated within the last 60 minutes for the specified Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeClientVpnConnections>`_
        
        **Request Syntax**
        ::
          response = client.describe_client_vpn_connections(
              ClientVpnEndpointId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              NextToken='string',
              MaxResults=123,
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Connections': [
                    {
                        'ClientVpnEndpointId': 'string',
                        'Timestamp': 'string',
                        'ConnectionId': 'string',
                        'Username': 'string',
                        'ConnectionEstablishedTime': 'string',
                        'IngressBytes': 'string',
                        'EgressBytes': 'string',
                        'IngressPackets': 'string',
                        'EgressPackets': 'string',
                        'ClientIp': 'string',
                        'CommonName': 'string',
                        'Status': {
                            'Code': 'active'|'failed-to-terminate'|'terminating'|'terminated',
                            'Message': 'string'
                        },
                        'ConnectionEndTime': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Connections** *(list) --* 
              Information about the active and terminated client connections.
              - *(dict) --* 
                Describes a client connection.
                - **ClientVpnEndpointId** *(string) --* 
                  The ID of the Client VPN endpoint to which the client is connected.
                - **Timestamp** *(string) --* 
                  The current date and time.
                - **ConnectionId** *(string) --* 
                  The ID of the client connection.
                - **Username** *(string) --* 
                  The username of the client who established the client connection. This information is only provided if Active Directory client authentication is used.
                - **ConnectionEstablishedTime** *(string) --* 
                  The date and time the client connection was established.
                - **IngressBytes** *(string) --* 
                  The number of bytes sent by the client.
                - **EgressBytes** *(string) --* 
                  The number of bytes received by the client.
                - **IngressPackets** *(string) --* 
                  The number of packets sent by the client.
                - **EgressPackets** *(string) --* 
                  The number of packets received by the client.
                - **ClientIp** *(string) --* 
                  The IP address of the client.
                - **CommonName** *(string) --* 
                  The common name associated with the client. This is either the name of the client certificate, or the Active Directory user name.
                - **Status** *(dict) --* 
                  The current state of the client connection.
                  - **Code** *(string) --* 
                    The state of the client connection.
                  - **Message** *(string) --* 
                    A message about the status of the client connection, if applicable.
                - **ConnectionEndTime** *(string) --* 
                  The date and time the client connection was terminated.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type Filters: list
        :param Filters:
          One or more filters. Filter names and values are case-sensitive.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_client_vpn_endpoints(self, ClientVpnEndpointIds: List = None, MaxResults: int = None, NextToken: str = None, Filters: List = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more Client VPN endpoints in the account.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeClientVpnEndpoints>`_
        
        **Request Syntax**
        ::
          response = client.describe_client_vpn_endpoints(
              ClientVpnEndpointIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ClientVpnEndpoints': [
                    {
                        'ClientVpnEndpointId': 'string',
                        'Description': 'string',
                        'Status': {
                            'Code': 'pending-associate'|'available'|'deleting'|'deleted',
                            'Message': 'string'
                        },
                        'CreationTime': 'string',
                        'DeletionTime': 'string',
                        'DnsName': 'string',
                        'ClientCidrBlock': 'string',
                        'DnsServers': [
                            'string',
                        ],
                        'SplitTunnel': True|False,
                        'VpnProtocol': 'openvpn',
                        'TransportProtocol': 'tcp'|'udp',
                        'AssociatedTargetNetworks': [
                            {
                                'NetworkId': 'string',
                                'NetworkType': 'vpc'
                            },
                        ],
                        'ServerCertificateArn': 'string',
                        'AuthenticationOptions': [
                            {
                                'Type': 'certificate-authentication'|'directory-service-authentication',
                                'ActiveDirectory': {
                                    'DirectoryId': 'string'
                                },
                                'MutualAuthentication': {
                                    'ClientRootCertificateChain': 'string'
                                }
                            },
                        ],
                        'ConnectionLogOptions': {
                            'Enabled': True|False,
                            'CloudwatchLogGroup': 'string',
                            'CloudwatchLogStream': 'string'
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientVpnEndpoints** *(list) --* 
              Information about the Client VPN endpoints.
              - *(dict) --* 
                Describes a Client VPN endpoint.
                - **ClientVpnEndpointId** *(string) --* 
                  The ID of the Client VPN endpoint.
                - **Description** *(string) --* 
                  A brief description of the endpoint.
                - **Status** *(dict) --* 
                  The current state of the Client VPN endpoint.
                  - **Code** *(string) --* 
                    The state of the Client VPN endpoint. Possible states include:
                    * ``pending-associate`` - The Client VPN endpoint has been created but no target networks have been associated. The Client VPN endpoint cannot accept connections. 
                    * ``available`` - The Client VPN endpoint has been created and a target network has been associated. The Client VPN endpoint can accept connections. 
                    * ``deleting`` - The Client VPN endpoint is being deleted. The Client VPN endpoint cannot accept connections. 
                    * ``deleted`` - The Client VPN endpoint has been deleted. The Client VPN endpoint cannot accept connections. 
                  - **Message** *(string) --* 
                    A message about the status of the Client VPN endpoint.
                - **CreationTime** *(string) --* 
                  The date and time the Client VPN endpoint was created.
                - **DeletionTime** *(string) --* 
                  The date and time the Client VPN endpoint was deleted, if applicable.
                - **DnsName** *(string) --* 
                  The DNS name to be used by clients when connecting to the Client VPN endpoint.
                - **ClientCidrBlock** *(string) --* 
                  The IPv4 address range, in CIDR notation, from which client IP addresses are assigned.
                - **DnsServers** *(list) --* 
                  Information about the DNS servers to be used for DNS resolution. 
                  - *(string) --* 
                - **SplitTunnel** *(boolean) --* 
                  Indicates whether VPN split tunneling is supported.
                - **VpnProtocol** *(string) --* 
                  The protocol used by the VPN session.
                - **TransportProtocol** *(string) --* 
                  The transport protocol used by the Client VPN endpoint.
                - **AssociatedTargetNetworks** *(list) --* 
                  Information about the associated target networks. A target network is a subnet in a VPC.
                  - *(dict) --* 
                    Describes a target network that is associated with a Client VPN endpoint. A target network is a subnet in a VPC.
                    - **NetworkId** *(string) --* 
                      The ID of the subnet.
                    - **NetworkType** *(string) --* 
                      The target network type.
                - **ServerCertificateArn** *(string) --* 
                  The ARN of the server certificate.
                - **AuthenticationOptions** *(list) --* 
                  Information about the authentication method used by the Client VPN endpoint.
                  - *(dict) --* 
                    Describes the authentication methods used by a Client VPN endpoint. Client VPN supports Active Directory and mutual authentication. For more information, see `Authentication <https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/authentication-authrization.html#client-authentication>`__ in the *AWS Client VPN Administrator Guide* .
                    - **Type** *(string) --* 
                      The authentication type used.
                    - **ActiveDirectory** *(dict) --* 
                      Information about the Active Directory, if applicable.
                      - **DirectoryId** *(string) --* 
                        The ID of the Active Directory used for authentication.
                    - **MutualAuthentication** *(dict) --* 
                      Information about the authentication certificates, if applicable.
                      - **ClientRootCertificateChain** *(string) --* 
                        The ARN of the client certificate. 
                - **ConnectionLogOptions** *(dict) --* 
                  Information about the client connection logging options for the Client VPN endpoint.
                  - **Enabled** *(boolean) --* 
                    Indicates whether client connection logging is enabled for the Client VPN endpoint.
                  - **CloudwatchLogGroup** *(string) --* 
                    The name of the Amazon CloudWatch Logs log group to which connection logging data is published.
                  - **CloudwatchLogStream** *(string) --* 
                    The name of the Amazon CloudWatch Logs log stream to which connection logging data is published.
                - **Tags** *(list) --* 
                  Any tags assigned to the Client VPN endpoint.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type ClientVpnEndpointIds: list
        :param ClientVpnEndpointIds:
          The ID of the Client VPN endpoint.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type Filters: list
        :param Filters:
          One or more filters. Filter names and values are case-sensitive.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_client_vpn_routes(self, ClientVpnEndpointId: str, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Describes the routes for the specified Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeClientVpnRoutes>`_
        
        **Request Syntax**
        ::
          response = client.describe_client_vpn_routes(
              ClientVpnEndpointId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Routes': [
                    {
                        'ClientVpnEndpointId': 'string',
                        'DestinationCidr': 'string',
                        'TargetSubnet': 'string',
                        'Type': 'string',
                        'Origin': 'string',
                        'Status': {
                            'Code': 'creating'|'active'|'failed'|'deleting',
                            'Message': 'string'
                        },
                        'Description': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Routes** *(list) --* 
              Information about the Client VPN endpoint routes.
              - *(dict) --* 
                Information about a Client VPN endpoint route.
                - **ClientVpnEndpointId** *(string) --* 
                  The ID of the Client VPN endpoint with which the route is associated.
                - **DestinationCidr** *(string) --* 
                  The IPv4 address range, in CIDR notation, of the route destination.
                - **TargetSubnet** *(string) --* 
                  The ID of the subnet through which traffic is routed.
                - **Type** *(string) --* 
                  The route type.
                - **Origin** *(string) --* 
                  Indicates how the route was associated with the Client VPN endpoint. ``associate`` indicates that the route was automatically added when the target network was associated with the Client VPN endpoint. ``add-route`` indicates that the route was manually added using the **CreateClientVpnRoute** action.
                - **Status** *(dict) --* 
                  The current state of the route.
                  - **Code** *(string) --* 
                    The state of the Client VPN endpoint route.
                  - **Message** *(string) --* 
                    A message about the status of the Client VPN endpoint route, if applicable.
                - **Description** *(string) --* 
                  A brief description of the route.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type Filters: list
        :param Filters:
          One or more filters. Filter names and values are case-sensitive.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_client_vpn_target_networks(self, ClientVpnEndpointId: str, AssociationIds: List = None, MaxResults: int = None, NextToken: str = None, Filters: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the target networks associated with the specified Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeClientVpnTargetNetworks>`_
        
        **Request Syntax**
        ::
          response = client.describe_client_vpn_target_networks(
              ClientVpnEndpointId='string',
              AssociationIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ClientVpnTargetNetworks': [
                    {
                        'AssociationId': 'string',
                        'VpcId': 'string',
                        'TargetNetworkId': 'string',
                        'ClientVpnEndpointId': 'string',
                        'Status': {
                            'Code': 'associating'|'associated'|'association-failed'|'disassociating'|'disassociated',
                            'Message': 'string'
                        },
                        'SecurityGroups': [
                            'string',
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientVpnTargetNetworks** *(list) --* 
              Information about the associated target networks.
              - *(dict) --* 
                Describes a target network associated with a Client VPN endpoint.
                - **AssociationId** *(string) --* 
                  The ID of the association.
                - **VpcId** *(string) --* 
                  The ID of the VPC in which the target network (subnet) is located.
                - **TargetNetworkId** *(string) --* 
                  The ID of the subnet specified as the target network.
                - **ClientVpnEndpointId** *(string) --* 
                  The ID of the Client VPN endpoint with which the target network is associated.
                - **Status** *(dict) --* 
                  The current state of the target network association.
                  - **Code** *(string) --* 
                    The state of the target network association.
                  - **Message** *(string) --* 
                    A message about the status of the target network association, if applicable.
                - **SecurityGroups** *(list) --* 
                  The IDs of the security groups applied to the target network association.
                  - *(string) --* 
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type AssociationIds: list
        :param AssociationIds:
          The IDs of the target network associations.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type Filters: list
        :param Filters:
          One or more filters. Filter names and values are case-sensitive.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_conversion_tasks(self, ConversionTaskIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the specified conversion tasks or all your conversion tasks. For more information, see the `VM Import/Export User Guide <https://docs.aws.amazon.com/vm-import/latest/userguide/>`__ .
        For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeConversionTasks>`_
        
        **Request Syntax**
        ::
          response = client.describe_conversion_tasks(
              ConversionTaskIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ConversionTasks': [
                    {
                        'ConversionTaskId': 'string',
                        'ExpirationTime': 'string',
                        'ImportInstance': {
                            'Description': 'string',
                            'InstanceId': 'string',
                            'Platform': 'Windows',
                            'Volumes': [
                                {
                                    'AvailabilityZone': 'string',
                                    'BytesConverted': 123,
                                    'Description': 'string',
                                    'Image': {
                                        'Checksum': 'string',
                                        'Format': 'VMDK'|'RAW'|'VHD',
                                        'ImportManifestUrl': 'string',
                                        'Size': 123
                                    },
                                    'Status': 'string',
                                    'StatusMessage': 'string',
                                    'Volume': {
                                        'Id': 'string',
                                        'Size': 123
                                    }
                                },
                            ]
                        },
                        'ImportVolume': {
                            'AvailabilityZone': 'string',
                            'BytesConverted': 123,
                            'Description': 'string',
                            'Image': {
                                'Checksum': 'string',
                                'Format': 'VMDK'|'RAW'|'VHD',
                                'ImportManifestUrl': 'string',
                                'Size': 123
                            },
                            'Volume': {
                                'Id': 'string',
                                'Size': 123
                            }
                        },
                        'State': 'active'|'cancelling'|'cancelled'|'completed',
                        'StatusMessage': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for DescribeConversionTasks.
            - **ConversionTasks** *(list) --* 
              Information about the conversion tasks.
              - *(dict) --* 
                Describes a conversion task.
                - **ConversionTaskId** *(string) --* 
                  The ID of the conversion task.
                - **ExpirationTime** *(string) --* 
                  The time when the task expires. If the upload isn't complete before the expiration time, we automatically cancel the task.
                - **ImportInstance** *(dict) --* 
                  If the task is for importing an instance, this contains information about the import instance task.
                  - **Description** *(string) --* 
                    A description of the task.
                  - **InstanceId** *(string) --* 
                    The ID of the instance.
                  - **Platform** *(string) --* 
                    The instance operating system.
                  - **Volumes** *(list) --* 
                    The volumes.
                    - *(dict) --* 
                      Describes an import volume task.
                      - **AvailabilityZone** *(string) --* 
                        The Availability Zone where the resulting instance will reside.
                      - **BytesConverted** *(integer) --* 
                        The number of bytes converted so far.
                      - **Description** *(string) --* 
                        A description of the task.
                      - **Image** *(dict) --* 
                        The image.
                        - **Checksum** *(string) --* 
                          The checksum computed for the disk image.
                        - **Format** *(string) --* 
                          The disk image format.
                        - **ImportManifestUrl** *(string) --* 
                          A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
                          For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
                        - **Size** *(integer) --* 
                          The size of the disk image, in GiB.
                      - **Status** *(string) --* 
                        The status of the import of this particular disk image.
                      - **StatusMessage** *(string) --* 
                        The status information or errors related to the disk image.
                      - **Volume** *(dict) --* 
                        The volume.
                        - **Id** *(string) --* 
                          The volume identifier.
                        - **Size** *(integer) --* 
                          The size of the volume, in GiB.
                - **ImportVolume** *(dict) --* 
                  If the task is for importing a volume, this contains information about the import volume task.
                  - **AvailabilityZone** *(string) --* 
                    The Availability Zone where the resulting volume will reside.
                  - **BytesConverted** *(integer) --* 
                    The number of bytes converted so far.
                  - **Description** *(string) --* 
                    The description you provided when starting the import volume task.
                  - **Image** *(dict) --* 
                    The image.
                    - **Checksum** *(string) --* 
                      The checksum computed for the disk image.
                    - **Format** *(string) --* 
                      The disk image format.
                    - **ImportManifestUrl** *(string) --* 
                      A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
                      For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
                    - **Size** *(integer) --* 
                      The size of the disk image, in GiB.
                  - **Volume** *(dict) --* 
                    The volume.
                    - **Id** *(string) --* 
                      The volume identifier.
                    - **Size** *(integer) --* 
                      The size of the volume, in GiB.
                - **State** *(string) --* 
                  The state of the conversion task.
                - **StatusMessage** *(string) --* 
                  The status message related to the conversion task.
                - **Tags** *(list) --* 
                  Any tags assigned to the task.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type ConversionTaskIds: list
        :param ConversionTaskIds:
          The conversion task IDs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_customer_gateways(self, CustomerGatewayIds: List = None, Filters: List = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more of your VPN customer gateways.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeCustomerGateways>`_
        
        **Request Syntax**
        ::
          response = client.describe_customer_gateways(
              CustomerGatewayIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'CustomerGateways': [
                    {
                        'BgpAsn': 'string',
                        'CustomerGatewayId': 'string',
                        'IpAddress': 'string',
                        'State': 'string',
                        'Type': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeCustomerGateways.
            - **CustomerGateways** *(list) --* 
              Information about one or more customer gateways.
              - *(dict) --* 
                Describes a customer gateway.
                - **BgpAsn** *(string) --* 
                  The customer gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).
                - **CustomerGatewayId** *(string) --* 
                  The ID of the customer gateway.
                - **IpAddress** *(string) --* 
                  The Internet-routable IP address of the customer gateway's outside interface.
                - **State** *(string) --* 
                  The current state of the customer gateway (``pending | available | deleting | deleted`` ).
                - **Type** *(string) --* 
                  The type of VPN connection the customer gateway supports (``ipsec.1`` ).
                - **Tags** *(list) --* 
                  Any tags assigned to the customer gateway.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type CustomerGatewayIds: list
        :param CustomerGatewayIds:
          One or more customer gateway IDs.
          Default: Describes all your customer gateways.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``bgp-asn`` - The customer gateway\'s Border Gateway Protocol (BGP) Autonomous System Number (ASN).
          * ``customer-gateway-id`` - The ID of the customer gateway.
          * ``ip-address`` - The IP address of the customer gateway\'s Internet-routable external interface.
          * ``state`` - The state of the customer gateway (``pending`` | ``available`` | ``deleting`` | ``deleted`` ).
          * ``type`` - The type of customer gateway. Currently, the only supported type is ``ipsec.1`` .
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_dhcp_options(self, DhcpOptionsIds: List = None, Filters: List = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more of your DHCP options sets.
        For more information, see `DHCP Options Sets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_DHCP_Options.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeDhcpOptions>`_
        
        **Request Syntax**
        ::
          response = client.describe_dhcp_options(
              DhcpOptionsIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'DhcpOptions': [
                    {
                        'DhcpConfigurations': [
                            {
                                'Key': 'string',
                                'Values': [
                                    {
                                        'Value': 'string'
                                    },
                                ]
                            },
                        ],
                        'DhcpOptionsId': 'string',
                        'OwnerId': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **DhcpOptions** *(list) --* 
              Information about one or more DHCP options sets.
              - *(dict) --* 
                Describes a set of DHCP options.
                - **DhcpConfigurations** *(list) --* 
                  One or more DHCP options in the set.
                  - *(dict) --* 
                    Describes a DHCP configuration option.
                    - **Key** *(string) --* 
                      The name of a DHCP option.
                    - **Values** *(list) --* 
                      One or more values for the DHCP option.
                      - *(dict) --* 
                        Describes a value for a resource attribute that is a String.
                        - **Value** *(string) --* 
                          The attribute value. The value is case-sensitive.
                - **DhcpOptionsId** *(string) --* 
                  The ID of the set of DHCP options.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account that owns the DHCP options set.
                - **Tags** *(list) --* 
                  Any tags assigned to the DHCP options set.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DhcpOptionsIds: list
        :param DhcpOptionsIds:
          The IDs of one or more DHCP options sets.
          Default: Describes all your DHCP options sets.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``dhcp-options-id`` - The ID of a DHCP options set.
          * ``key`` - The key for one of the options (for example, ``domain-name`` ).
          * ``value`` - The value for one of the options.
          * ``owner-id`` - The ID of the AWS account that owns the DHCP options set.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_egress_only_internet_gateways(self, DryRun: bool = None, EgressOnlyInternetGatewayIds: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes one or more of your egress-only internet gateways.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeEgressOnlyInternetGateways>`_
        
        **Request Syntax**
        ::
          response = client.describe_egress_only_internet_gateways(
              DryRun=True|False,
              EgressOnlyInternetGatewayIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'EgressOnlyInternetGateways': [
                    {
                        'Attachments': [
                            {
                                'State': 'attaching'|'attached'|'detaching'|'detached',
                                'VpcId': 'string'
                            },
                        ],
                        'EgressOnlyInternetGatewayId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **EgressOnlyInternetGateways** *(list) --* 
              Information about the egress-only internet gateways.
              - *(dict) --* 
                Describes an egress-only internet gateway.
                - **Attachments** *(list) --* 
                  Information about the attachment of the egress-only internet gateway.
                  - *(dict) --* 
                    Describes the attachment of a VPC to an internet gateway or an egress-only internet gateway.
                    - **State** *(string) --* 
                      The current state of the attachment. For an internet gateway, the state is ``available`` when attached to a VPC; otherwise, this value is not returned.
                    - **VpcId** *(string) --* 
                      The ID of the VPC.
                - **EgressOnlyInternetGatewayId** *(string) --* 
                  The ID of the egress-only internet gateway.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EgressOnlyInternetGatewayIds: list
        :param EgressOnlyInternetGatewayIds:
          One or more egress-only internet gateway IDs.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_elastic_gpus(self, ElasticGpuIds: List = None, DryRun: bool = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the Elastic Graphics accelerator associated with your instances. For more information about Elastic Graphics, see `Amazon Elastic Graphics <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/elastic-graphics.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeElasticGpus>`_
        
        **Request Syntax**
        ::
          response = client.describe_elastic_gpus(
              ElasticGpuIds=[
                  'string',
              ],
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ElasticGpuSet': [
                    {
                        'ElasticGpuId': 'string',
                        'AvailabilityZone': 'string',
                        'ElasticGpuType': 'string',
                        'ElasticGpuHealth': {
                            'Status': 'OK'|'IMPAIRED'
                        },
                        'ElasticGpuState': 'ATTACHED',
                        'InstanceId': 'string'
                    },
                ],
                'MaxResults': 123,
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ElasticGpuSet** *(list) --* 
              Information about the Elastic Graphics accelerators.
              - *(dict) --* 
                Describes an Elastic Graphics accelerator.
                - **ElasticGpuId** *(string) --* 
                  The ID of the Elastic Graphics accelerator.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone in the which the Elastic Graphics accelerator resides.
                - **ElasticGpuType** *(string) --* 
                  The type of Elastic Graphics accelerator.
                - **ElasticGpuHealth** *(dict) --* 
                  The status of the Elastic Graphics accelerator.
                  - **Status** *(string) --* 
                    The health status.
                - **ElasticGpuState** *(string) --* 
                  The state of the Elastic Graphics accelerator.
                - **InstanceId** *(string) --* 
                  The ID of the instance to which the Elastic Graphics accelerator is attached.
            - **MaxResults** *(integer) --* 
              The total number of items to return. If the total number of items available is more than the value specified in max-items then a Next-Token will be provided in the output that you can use to resume pagination.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type ElasticGpuIds: list
        :param ElasticGpuIds:
          The Elastic Graphics accelerator IDs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          The filters.
          * ``availability-zone`` - The Availability Zone in which the Elastic Graphics accelerator resides.
          * ``elastic-gpu-health`` - The status of the Elastic Graphics accelerator (``OK`` | ``IMPAIRED`` ).
          * ``elastic-gpu-state`` - The state of the Elastic Graphics accelerator (``ATTACHED`` ).
          * ``elastic-gpu-type`` - The type of Elastic Graphics accelerator; for example, ``eg1.medium`` .
          * ``instance-id`` - The ID of the instance to which the Elastic Graphics accelerator is associated.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value. This value can be between 5 and 1000.
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_export_tasks(self, ExportTaskIds: List = None) -> Dict:
        """
        Describes the specified export tasks or all your export tasks.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeExportTasks>`_
        
        **Request Syntax**
        ::
          response = client.describe_export_tasks(
              ExportTaskIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ExportTasks': [
                    {
                        'Description': 'string',
                        'ExportTaskId': 'string',
                        'ExportToS3Task': {
                            'ContainerFormat': 'ova',
                            'DiskImageFormat': 'VMDK'|'RAW'|'VHD',
                            'S3Bucket': 'string',
                            'S3Key': 'string'
                        },
                        'InstanceExportDetails': {
                            'InstanceId': 'string',
                            'TargetEnvironment': 'citrix'|'vmware'|'microsoft'
                        },
                        'State': 'active'|'cancelling'|'cancelled'|'completed',
                        'StatusMessage': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for DescribeExportTasks.
            - **ExportTasks** *(list) --* 
              Information about the export tasks.
              - *(dict) --* 
                Describes an instance export task.
                - **Description** *(string) --* 
                  A description of the resource being exported.
                - **ExportTaskId** *(string) --* 
                  The ID of the export task.
                - **ExportToS3Task** *(dict) --* 
                  Information about the export task.
                  - **ContainerFormat** *(string) --* 
                    The container format used to combine disk images with metadata (such as OVF). If absent, only the disk image is exported.
                  - **DiskImageFormat** *(string) --* 
                    The format for the exported image.
                  - **S3Bucket** *(string) --* 
                    The S3 bucket for the destination image. The destination bucket must exist and grant WRITE and READ_ACP permissions to the AWS account ``vm-import-export@amazon.com`` .
                  - **S3Key** *(string) --* 
                    The encryption key for your S3 bucket.
                - **InstanceExportDetails** *(dict) --* 
                  Information about the instance to export.
                  - **InstanceId** *(string) --* 
                    The ID of the resource being exported.
                  - **TargetEnvironment** *(string) --* 
                    The target virtualization environment.
                - **State** *(string) --* 
                  The state of the export task.
                - **StatusMessage** *(string) --* 
                  The status message related to the export task.
        :type ExportTaskIds: list
        :param ExportTaskIds:
          The export task IDs.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_fleet_history(self, FleetId: str, StartTime: datetime, DryRun: bool = None, EventType: str = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the events for the specified EC2 Fleet during the specified time.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeFleetHistory>`_
        
        **Request Syntax**
        ::
          response = client.describe_fleet_history(
              DryRun=True|False,
              EventType='instance-change'|'fleet-change'|'service-error',
              MaxResults=123,
              NextToken='string',
              FleetId='string',
              StartTime=datetime(2015, 1, 1)
          )
        
        **Response Syntax**
        ::
            {
                'HistoryRecords': [
                    {
                        'EventInformation': {
                            'EventDescription': 'string',
                            'EventSubType': 'string',
                            'InstanceId': 'string'
                        },
                        'EventType': 'instance-change'|'fleet-change'|'service-error',
                        'Timestamp': datetime(2015, 1, 1)
                    },
                ],
                'LastEvaluatedTime': datetime(2015, 1, 1),
                'NextToken': 'string',
                'FleetId': 'string',
                'StartTime': datetime(2015, 1, 1)
            }
        
        **Response Structure**
          - *(dict) --* 
            - **HistoryRecords** *(list) --* 
              Information about the events in the history of the EC2 Fleet.
              - *(dict) --* 
                Describes an event in the history of an EC2 Fleet.
                - **EventInformation** *(dict) --* 
                  Information about the event.
                  - **EventDescription** *(string) --* 
                    The description of the event.
                  - **EventSubType** *(string) --* 
                    The event.
                    The following are the ``error`` events:
                    * ``iamFleetRoleInvalid`` - The EC2 Fleet or Spot Fleet did not have the required permissions either to launch or terminate an instance. 
                    * ``spotFleetRequestConfigurationInvalid`` - The configuration is not valid. For more information, see the description of the event. 
                    * ``spotInstanceCountLimitExceeded`` - You've reached the limit on the number of Spot Instances that you can launch. 
                    The following are the ``fleetRequestChange`` events:
                    * ``active`` - The EC2 Fleet or Spot Fleet request has been validated and Amazon EC2 is attempting to maintain the target number of running Spot Instances. 
                    * ``cancelled`` - The EC2 Fleet or Spot Fleet request is canceled and has no running Spot Instances. The EC2 Fleet or Spot Fleet will be deleted two days after its instances were terminated. 
                    * ``cancelled_running`` - The EC2 Fleet or Spot Fleet request is canceled and does not launch additional Spot Instances. Existing Spot Instances continue to run until they are interrupted or terminated. 
                    * ``cancelled_terminating`` - The EC2 Fleet or Spot Fleet request is canceled and its Spot Instances are terminating. 
                    * ``expired`` - The EC2 Fleet or Spot Fleet request has expired. A subsequent event indicates that the instances were terminated, if the request was created with ``TerminateInstancesWithExpiration`` set. 
                    * ``modify_in_progress`` - A request to modify the EC2 Fleet or Spot Fleet request was accepted and is in progress. 
                    * ``modify_successful`` - The EC2 Fleet or Spot Fleet request was modified. 
                    * ``price_update`` - The price for a launch configuration was adjusted because it was too high. This change is permanent. 
                    * ``submitted`` - The EC2 Fleet or Spot Fleet request is being evaluated and Amazon EC2 is preparing to launch the target number of Spot Instances. 
                    The following are the ``instanceChange`` events:
                    * ``launched`` - A request was fulfilled and a new instance was launched. 
                    * ``terminated`` - An instance was terminated by the user. 
                    The following are the ``Information`` events:
                    * ``launchSpecTemporarilyBlacklisted`` - The configuration is not valid and several attempts to launch instances have failed. For more information, see the description of the event. 
                    * ``launchSpecUnusable`` - The price in a launch specification is not valid because it is below the Spot price or the Spot price is above the On-Demand price. 
                    * ``fleetProgressHalted`` - The price in every launch specification is not valid. A launch specification might become valid if the Spot price changes. 
                  - **InstanceId** *(string) --* 
                    The ID of the instance. This information is available only for ``instanceChange`` events.
                - **EventType** *(string) --* 
                  The event type.
                - **Timestamp** *(datetime) --* 
                  The date and time of the event, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
            - **LastEvaluatedTime** *(datetime) --* 
              The last date and time for the events, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). All records up to this time were retrieved.
              If ``nextToken`` indicates that there are more results, this value is not present.
            - **NextToken** *(string) --* 
              The token for the next set of results.
            - **FleetId** *(string) --* 
              The ID of the EC Fleet.
            - **StartTime** *(datetime) --* 
              The start date and time for the events, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EventType: string
        :param EventType:
          The type of events to describe. By default, all events are described.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type FleetId: string
        :param FleetId: **[REQUIRED]**
          The ID of the EC2 Fleet.
        :type StartTime: datetime
        :param StartTime: **[REQUIRED]**
          The start date and time for the events, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
        :rtype: dict
        :returns:
        """
        pass

    def describe_fleet_instances(self, FleetId: str, DryRun: bool = None, MaxResults: int = None, NextToken: str = None, Filters: List = None) -> Dict:
        """
        Describes the running instances for the specified EC2 Fleet.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeFleetInstances>`_
        
        **Request Syntax**
        ::
          response = client.describe_fleet_instances(
              DryRun=True|False,
              MaxResults=123,
              NextToken='string',
              FleetId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ActiveInstances': [
                    {
                        'InstanceId': 'string',
                        'InstanceType': 'string',
                        'SpotInstanceRequestId': 'string',
                        'InstanceHealth': 'healthy'|'unhealthy'
                    },
                ],
                'NextToken': 'string',
                'FleetId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ActiveInstances** *(list) --* 
              The running instances. This list is refreshed periodically and might be out of date.
              - *(dict) --* 
                Describes a running instance in a Spot Fleet.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **InstanceType** *(string) --* 
                  The instance type.
                - **SpotInstanceRequestId** *(string) --* 
                  The ID of the Spot Instance request.
                - **InstanceHealth** *(string) --* 
                  The health status of the instance. If the status of either the instance status check or the system status check is ``impaired`` , the health status of the instance is ``unhealthy`` . Otherwise, the health status is ``healthy`` .
            - **NextToken** *(string) --* 
              The token for the next set of results.
            - **FleetId** *(string) --* 
              The ID of the EC2 Fleet.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type FleetId: string
        :param FleetId: **[REQUIRED]**
          The ID of the EC2 Fleet.
        :type Filters: list
        :param Filters:
          The filters.
          * ``instance-type`` - The instance type.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_fleets(self, DryRun: bool = None, MaxResults: int = None, NextToken: str = None, FleetIds: List = None, Filters: List = None) -> Dict:
        """
        Describes the specified EC2 Fleets or all your EC2 Fleets.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeFleets>`_
        
        **Request Syntax**
        ::
          response = client.describe_fleets(
              DryRun=True|False,
              MaxResults=123,
              NextToken='string',
              FleetIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'Fleets': [
                    {
                        'ActivityStatus': 'error'|'pending-fulfillment'|'pending-termination'|'fulfilled',
                        'CreateTime': datetime(2015, 1, 1),
                        'FleetId': 'string',
                        'FleetState': 'submitted'|'active'|'deleted'|'failed'|'deleted-running'|'deleted-terminating'|'modifying',
                        'ClientToken': 'string',
                        'ExcessCapacityTerminationPolicy': 'no-termination'|'termination',
                        'FulfilledCapacity': 123.0,
                        'FulfilledOnDemandCapacity': 123.0,
                        'LaunchTemplateConfigs': [
                            {
                                'LaunchTemplateSpecification': {
                                    'LaunchTemplateId': 'string',
                                    'LaunchTemplateName': 'string',
                                    'Version': 'string'
                                },
                                'Overrides': [
                                    {
                                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                        'MaxPrice': 'string',
                                        'SubnetId': 'string',
                                        'AvailabilityZone': 'string',
                                        'WeightedCapacity': 123.0,
                                        'Priority': 123.0,
                                        'Placement': {
                                            'GroupName': 'string'
                                        }
                                    },
                                ]
                            },
                        ],
                        'TargetCapacitySpecification': {
                            'TotalTargetCapacity': 123,
                            'OnDemandTargetCapacity': 123,
                            'SpotTargetCapacity': 123,
                            'DefaultTargetCapacityType': 'spot'|'on-demand'
                        },
                        'TerminateInstancesWithExpiration': True|False,
                        'Type': 'request'|'maintain'|'instant',
                        'ValidFrom': datetime(2015, 1, 1),
                        'ValidUntil': datetime(2015, 1, 1),
                        'ReplaceUnhealthyInstances': True|False,
                        'SpotOptions': {
                            'AllocationStrategy': 'lowest-price'|'diversified',
                            'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate',
                            'InstancePoolsToUseCount': 123,
                            'SingleInstanceType': True|False,
                            'SingleAvailabilityZone': True|False,
                            'MinTargetCapacity': 123
                        },
                        'OnDemandOptions': {
                            'AllocationStrategy': 'lowest-price'|'prioritized',
                            'SingleInstanceType': True|False,
                            'SingleAvailabilityZone': True|False,
                            'MinTargetCapacity': 123
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'Errors': [
                            {
                                'LaunchTemplateAndOverrides': {
                                    'LaunchTemplateSpecification': {
                                        'LaunchTemplateId': 'string',
                                        'LaunchTemplateName': 'string',
                                        'Version': 'string'
                                    },
                                    'Overrides': {
                                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                        'MaxPrice': 'string',
                                        'SubnetId': 'string',
                                        'AvailabilityZone': 'string',
                                        'WeightedCapacity': 123.0,
                                        'Priority': 123.0,
                                        'Placement': {
                                            'GroupName': 'string'
                                        }
                                    }
                                },
                                'Lifecycle': 'spot'|'on-demand',
                                'ErrorCode': 'string',
                                'ErrorMessage': 'string'
                            },
                        ],
                        'Instances': [
                            {
                                'LaunchTemplateAndOverrides': {
                                    'LaunchTemplateSpecification': {
                                        'LaunchTemplateId': 'string',
                                        'LaunchTemplateName': 'string',
                                        'Version': 'string'
                                    },
                                    'Overrides': {
                                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                        'MaxPrice': 'string',
                                        'SubnetId': 'string',
                                        'AvailabilityZone': 'string',
                                        'WeightedCapacity': 123.0,
                                        'Priority': 123.0,
                                        'Placement': {
                                            'GroupName': 'string'
                                        }
                                    }
                                },
                                'Lifecycle': 'spot'|'on-demand',
                                'InstanceIds': [
                                    'string',
                                ],
                                'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                'Platform': 'Windows'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token for the next set of results.
            - **Fleets** *(list) --* 
              Information about the EC2 Fleets.
              - *(dict) --* 
                Describes an EC2 Fleet.
                - **ActivityStatus** *(string) --* 
                  The progress of the EC2 Fleet. If there is an error, the status is ``error`` . After all requests are placed, the status is ``pending_fulfillment`` . If the size of the EC2 Fleet is equal to or greater than its target capacity, the status is ``fulfilled`` . If the size of the EC2 Fleet is decreased, the status is ``pending_termination`` while instances are terminating.
                - **CreateTime** *(datetime) --* 
                  The creation date and time of the EC2 Fleet.
                - **FleetId** *(string) --* 
                  The ID of the EC2 Fleet.
                - **FleetState** *(string) --* 
                  The state of the EC2 Fleet.
                - **ClientToken** *(string) --* 
                  Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
                  Constraints: Maximum 64 ASCII characters
                - **ExcessCapacityTerminationPolicy** *(string) --* 
                  Indicates whether running instances should be terminated if the target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet.
                - **FulfilledCapacity** *(float) --* 
                  The number of units fulfilled by this request compared to the set target capacity.
                - **FulfilledOnDemandCapacity** *(float) --* 
                  The number of units fulfilled by this request compared to the set target On-Demand capacity.
                - **LaunchTemplateConfigs** *(list) --* 
                  The launch template and overrides.
                  - *(dict) --* 
                    Describes a launch template and overrides.
                    - **LaunchTemplateSpecification** *(dict) --* 
                      The launch template.
                      - **LaunchTemplateId** *(string) --* 
                        The ID of the launch template. You must specify either a template ID or a template name.
                      - **LaunchTemplateName** *(string) --* 
                        The name of the launch template. You must specify either a template name or a template ID.
                      - **Version** *(string) --* 
                        The version number of the launch template. You must specify a version number.
                    - **Overrides** *(list) --* 
                      Any parameters that you specify override the same parameters in the launch template.
                      - *(dict) --* 
                        Describes overrides for a launch template.
                        - **InstanceType** *(string) --* 
                          The instance type.
                        - **MaxPrice** *(string) --* 
                          The maximum price per unit hour that you are willing to pay for a Spot Instance.
                        - **SubnetId** *(string) --* 
                          The ID of the subnet in which to launch the instances.
                        - **AvailabilityZone** *(string) --* 
                          The Availability Zone in which to launch the instances.
                        - **WeightedCapacity** *(float) --* 
                          The number of units provided by the specified instance type.
                        - **Priority** *(float) --* 
                          The priority for the launch template override. If **AllocationStrategy** is set to ``prioritized`` , EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the override has the lowest priority.
                        - **Placement** *(dict) --* 
                          The location where the instance launched, if applicable.
                          - **GroupName** *(string) --* 
                            The name of the placement group the instance is in.
                - **TargetCapacitySpecification** *(dict) --* 
                  The number of units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is ``maintain`` , you can specify a target capacity of 0 and add capacity later.
                  - **TotalTargetCapacity** *(integer) --* 
                    The number of units to request, filled using ``DefaultTargetCapacityType`` .
                  - **OnDemandTargetCapacity** *(integer) --* 
                    The number of On-Demand units to request.
                  - **SpotTargetCapacity** *(integer) --* 
                    The maximum number of Spot units to launch.
                  - **DefaultTargetCapacityType** *(string) --* 
                    The default ``TotalTargetCapacity`` , which is either ``Spot`` or ``On-Demand`` .
                - **TerminateInstancesWithExpiration** *(boolean) --* 
                  Indicates whether running instances should be terminated when the EC2 Fleet expires. 
                - **Type** *(string) --* 
                  The type of request. Indicates whether the EC2 Fleet only ``requests`` the target capacity, or also attempts to ``maintain`` it. If you request a certain target capacity, EC2 Fleet only places the required requests; it does not attempt to replenish instances if capacity is diminished, and does not submit requests in alternative capacity pools if capacity is unavailable. To maintain a certain target capacity, EC2 Fleet places the required requests to meet this target capacity. It also automatically replenishes any interrupted Spot Instances. Default: ``maintain`` .
                - **ValidFrom** *(datetime) --* 
                  The start date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). The default is to start fulfilling the request immediately. 
                - **ValidUntil** *(datetime) --* 
                  The end date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). At this point, no new instance requests are placed or able to fulfill the request. The default end date is 7 days from the current date. 
                - **ReplaceUnhealthyInstances** *(boolean) --* 
                  Indicates whether EC2 Fleet should replace unhealthy instances.
                - **SpotOptions** *(dict) --* 
                  The configuration of Spot Instances in an EC2 Fleet.
                  - **AllocationStrategy** *(string) --* 
                    Indicates how to allocate the target capacity across the Spot pools specified by the Spot Fleet request. The default is ``lowest-price`` .
                  - **InstanceInterruptionBehavior** *(string) --* 
                    The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
                  - **InstancePoolsToUseCount** *(integer) --* 
                    The number of Spot pools across which to allocate your target Spot capacity. Valid only when **AllocationStrategy** is set to ``lowestPrice`` . EC2 Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify.
                  - **SingleInstanceType** *(boolean) --* 
                    Indicates that the fleet uses a single instance type to launch all Spot Instances in the fleet.
                  - **SingleAvailabilityZone** *(boolean) --* 
                    Indicates that the fleet launches all Spot Instances into a single Availability Zone.
                  - **MinTargetCapacity** *(integer) --* 
                    The minimum target capacity for Spot Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances.
                - **OnDemandOptions** *(dict) --* 
                  The allocation strategy of On-Demand Instances in an EC2 Fleet.
                  - **AllocationStrategy** *(string) --* 
                    The order of the launch template overrides to use in fulfilling On-Demand capacity. If you specify ``lowest-price`` , EC2 Fleet uses price to determine the order, launching the lowest price first. If you specify ``prioritized`` , EC2 Fleet uses the priority that you assigned to each launch template override, launching the highest priority first. If you do not specify a value, EC2 Fleet defaults to ``lowest-price`` .
                  - **SingleInstanceType** *(boolean) --* 
                    Indicates that the fleet uses a single instance type to launch all On-Demand Instances in the fleet.
                  - **SingleAvailabilityZone** *(boolean) --* 
                    Indicates that the fleet launches all On-Demand Instances into a single Availability Zone.
                  - **MinTargetCapacity** *(integer) --* 
                    The minimum target capacity for On-Demand Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances.
                - **Tags** *(list) --* 
                  The tags for an EC2 Fleet resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **Errors** *(list) --* 
                  Information about the instances that could not be launched by the fleet. Valid only when **Type** is set to ``instant`` .
                  - *(dict) --* 
                    Describes the instances that could not be launched by the fleet.
                    - **LaunchTemplateAndOverrides** *(dict) --* 
                      The launch templates and overrides that were used for launching the instances. Any parameters that you specify in the Overrides override the same parameters in the launch template.
                      - **LaunchTemplateSpecification** *(dict) --* 
                        The launch template.
                        - **LaunchTemplateId** *(string) --* 
                          The ID of the launch template. You must specify either a template ID or a template name.
                        - **LaunchTemplateName** *(string) --* 
                          The name of the launch template. You must specify either a template name or a template ID.
                        - **Version** *(string) --* 
                          The version number of the launch template. You must specify a version number.
                      - **Overrides** *(dict) --* 
                        Any parameters that you specify override the same parameters in the launch template.
                        - **InstanceType** *(string) --* 
                          The instance type.
                        - **MaxPrice** *(string) --* 
                          The maximum price per unit hour that you are willing to pay for a Spot Instance.
                        - **SubnetId** *(string) --* 
                          The ID of the subnet in which to launch the instances.
                        - **AvailabilityZone** *(string) --* 
                          The Availability Zone in which to launch the instances.
                        - **WeightedCapacity** *(float) --* 
                          The number of units provided by the specified instance type.
                        - **Priority** *(float) --* 
                          The priority for the launch template override. If **AllocationStrategy** is set to ``prioritized`` , EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the override has the lowest priority.
                        - **Placement** *(dict) --* 
                          The location where the instance launched, if applicable.
                          - **GroupName** *(string) --* 
                            The name of the placement group the instance is in.
                    - **Lifecycle** *(string) --* 
                      Indicates if the instance that could not be launched was a Spot Instance or On-Demand Instance.
                    - **ErrorCode** *(string) --* 
                      The error code that indicates why the instance could not be launched. For more information about error codes, see `Error Codes <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html>`__ .
                    - **ErrorMessage** *(string) --* 
                      The error message that describes why the instance could not be launched. For more information about error messages, see ee `Error Codes <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html>`__ .
                - **Instances** *(list) --* 
                  Information about the instances that were launched by the fleet. Valid only when **Type** is set to ``instant`` .
                  - *(dict) --* 
                    Describes the instances that were launched by the fleet.
                    - **LaunchTemplateAndOverrides** *(dict) --* 
                      The launch templates and overrides that were used for launching the instances. Any parameters that you specify in the Overrides override the same parameters in the launch template.
                      - **LaunchTemplateSpecification** *(dict) --* 
                        The launch template.
                        - **LaunchTemplateId** *(string) --* 
                          The ID of the launch template. You must specify either a template ID or a template name.
                        - **LaunchTemplateName** *(string) --* 
                          The name of the launch template. You must specify either a template name or a template ID.
                        - **Version** *(string) --* 
                          The version number of the launch template. You must specify a version number.
                      - **Overrides** *(dict) --* 
                        Any parameters that you specify override the same parameters in the launch template.
                        - **InstanceType** *(string) --* 
                          The instance type.
                        - **MaxPrice** *(string) --* 
                          The maximum price per unit hour that you are willing to pay for a Spot Instance.
                        - **SubnetId** *(string) --* 
                          The ID of the subnet in which to launch the instances.
                        - **AvailabilityZone** *(string) --* 
                          The Availability Zone in which to launch the instances.
                        - **WeightedCapacity** *(float) --* 
                          The number of units provided by the specified instance type.
                        - **Priority** *(float) --* 
                          The priority for the launch template override. If **AllocationStrategy** is set to ``prioritized`` , EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the override has the lowest priority.
                        - **Placement** *(dict) --* 
                          The location where the instance launched, if applicable.
                          - **GroupName** *(string) --* 
                            The name of the placement group the instance is in.
                    - **Lifecycle** *(string) --* 
                      Indicates if the instance that was launched is a Spot Instance or On-Demand Instance.
                    - **InstanceIds** *(list) --* 
                      The IDs of the instances.
                      - *(string) --* 
                    - **InstanceType** *(string) --* 
                      The instance type.
                    - **Platform** *(string) --* 
                      The value is ``Windows`` for Windows instances; otherwise blank.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type FleetIds: list
        :param FleetIds:
          The ID of the EC2 Fleets.
          - *(string) --*
        :type Filters: list
        :param Filters:
          The filters.
          * ``activity-status`` - The progress of the EC2 Fleet ( ``error`` | ``pending-fulfillment`` | ``pending-termination`` | ``fulfilled`` ).
          * ``excess-capacity-termination-policy`` - Indicates whether to terminate running instances if the target capacity is decreased below the current EC2 Fleet size (``true`` | ``false`` ).
          * ``fleet-state`` - The state of the EC2 Fleet (``submitted`` | ``active`` | ``deleted`` | ``failed`` | ``deleted-running`` | ``deleted-terminating`` | ``modifying`` ).
          * ``replace-unhealthy-instances`` - Indicates whether EC2 Fleet should replace unhealthy instances (``true`` | ``false`` ).
          * ``type`` - The type of request (``instant`` | ``request`` | ``maintain`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_flow_logs(self, DryRun: bool = None, Filters: List = None, FlowLogIds: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes one or more flow logs. To view the information in your flow logs (the log streams for the network interfaces), you must use the CloudWatch Logs console or the CloudWatch Logs API.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeFlowLogs>`_
        
        **Request Syntax**
        ::
          response = client.describe_flow_logs(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              FlowLogIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'FlowLogs': [
                    {
                        'CreationTime': datetime(2015, 1, 1),
                        'DeliverLogsErrorMessage': 'string',
                        'DeliverLogsPermissionArn': 'string',
                        'DeliverLogsStatus': 'string',
                        'FlowLogId': 'string',
                        'FlowLogStatus': 'string',
                        'LogGroupName': 'string',
                        'ResourceId': 'string',
                        'TrafficType': 'ACCEPT'|'REJECT'|'ALL',
                        'LogDestinationType': 'cloud-watch-logs'|'s3',
                        'LogDestination': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **FlowLogs** *(list) --* 
              Information about the flow logs.
              - *(dict) --* 
                Describes a flow log.
                - **CreationTime** *(datetime) --* 
                  The date and time the flow log was created.
                - **DeliverLogsErrorMessage** *(string) --* 
                  Information about the error that occurred. ``Rate limited`` indicates that CloudWatch Logs throttling has been applied for one or more network interfaces, or that you've reached the limit on the number of log groups that you can create. ``Access error`` indicates that the IAM role associated with the flow log does not have sufficient permissions to publish to CloudWatch Logs. ``Unknown error`` indicates an internal error.
                - **DeliverLogsPermissionArn** *(string) --* 
                  The ARN of the IAM role that posts logs to CloudWatch Logs.
                - **DeliverLogsStatus** *(string) --* 
                  The status of the logs delivery (``SUCCESS`` | ``FAILED`` ).
                - **FlowLogId** *(string) --* 
                  The flow log ID.
                - **FlowLogStatus** *(string) --* 
                  The status of the flow log (``ACTIVE`` ).
                - **LogGroupName** *(string) --* 
                  The name of the flow log group.
                - **ResourceId** *(string) --* 
                  The ID of the resource on which the flow log was created.
                - **TrafficType** *(string) --* 
                  The type of traffic captured for the flow log.
                - **LogDestinationType** *(string) --* 
                  Specifies the type of destination to which the flow log data is published. Flow log data can be published to CloudWatch Logs or Amazon S3.
                - **LogDestination** *(string) --* 
                  Specifies the destination to which the flow log data is published. Flow log data can be published to an CloudWatch Logs log group or an Amazon S3 bucket. If the flow log publishes to CloudWatch Logs, this element indicates the Amazon Resource Name (ARN) of the CloudWatch Logs log group to which the data is published. If the flow log publishes to Amazon S3, this element indicates the ARN of the Amazon S3 bucket to which the data is published.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``deliver-log-status`` - The status of the logs delivery (``SUCCESS`` | ``FAILED`` ).
          * ``log-destination-type`` - The type of destination to which the flow log publishes data. Possible destination types include ``cloud-watch-logs`` and ``S3`` .
          * ``flow-log-id`` - The ID of the flow log.
          * ``log-group-name`` - The name of the log group.
          * ``resource-id`` - The ID of the VPC, subnet, or network interface.
          * ``traffic-type`` - The type of traffic (``ACCEPT`` | ``REJECT`` | ``ALL`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type FlowLogIds: list
        :param FlowLogIds:
          One or more flow log IDs.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_fpga_image_attribute(self, FpgaImageId: str, Attribute: str, DryRun: bool = None) -> Dict:
        """
        Describes the specified attribute of the specified Amazon FPGA Image (AFI).
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeFpgaImageAttribute>`_
        
        **Request Syntax**
        ::
          response = client.describe_fpga_image_attribute(
              DryRun=True|False,
              FpgaImageId='string',
              Attribute='description'|'name'|'loadPermission'|'productCodes'
          )
        
        **Response Syntax**
        ::
            {
                'FpgaImageAttribute': {
                    'FpgaImageId': 'string',
                    'Name': 'string',
                    'Description': 'string',
                    'LoadPermissions': [
                        {
                            'UserId': 'string',
                            'Group': 'all'
                        },
                    ],
                    'ProductCodes': [
                        {
                            'ProductCodeId': 'string',
                            'ProductCodeType': 'devpay'|'marketplace'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **FpgaImageAttribute** *(dict) --* 
              Information about the attribute.
              - **FpgaImageId** *(string) --* 
                The ID of the AFI.
              - **Name** *(string) --* 
                The name of the AFI.
              - **Description** *(string) --* 
                The description of the AFI.
              - **LoadPermissions** *(list) --* 
                The load permissions.
                - *(dict) --* 
                  Describes a load permission.
                  - **UserId** *(string) --* 
                    The AWS account ID.
                  - **Group** *(string) --* 
                    The name of the group.
              - **ProductCodes** *(list) --* 
                The product codes.
                - *(dict) --* 
                  Describes a product code.
                  - **ProductCodeId** *(string) --* 
                    The product code.
                  - **ProductCodeType** *(string) --* 
                    The type of product code.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type FpgaImageId: string
        :param FpgaImageId: **[REQUIRED]**
          The ID of the AFI.
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The AFI attribute.
        :rtype: dict
        :returns:
        """
        pass

    def describe_fpga_images(self, DryRun: bool = None, FpgaImageIds: List = None, Owners: List = None, Filters: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes the Amazon FPGA Images (AFIs) available to you. These include public AFIs, private AFIs that you own, and AFIs owned by other AWS accounts for which you have load permissions.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeFpgaImages>`_
        
        **Request Syntax**
        ::
          response = client.describe_fpga_images(
              DryRun=True|False,
              FpgaImageIds=[
                  'string',
              ],
              Owners=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'FpgaImages': [
                    {
                        'FpgaImageId': 'string',
                        'FpgaImageGlobalId': 'string',
                        'Name': 'string',
                        'Description': 'string',
                        'ShellVersion': 'string',
                        'PciId': {
                            'DeviceId': 'string',
                            'VendorId': 'string',
                            'SubsystemId': 'string',
                            'SubsystemVendorId': 'string'
                        },
                        'State': {
                            'Code': 'pending'|'failed'|'available'|'unavailable',
                            'Message': 'string'
                        },
                        'CreateTime': datetime(2015, 1, 1),
                        'UpdateTime': datetime(2015, 1, 1),
                        'OwnerId': 'string',
                        'OwnerAlias': 'string',
                        'ProductCodes': [
                            {
                                'ProductCodeId': 'string',
                                'ProductCodeType': 'devpay'|'marketplace'
                            },
                        ],
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'Public': True|False,
                        'DataRetentionSupport': True|False
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **FpgaImages** *(list) --* 
              Information about the FPGA images.
              - *(dict) --* 
                Describes an Amazon FPGA image (AFI).
                - **FpgaImageId** *(string) --* 
                  The FPGA image identifier (AFI ID).
                - **FpgaImageGlobalId** *(string) --* 
                  The global FPGA image identifier (AGFI ID).
                - **Name** *(string) --* 
                  The name of the AFI.
                - **Description** *(string) --* 
                  The description of the AFI.
                - **ShellVersion** *(string) --* 
                  The version of the AWS Shell that was used to create the bitstream.
                - **PciId** *(dict) --* 
                  Information about the PCI bus.
                  - **DeviceId** *(string) --* 
                    The ID of the device.
                  - **VendorId** *(string) --* 
                    The ID of the vendor.
                  - **SubsystemId** *(string) --* 
                    The ID of the subsystem.
                  - **SubsystemVendorId** *(string) --* 
                    The ID of the vendor for the subsystem.
                - **State** *(dict) --* 
                  Information about the state of the AFI.
                  - **Code** *(string) --* 
                    The state. The following are the possible values:
                    * ``pending`` - AFI bitstream generation is in progress. 
                    * ``available`` - The AFI is available for use. 
                    * ``failed`` - AFI bitstream generation failed. 
                    * ``unavailable`` - The AFI is no longer available for use. 
                  - **Message** *(string) --* 
                    If the state is ``failed`` , this is the error message.
                - **CreateTime** *(datetime) --* 
                  The date and time the AFI was created.
                - **UpdateTime** *(datetime) --* 
                  The time of the most recent update to the AFI.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the AFI owner.
                - **OwnerAlias** *(string) --* 
                  The alias of the AFI owner. Possible values include ``self`` , ``amazon`` , and ``aws-marketplace`` .
                - **ProductCodes** *(list) --* 
                  The product codes for the AFI.
                  - *(dict) --* 
                    Describes a product code.
                    - **ProductCodeId** *(string) --* 
                      The product code.
                    - **ProductCodeType** *(string) --* 
                      The type of product code.
                - **Tags** *(list) --* 
                  Any tags assigned to the AFI.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **Public** *(boolean) --* 
                  Indicates whether the AFI is public.
                - **DataRetentionSupport** *(boolean) --* 
                  Indicates whether data retention support is enabled for the AFI.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type FpgaImageIds: list
        :param FpgaImageIds:
          The AFI IDs.
          - *(string) --*
        :type Owners: list
        :param Owners:
          Filters the AFI by owner. Specify an AWS account ID, ``self`` (owner is the sender of the request), or an AWS owner alias (valid values are ``amazon`` | ``aws-marketplace`` ).
          - *(string) --*
        :type Filters: list
        :param Filters:
          The filters.
          * ``create-time`` - The creation time of the AFI.
          * ``fpga-image-id`` - The FPGA image identifier (AFI ID).
          * ``fpga-image-global-id`` - The global FPGA image identifier (AGFI ID).
          * ``name`` - The name of the AFI.
          * ``owner-id`` - The AWS account ID of the AFI owner.
          * ``product-code`` - The product code.
          * ``shell-version`` - The version of the AWS Shell that was used to create the bitstream.
          * ``state`` - The state of the AFI (``pending`` | ``failed`` | ``available`` | ``unavailable`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``update-time`` - The time of the most recent update.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call.
        :rtype: dict
        :returns:
        """
        pass

    def describe_host_reservation_offerings(self, Filters: List = None, MaxDuration: int = None, MaxResults: int = None, MinDuration: int = None, NextToken: str = None, OfferingId: str = None) -> Dict:
        """
        Describes the Dedicated Host reservations that are available to purchase.
        The results describe all the Dedicated Host reservation offerings, including offerings that may not match the instance family and Region of your Dedicated Hosts. When purchasing an offering, ensure that the instance family and Region of the offering matches that of the Dedicated Hosts with which it is to be associated. For more information about supported instance types, see `Dedicated Hosts Overview <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-hosts-overview.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeHostReservationOfferings>`_
        
        **Request Syntax**
        ::
          response = client.describe_host_reservation_offerings(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxDuration=123,
              MaxResults=123,
              MinDuration=123,
              NextToken='string',
              OfferingId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'OfferingSet': [
                    {
                        'CurrencyCode': 'USD',
                        'Duration': 123,
                        'HourlyPrice': 'string',
                        'InstanceFamily': 'string',
                        'OfferingId': 'string',
                        'PaymentOption': 'AllUpfront'|'PartialUpfront'|'NoUpfront',
                        'UpfrontPrice': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
            - **OfferingSet** *(list) --* 
              Information about the offerings.
              - *(dict) --* 
                Details about the Dedicated Host Reservation offering.
                - **CurrencyCode** *(string) --* 
                  The currency of the offering.
                - **Duration** *(integer) --* 
                  The duration of the offering (in seconds).
                - **HourlyPrice** *(string) --* 
                  The hourly price of the offering.
                - **InstanceFamily** *(string) --* 
                  The instance family of the offering.
                - **OfferingId** *(string) --* 
                  The ID of the offering.
                - **PaymentOption** *(string) --* 
                  The available payment option.
                - **UpfrontPrice** *(string) --* 
                  The upfront price of the offering. Does not apply to No Upfront offerings.
        :type Filters: list
        :param Filters:
          The filters.
          * ``instance-family`` - The instance family of the offering (for example, ``m4`` ).
          * ``payment-option`` - The payment option (``NoUpfront`` | ``PartialUpfront`` | ``AllUpfront`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxDuration: integer
        :param MaxDuration:
          This is the maximum duration of the reservation to purchase, specified in seconds. Reservations are available in one-year and three-year terms. The number of seconds specified must be the number of seconds in a year (365x24x60x60) times one of the supported durations (1 or 3). For example, specify 94608000 for three years.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned ``nextToken`` value. This value can be between 5 and 500. If ``maxResults`` is given a larger value than 500, you receive an error.
        :type MinDuration: integer
        :param MinDuration:
          This is the minimum duration of the reservation you\'d like to purchase, specified in seconds. Reservations are available in one-year and three-year terms. The number of seconds specified must be the number of seconds in a year (365x24x60x60) times one of the supported durations (1 or 3). For example, specify 31536000 for one year.
        :type NextToken: string
        :param NextToken:
          The token to use to retrieve the next page of results.
        :type OfferingId: string
        :param OfferingId:
          The ID of the reservation offering.
        :rtype: dict
        :returns:
        """
        pass

    def describe_host_reservations(self, Filters: List = None, HostReservationIdSet: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes reservations that are associated with Dedicated Hosts in your account.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeHostReservations>`_
        
        **Request Syntax**
        ::
          response = client.describe_host_reservations(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              HostReservationIdSet=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'HostReservationSet': [
                    {
                        'Count': 123,
                        'CurrencyCode': 'USD',
                        'Duration': 123,
                        'End': datetime(2015, 1, 1),
                        'HostIdSet': [
                            'string',
                        ],
                        'HostReservationId': 'string',
                        'HourlyPrice': 'string',
                        'InstanceFamily': 'string',
                        'OfferingId': 'string',
                        'PaymentOption': 'AllUpfront'|'PartialUpfront'|'NoUpfront',
                        'Start': datetime(2015, 1, 1),
                        'State': 'payment-pending'|'payment-failed'|'active'|'retired',
                        'UpfrontPrice': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **HostReservationSet** *(list) --* 
              Details about the reservation's configuration.
              - *(dict) --* 
                Details about the Dedicated Host Reservation and associated Dedicated Hosts.
                - **Count** *(integer) --* 
                  The number of Dedicated Hosts the reservation is associated with.
                - **CurrencyCode** *(string) --* 
                  The currency in which the ``upfrontPrice`` and ``hourlyPrice`` amounts are specified. At this time, the only supported currency is ``USD`` .
                - **Duration** *(integer) --* 
                  The length of the reservation's term, specified in seconds. Can be ``31536000 (1 year)`` | ``94608000 (3 years)`` .
                - **End** *(datetime) --* 
                  The date and time that the reservation ends.
                - **HostIdSet** *(list) --* 
                  The IDs of the Dedicated Hosts associated with the reservation.
                  - *(string) --* 
                - **HostReservationId** *(string) --* 
                  The ID of the reservation that specifies the associated Dedicated Hosts.
                - **HourlyPrice** *(string) --* 
                  The hourly price of the reservation.
                - **InstanceFamily** *(string) --* 
                  The instance family of the Dedicated Host Reservation. The instance family on the Dedicated Host must be the same in order for it to benefit from the reservation.
                - **OfferingId** *(string) --* 
                  The ID of the reservation. This remains the same regardless of which Dedicated Hosts are associated with it.
                - **PaymentOption** *(string) --* 
                  The payment option selected for this reservation.
                - **Start** *(datetime) --* 
                  The date and time that the reservation started.
                - **State** *(string) --* 
                  The state of the reservation.
                - **UpfrontPrice** *(string) --* 
                  The upfront price of the reservation.
                - **Tags** *(list) --* 
                  Any tags assigned to the Dedicated Host Reservation.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          The filters.
          * ``instance-family`` - The instance family (for example, ``m4`` ).
          * ``payment-option`` - The payment option (``NoUpfront`` | ``PartialUpfront`` | ``AllUpfront`` ).
          * ``state`` - The state of the reservation (``payment-pending`` | ``payment-failed`` | ``active`` | ``retired`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type HostReservationIdSet: list
        :param HostReservationIdSet:
          The host reservation IDs.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned ``nextToken`` value. This value can be between 5 and 500. If ``maxResults`` is given a larger value than 500, you receive an error.
        :type NextToken: string
        :param NextToken:
          The token to use to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_hosts(self, Filters: List = None, HostIds: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the specified Dedicated Hosts or all your Dedicated Hosts.
        The results describe only the Dedicated Hosts in the Region you're currently using. All listed instances consume capacity on your Dedicated Host. Dedicated Hosts that have recently been released are listed with the state ``released`` .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeHosts>`_
        
        **Request Syntax**
        ::
          response = client.describe_hosts(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              HostIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'Hosts': [
                    {
                        'AutoPlacement': 'on'|'off',
                        'AvailabilityZone': 'string',
                        'AvailableCapacity': {
                            'AvailableInstanceCapacity': [
                                {
                                    'AvailableCapacity': 123,
                                    'InstanceType': 'string',
                                    'TotalCapacity': 123
                                },
                            ],
                            'AvailableVCpus': 123
                        },
                        'ClientToken': 'string',
                        'HostId': 'string',
                        'HostProperties': {
                            'Cores': 123,
                            'InstanceType': 'string',
                            'Sockets': 123,
                            'TotalVCpus': 123
                        },
                        'HostReservationId': 'string',
                        'Instances': [
                            {
                                'InstanceId': 'string',
                                'InstanceType': 'string'
                            },
                        ],
                        'State': 'available'|'under-assessment'|'permanent-failure'|'released'|'released-permanent-failure',
                        'AllocationTime': datetime(2015, 1, 1),
                        'ReleaseTime': datetime(2015, 1, 1),
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Hosts** *(list) --* 
              Information about the Dedicated Hosts.
              - *(dict) --* 
                Describes the properties of the Dedicated Host.
                - **AutoPlacement** *(string) --* 
                  Whether auto-placement is on or off.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone of the Dedicated Host.
                - **AvailableCapacity** *(dict) --* 
                  The number of new instances that can be launched onto the Dedicated Host.
                  - **AvailableInstanceCapacity** *(list) --* 
                    The total number of instances supported by the Dedicated Host.
                    - *(dict) --* 
                      Information about the instance type that the Dedicated Host supports.
                      - **AvailableCapacity** *(integer) --* 
                        The number of instances that can still be launched onto the Dedicated Host.
                      - **InstanceType** *(string) --* 
                        The instance type size supported by the Dedicated Host.
                      - **TotalCapacity** *(integer) --* 
                        The total number of instances that can be launched onto the Dedicated Host.
                  - **AvailableVCpus** *(integer) --* 
                    The number of vCPUs available on the Dedicated Host.
                - **ClientToken** *(string) --* 
                  Unique, case-sensitive identifier that you provide to ensure idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . 
                - **HostId** *(string) --* 
                  The ID of the Dedicated Host.
                - **HostProperties** *(dict) --* 
                  The hardware specifications of the Dedicated Host.
                  - **Cores** *(integer) --* 
                    The number of cores on the Dedicated Host.
                  - **InstanceType** *(string) --* 
                    The instance type size that the Dedicated Host supports (for example, ``m3.medium`` ).
                  - **Sockets** *(integer) --* 
                    The number of sockets on the Dedicated Host.
                  - **TotalVCpus** *(integer) --* 
                    The number of vCPUs on the Dedicated Host.
                - **HostReservationId** *(string) --* 
                  The reservation ID of the Dedicated Host. This returns a ``null`` response if the Dedicated Host doesn't have an associated reservation.
                - **Instances** *(list) --* 
                  The IDs and instance type that are currently running on the Dedicated Host.
                  - *(dict) --* 
                    Describes an instance running on a Dedicated Host.
                    - **InstanceId** *(string) --* 
                      the IDs of instances that are running on the Dedicated Host.
                    - **InstanceType** *(string) --* 
                      The instance type size (for example, ``m3.medium`` ) of the running instance.
                - **State** *(string) --* 
                  The Dedicated Host's state.
                - **AllocationTime** *(datetime) --* 
                  The time that the Dedicated Host was allocated.
                - **ReleaseTime** *(datetime) --* 
                  The time that the Dedicated Host was released.
                - **Tags** *(list) --* 
                  Any tags assigned to the Dedicated Host.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          The filters.
          * ``auto-placement`` - Whether auto-placement is enabled or disabled (``on`` | ``off`` ).
          * ``availability-zone`` - The Availability Zone of the host.
          * ``client-token`` - The idempotency token that you provided when you allocated the host.
          * ``host-reservation-id`` - The ID of the reservation assigned to this host.
          * ``instance-type`` - The instance type size that the Dedicated Host is configured to support.
          * ``state`` - The allocation state of the Dedicated Host (``available`` | ``under-assessment`` | ``permanent-failure`` | ``released`` | ``released-permanent-failure`` ).
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type HostIds: list
        :param HostIds:
          The IDs of the Dedicated Hosts. The IDs are used for targeted instance launches.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned ``nextToken`` value. This value can be between 5 and 500. If ``maxResults`` is given a larger value than 500, you receive an error. You cannot specify this parameter and the host IDs parameter in the same request.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_iam_instance_profile_associations(self, AssociationIds: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes your IAM instance profile associations.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeIamInstanceProfileAssociations>`_
        
        **Request Syntax**
        ::
          response = client.describe_iam_instance_profile_associations(
              AssociationIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'IamInstanceProfileAssociations': [
                    {
                        'AssociationId': 'string',
                        'InstanceId': 'string',
                        'IamInstanceProfile': {
                            'Arn': 'string',
                            'Id': 'string'
                        },
                        'State': 'associating'|'associated'|'disassociating'|'disassociated',
                        'Timestamp': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **IamInstanceProfileAssociations** *(list) --* 
              Information about the IAM instance profile associations.
              - *(dict) --* 
                Describes an association between an IAM instance profile and an instance.
                - **AssociationId** *(string) --* 
                  The ID of the association.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **IamInstanceProfile** *(dict) --* 
                  The IAM instance profile.
                  - **Arn** *(string) --* 
                    The Amazon Resource Name (ARN) of the instance profile.
                  - **Id** *(string) --* 
                    The ID of the instance profile.
                - **State** *(string) --* 
                  The state of the association.
                - **Timestamp** *(datetime) --* 
                  The time the IAM instance profile was associated with the instance.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type AssociationIds: list
        :param AssociationIds:
          The IAM instance profile associations.
          - *(string) --*
        :type Filters: list
        :param Filters:
          The filters.
          * ``instance-id`` - The ID of the instance.
          * ``state`` - The state of the association (``associating`` | ``associated`` | ``disassociating`` | ``disassociated`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_id_format(self, Resource: str = None) -> Dict:
        """
        Describes the ID format settings for your resources on a per-region basis, for example, to view which resource types are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types.
        The following resource types support longer IDs: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``instance`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``reservation`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``snapshot`` | ``subnet`` | ``subnet-cidr-block-association`` | ``volume`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` . 
        These settings apply to the IAM user who makes the request; they do not apply to the entire AWS account. By default, an IAM user defaults to the same settings as the root user, unless they explicitly override the settings by running the  ModifyIdFormat command. Resources created with longer IDs are visible to all IAM users, regardless of these settings and provided that they have permission to use the relevant ``Describe`` command for the resource type.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeIdFormat>`_
        
        **Request Syntax**
        ::
          response = client.describe_id_format(
              Resource='string'
          )
        
        **Response Syntax**
        ::
            {
                'Statuses': [
                    {
                        'Deadline': datetime(2015, 1, 1),
                        'Resource': 'string',
                        'UseLongIds': True|False
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Statuses** *(list) --* 
              Information about the ID format for the resource.
              - *(dict) --* 
                Describes the ID format for a resource.
                - **Deadline** *(datetime) --* 
                  The date in UTC at which you are permanently switched over to using longer IDs. If a deadline is not yet available for this resource type, this field is not returned.
                - **Resource** *(string) --* 
                  The type of resource.
                - **UseLongIds** *(boolean) --* 
                  Indicates whether longer IDs (17-character IDs) are enabled for the resource.
        :type Resource: string
        :param Resource:
          The type of resource: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``instance`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``reservation`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``snapshot`` | ``subnet`` | ``subnet-cidr-block-association`` | ``volume`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway``
        :rtype: dict
        :returns:
        """
        pass

    def describe_identity_id_format(self, PrincipalArn: str, Resource: str = None) -> Dict:
        """
        Describes the ID format settings for resources for the specified IAM user, IAM role, or root user. For example, you can view the resource types that are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types. For more information, see `Resource IDs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/resource-ids.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . 
        The following resource types support longer IDs: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``instance`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``reservation`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``snapshot`` | ``subnet`` | ``subnet-cidr-block-association`` | ``volume`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` . 
        These settings apply to the principal specified in the request. They do not apply to the principal that makes the request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeIdentityIdFormat>`_
        
        **Request Syntax**
        ::
          response = client.describe_identity_id_format(
              PrincipalArn='string',
              Resource='string'
          )
        
        **Response Syntax**
        ::
            {
                'Statuses': [
                    {
                        'Deadline': datetime(2015, 1, 1),
                        'Resource': 'string',
                        'UseLongIds': True|False
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Statuses** *(list) --* 
              Information about the ID format for the resources.
              - *(dict) --* 
                Describes the ID format for a resource.
                - **Deadline** *(datetime) --* 
                  The date in UTC at which you are permanently switched over to using longer IDs. If a deadline is not yet available for this resource type, this field is not returned.
                - **Resource** *(string) --* 
                  The type of resource.
                - **UseLongIds** *(boolean) --* 
                  Indicates whether longer IDs (17-character IDs) are enabled for the resource.
        :type PrincipalArn: string
        :param PrincipalArn: **[REQUIRED]**
          The ARN of the principal, which can be an IAM role, IAM user, or the root user.
        :type Resource: string
        :param Resource:
          The type of resource: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``instance`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``reservation`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``snapshot`` | ``subnet`` | ``subnet-cidr-block-association`` | ``volume`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway``
        :rtype: dict
        :returns:
        """
        pass

    def describe_image_attribute(self, Attribute: str, ImageId: str, DryRun: bool = None) -> Dict:
        """
        Describes the specified attribute of the specified AMI. You can specify only one attribute at a time.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeImageAttribute>`_
        
        **Request Syntax**
        ::
          response = client.describe_image_attribute(
              Attribute='description'|'kernel'|'ramdisk'|'launchPermission'|'productCodes'|'blockDeviceMapping'|'sriovNetSupport',
              ImageId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'BlockDeviceMappings': [
                    {
                        'DeviceName': 'string',
                        'VirtualName': 'string',
                        'Ebs': {
                            'DeleteOnTermination': True|False,
                            'Iops': 123,
                            'SnapshotId': 'string',
                            'VolumeSize': 123,
                            'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                            'Encrypted': True|False,
                            'KmsKeyId': 'string'
                        },
                        'NoDevice': 'string'
                    },
                ],
                'ImageId': 'string',
                'LaunchPermissions': [
                    {
                        'Group': 'all',
                        'UserId': 'string'
                    },
                ],
                'ProductCodes': [
                    {
                        'ProductCodeId': 'string',
                        'ProductCodeType': 'devpay'|'marketplace'
                    },
                ],
                'Description': {
                    'Value': 'string'
                },
                'KernelId': {
                    'Value': 'string'
                },
                'RamdiskId': {
                    'Value': 'string'
                },
                'SriovNetSupport': {
                    'Value': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes an image attribute.
            - **BlockDeviceMappings** *(list) --* 
              The block device mapping entries.
              - *(dict) --* 
                Describes a block device mapping.
                - **DeviceName** *(string) --* 
                  The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                - **VirtualName** *(string) --* 
                  The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                  NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
                  Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
                - **Ebs** *(dict) --* 
                  Parameters used to automatically set up EBS volumes when the instance is launched.
                  - **DeleteOnTermination** *(boolean) --* 
                    Indicates whether the EBS volume is deleted on instance termination.
                  - **Iops** *(integer) --* 
                    The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                    Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                    Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                  - **SnapshotId** *(string) --* 
                    The ID of the snapshot.
                  - **VolumeSize** *(integer) --* 
                    The size of the volume, in GiB.
                    Default: If you're creating the volume from a snapshot and don't specify a volume size, the default is the snapshot size.
                    Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
                  - **VolumeType** *(string) --* 
                    The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                    Default: ``standard``  
                  - **Encrypted** *(boolean) --* 
                    Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                    If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
                  - **KmsKeyId** *(string) --* 
                    Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                    This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
                - **NoDevice** *(string) --* 
                  Suppresses the specified device included in the block device mapping of the AMI.
            - **ImageId** *(string) --* 
              The ID of the AMI.
            - **LaunchPermissions** *(list) --* 
              The launch permissions.
              - *(dict) --* 
                Describes a launch permission.
                - **Group** *(string) --* 
                  The name of the group.
                - **UserId** *(string) --* 
                  The AWS account ID.
            - **ProductCodes** *(list) --* 
              The product codes.
              - *(dict) --* 
                Describes a product code.
                - **ProductCodeId** *(string) --* 
                  The product code.
                - **ProductCodeType** *(string) --* 
                  The type of product code.
            - **Description** *(dict) --* 
              A description for the AMI.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **KernelId** *(dict) --* 
              The kernel ID.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **RamdiskId** *(dict) --* 
              The RAM disk ID.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **SriovNetSupport** *(dict) --* 
              Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The AMI attribute.
           **Note** : Depending on your account privileges, the ``blockDeviceMapping`` attribute may return a ``Client.AuthFailure`` error. If this happens, use  DescribeImages to get information about the block device mapping for the AMI.
        :type ImageId: string
        :param ImageId: **[REQUIRED]**
          The ID of the AMI.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_images(self, ExecutableUsers: List = None, Filters: List = None, ImageIds: List = None, Owners: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the specified images (AMIs, AKIs, and ARIs) available to you or all of the images available to you.
        The images available to you include public images, private images that you own, and private images owned by other AWS accounts for which you have explicit launch permissions.
        Recently deregistered images might appear in the returned results for a short interval.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeImages>`_
        
        **Request Syntax**
        ::
          response = client.describe_images(
              ExecutableUsers=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              ImageIds=[
                  'string',
              ],
              Owners=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Images': [
                    {
                        'Architecture': 'i386'|'x86_64'|'arm64',
                        'CreationDate': 'string',
                        'ImageId': 'string',
                        'ImageLocation': 'string',
                        'ImageType': 'machine'|'kernel'|'ramdisk',
                        'Public': True|False,
                        'KernelId': 'string',
                        'OwnerId': 'string',
                        'Platform': 'Windows',
                        'ProductCodes': [
                            {
                                'ProductCodeId': 'string',
                                'ProductCodeType': 'devpay'|'marketplace'
                            },
                        ],
                        'RamdiskId': 'string',
                        'State': 'pending'|'available'|'invalid'|'deregistered'|'transient'|'failed'|'error',
                        'BlockDeviceMappings': [
                            {
                                'DeviceName': 'string',
                                'VirtualName': 'string',
                                'Ebs': {
                                    'DeleteOnTermination': True|False,
                                    'Iops': 123,
                                    'SnapshotId': 'string',
                                    'VolumeSize': 123,
                                    'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                                    'Encrypted': True|False,
                                    'KmsKeyId': 'string'
                                },
                                'NoDevice': 'string'
                            },
                        ],
                        'Description': 'string',
                        'EnaSupport': True|False,
                        'Hypervisor': 'ovm'|'xen',
                        'ImageOwnerAlias': 'string',
                        'Name': 'string',
                        'RootDeviceName': 'string',
                        'RootDeviceType': 'ebs'|'instance-store',
                        'SriovNetSupport': 'string',
                        'StateReason': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VirtualizationType': 'hvm'|'paravirtual'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Images** *(list) --* 
              Information about the images.
              - *(dict) --* 
                Describes an image.
                - **Architecture** *(string) --* 
                  The architecture of the image.
                - **CreationDate** *(string) --* 
                  The date and time the image was created.
                - **ImageId** *(string) --* 
                  The ID of the AMI.
                - **ImageLocation** *(string) --* 
                  The location of the AMI.
                - **ImageType** *(string) --* 
                  The type of image.
                - **Public** *(boolean) --* 
                  Indicates whether the image has public launch permissions. The value is ``true`` if this image has public launch permissions or ``false`` if it has only implicit and explicit launch permissions.
                - **KernelId** *(string) --* 
                  The kernel associated with the image, if any. Only applicable for machine images.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the image owner.
                - **Platform** *(string) --* 
                  The value is ``Windows`` for Windows AMIs; otherwise blank.
                - **ProductCodes** *(list) --* 
                  Any product codes associated with the AMI.
                  - *(dict) --* 
                    Describes a product code.
                    - **ProductCodeId** *(string) --* 
                      The product code.
                    - **ProductCodeType** *(string) --* 
                      The type of product code.
                - **RamdiskId** *(string) --* 
                  The RAM disk associated with the image, if any. Only applicable for machine images.
                - **State** *(string) --* 
                  The current state of the AMI. If the state is ``available`` , the image is successfully registered and can be used to launch an instance.
                - **BlockDeviceMappings** *(list) --* 
                  Any block device mapping entries.
                  - *(dict) --* 
                    Describes a block device mapping.
                    - **DeviceName** *(string) --* 
                      The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                    - **VirtualName** *(string) --* 
                      The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                      NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
                      Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
                    - **Ebs** *(dict) --* 
                      Parameters used to automatically set up EBS volumes when the instance is launched.
                      - **DeleteOnTermination** *(boolean) --* 
                        Indicates whether the EBS volume is deleted on instance termination.
                      - **Iops** *(integer) --* 
                        The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                        Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                        Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                      - **SnapshotId** *(string) --* 
                        The ID of the snapshot.
                      - **VolumeSize** *(integer) --* 
                        The size of the volume, in GiB.
                        Default: If you're creating the volume from a snapshot and don't specify a volume size, the default is the snapshot size.
                        Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
                      - **VolumeType** *(string) --* 
                        The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                        Default: ``standard``  
                      - **Encrypted** *(boolean) --* 
                        Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                        If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
                      - **KmsKeyId** *(string) --* 
                        Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                        This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
                    - **NoDevice** *(string) --* 
                      Suppresses the specified device included in the block device mapping of the AMI.
                - **Description** *(string) --* 
                  The description of the AMI that was provided during image creation.
                - **EnaSupport** *(boolean) --* 
                  Specifies whether enhanced networking with ENA is enabled.
                - **Hypervisor** *(string) --* 
                  The hypervisor type of the image.
                - **ImageOwnerAlias** *(string) --* 
                  The AWS account alias (for example, ``amazon`` , ``self`` ) or the AWS account ID of the AMI owner.
                - **Name** *(string) --* 
                  The name of the AMI that was provided during image creation.
                - **RootDeviceName** *(string) --* 
                  The device name of the root device volume (for example, ``/dev/sda1`` ).
                - **RootDeviceType** *(string) --* 
                  The type of root device used by the AMI. The AMI can use an EBS volume or an instance store volume.
                - **SriovNetSupport** *(string) --* 
                  Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
                - **StateReason** *(dict) --* 
                  The reason for the state change.
                  - **Code** *(string) --* 
                    The reason code for the state change.
                  - **Message** *(string) --* 
                    The message for the state change.
                    * ``Server.InsufficientInstanceCapacity`` : There was insufficient capacity available to satisfy the launch request. 
                    * ``Server.InternalError`` : An internal error caused the instance to terminate during launch. 
                    * ``Server.ScheduledStop`` : The instance was stopped due to a scheduled retirement. 
                    * ``Server.SpotInstanceShutdown`` : The instance was stopped because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. 
                    * ``Server.SpotInstanceTermination`` : The instance was terminated because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. 
                    * ``Client.InstanceInitiatedShutdown`` : The instance was shut down using the ``shutdown -h`` command from the instance. 
                    * ``Client.InstanceTerminated`` : The instance was terminated or rebooted during AMI creation. 
                    * ``Client.InternalError`` : A client error caused the instance to terminate during launch. 
                    * ``Client.InvalidSnapshot.NotFound`` : The specified snapshot was not found. 
                    * ``Client.UserInitiatedHibernate`` : Hibernation was initiated on the instance. 
                    * ``Client.UserInitiatedShutdown`` : The instance was shut down using the Amazon EC2 API. 
                    * ``Client.VolumeLimitExceeded`` : The limit on the number of EBS volumes or total storage was exceeded. Decrease usage or request an increase in your account limits. 
                - **Tags** *(list) --* 
                  Any tags assigned to the image.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VirtualizationType** *(string) --* 
                  The type of virtualization of the AMI.
        :type ExecutableUsers: list
        :param ExecutableUsers:
          Scopes the images by users with explicit launch permissions. Specify an AWS account ID, ``self`` (the sender of the request), or ``all`` (public AMIs).
          - *(string) --*
        :type Filters: list
        :param Filters:
          The filters.
          * ``architecture`` - The image architecture (``i386`` | ``x86_64`` ).
          * ``block-device-mapping.delete-on-termination`` - A Boolean value that indicates whether the Amazon EBS volume is deleted on instance termination.
          * ``block-device-mapping.device-name`` - The device name specified in the block device mapping (for example, ``/dev/sdh`` or ``xvdh`` ).
          * ``block-device-mapping.snapshot-id`` - The ID of the snapshot used for the EBS volume.
          * ``block-device-mapping.volume-size`` - The volume size of the EBS volume, in GiB.
          * ``block-device-mapping.volume-type`` - The volume type of the EBS volume (``gp2`` | ``io1`` | ``st1`` | ``sc1`` | ``standard`` ).
          * ``block-device-mapping.encrypted`` - A Boolean that indicates whether the EBS volume is encrypted.
          * ``description`` - The description of the image (provided during image creation).
          * ``ena-support`` - A Boolean that indicates whether enhanced networking with ENA is enabled.
          * ``hypervisor`` - The hypervisor type (``ovm`` | ``xen`` ).
          * ``image-id`` - The ID of the image.
          * ``image-type`` - The image type (``machine`` | ``kernel`` | ``ramdisk`` ).
          * ``is-public`` - A Boolean that indicates whether the image is public.
          * ``kernel-id`` - The kernel ID.
          * ``manifest-location`` - The location of the image manifest.
          * ``name`` - The name of the AMI (provided during image creation).
          * ``owner-alias`` - String value from an Amazon-maintained list (``amazon`` | ``aws-marketplace`` | ``microsoft`` ) of snapshot owners. Not to be confused with the user-configured AWS account alias, which is set from the IAM console.
          * ``owner-id`` - The AWS account ID of the image owner.
          * ``platform`` - The platform. To only list Windows-based AMIs, use ``windows`` .
          * ``product-code`` - The product code.
          * ``product-code.type`` - The type of the product code (``devpay`` | ``marketplace`` ).
          * ``ramdisk-id`` - The RAM disk ID.
          * ``root-device-name`` - The device name of the root device volume (for example, ``/dev/sda1`` ).
          * ``root-device-type`` - The type of the root device volume (``ebs`` | ``instance-store`` ).
          * ``state`` - The state of the image (``available`` | ``pending`` | ``failed`` ).
          * ``state-reason-code`` - The reason code for the state change.
          * ``state-reason-message`` - The message for the state change.
          * ``sriov-net-support`` - A value of ``simple`` indicates that enhanced networking with the Intel 82599 VF interface is enabled.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``virtualization-type`` - The virtualization type (``paravirtual`` | ``hvm`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type ImageIds: list
        :param ImageIds:
          The image IDs.
          Default: Describes all images available to you.
          - *(string) --*
        :type Owners: list
        :param Owners:
          Filters the images by the owner. Specify an AWS account ID, ``self`` (owner is the sender of the request), or an AWS owner alias (valid values are ``amazon`` | ``aws-marketplace`` | ``microsoft`` ). Omitting this option returns all images for which you have launch permissions, regardless of ownership.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_import_image_tasks(self, DryRun: bool = None, Filters: List = None, ImportTaskIds: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Displays details about an import virtual machine or import snapshot tasks that are already created.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeImportImageTasks>`_
        
        **Request Syntax**
        ::
          response = client.describe_import_image_tasks(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              ImportTaskIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ImportImageTasks': [
                    {
                        'Architecture': 'string',
                        'Description': 'string',
                        'Encrypted': True|False,
                        'Hypervisor': 'string',
                        'ImageId': 'string',
                        'ImportTaskId': 'string',
                        'KmsKeyId': 'string',
                        'LicenseType': 'string',
                        'Platform': 'string',
                        'Progress': 'string',
                        'SnapshotDetails': [
                            {
                                'Description': 'string',
                                'DeviceName': 'string',
                                'DiskImageSize': 123.0,
                                'Format': 'string',
                                'Progress': 'string',
                                'SnapshotId': 'string',
                                'Status': 'string',
                                'StatusMessage': 'string',
                                'Url': 'string',
                                'UserBucket': {
                                    'S3Bucket': 'string',
                                    'S3Key': 'string'
                                }
                            },
                        ],
                        'Status': 'string',
                        'StatusMessage': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for DescribeImportImageTasks.
            - **ImportImageTasks** *(list) --* 
              A list of zero or more import image tasks that are currently active or were completed or canceled in the previous 7 days.
              - *(dict) --* 
                Describes an import image task.
                - **Architecture** *(string) --* 
                  The architecture of the virtual machine.
                  Valid values: ``i386`` | ``x86_64``  
                - **Description** *(string) --* 
                  A description of the import task.
                - **Encrypted** *(boolean) --* 
                  Indicates whether the image is encrypted.
                - **Hypervisor** *(string) --* 
                  The target hypervisor for the import task.
                  Valid values: ``xen``  
                - **ImageId** *(string) --* 
                  The ID of the Amazon Machine Image (AMI) of the imported virtual machine.
                - **ImportTaskId** *(string) --* 
                  The ID of the import image task.
                - **KmsKeyId** *(string) --* 
                  The identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to create the encrypted image.
                - **LicenseType** *(string) --* 
                  The license type of the virtual machine.
                - **Platform** *(string) --* 
                  The description string for the import image task.
                - **Progress** *(string) --* 
                  The percentage of progress of the import image task.
                - **SnapshotDetails** *(list) --* 
                  Information about the snapshots.
                  - *(dict) --* 
                    Describes the snapshot created from the imported disk.
                    - **Description** *(string) --* 
                      A description for the snapshot.
                    - **DeviceName** *(string) --* 
                      The block device mapping for the snapshot.
                    - **DiskImageSize** *(float) --* 
                      The size of the disk in the snapshot, in GiB.
                    - **Format** *(string) --* 
                      The format of the disk image from which the snapshot is created.
                    - **Progress** *(string) --* 
                      The percentage of progress for the task.
                    - **SnapshotId** *(string) --* 
                      The snapshot ID of the disk being imported.
                    - **Status** *(string) --* 
                      A brief status of the snapshot creation.
                    - **StatusMessage** *(string) --* 
                      A detailed status message for the snapshot creation.
                    - **Url** *(string) --* 
                      The URL used to access the disk image.
                    - **UserBucket** *(dict) --* 
                      The S3 bucket for the disk image.
                      - **S3Bucket** *(string) --* 
                        The S3 bucket from which the disk image was created.
                      - **S3Key** *(string) --* 
                        The file name of the disk image.
                - **Status** *(string) --* 
                  A brief status for the import image task.
                - **StatusMessage** *(string) --* 
                  A descriptive status message for the import image task.
            - **NextToken** *(string) --* 
              The token to use to get the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          Filter tasks using the ``task-state`` filter and one of the following values: active, completed, deleting, deleted.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type ImportTaskIds: list
        :param ImportTaskIds:
          A list of import image task IDs.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          A token that indicates the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_import_snapshot_tasks(self, DryRun: bool = None, Filters: List = None, ImportTaskIds: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes your import snapshot tasks.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeImportSnapshotTasks>`_
        
        **Request Syntax**
        ::
          response = client.describe_import_snapshot_tasks(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              ImportTaskIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ImportSnapshotTasks': [
                    {
                        'Description': 'string',
                        'ImportTaskId': 'string',
                        'SnapshotTaskDetail': {
                            'Description': 'string',
                            'DiskImageSize': 123.0,
                            'Encrypted': True|False,
                            'Format': 'string',
                            'KmsKeyId': 'string',
                            'Progress': 'string',
                            'SnapshotId': 'string',
                            'Status': 'string',
                            'StatusMessage': 'string',
                            'Url': 'string',
                            'UserBucket': {
                                'S3Bucket': 'string',
                                'S3Key': 'string'
                            }
                        }
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for DescribeImportSnapshotTasks.
            - **ImportSnapshotTasks** *(list) --* 
              A list of zero or more import snapshot tasks that are currently active or were completed or canceled in the previous 7 days.
              - *(dict) --* 
                Describes an import snapshot task.
                - **Description** *(string) --* 
                  A description of the import snapshot task.
                - **ImportTaskId** *(string) --* 
                  The ID of the import snapshot task.
                - **SnapshotTaskDetail** *(dict) --* 
                  Describes an import snapshot task.
                  - **Description** *(string) --* 
                    The description of the snapshot.
                  - **DiskImageSize** *(float) --* 
                    The size of the disk in the snapshot, in GiB.
                  - **Encrypted** *(boolean) --* 
                    Indicates whether the snapshot is encrypted.
                  - **Format** *(string) --* 
                    The format of the disk image from which the snapshot is created.
                  - **KmsKeyId** *(string) --* 
                    The identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to create the encrypted snapshot.
                  - **Progress** *(string) --* 
                    The percentage of completion for the import snapshot task.
                  - **SnapshotId** *(string) --* 
                    The snapshot ID of the disk being imported.
                  - **Status** *(string) --* 
                    A brief status for the import snapshot task.
                  - **StatusMessage** *(string) --* 
                    A detailed status message for the import snapshot task.
                  - **Url** *(string) --* 
                    The URL of the disk image from which the snapshot is created.
                  - **UserBucket** *(dict) --* 
                    The S3 bucket for the disk image.
                    - **S3Bucket** *(string) --* 
                      The S3 bucket from which the disk image was created.
                    - **S3Key** *(string) --* 
                      The file name of the disk image.
            - **NextToken** *(string) --* 
              The token to use to get the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          The filters.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type ImportTaskIds: list
        :param ImportTaskIds:
          A list of import snapshot task IDs.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          A token that indicates the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_instance_attribute(self, Attribute: str, InstanceId: str, DryRun: bool = None) -> Dict:
        """
        Describes the specified attribute of the specified instance. You can specify only one attribute at a time. Valid attribute values are: ``instanceType`` | ``kernel`` | ``ramdisk`` | ``userData`` | ``disableApiTermination`` | ``instanceInitiatedShutdownBehavior`` | ``rootDeviceName`` | ``blockDeviceMapping`` | ``productCodes`` | ``sourceDestCheck`` | ``groupSet`` | ``ebsOptimized`` | ``sriovNetSupport``  
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeInstanceAttribute>`_
        
        **Request Syntax**
        ::
          response = client.describe_instance_attribute(
              Attribute='instanceType'|'kernel'|'ramdisk'|'userData'|'disableApiTermination'|'instanceInitiatedShutdownBehavior'|'rootDeviceName'|'blockDeviceMapping'|'productCodes'|'sourceDestCheck'|'groupSet'|'ebsOptimized'|'sriovNetSupport'|'enaSupport',
              DryRun=True|False,
              InstanceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Groups': [
                    {
                        'GroupName': 'string',
                        'GroupId': 'string'
                    },
                ],
                'BlockDeviceMappings': [
                    {
                        'DeviceName': 'string',
                        'Ebs': {
                            'AttachTime': datetime(2015, 1, 1),
                            'DeleteOnTermination': True|False,
                            'Status': 'attaching'|'attached'|'detaching'|'detached',
                            'VolumeId': 'string'
                        }
                    },
                ],
                'DisableApiTermination': {
                    'Value': True|False
                },
                'EnaSupport': {
                    'Value': True|False
                },
                'EbsOptimized': {
                    'Value': True|False
                },
                'InstanceId': 'string',
                'InstanceInitiatedShutdownBehavior': {
                    'Value': 'string'
                },
                'InstanceType': {
                    'Value': 'string'
                },
                'KernelId': {
                    'Value': 'string'
                },
                'ProductCodes': [
                    {
                        'ProductCodeId': 'string',
                        'ProductCodeType': 'devpay'|'marketplace'
                    },
                ],
                'RamdiskId': {
                    'Value': 'string'
                },
                'RootDeviceName': {
                    'Value': 'string'
                },
                'SourceDestCheck': {
                    'Value': True|False
                },
                'SriovNetSupport': {
                    'Value': 'string'
                },
                'UserData': {
                    'Value': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes an instance attribute.
            - **Groups** *(list) --* 
              The security groups associated with the instance.
              - *(dict) --* 
                Describes a security group.
                - **GroupName** *(string) --* 
                  The name of the security group.
                - **GroupId** *(string) --* 
                  The ID of the security group.
            - **BlockDeviceMappings** *(list) --* 
              The block device mapping of the instance.
              - *(dict) --* 
                Describes a block device mapping.
                - **DeviceName** *(string) --* 
                  The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                - **Ebs** *(dict) --* 
                  Parameters used to automatically set up EBS volumes when the instance is launched.
                  - **AttachTime** *(datetime) --* 
                    The time stamp when the attachment initiated.
                  - **DeleteOnTermination** *(boolean) --* 
                    Indicates whether the volume is deleted on instance termination.
                  - **Status** *(string) --* 
                    The attachment state.
                  - **VolumeId** *(string) --* 
                    The ID of the EBS volume.
            - **DisableApiTermination** *(dict) --* 
              If the value is ``true`` , you can't terminate the instance through the Amazon EC2 console, CLI, or API; otherwise, you can.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
            - **EnaSupport** *(dict) --* 
              Indicates whether enhanced networking with ENA is enabled.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
            - **EbsOptimized** *(dict) --* 
              Indicates whether the instance is optimized for Amazon EBS I/O.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
            - **InstanceId** *(string) --* 
              The ID of the instance.
            - **InstanceInitiatedShutdownBehavior** *(dict) --* 
              Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **InstanceType** *(dict) --* 
              The instance type.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **KernelId** *(dict) --* 
              The kernel ID.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **ProductCodes** *(list) --* 
              A list of product codes.
              - *(dict) --* 
                Describes a product code.
                - **ProductCodeId** *(string) --* 
                  The product code.
                - **ProductCodeType** *(string) --* 
                  The type of product code.
            - **RamdiskId** *(dict) --* 
              The RAM disk ID.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **RootDeviceName** *(dict) --* 
              The device name of the root device volume (for example, ``/dev/sda1`` ).
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **SourceDestCheck** *(dict) --* 
              Indicates whether source/destination checking is enabled. A value of ``true`` means that checking is enabled, and ``false`` means that checking is disabled. This value must be ``false`` for a NAT instance to perform NAT.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
            - **SriovNetSupport** *(dict) --* 
              Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **UserData** *(dict) --* 
              The user data.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The instance attribute.
          Note: The ``enaSupport`` attribute is not supported at this time.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :rtype: dict
        :returns:
        """
        pass

    def describe_instance_credit_specifications(self, DryRun: bool = None, Filters: List = None, InstanceIds: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the credit option for CPU usage of the specified T2 or T3 instances. The credit options are ``standard`` and ``unlimited`` .
        If you do not specify an instance ID, Amazon EC2 returns T2 and T3 instances with the ``unlimited`` credit option, as well as instances that were previously configured as T2 or T3 with the ``unlimited`` credit option. For example, if you resize a T2 instance, while it is configured as ``unlimited`` , to an M4 instance, Amazon EC2 returns the M4 instance.
        If you specify one or more instance IDs, Amazon EC2 returns the credit option (``standard`` or ``unlimited`` ) of those instances. If you specify an instance ID that is not valid, such as an instance that is not a T2 or T3 instance, an error is returned.
        Recently terminated instances might appear in the returned results. This interval is usually less than one hour.
        If an Availability Zone is experiencing a service disruption and you specify instance IDs in the affected zone, or do not specify any instance IDs at all, the call fails. If you specify only instance IDs in an unaffected zone, the call works normally.
        For more information, see `Burstable Performance Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeInstanceCreditSpecifications>`_
        
        **Request Syntax**
        ::
          response = client.describe_instance_credit_specifications(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              InstanceIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'InstanceCreditSpecifications': [
                    {
                        'InstanceId': 'string',
                        'CpuCredits': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InstanceCreditSpecifications** *(list) --* 
              Information about the credit option for CPU usage of an instance.
              - *(dict) --* 
                Describes the credit option for CPU usage of a T2 or T3 instance. 
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **CpuCredits** *(string) --* 
                  The credit option for CPU usage of the instance. Valid values are ``standard`` and ``unlimited`` .
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          The filters.
          * ``instance-id`` - The ID of the instance.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type InstanceIds: list
        :param InstanceIds:
          The instance IDs.
          Default: Describes all your instances.
          Constraints: Maximum 1000 explicitly specified instance IDs.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value. This value can be between 5 and 1000. You cannot specify this parameter and the instance IDs parameter in the same call.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_instance_status(self, Filters: List = None, InstanceIds: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None, IncludeAllInstances: bool = None) -> Dict:
        """
        Describes the status of the specified instances or all of your instances. By default, only running instances are described, unless you specifically indicate to return the status of all instances.
        Instance status includes the following components:
        * **Status checks** - Amazon EC2 performs status checks on running EC2 instances to identify hardware and software issues. For more information, see `Status Checks for Your Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-system-instance-status-check.html>`__ and `Troubleshooting Instances with Failed Status Checks <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstances.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . 
        * **Scheduled events** - Amazon EC2 can schedule events (such as reboot, stop, or terminate) for your instances related to hardware issues, software updates, or system maintenance. For more information, see `Scheduled Events for Your Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-instances-status-check_sched.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . 
        * **Instance state** - You can manage your instances from the moment you launch them through their termination. For more information, see `Instance Lifecycle <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-lifecycle.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeInstanceStatus>`_
        
        **Request Syntax**
        ::
          response = client.describe_instance_status(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              InstanceIds=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False,
              IncludeAllInstances=True|False
          )
        
        **Response Syntax**
        ::
            {
                'InstanceStatuses': [
                    {
                        'AvailabilityZone': 'string',
                        'Events': [
                            {
                                'InstanceEventId': 'string',
                                'Code': 'instance-reboot'|'system-reboot'|'system-maintenance'|'instance-retirement'|'instance-stop',
                                'Description': 'string',
                                'NotAfter': datetime(2015, 1, 1),
                                'NotBefore': datetime(2015, 1, 1),
                                'NotBeforeDeadline': datetime(2015, 1, 1)
                            },
                        ],
                        'InstanceId': 'string',
                        'InstanceState': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        },
                        'InstanceStatus': {
                            'Details': [
                                {
                                    'ImpairedSince': datetime(2015, 1, 1),
                                    'Name': 'reachability',
                                    'Status': 'passed'|'failed'|'insufficient-data'|'initializing'
                                },
                            ],
                            'Status': 'ok'|'impaired'|'insufficient-data'|'not-applicable'|'initializing'
                        },
                        'SystemStatus': {
                            'Details': [
                                {
                                    'ImpairedSince': datetime(2015, 1, 1),
                                    'Name': 'reachability',
                                    'Status': 'passed'|'failed'|'insufficient-data'|'initializing'
                                },
                            ],
                            'Status': 'ok'|'impaired'|'insufficient-data'|'not-applicable'|'initializing'
                        }
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InstanceStatuses** *(list) --* 
              Information about the status of the instances.
              - *(dict) --* 
                Describes the status of an instance.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone of the instance.
                - **Events** *(list) --* 
                  Any scheduled events associated with the instance.
                  - *(dict) --* 
                    Describes a scheduled event for an instance.
                    - **InstanceEventId** *(string) --* 
                      The ID of the event.
                    - **Code** *(string) --* 
                      The event code.
                    - **Description** *(string) --* 
                      A description of the event.
                      After a scheduled event is completed, it can still be described for up to a week. If the event has been completed, this description starts with the following text: [Completed].
                    - **NotAfter** *(datetime) --* 
                      The latest scheduled end time for the event.
                    - **NotBefore** *(datetime) --* 
                      The earliest scheduled start time for the event.
                    - **NotBeforeDeadline** *(datetime) --* 
                      The deadline for starting the event.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **InstanceState** *(dict) --* 
                  The intended state of the instance.  DescribeInstanceStatus requires that an instance be in the ``running`` state.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
                - **InstanceStatus** *(dict) --* 
                  Reports impaired functionality that stems from issues internal to the instance, such as impaired reachability.
                  - **Details** *(list) --* 
                    The system instance health or application instance health.
                    - *(dict) --* 
                      Describes the instance status.
                      - **ImpairedSince** *(datetime) --* 
                        The time when a status check failed. For an instance that was launched and impaired, this is the time when the instance was launched.
                      - **Name** *(string) --* 
                        The type of instance status.
                      - **Status** *(string) --* 
                        The status.
                  - **Status** *(string) --* 
                    The status.
                - **SystemStatus** *(dict) --* 
                  Reports impaired functionality that stems from issues related to the systems that support an instance, such as hardware failures and network connectivity problems.
                  - **Details** *(list) --* 
                    The system instance health or application instance health.
                    - *(dict) --* 
                      Describes the instance status.
                      - **ImpairedSince** *(datetime) --* 
                        The time when a status check failed. For an instance that was launched and impaired, this is the time when the instance was launched.
                      - **Name** *(string) --* 
                        The type of instance status.
                      - **Status** *(string) --* 
                        The status.
                  - **Status** *(string) --* 
                    The status.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          The filters.
          * ``availability-zone`` - The Availability Zone of the instance.
          * ``event.code`` - The code for the scheduled event (``instance-reboot`` | ``system-reboot`` | ``system-maintenance`` | ``instance-retirement`` | ``instance-stop`` ).
          * ``event.description`` - A description of the event.
          * ``event.instance-event-id`` - The ID of the event whose date and time you are modifying.
          * ``event.not-after`` - The latest end time for the scheduled event (for example, ``2014-09-15T17:15:20.000Z`` ).
          * ``event.not-before`` - The earliest start time for the scheduled event (for example, ``2014-09-15T17:15:20.000Z`` ).
          * ``event.not-before-deadline`` - The deadline for starting the event (for example, ``2014-09-15T17:15:20.000Z`` ).
          * ``instance-state-code`` - The code for the instance state, as a 16-bit unsigned integer. The high byte is used for internal purposes and should be ignored. The low byte is set based on the state represented. The valid values are 0 (pending), 16 (running), 32 (shutting-down), 48 (terminated), 64 (stopping), and 80 (stopped).
          * ``instance-state-name`` - The state of the instance (``pending`` | ``running`` | ``shutting-down`` | ``terminated`` | ``stopping`` | ``stopped`` ).
          * ``instance-status.reachability`` - Filters on instance status where the name is ``reachability`` (``passed`` | ``failed`` | ``initializing`` | ``insufficient-data`` ).
          * ``instance-status.status`` - The status of the instance (``ok`` | ``impaired`` | ``initializing`` | ``insufficient-data`` | ``not-applicable`` ).
          * ``system-status.reachability`` - Filters on system status where the name is ``reachability`` (``passed`` | ``failed`` | ``initializing`` | ``insufficient-data`` ).
          * ``system-status.status`` - The system status of the instance (``ok`` | ``impaired`` | ``initializing`` | ``insufficient-data`` | ``not-applicable`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type InstanceIds: list
        :param InstanceIds:
          The instance IDs.
          Default: Describes all your instances.
          Constraints: Maximum 100 explicitly specified instance IDs.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value. This value can be between 5 and 1000. You cannot specify this parameter and the instance IDs parameter in the same call.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type IncludeAllInstances: boolean
        :param IncludeAllInstances:
          When ``true`` , includes the health status for all instances. When ``false`` , includes the health status for running instances only.
          Default: ``false``
        :rtype: dict
        :returns:
        """
        pass

    def describe_instances(self, Filters: List = None, InstanceIds: List = None, DryRun: bool = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the specified instances or all of your instances.
        If you specify one or more instance IDs, Amazon EC2 returns information for those instances. If you do not specify instance IDs, Amazon EC2 returns information for all relevant instances. If you specify an instance ID that is not valid, an error is returned. If you specify an instance that you do not own, it is not included in the returned results.
        Recently terminated instances might appear in the returned results. This interval is usually less than one hour.
        If you describe instances in the rare case where an Availability Zone is experiencing a service disruption and you specify instance IDs that are in the affected zone, or do not specify any instance IDs at all, the call fails. If you describe instances and specify only instance IDs that are in an unaffected zone, the call works normally.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeInstances>`_
        
        **Request Syntax**
        ::
          response = client.describe_instances(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              InstanceIds=[
                  'string',
              ],
              DryRun=True|False,
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'Reservations': [
                    {
                        'Groups': [
                            {
                                'GroupName': 'string',
                                'GroupId': 'string'
                            },
                        ],
                        'Instances': [
                            {
                                'AmiLaunchIndex': 123,
                                'ImageId': 'string',
                                'InstanceId': 'string',
                                'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                'KernelId': 'string',
                                'KeyName': 'string',
                                'LaunchTime': datetime(2015, 1, 1),
                                'Monitoring': {
                                    'State': 'disabled'|'disabling'|'enabled'|'pending'
                                },
                                'Placement': {
                                    'AvailabilityZone': 'string',
                                    'Affinity': 'string',
                                    'GroupName': 'string',
                                    'PartitionNumber': 123,
                                    'HostId': 'string',
                                    'Tenancy': 'default'|'dedicated'|'host',
                                    'SpreadDomain': 'string'
                                },
                                'Platform': 'Windows',
                                'PrivateDnsName': 'string',
                                'PrivateIpAddress': 'string',
                                'ProductCodes': [
                                    {
                                        'ProductCodeId': 'string',
                                        'ProductCodeType': 'devpay'|'marketplace'
                                    },
                                ],
                                'PublicDnsName': 'string',
                                'PublicIpAddress': 'string',
                                'RamdiskId': 'string',
                                'State': {
                                    'Code': 123,
                                    'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                                },
                                'StateTransitionReason': 'string',
                                'SubnetId': 'string',
                                'VpcId': 'string',
                                'Architecture': 'i386'|'x86_64'|'arm64',
                                'BlockDeviceMappings': [
                                    {
                                        'DeviceName': 'string',
                                        'Ebs': {
                                            'AttachTime': datetime(2015, 1, 1),
                                            'DeleteOnTermination': True|False,
                                            'Status': 'attaching'|'attached'|'detaching'|'detached',
                                            'VolumeId': 'string'
                                        }
                                    },
                                ],
                                'ClientToken': 'string',
                                'EbsOptimized': True|False,
                                'EnaSupport': True|False,
                                'Hypervisor': 'ovm'|'xen',
                                'IamInstanceProfile': {
                                    'Arn': 'string',
                                    'Id': 'string'
                                },
                                'InstanceLifecycle': 'spot'|'scheduled',
                                'ElasticGpuAssociations': [
                                    {
                                        'ElasticGpuId': 'string',
                                        'ElasticGpuAssociationId': 'string',
                                        'ElasticGpuAssociationState': 'string',
                                        'ElasticGpuAssociationTime': 'string'
                                    },
                                ],
                                'ElasticInferenceAcceleratorAssociations': [
                                    {
                                        'ElasticInferenceAcceleratorArn': 'string',
                                        'ElasticInferenceAcceleratorAssociationId': 'string',
                                        'ElasticInferenceAcceleratorAssociationState': 'string',
                                        'ElasticInferenceAcceleratorAssociationTime': datetime(2015, 1, 1)
                                    },
                                ],
                                'NetworkInterfaces': [
                                    {
                                        'Association': {
                                            'IpOwnerId': 'string',
                                            'PublicDnsName': 'string',
                                            'PublicIp': 'string'
                                        },
                                        'Attachment': {
                                            'AttachTime': datetime(2015, 1, 1),
                                            'AttachmentId': 'string',
                                            'DeleteOnTermination': True|False,
                                            'DeviceIndex': 123,
                                            'Status': 'attaching'|'attached'|'detaching'|'detached'
                                        },
                                        'Description': 'string',
                                        'Groups': [
                                            {
                                                'GroupName': 'string',
                                                'GroupId': 'string'
                                            },
                                        ],
                                        'Ipv6Addresses': [
                                            {
                                                'Ipv6Address': 'string'
                                            },
                                        ],
                                        'MacAddress': 'string',
                                        'NetworkInterfaceId': 'string',
                                        'OwnerId': 'string',
                                        'PrivateDnsName': 'string',
                                        'PrivateIpAddress': 'string',
                                        'PrivateIpAddresses': [
                                            {
                                                'Association': {
                                                    'IpOwnerId': 'string',
                                                    'PublicDnsName': 'string',
                                                    'PublicIp': 'string'
                                                },
                                                'Primary': True|False,
                                                'PrivateDnsName': 'string',
                                                'PrivateIpAddress': 'string'
                                            },
                                        ],
                                        'SourceDestCheck': True|False,
                                        'Status': 'available'|'associated'|'attaching'|'in-use'|'detaching',
                                        'SubnetId': 'string',
                                        'VpcId': 'string',
                                        'InterfaceType': 'string'
                                    },
                                ],
                                'RootDeviceName': 'string',
                                'RootDeviceType': 'ebs'|'instance-store',
                                'SecurityGroups': [
                                    {
                                        'GroupName': 'string',
                                        'GroupId': 'string'
                                    },
                                ],
                                'SourceDestCheck': True|False,
                                'SpotInstanceRequestId': 'string',
                                'SriovNetSupport': 'string',
                                'StateReason': {
                                    'Code': 'string',
                                    'Message': 'string'
                                },
                                'Tags': [
                                    {
                                        'Key': 'string',
                                        'Value': 'string'
                                    },
                                ],
                                'VirtualizationType': 'hvm'|'paravirtual',
                                'CpuOptions': {
                                    'CoreCount': 123,
                                    'ThreadsPerCore': 123
                                },
                                'CapacityReservationId': 'string',
                                'CapacityReservationSpecification': {
                                    'CapacityReservationPreference': 'open'|'none',
                                    'CapacityReservationTarget': {
                                        'CapacityReservationId': 'string'
                                    }
                                },
                                'HibernationOptions': {
                                    'Configured': True|False
                                },
                                'Licenses': [
                                    {
                                        'LicenseConfigurationArn': 'string'
                                    },
                                ]
                            },
                        ],
                        'OwnerId': 'string',
                        'RequesterId': 'string',
                        'ReservationId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Reservations** *(list) --* 
              Information about the reservations.
              - *(dict) --* 
                Describes a reservation.
                - **Groups** *(list) --* 
                  [EC2-Classic only] The security groups.
                  - *(dict) --* 
                    Describes a security group.
                    - **GroupName** *(string) --* 
                      The name of the security group.
                    - **GroupId** *(string) --* 
                      The ID of the security group.
                - **Instances** *(list) --* 
                  The instances.
                  - *(dict) --* 
                    Describes an instance.
                    - **AmiLaunchIndex** *(integer) --* 
                      The AMI launch index, which can be used to find this instance in the launch group.
                    - **ImageId** *(string) --* 
                      The ID of the AMI used to launch the instance.
                    - **InstanceId** *(string) --* 
                      The ID of the instance.
                    - **InstanceType** *(string) --* 
                      The instance type.
                    - **KernelId** *(string) --* 
                      The kernel associated with this instance, if applicable.
                    - **KeyName** *(string) --* 
                      The name of the key pair, if this instance was launched with an associated key pair.
                    - **LaunchTime** *(datetime) --* 
                      The time the instance was launched.
                    - **Monitoring** *(dict) --* 
                      The monitoring for the instance.
                      - **State** *(string) --* 
                        Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
                    - **Placement** *(dict) --* 
                      The location where the instance launched, if applicable.
                      - **AvailabilityZone** *(string) --* 
                        The Availability Zone of the instance.
                        If not specified, an Availability Zone will be automatically chosen for you based on the load balancing criteria for the region.
                      - **Affinity** *(string) --* 
                        The affinity setting for the instance on the Dedicated Host. This parameter is not supported for the  ImportInstance command.
                      - **GroupName** *(string) --* 
                        The name of the placement group the instance is in.
                      - **PartitionNumber** *(integer) --* 
                        The number of the partition the instance is in. Valid only if the placement group strategy is set to ``partition`` .
                      - **HostId** *(string) --* 
                        The ID of the Dedicated Host on which the instance resides. This parameter is not supported for the  ImportInstance command.
                      - **Tenancy** *(string) --* 
                        The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for the  ImportInstance command.
                      - **SpreadDomain** *(string) --* 
                        Reserved for future use.
                    - **Platform** *(string) --* 
                      The value is ``Windows`` for Windows instances; otherwise blank.
                    - **PrivateDnsName** *(string) --* 
                      (IPv4 only) The private DNS hostname name assigned to the instance. This DNS hostname can only be used inside the Amazon EC2 network. This name is not available until the instance enters the ``running`` state. 
                      [EC2-VPC] The Amazon-provided DNS server resolves Amazon-provided private DNS hostnames if you've enabled DNS resolution and DNS hostnames in your VPC. If you are not using the Amazon-provided DNS server in your VPC, your custom domain name servers must resolve the hostname as appropriate.
                    - **PrivateIpAddress** *(string) --* 
                      The private IPv4 address assigned to the instance.
                    - **ProductCodes** *(list) --* 
                      The product codes attached to this instance, if applicable.
                      - *(dict) --* 
                        Describes a product code.
                        - **ProductCodeId** *(string) --* 
                          The product code.
                        - **ProductCodeType** *(string) --* 
                          The type of product code.
                    - **PublicDnsName** *(string) --* 
                      (IPv4 only) The public DNS name assigned to the instance. This name is not available until the instance enters the ``running`` state. For EC2-VPC, this name is only available if you've enabled DNS hostnames for your VPC.
                    - **PublicIpAddress** *(string) --* 
                      The public IPv4 address assigned to the instance, if applicable.
                    - **RamdiskId** *(string) --* 
                      The RAM disk associated with this instance, if applicable.
                    - **State** *(dict) --* 
                      The current state of the instance.
                      - **Code** *(integer) --* 
                        The state of the instance as a 16-bit unsigned integer. 
                        The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                        The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                        The valid values for instance-state-code will all be in the range of the low byte and they are:
                        * ``0`` : ``pending``   
                        * ``16`` : ``running``   
                        * ``32`` : ``shutting-down``   
                        * ``48`` : ``terminated``   
                        * ``64`` : ``stopping``   
                        * ``80`` : ``stopped``   
                        You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                      - **Name** *(string) --* 
                        The current state of the instance.
                    - **StateTransitionReason** *(string) --* 
                      The reason for the most recent state transition. This might be an empty string.
                    - **SubnetId** *(string) --* 
                      [EC2-VPC] The ID of the subnet in which the instance is running.
                    - **VpcId** *(string) --* 
                      [EC2-VPC] The ID of the VPC in which the instance is running.
                    - **Architecture** *(string) --* 
                      The architecture of the image.
                    - **BlockDeviceMappings** *(list) --* 
                      Any block device mapping entries for the instance.
                      - *(dict) --* 
                        Describes a block device mapping.
                        - **DeviceName** *(string) --* 
                          The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                        - **Ebs** *(dict) --* 
                          Parameters used to automatically set up EBS volumes when the instance is launched.
                          - **AttachTime** *(datetime) --* 
                            The time stamp when the attachment initiated.
                          - **DeleteOnTermination** *(boolean) --* 
                            Indicates whether the volume is deleted on instance termination.
                          - **Status** *(string) --* 
                            The attachment state.
                          - **VolumeId** *(string) --* 
                            The ID of the EBS volume.
                    - **ClientToken** *(string) --* 
                      The idempotency token you provided when you launched the instance, if applicable.
                    - **EbsOptimized** *(boolean) --* 
                      Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
                    - **EnaSupport** *(boolean) --* 
                      Specifies whether enhanced networking with ENA is enabled.
                    - **Hypervisor** *(string) --* 
                      The hypervisor type of the instance.
                    - **IamInstanceProfile** *(dict) --* 
                      The IAM instance profile associated with the instance, if applicable.
                      - **Arn** *(string) --* 
                        The Amazon Resource Name (ARN) of the instance profile.
                      - **Id** *(string) --* 
                        The ID of the instance profile.
                    - **InstanceLifecycle** *(string) --* 
                      Indicates whether this is a Spot Instance or a Scheduled Instance.
                    - **ElasticGpuAssociations** *(list) --* 
                      The Elastic GPU associated with the instance.
                      - *(dict) --* 
                        Describes the association between an instance and an Elastic Graphics accelerator.
                        - **ElasticGpuId** *(string) --* 
                          The ID of the Elastic Graphics accelerator.
                        - **ElasticGpuAssociationId** *(string) --* 
                          The ID of the association.
                        - **ElasticGpuAssociationState** *(string) --* 
                          The state of the association between the instance and the Elastic Graphics accelerator.
                        - **ElasticGpuAssociationTime** *(string) --* 
                          The time the Elastic Graphics accelerator was associated with the instance.
                    - **ElasticInferenceAcceleratorAssociations** *(list) --* 
                      The elastic inference accelerator associated with the instance. 
                      - *(dict) --* 
                        Describes the association between an instance and an elastic inference accelerator. 
                        - **ElasticInferenceAcceleratorArn** *(string) --* 
                          The Amazon Resource Name (ARN) of the elastic inference accelerator. 
                        - **ElasticInferenceAcceleratorAssociationId** *(string) --* 
                          The ID of the association. 
                        - **ElasticInferenceAcceleratorAssociationState** *(string) --* 
                          The state of the elastic inference accelerator. 
                        - **ElasticInferenceAcceleratorAssociationTime** *(datetime) --* 
                          The time at which the elastic inference accelerator is associated with an instance. 
                    - **NetworkInterfaces** *(list) --* 
                      [EC2-VPC] The network interfaces for the instance.
                      - *(dict) --* 
                        Describes a network interface.
                        - **Association** *(dict) --* 
                          The association information for an Elastic IPv4 associated with the network interface.
                          - **IpOwnerId** *(string) --* 
                            The ID of the owner of the Elastic IP address.
                          - **PublicDnsName** *(string) --* 
                            The public DNS name.
                          - **PublicIp** *(string) --* 
                            The public IP address or Elastic IP address bound to the network interface.
                        - **Attachment** *(dict) --* 
                          The network interface attachment.
                          - **AttachTime** *(datetime) --* 
                            The time stamp when the attachment initiated.
                          - **AttachmentId** *(string) --* 
                            The ID of the network interface attachment.
                          - **DeleteOnTermination** *(boolean) --* 
                            Indicates whether the network interface is deleted when the instance is terminated.
                          - **DeviceIndex** *(integer) --* 
                            The index of the device on the instance for the network interface attachment.
                          - **Status** *(string) --* 
                            The attachment state.
                        - **Description** *(string) --* 
                          The description.
                        - **Groups** *(list) --* 
                          One or more security groups.
                          - *(dict) --* 
                            Describes a security group.
                            - **GroupName** *(string) --* 
                              The name of the security group.
                            - **GroupId** *(string) --* 
                              The ID of the security group.
                        - **Ipv6Addresses** *(list) --* 
                          One or more IPv6 addresses associated with the network interface.
                          - *(dict) --* 
                            Describes an IPv6 address.
                            - **Ipv6Address** *(string) --* 
                              The IPv6 address.
                        - **MacAddress** *(string) --* 
                          The MAC address.
                        - **NetworkInterfaceId** *(string) --* 
                          The ID of the network interface.
                        - **OwnerId** *(string) --* 
                          The ID of the AWS account that created the network interface.
                        - **PrivateDnsName** *(string) --* 
                          The private DNS name.
                        - **PrivateIpAddress** *(string) --* 
                          The IPv4 address of the network interface within the subnet.
                        - **PrivateIpAddresses** *(list) --* 
                          One or more private IPv4 addresses associated with the network interface.
                          - *(dict) --* 
                            Describes a private IPv4 address.
                            - **Association** *(dict) --* 
                              The association information for an Elastic IP address for the network interface.
                              - **IpOwnerId** *(string) --* 
                                The ID of the owner of the Elastic IP address.
                              - **PublicDnsName** *(string) --* 
                                The public DNS name.
                              - **PublicIp** *(string) --* 
                                The public IP address or Elastic IP address bound to the network interface.
                            - **Primary** *(boolean) --* 
                              Indicates whether this IPv4 address is the primary private IP address of the network interface.
                            - **PrivateDnsName** *(string) --* 
                              The private IPv4 DNS name.
                            - **PrivateIpAddress** *(string) --* 
                              The private IPv4 address of the network interface.
                        - **SourceDestCheck** *(boolean) --* 
                          Indicates whether to validate network traffic to or from this network interface.
                        - **Status** *(string) --* 
                          The status of the network interface.
                        - **SubnetId** *(string) --* 
                          The ID of the subnet.
                        - **VpcId** *(string) --* 
                          The ID of the VPC.
                        - **InterfaceType** *(string) --* 
                          Describes the type of network interface.
                    - **RootDeviceName** *(string) --* 
                      The device name of the root device volume (for example, ``/dev/sda1`` ).
                    - **RootDeviceType** *(string) --* 
                      The root device type used by the AMI. The AMI can use an EBS volume or an instance store volume.
                    - **SecurityGroups** *(list) --* 
                      The security groups for the instance.
                      - *(dict) --* 
                        Describes a security group.
                        - **GroupName** *(string) --* 
                          The name of the security group.
                        - **GroupId** *(string) --* 
                          The ID of the security group.
                    - **SourceDestCheck** *(boolean) --* 
                      Specifies whether to enable an instance launched in a VPC to perform NAT. This controls whether source/destination checking is enabled on the instance. A value of ``true`` means that checking is enabled, and ``false`` means that checking is disabled. The value must be ``false`` for the instance to perform NAT. For more information, see `NAT Instances <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_NAT_Instance.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
                    - **SpotInstanceRequestId** *(string) --* 
                      If the request is a Spot Instance request, the ID of the request.
                    - **SriovNetSupport** *(string) --* 
                      Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
                    - **StateReason** *(dict) --* 
                      The reason for the most recent state transition.
                      - **Code** *(string) --* 
                        The reason code for the state change.
                      - **Message** *(string) --* 
                        The message for the state change.
                        * ``Server.InsufficientInstanceCapacity`` : There was insufficient capacity available to satisfy the launch request. 
                        * ``Server.InternalError`` : An internal error caused the instance to terminate during launch. 
                        * ``Server.ScheduledStop`` : The instance was stopped due to a scheduled retirement. 
                        * ``Server.SpotInstanceShutdown`` : The instance was stopped because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. 
                        * ``Server.SpotInstanceTermination`` : The instance was terminated because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. 
                        * ``Client.InstanceInitiatedShutdown`` : The instance was shut down using the ``shutdown -h`` command from the instance. 
                        * ``Client.InstanceTerminated`` : The instance was terminated or rebooted during AMI creation. 
                        * ``Client.InternalError`` : A client error caused the instance to terminate during launch. 
                        * ``Client.InvalidSnapshot.NotFound`` : The specified snapshot was not found. 
                        * ``Client.UserInitiatedHibernate`` : Hibernation was initiated on the instance. 
                        * ``Client.UserInitiatedShutdown`` : The instance was shut down using the Amazon EC2 API. 
                        * ``Client.VolumeLimitExceeded`` : The limit on the number of EBS volumes or total storage was exceeded. Decrease usage or request an increase in your account limits. 
                    - **Tags** *(list) --* 
                      Any tags assigned to the instance.
                      - *(dict) --* 
                        Describes a tag.
                        - **Key** *(string) --* 
                          The key of the tag.
                          Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                        - **Value** *(string) --* 
                          The value of the tag.
                          Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                    - **VirtualizationType** *(string) --* 
                      The virtualization type of the instance.
                    - **CpuOptions** *(dict) --* 
                      The CPU options for the instance.
                      - **CoreCount** *(integer) --* 
                        The number of CPU cores for the instance.
                      - **ThreadsPerCore** *(integer) --* 
                        The number of threads per CPU core.
                    - **CapacityReservationId** *(string) --* 
                      The ID of the Capacity Reservation.
                    - **CapacityReservationSpecification** *(dict) --* 
                      Information about the Capacity Reservation targeting option.
                      - **CapacityReservationPreference** *(string) --* 
                        Describes the instance's Capacity Reservation preferences. Possible preferences include:
                        * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone). 
                        * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity. 
                      - **CapacityReservationTarget** *(dict) --* 
                        Information about the targeted Capacity Reservation.
                        - **CapacityReservationId** *(string) --* 
                          The ID of the Capacity Reservation.
                    - **HibernationOptions** *(dict) --* 
                      Indicates whether the instance is enabled for hibernation.
                      - **Configured** *(boolean) --* 
                        If this parameter is set to ``true`` , your instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
                    - **Licenses** *(list) --* 
                      The license configurations.
                      - *(dict) --* 
                        Describes a license configuration.
                        - **LicenseConfigurationArn** *(string) --* 
                          The Amazon Resource Name (ARN) of the license configuration.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account that owns the reservation.
                - **RequesterId** *(string) --* 
                  The ID of the requester that launched the instances on your behalf (for example, AWS Management Console or Auto Scaling).
                - **ReservationId** *(string) --* 
                  The ID of the reservation.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          The filters.
          * ``affinity`` - The affinity setting for an instance running on a Dedicated Host (``default`` | ``host`` ).
          * ``architecture`` - The instance architecture (``i386`` | ``x86_64`` ).
          * ``availability-zone`` - The Availability Zone of the instance.
          * ``block-device-mapping.attach-time`` - The attach time for an EBS volume mapped to the instance, for example, ``2010-09-15T17:15:20.000Z`` .
          * ``block-device-mapping.delete-on-termination`` - A Boolean that indicates whether the EBS volume is deleted on instance termination.
          * ``block-device-mapping.device-name`` - The device name specified in the block device mapping (for example, ``/dev/sdh`` or ``xvdh`` ).
          * ``block-device-mapping.status`` - The status for the EBS volume (``attaching`` | ``attached`` | ``detaching`` | ``detached`` ).
          * ``block-device-mapping.volume-id`` - The volume ID of the EBS volume.
          * ``client-token`` - The idempotency token you provided when you launched the instance.
          * ``dns-name`` - The public DNS name of the instance.
          * ``group-id`` - The ID of the security group for the instance. EC2-Classic only.
          * ``group-name`` - The name of the security group for the instance. EC2-Classic only.
          * ``hibernation-options.configured`` - A Boolean that indicates whether the instance is enabled for hibernation. A value of ``true`` means that the instance is enabled for hibernation.
          * ``host-id`` - The ID of the Dedicated Host on which the instance is running, if applicable.
          * ``hypervisor`` - The hypervisor type of the instance (``ovm`` | ``xen`` ).
          * ``iam-instance-profile.arn`` - The instance profile associated with the instance. Specified as an ARN.
          * ``image-id`` - The ID of the image used to launch the instance.
          * ``instance-id`` - The ID of the instance.
          * ``instance-lifecycle`` - Indicates whether this is a Spot Instance or a Scheduled Instance (``spot`` | ``scheduled`` ).
          * ``instance-state-code`` - The state of the instance, as a 16-bit unsigned integer. The high byte is used for internal purposes and should be ignored. The low byte is set based on the state represented. The valid values are: 0 (pending), 16 (running), 32 (shutting-down), 48 (terminated), 64 (stopping), and 80 (stopped).
          * ``instance-state-name`` - The state of the instance (``pending`` | ``running`` | ``shutting-down`` | ``terminated`` | ``stopping`` | ``stopped`` ).
          * ``instance-type`` - The type of instance (for example, ``t2.micro`` ).
          * ``instance.group-id`` - The ID of the security group for the instance.
          * ``instance.group-name`` - The name of the security group for the instance.
          * ``ip-address`` - The public IPv4 address of the instance.
          * ``kernel-id`` - The kernel ID.
          * ``key-name`` - The name of the key pair used when the instance was launched.
          * ``launch-index`` - When launching multiple instances, this is the index for the instance in the launch group (for example, 0, 1, 2, and so on).
          * ``launch-time`` - The time when the instance was launched.
          * ``monitoring-state`` - Indicates whether detailed monitoring is enabled (``disabled`` | ``enabled`` ).
          * ``network-interface.addresses.private-ip-address`` - The private IPv4 address associated with the network interface.
          * ``network-interface.addresses.primary`` - Specifies whether the IPv4 address of the network interface is the primary private IPv4 address.
          * ``network-interface.addresses.association.public-ip`` - The ID of the association of an Elastic IP address (IPv4) with a network interface.
          * ``network-interface.addresses.association.ip-owner-id`` - The owner ID of the private IPv4 address associated with the network interface.
          * ``network-interface.association.public-ip`` - The address of the Elastic IP address (IPv4) bound to the network interface.
          * ``network-interface.association.ip-owner-id`` - The owner of the Elastic IP address (IPv4) associated with the network interface.
          * ``network-interface.association.allocation-id`` - The allocation ID returned when you allocated the Elastic IP address (IPv4) for your network interface.
          * ``network-interface.association.association-id`` - The association ID returned when the network interface was associated with an IPv4 address.
          * ``network-interface.attachment.attachment-id`` - The ID of the interface attachment.
          * ``network-interface.attachment.instance-id`` - The ID of the instance to which the network interface is attached.
          * ``network-interface.attachment.instance-owner-id`` - The owner ID of the instance to which the network interface is attached.
          * ``network-interface.attachment.device-index`` - The device index to which the network interface is attached.
          * ``network-interface.attachment.status`` - The status of the attachment (``attaching`` | ``attached`` | ``detaching`` | ``detached`` ).
          * ``network-interface.attachment.attach-time`` - The time that the network interface was attached to an instance.
          * ``network-interface.attachment.delete-on-termination`` - Specifies whether the attachment is deleted when an instance is terminated.
          * ``network-interface.availability-zone`` - The Availability Zone for the network interface.
          * ``network-interface.description`` - The description of the network interface.
          * ``network-interface.group-id`` - The ID of a security group associated with the network interface.
          * ``network-interface.group-name`` - The name of a security group associated with the network interface.
          * ``network-interface.ipv6-addresses.ipv6-address`` - The IPv6 address associated with the network interface.
          * ``network-interface.mac-address`` - The MAC address of the network interface.
          * ``network-interface.network-interface-id`` - The ID of the network interface.
          * ``network-interface.owner-id`` - The ID of the owner of the network interface.
          * ``network-interface.private-dns-name`` - The private DNS name of the network interface.
          * ``network-interface.requester-id`` - The requester ID for the network interface.
          * ``network-interface.requester-managed`` - Indicates whether the network interface is being managed by AWS.
          * ``network-interface.status`` - The status of the network interface (``available`` ) | ``in-use`` ).
          * ``network-interface.source-dest-check`` - Whether the network interface performs source/destination checking. A value of ``true`` means that checking is enabled, and ``false`` means that checking is disabled. The value must be ``false`` for the network interface to perform network address translation (NAT) in your VPC.
          * ``network-interface.subnet-id`` - The ID of the subnet for the network interface.
          * ``network-interface.vpc-id`` - The ID of the VPC for the network interface.
          * ``owner-id`` - The AWS account ID of the instance owner.
          * ``placement-group-name`` - The name of the placement group for the instance.
          * ``placement-partition-number`` - The partition in which the instance is located.
          * ``platform`` - The platform. To list only Windows instances, use ``windows`` .
          * ``private-dns-name`` - The private IPv4 DNS name of the instance.
          * ``private-ip-address`` - The private IPv4 address of the instance.
          * ``product-code`` - The product code associated with the AMI used to launch the instance.
          * ``product-code.type`` - The type of product code (``devpay`` | ``marketplace`` ).
          * ``ramdisk-id`` - The RAM disk ID.
          * ``reason`` - The reason for the current state of the instance (for example, shows \"User Initiated [date]\" when you stop or terminate the instance). Similar to the state-reason-code filter.
          * ``requester-id`` - The ID of the entity that launched the instance on your behalf (for example, AWS Management Console, Auto Scaling, and so on).
          * ``reservation-id`` - The ID of the instance\'s reservation. A reservation ID is created any time you launch an instance. A reservation ID has a one-to-one relationship with an instance launch request, but can be associated with more than one instance if you launch multiple instances using the same launch request. For example, if you launch one instance, you get one reservation ID. If you launch ten instances using the same launch request, you also get one reservation ID.
          * ``root-device-name`` - The device name of the root device volume (for example, ``/dev/sda1`` ).
          * ``root-device-type`` - The type of the root device volume (``ebs`` | ``instance-store`` ).
          * ``source-dest-check`` - Indicates whether the instance performs source/destination checking. A value of ``true`` means that checking is enabled, and ``false`` means that checking is disabled. The value must be ``false`` for the instance to perform network address translation (NAT) in your VPC.
          * ``spot-instance-request-id`` - The ID of the Spot Instance request.
          * ``state-reason-code`` - The reason code for the state change.
          * ``state-reason-message`` - A message that describes the state change.
          * ``subnet-id`` - The ID of the subnet for the instance.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources that have a tag with a specific key, regardless of the tag value.
          * ``tenancy`` - The tenancy of an instance (``dedicated`` | ``default`` | ``host`` ).
          * ``virtualization-type`` - The virtualization type of the instance (``paravirtual`` | ``hvm`` ).
          * ``vpc-id`` - The ID of the VPC that the instance is running in.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type InstanceIds: list
        :param InstanceIds:
          The instance IDs.
          Default: Describes all your instances.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value. This value can be between 5 and 1000. You cannot specify this parameter and the instance IDs parameter in the same call.
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_internet_gateways(self, Filters: List = None, DryRun: bool = None, InternetGatewayIds: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes one or more of your internet gateways.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeInternetGateways>`_
        
        **Request Syntax**
        ::
          response = client.describe_internet_gateways(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              InternetGatewayIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'InternetGateways': [
                    {
                        'Attachments': [
                            {
                                'State': 'attaching'|'attached'|'detaching'|'detached',
                                'VpcId': 'string'
                            },
                        ],
                        'InternetGatewayId': 'string',
                        'OwnerId': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InternetGateways** *(list) --* 
              Information about one or more internet gateways.
              - *(dict) --* 
                Describes an internet gateway.
                - **Attachments** *(list) --* 
                  Any VPCs attached to the internet gateway.
                  - *(dict) --* 
                    Describes the attachment of a VPC to an internet gateway or an egress-only internet gateway.
                    - **State** *(string) --* 
                      The current state of the attachment. For an internet gateway, the state is ``available`` when attached to a VPC; otherwise, this value is not returned.
                    - **VpcId** *(string) --* 
                      The ID of the VPC.
                - **InternetGatewayId** *(string) --* 
                  The ID of the internet gateway.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account that owns the internet gateway.
                - **Tags** *(list) --* 
                  Any tags assigned to the internet gateway.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``attachment.state`` - The current state of the attachment between the gateway and the VPC (``available`` ). Present only if a VPC is attached.
          * ``attachment.vpc-id`` - The ID of an attached VPC.
          * ``internet-gateway-id`` - The ID of the Internet gateway.
          * ``owner-id`` - The ID of the AWS account that owns the internet gateway.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InternetGatewayIds: list
        :param InternetGatewayIds:
          One or more internet gateway IDs.
          Default: Describes all your internet gateways.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_key_pairs(self, Filters: List = None, KeyNames: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the specified key pairs or all of your key pairs.
        For more information about key pairs, see `Key Pairs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeKeyPairs>`_
        
        **Request Syntax**
        ::
          response = client.describe_key_pairs(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              KeyNames=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'KeyPairs': [
                    {
                        'KeyFingerprint': 'string',
                        'KeyName': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **KeyPairs** *(list) --* 
              Information about the key pairs.
              - *(dict) --* 
                Describes a key pair.
                - **KeyFingerprint** *(string) --* 
                  If you used  CreateKeyPair to create the key pair, this is the SHA-1 digest of the DER encoded private key. If you used  ImportKeyPair to provide AWS the public key, this is the MD5 public key fingerprint as specified in section 4 of RFC4716.
                - **KeyName** *(string) --* 
                  The name of the key pair.
        :type Filters: list
        :param Filters:
          The filters.
          * ``fingerprint`` - The fingerprint of the key pair.
          * ``key-name`` - The name of the key pair.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type KeyNames: list
        :param KeyNames:
          The key pair names.
          Default: Describes all your key pairs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_launch_template_versions(self, DryRun: bool = None, LaunchTemplateId: str = None, LaunchTemplateName: str = None, Versions: List = None, MinVersion: str = None, MaxVersion: str = None, NextToken: str = None, MaxResults: int = None, Filters: List = None) -> Dict:
        """
        Describes one or more versions of a specified launch template. You can describe all versions, individual versions, or a range of versions.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeLaunchTemplateVersions>`_
        
        **Request Syntax**
        ::
          response = client.describe_launch_template_versions(
              DryRun=True|False,
              LaunchTemplateId='string',
              LaunchTemplateName='string',
              Versions=[
                  'string',
              ],
              MinVersion='string',
              MaxVersion='string',
              NextToken='string',
              MaxResults=123,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'LaunchTemplateVersions': [
                    {
                        'LaunchTemplateId': 'string',
                        'LaunchTemplateName': 'string',
                        'VersionNumber': 123,
                        'VersionDescription': 'string',
                        'CreateTime': datetime(2015, 1, 1),
                        'CreatedBy': 'string',
                        'DefaultVersion': True|False,
                        'LaunchTemplateData': {
                            'KernelId': 'string',
                            'EbsOptimized': True|False,
                            'IamInstanceProfile': {
                                'Arn': 'string',
                                'Name': 'string'
                            },
                            'BlockDeviceMappings': [
                                {
                                    'DeviceName': 'string',
                                    'VirtualName': 'string',
                                    'Ebs': {
                                        'Encrypted': True|False,
                                        'DeleteOnTermination': True|False,
                                        'Iops': 123,
                                        'KmsKeyId': 'string',
                                        'SnapshotId': 'string',
                                        'VolumeSize': 123,
                                        'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1'
                                    },
                                    'NoDevice': 'string'
                                },
                            ],
                            'NetworkInterfaces': [
                                {
                                    'AssociatePublicIpAddress': True|False,
                                    'DeleteOnTermination': True|False,
                                    'Description': 'string',
                                    'DeviceIndex': 123,
                                    'Groups': [
                                        'string',
                                    ],
                                    'InterfaceType': 'string',
                                    'Ipv6AddressCount': 123,
                                    'Ipv6Addresses': [
                                        {
                                            'Ipv6Address': 'string'
                                        },
                                    ],
                                    'NetworkInterfaceId': 'string',
                                    'PrivateIpAddress': 'string',
                                    'PrivateIpAddresses': [
                                        {
                                            'Primary': True|False,
                                            'PrivateIpAddress': 'string'
                                        },
                                    ],
                                    'SecondaryPrivateIpAddressCount': 123,
                                    'SubnetId': 'string'
                                },
                            ],
                            'ImageId': 'string',
                            'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                            'KeyName': 'string',
                            'Monitoring': {
                                'Enabled': True|False
                            },
                            'Placement': {
                                'AvailabilityZone': 'string',
                                'Affinity': 'string',
                                'GroupName': 'string',
                                'HostId': 'string',
                                'Tenancy': 'default'|'dedicated'|'host',
                                'SpreadDomain': 'string'
                            },
                            'RamDiskId': 'string',
                            'DisableApiTermination': True|False,
                            'InstanceInitiatedShutdownBehavior': 'stop'|'terminate',
                            'UserData': 'string',
                            'TagSpecifications': [
                                {
                                    'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                                    'Tags': [
                                        {
                                            'Key': 'string',
                                            'Value': 'string'
                                        },
                                    ]
                                },
                            ],
                            'ElasticGpuSpecifications': [
                                {
                                    'Type': 'string'
                                },
                            ],
                            'ElasticInferenceAccelerators': [
                                {
                                    'Type': 'string'
                                },
                            ],
                            'SecurityGroupIds': [
                                'string',
                            ],
                            'SecurityGroups': [
                                'string',
                            ],
                            'InstanceMarketOptions': {
                                'MarketType': 'spot',
                                'SpotOptions': {
                                    'MaxPrice': 'string',
                                    'SpotInstanceType': 'one-time'|'persistent',
                                    'BlockDurationMinutes': 123,
                                    'ValidUntil': datetime(2015, 1, 1),
                                    'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                                }
                            },
                            'CreditSpecification': {
                                'CpuCredits': 'string'
                            },
                            'CpuOptions': {
                                'CoreCount': 123,
                                'ThreadsPerCore': 123
                            },
                            'CapacityReservationSpecification': {
                                'CapacityReservationPreference': 'open'|'none',
                                'CapacityReservationTarget': {
                                    'CapacityReservationId': 'string'
                                }
                            },
                            'LicenseSpecifications': [
                                {
                                    'LicenseConfigurationArn': 'string'
                                },
                            ],
                            'HibernationOptions': {
                                'Configured': True|False
                            }
                        }
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **LaunchTemplateVersions** *(list) --* 
              Information about the launch template versions.
              - *(dict) --* 
                Describes a launch template version.
                - **LaunchTemplateId** *(string) --* 
                  The ID of the launch template.
                - **LaunchTemplateName** *(string) --* 
                  The name of the launch template.
                - **VersionNumber** *(integer) --* 
                  The version number.
                - **VersionDescription** *(string) --* 
                  The description for the version.
                - **CreateTime** *(datetime) --* 
                  The time the version was created.
                - **CreatedBy** *(string) --* 
                  The principal that created the version.
                - **DefaultVersion** *(boolean) --* 
                  Indicates whether the version is the default version.
                - **LaunchTemplateData** *(dict) --* 
                  Information about the launch template.
                  - **KernelId** *(string) --* 
                    The ID of the kernel, if applicable.
                  - **EbsOptimized** *(boolean) --* 
                    Indicates whether the instance is optimized for Amazon EBS I/O. 
                  - **IamInstanceProfile** *(dict) --* 
                    The IAM instance profile.
                    - **Arn** *(string) --* 
                      The Amazon Resource Name (ARN) of the instance profile.
                    - **Name** *(string) --* 
                      The name of the instance profile.
                  - **BlockDeviceMappings** *(list) --* 
                    The block device mappings.
                    - *(dict) --* 
                      Describes a block device mapping.
                      - **DeviceName** *(string) --* 
                        The device name.
                      - **VirtualName** *(string) --* 
                        The virtual device name (ephemeralN).
                      - **Ebs** *(dict) --* 
                        Information about the block device for an EBS volume.
                        - **Encrypted** *(boolean) --* 
                          Indicates whether the EBS volume is encrypted.
                        - **DeleteOnTermination** *(boolean) --* 
                          Indicates whether the EBS volume is deleted on instance termination.
                        - **Iops** *(integer) --* 
                          The number of I/O operations per second (IOPS) that the volume supports. 
                        - **KmsKeyId** *(string) --* 
                          The ARN of the AWS Key Management Service (AWS KMS) CMK used for encryption.
                        - **SnapshotId** *(string) --* 
                          The ID of the snapshot.
                        - **VolumeSize** *(integer) --* 
                          The size of the volume, in GiB.
                        - **VolumeType** *(string) --* 
                          The volume type.
                      - **NoDevice** *(string) --* 
                        Suppresses the specified device included in the block device mapping of the AMI.
                  - **NetworkInterfaces** *(list) --* 
                    The network interfaces.
                    - *(dict) --* 
                      Describes a network interface.
                      - **AssociatePublicIpAddress** *(boolean) --* 
                        Indicates whether to associate a public IPv4 address with eth0 for a new network interface.
                      - **DeleteOnTermination** *(boolean) --* 
                        Indicates whether the network interface is deleted when the instance is terminated.
                      - **Description** *(string) --* 
                        A description for the network interface.
                      - **DeviceIndex** *(integer) --* 
                        The device index for the network interface attachment.
                      - **Groups** *(list) --* 
                        The IDs of one or more security groups.
                        - *(string) --* 
                      - **InterfaceType** *(string) --* 
                        The type of network interface.
                      - **Ipv6AddressCount** *(integer) --* 
                        The number of IPv6 addresses for the network interface.
                      - **Ipv6Addresses** *(list) --* 
                        The IPv6 addresses for the network interface.
                        - *(dict) --* 
                          Describes an IPv6 address.
                          - **Ipv6Address** *(string) --* 
                            The IPv6 address.
                      - **NetworkInterfaceId** *(string) --* 
                        The ID of the network interface.
                      - **PrivateIpAddress** *(string) --* 
                        The primary private IPv4 address of the network interface.
                      - **PrivateIpAddresses** *(list) --* 
                        One or more private IPv4 addresses.
                        - *(dict) --* 
                          Describes a secondary private IPv4 address for a network interface.
                          - **Primary** *(boolean) --* 
                            Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                          - **PrivateIpAddress** *(string) --* 
                            The private IPv4 addresses.
                      - **SecondaryPrivateIpAddressCount** *(integer) --* 
                        The number of secondary private IPv4 addresses for the network interface.
                      - **SubnetId** *(string) --* 
                        The ID of the subnet for the network interface.
                  - **ImageId** *(string) --* 
                    The ID of the AMI that was used to launch the instance.
                  - **InstanceType** *(string) --* 
                    The instance type.
                  - **KeyName** *(string) --* 
                    The name of the key pair.
                  - **Monitoring** *(dict) --* 
                    The monitoring for the instance.
                    - **Enabled** *(boolean) --* 
                      Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
                  - **Placement** *(dict) --* 
                    The placement of the instance.
                    - **AvailabilityZone** *(string) --* 
                      The Availability Zone of the instance.
                    - **Affinity** *(string) --* 
                      The affinity setting for the instance on the Dedicated Host.
                    - **GroupName** *(string) --* 
                      The name of the placement group for the instance.
                    - **HostId** *(string) --* 
                      The ID of the Dedicated Host for the instance.
                    - **Tenancy** *(string) --* 
                      The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. 
                    - **SpreadDomain** *(string) --* 
                      Reserved for future use.
                  - **RamDiskId** *(string) --* 
                    The ID of the RAM disk, if applicable.
                  - **DisableApiTermination** *(boolean) --* 
                    If set to ``true`` , indicates that the instance cannot be terminated using the Amazon EC2 console, command line tool, or API.
                  - **InstanceInitiatedShutdownBehavior** *(string) --* 
                    Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
                  - **UserData** *(string) --* 
                    The user data for the instance. 
                  - **TagSpecifications** *(list) --* 
                    The tags.
                    - *(dict) --* 
                      The tag specification for the launch template.
                      - **ResourceType** *(string) --* 
                        The type of resource.
                      - **Tags** *(list) --* 
                        The tags for the resource.
                        - *(dict) --* 
                          Describes a tag.
                          - **Key** *(string) --* 
                            The key of the tag.
                            Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                          - **Value** *(string) --* 
                            The value of the tag.
                            Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                  - **ElasticGpuSpecifications** *(list) --* 
                    The elastic GPU specification.
                    - *(dict) --* 
                      Describes an elastic GPU.
                      - **Type** *(string) --* 
                        The elastic GPU type.
                  - **ElasticInferenceAccelerators** *(list) --* 
                    The elastic inference accelerator for the instance. 
                    - *(dict) --* 
                      Describes an elastic inference accelerator. 
                      - **Type** *(string) --* 
                        The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge. 
                  - **SecurityGroupIds** *(list) --* 
                    The security group IDs.
                    - *(string) --* 
                  - **SecurityGroups** *(list) --* 
                    The security group names.
                    - *(string) --* 
                  - **InstanceMarketOptions** *(dict) --* 
                    The market (purchasing) option for the instances.
                    - **MarketType** *(string) --* 
                      The market type.
                    - **SpotOptions** *(dict) --* 
                      The options for Spot Instances.
                      - **MaxPrice** *(string) --* 
                        The maximum hourly price you're willing to pay for the Spot Instances.
                      - **SpotInstanceType** *(string) --* 
                        The Spot Instance request type.
                      - **BlockDurationMinutes** *(integer) --* 
                        The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
                      - **ValidUntil** *(datetime) --* 
                        The end date of the request. For a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date and time is reached.
                      - **InstanceInterruptionBehavior** *(string) --* 
                        The behavior when a Spot Instance is interrupted.
                  - **CreditSpecification** *(dict) --* 
                    The credit option for CPU usage of the instance.
                    - **CpuCredits** *(string) --* 
                      The credit option for CPU usage of a T2 or T3 instance. Valid values are ``standard`` and ``unlimited`` .
                  - **CpuOptions** *(dict) --* 
                    The CPU options for the instance. For more information, see `Optimizing CPU Options <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                    - **CoreCount** *(integer) --* 
                      The number of CPU cores for the instance.
                    - **ThreadsPerCore** *(integer) --* 
                      The number of threads per CPU core.
                  - **CapacityReservationSpecification** *(dict) --* 
                    Information about the Capacity Reservation targeting option.
                    - **CapacityReservationPreference** *(string) --* 
                      Indicates the instance's Capacity Reservation preferences. Possible preferences include:
                      * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone). 
                      * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity. 
                    - **CapacityReservationTarget** *(dict) --* 
                      Information about the target Capacity Reservation.
                      - **CapacityReservationId** *(string) --* 
                        The ID of the Capacity Reservation.
                  - **LicenseSpecifications** *(list) --* 
                    The license configurations.
                    - *(dict) --* 
                      Describes a license configuration.
                      - **LicenseConfigurationArn** *(string) --* 
                        The Amazon Resource Name (ARN) of the license configuration.
                  - **HibernationOptions** *(dict) --* 
                    Indicates whether an instance is configured for hibernation. For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                    - **Configured** *(boolean) --* 
                      If this parameter is set to ``true`` , the instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type LaunchTemplateId: string
        :param LaunchTemplateId:
          The ID of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type LaunchTemplateName: string
        :param LaunchTemplateName:
          The name of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type Versions: list
        :param Versions:
          One or more versions of the launch template.
          - *(string) --*
        :type MinVersion: string
        :param MinVersion:
          The version number after which to describe launch template versions.
        :type MaxVersion: string
        :param MaxVersion:
          The version number up to which to describe launch template versions.
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value. This value can be between 1 and 200.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``create-time`` - The time the launch template version was created.
          * ``ebs-optimized`` - A boolean that indicates whether the instance is optimized for Amazon EBS I/O.
          * ``iam-instance-profile`` - The ARN of the IAM instance profile.
          * ``image-id`` - The ID of the AMI.
          * ``instance-type`` - The instance type.
          * ``is-default-version`` - A boolean that indicates whether the launch template version is the default version.
          * ``kernel-id`` - The kernel ID.
          * ``ram-disk-id`` - The RAM disk ID.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_launch_templates(self, DryRun: bool = None, LaunchTemplateIds: List = None, LaunchTemplateNames: List = None, Filters: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes one or more launch templates.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeLaunchTemplates>`_
        
        **Request Syntax**
        ::
          response = client.describe_launch_templates(
              DryRun=True|False,
              LaunchTemplateIds=[
                  'string',
              ],
              LaunchTemplateNames=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'LaunchTemplates': [
                    {
                        'LaunchTemplateId': 'string',
                        'LaunchTemplateName': 'string',
                        'CreateTime': datetime(2015, 1, 1),
                        'CreatedBy': 'string',
                        'DefaultVersionNumber': 123,
                        'LatestVersionNumber': 123,
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **LaunchTemplates** *(list) --* 
              Information about the launch templates.
              - *(dict) --* 
                Describes a launch template.
                - **LaunchTemplateId** *(string) --* 
                  The ID of the launch template.
                - **LaunchTemplateName** *(string) --* 
                  The name of the launch template.
                - **CreateTime** *(datetime) --* 
                  The time launch template was created.
                - **CreatedBy** *(string) --* 
                  The principal that created the launch template. 
                - **DefaultVersionNumber** *(integer) --* 
                  The version number of the default version of the launch template.
                - **LatestVersionNumber** *(integer) --* 
                  The version number of the latest version of the launch template.
                - **Tags** *(list) --* 
                  The tags for the launch template.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type LaunchTemplateIds: list
        :param LaunchTemplateIds:
          One or more launch template IDs.
          - *(string) --*
        :type LaunchTemplateNames: list
        :param LaunchTemplateNames:
          One or more launch template names.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``create-time`` - The time the launch template was created.
          * ``launch-template-name`` - The name of the launch template.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value. This value can be between 1 and 200.
        :rtype: dict
        :returns:
        """
        pass

    def describe_moving_addresses(self, Filters: List = None, DryRun: bool = None, MaxResults: int = None, NextToken: str = None, PublicIps: List = None) -> Dict:
        """
        Describes your Elastic IP addresses that are being moved to the EC2-VPC platform, or that are being restored to the EC2-Classic platform. This request does not return information about any other Elastic IP addresses in your account.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeMovingAddresses>`_
        
        **Request Syntax**
        ::
          response = client.describe_moving_addresses(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              MaxResults=123,
              NextToken='string',
              PublicIps=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'MovingAddressStatuses': [
                    {
                        'MoveStatus': 'movingToVpc'|'restoringToClassic',
                        'PublicIp': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **MovingAddressStatuses** *(list) --* 
              The status for each Elastic IP address.
              - *(dict) --* 
                Describes the status of a moving Elastic IP address.
                - **MoveStatus** *(string) --* 
                  The status of the Elastic IP address that's being moved to the EC2-VPC platform, or restored to the EC2-Classic platform.
                - **PublicIp** *(string) --* 
                  The Elastic IP address.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``moving-status`` - The status of the Elastic IP address (``MovingToVpc`` | ``RestoringToClassic`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ``NextToken`` value. This value can be between 5 and 1000; if ``MaxResults`` is given a value outside of this range, an error is returned.
          Default: If no value is provided, the default is 1000.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type PublicIps: list
        :param PublicIps:
          One or more Elastic IP addresses.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_nat_gateways(self, Filters: List = None, MaxResults: int = None, NatGatewayIds: List = None, NextToken: str = None) -> Dict:
        """
        Describes one or more of your NAT gateways.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeNatGateways>`_
        
        **Request Syntax**
        ::
          response = client.describe_nat_gateways(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NatGatewayIds=[
                  'string',
              ],
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'NatGateways': [
                    {
                        'CreateTime': datetime(2015, 1, 1),
                        'DeleteTime': datetime(2015, 1, 1),
                        'FailureCode': 'string',
                        'FailureMessage': 'string',
                        'NatGatewayAddresses': [
                            {
                                'AllocationId': 'string',
                                'NetworkInterfaceId': 'string',
                                'PrivateIp': 'string',
                                'PublicIp': 'string'
                            },
                        ],
                        'NatGatewayId': 'string',
                        'ProvisionedBandwidth': {
                            'ProvisionTime': datetime(2015, 1, 1),
                            'Provisioned': 'string',
                            'RequestTime': datetime(2015, 1, 1),
                            'Requested': 'string',
                            'Status': 'string'
                        },
                        'State': 'pending'|'failed'|'available'|'deleting'|'deleted',
                        'SubnetId': 'string',
                        'VpcId': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NatGateways** *(list) --* 
              Information about the NAT gateways.
              - *(dict) --* 
                Describes a NAT gateway.
                - **CreateTime** *(datetime) --* 
                  The date and time the NAT gateway was created.
                - **DeleteTime** *(datetime) --* 
                  The date and time the NAT gateway was deleted, if applicable.
                - **FailureCode** *(string) --* 
                  If the NAT gateway could not be created, specifies the error code for the failure. (``InsufficientFreeAddressesInSubnet`` | ``Gateway.NotAttached`` | ``InvalidAllocationID.NotFound`` | ``Resource.AlreadyAssociated`` | ``InternalError`` | ``InvalidSubnetID.NotFound`` )
                - **FailureMessage** *(string) --* 
                  If the NAT gateway could not be created, specifies the error message for the failure, that corresponds to the error code.
                  * For InsufficientFreeAddressesInSubnet: "Subnet has insufficient free addresses to create this NAT gateway" 
                  * For Gateway.NotAttached: "Network vpc-xxxxxxxx has no Internet gateway attached" 
                  * For InvalidAllocationID.NotFound: "Elastic IP address eipalloc-xxxxxxxx could not be associated with this NAT gateway" 
                  * For Resource.AlreadyAssociated: "Elastic IP address eipalloc-xxxxxxxx is already associated" 
                  * For InternalError: "Network interface eni-xxxxxxxx, created and used internally by this NAT gateway is in an invalid state. Please try again." 
                  * For InvalidSubnetID.NotFound: "The specified subnet subnet-xxxxxxxx does not exist or could not be found." 
                - **NatGatewayAddresses** *(list) --* 
                  Information about the IP addresses and network interface associated with the NAT gateway.
                  - *(dict) --* 
                    Describes the IP addresses and network interface associated with a NAT gateway.
                    - **AllocationId** *(string) --* 
                      The allocation ID of the Elastic IP address that's associated with the NAT gateway.
                    - **NetworkInterfaceId** *(string) --* 
                      The ID of the network interface associated with the NAT gateway.
                    - **PrivateIp** *(string) --* 
                      The private IP address associated with the Elastic IP address.
                    - **PublicIp** *(string) --* 
                      The Elastic IP address associated with the NAT gateway.
                - **NatGatewayId** *(string) --* 
                  The ID of the NAT gateway.
                - **ProvisionedBandwidth** *(dict) --* 
                  Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                  - **ProvisionTime** *(datetime) --* 
                    Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                  - **Provisioned** *(string) --* 
                    Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                  - **RequestTime** *(datetime) --* 
                    Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                  - **Requested** *(string) --* 
                    Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                  - **Status** *(string) --* 
                    Reserved. If you need to sustain traffic greater than the `documented limits <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-nat-gateway.html>`__ , contact us through the `Support Center <https://console.aws.amazon.com/support/home?>`__ .
                - **State** *(string) --* 
                  The state of the NAT gateway.
                  * ``pending`` : The NAT gateway is being created and is not ready to process traffic. 
                  * ``failed`` : The NAT gateway could not be created. Check the ``failureCode`` and ``failureMessage`` fields for the reason. 
                  * ``available`` : The NAT gateway is able to process traffic. This status remains until you delete the NAT gateway, and does not indicate the health of the NAT gateway. 
                  * ``deleting`` : The NAT gateway is in the process of being terminated and may still be processing traffic. 
                  * ``deleted`` : The NAT gateway has been terminated and is no longer processing traffic. 
                - **SubnetId** *(string) --* 
                  The ID of the subnet in which the NAT gateway is located.
                - **VpcId** *(string) --* 
                  The ID of the VPC in which the NAT gateway is located.
                - **Tags** *(list) --* 
                  The tags for the NAT gateway.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``nat-gateway-id`` - The ID of the NAT gateway.
          * ``state`` - The state of the NAT gateway (``pending`` | ``failed`` | ``available`` | ``deleting`` | ``deleted`` ).
          * ``subnet-id`` - The ID of the subnet in which the NAT gateway resides.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-id`` - The ID of the VPC in which the NAT gateway resides.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NatGatewayIds: list
        :param NatGatewayIds:
          One or more NAT gateway IDs.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_network_acls(self, Filters: List = None, DryRun: bool = None, NetworkAclIds: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes one or more of your network ACLs.
        For more information, see `Network ACLs <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_ACLs.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeNetworkAcls>`_
        
        **Request Syntax**
        ::
          response = client.describe_network_acls(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              NetworkAclIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'NetworkAcls': [
                    {
                        'Associations': [
                            {
                                'NetworkAclAssociationId': 'string',
                                'NetworkAclId': 'string',
                                'SubnetId': 'string'
                            },
                        ],
                        'Entries': [
                            {
                                'CidrBlock': 'string',
                                'Egress': True|False,
                                'IcmpTypeCode': {
                                    'Code': 123,
                                    'Type': 123
                                },
                                'Ipv6CidrBlock': 'string',
                                'PortRange': {
                                    'From': 123,
                                    'To': 123
                                },
                                'Protocol': 'string',
                                'RuleAction': 'allow'|'deny',
                                'RuleNumber': 123
                            },
                        ],
                        'IsDefault': True|False,
                        'NetworkAclId': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VpcId': 'string',
                        'OwnerId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NetworkAcls** *(list) --* 
              Information about one or more network ACLs.
              - *(dict) --* 
                Describes a network ACL.
                - **Associations** *(list) --* 
                  Any associations between the network ACL and one or more subnets
                  - *(dict) --* 
                    Describes an association between a network ACL and a subnet.
                    - **NetworkAclAssociationId** *(string) --* 
                      The ID of the association between a network ACL and a subnet.
                    - **NetworkAclId** *(string) --* 
                      The ID of the network ACL.
                    - **SubnetId** *(string) --* 
                      The ID of the subnet.
                - **Entries** *(list) --* 
                  One or more entries (rules) in the network ACL.
                  - *(dict) --* 
                    Describes an entry in a network ACL.
                    - **CidrBlock** *(string) --* 
                      The IPv4 network range to allow or deny, in CIDR notation.
                    - **Egress** *(boolean) --* 
                      Indicates whether the rule is an egress rule (applied to traffic leaving the subnet).
                    - **IcmpTypeCode** *(dict) --* 
                      ICMP protocol: The ICMP type and code.
                      - **Code** *(integer) --* 
                        The ICMP code. A value of -1 means all codes for the specified ICMP type.
                      - **Type** *(integer) --* 
                        The ICMP type. A value of -1 means all types.
                    - **Ipv6CidrBlock** *(string) --* 
                      The IPv6 network range to allow or deny, in CIDR notation.
                    - **PortRange** *(dict) --* 
                      TCP or UDP protocols: The range of ports the rule applies to.
                      - **From** *(integer) --* 
                        The first port in the range.
                      - **To** *(integer) --* 
                        The last port in the range.
                    - **Protocol** *(string) --* 
                      The protocol number. A value of "-1" means all protocols.
                    - **RuleAction** *(string) --* 
                      Indicates whether to allow or deny the traffic that matches the rule.
                    - **RuleNumber** *(integer) --* 
                      The rule number for the entry. ACL entries are processed in ascending order by rule number.
                - **IsDefault** *(boolean) --* 
                  Indicates whether this is the default network ACL for the VPC.
                - **NetworkAclId** *(string) --* 
                  The ID of the network ACL.
                - **Tags** *(list) --* 
                  Any tags assigned to the network ACL.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VpcId** *(string) --* 
                  The ID of the VPC for the network ACL.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account that owns the network ACL.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``association.association-id`` - The ID of an association ID for the ACL.
          * ``association.network-acl-id`` - The ID of the network ACL involved in the association.
          * ``association.subnet-id`` - The ID of the subnet involved in the association.
          * ``default`` - Indicates whether the ACL is the default network ACL for the VPC.
          * ``entry.cidr`` - The IPv4 CIDR range specified in the entry.
          * ``entry.icmp.code`` - The ICMP code specified in the entry, if any.
          * ``entry.icmp.type`` - The ICMP type specified in the entry, if any.
          * ``entry.ipv6-cidr`` - The IPv6 CIDR range specified in the entry.
          * ``entry.port-range.from`` - The start of the port range specified in the entry.
          * ``entry.port-range.to`` - The end of the port range specified in the entry.
          * ``entry.protocol`` - The protocol specified in the entry (``tcp`` | ``udp`` | ``icmp`` or a protocol number).
          * ``entry.rule-action`` - Allows or denies the matching traffic (``allow`` | ``deny`` ).
          * ``entry.rule-number`` - The number of an entry (in other words, rule) in the set of ACL entries.
          * ``network-acl-id`` - The ID of the network ACL.
          * ``owner-id`` - The ID of the AWS account that owns the network ACL.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-id`` - The ID of the VPC for the network ACL.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkAclIds: list
        :param NetworkAclIds:
          One or more network ACL IDs.
          Default: Describes all your network ACLs.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_network_interface_attribute(self, NetworkInterfaceId: str, Attribute: str = None, DryRun: bool = None) -> Dict:
        """
        Describes a network interface attribute. You can specify only one attribute at a time.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeNetworkInterfaceAttribute>`_
        
        **Request Syntax**
        ::
          response = client.describe_network_interface_attribute(
              Attribute='description'|'groupSet'|'sourceDestCheck'|'attachment',
              DryRun=True|False,
              NetworkInterfaceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Attachment': {
                    'AttachTime': datetime(2015, 1, 1),
                    'AttachmentId': 'string',
                    'DeleteOnTermination': True|False,
                    'DeviceIndex': 123,
                    'InstanceId': 'string',
                    'InstanceOwnerId': 'string',
                    'Status': 'attaching'|'attached'|'detaching'|'detached'
                },
                'Description': {
                    'Value': 'string'
                },
                'Groups': [
                    {
                        'GroupName': 'string',
                        'GroupId': 'string'
                    },
                ],
                'NetworkInterfaceId': 'string',
                'SourceDestCheck': {
                    'Value': True|False
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeNetworkInterfaceAttribute.
            - **Attachment** *(dict) --* 
              The attachment (if any) of the network interface.
              - **AttachTime** *(datetime) --* 
                The timestamp indicating when the attachment initiated.
              - **AttachmentId** *(string) --* 
                The ID of the network interface attachment.
              - **DeleteOnTermination** *(boolean) --* 
                Indicates whether the network interface is deleted when the instance is terminated.
              - **DeviceIndex** *(integer) --* 
                The device index of the network interface attachment on the instance.
              - **InstanceId** *(string) --* 
                The ID of the instance.
              - **InstanceOwnerId** *(string) --* 
                The AWS account ID of the owner of the instance.
              - **Status** *(string) --* 
                The attachment state.
            - **Description** *(dict) --* 
              The description of the network interface.
              - **Value** *(string) --* 
                The attribute value. The value is case-sensitive.
            - **Groups** *(list) --* 
              The security groups associated with the network interface.
              - *(dict) --* 
                Describes a security group.
                - **GroupName** *(string) --* 
                  The name of the security group.
                - **GroupId** *(string) --* 
                  The ID of the security group.
            - **NetworkInterfaceId** *(string) --* 
              The ID of the network interface.
            - **SourceDestCheck** *(dict) --* 
              Indicates whether source/destination checking is enabled.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
        :type Attribute: string
        :param Attribute:
          The attribute of the network interface. This parameter is required.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :rtype: dict
        :returns:
        """
        pass

    def describe_network_interface_permissions(self, NetworkInterfacePermissionIds: List = None, Filters: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes the permissions for your network interfaces. 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeNetworkInterfacePermissions>`_
        
        **Request Syntax**
        ::
          response = client.describe_network_interface_permissions(
              NetworkInterfacePermissionIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'NetworkInterfacePermissions': [
                    {
                        'NetworkInterfacePermissionId': 'string',
                        'NetworkInterfaceId': 'string',
                        'AwsAccountId': 'string',
                        'AwsService': 'string',
                        'Permission': 'INSTANCE-ATTACH'|'EIP-ASSOCIATE',
                        'PermissionState': {
                            'State': 'pending'|'granted'|'revoking'|'revoked',
                            'StatusMessage': 'string'
                        }
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for DescribeNetworkInterfacePermissions.
            - **NetworkInterfacePermissions** *(list) --* 
              The network interface permissions.
              - *(dict) --* 
                Describes a permission for a network interface.
                - **NetworkInterfacePermissionId** *(string) --* 
                  The ID of the network interface permission.
                - **NetworkInterfaceId** *(string) --* 
                  The ID of the network interface.
                - **AwsAccountId** *(string) --* 
                  The AWS account ID.
                - **AwsService** *(string) --* 
                  The AWS service.
                - **Permission** *(string) --* 
                  The type of permission.
                - **PermissionState** *(dict) --* 
                  Information about the state of the permission.
                  - **State** *(string) --* 
                    The state of the permission.
                  - **StatusMessage** *(string) --* 
                    A status message, if applicable.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results.
        :type NetworkInterfacePermissionIds: list
        :param NetworkInterfacePermissionIds:
          One or more network interface permission IDs.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``network-interface-permission.network-interface-permission-id`` - The ID of the permission.
          * ``network-interface-permission.network-interface-id`` - The ID of the network interface.
          * ``network-interface-permission.aws-account-id`` - The AWS account ID.
          * ``network-interface-permission.aws-service`` - The AWS service.
          * ``network-interface-permission.permission`` - The type of permission (``INSTANCE-ATTACH`` | ``EIP-ASSOCIATE`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ``NextToken`` value. If this parameter is not specified, up to 50 results are returned by default.
        :rtype: dict
        :returns:
        """
        pass

    def describe_network_interfaces(self, Filters: List = None, DryRun: bool = None, NetworkInterfaceIds: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes one or more of your network interfaces.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeNetworkInterfaces>`_
        
        **Request Syntax**
        ::
          response = client.describe_network_interfaces(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              NetworkInterfaceIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'NetworkInterfaces': [
                    {
                        'Association': {
                            'AllocationId': 'string',
                            'AssociationId': 'string',
                            'IpOwnerId': 'string',
                            'PublicDnsName': 'string',
                            'PublicIp': 'string'
                        },
                        'Attachment': {
                            'AttachTime': datetime(2015, 1, 1),
                            'AttachmentId': 'string',
                            'DeleteOnTermination': True|False,
                            'DeviceIndex': 123,
                            'InstanceId': 'string',
                            'InstanceOwnerId': 'string',
                            'Status': 'attaching'|'attached'|'detaching'|'detached'
                        },
                        'AvailabilityZone': 'string',
                        'Description': 'string',
                        'Groups': [
                            {
                                'GroupName': 'string',
                                'GroupId': 'string'
                            },
                        ],
                        'InterfaceType': 'interface'|'natGateway'|'efa',
                        'Ipv6Addresses': [
                            {
                                'Ipv6Address': 'string'
                            },
                        ],
                        'MacAddress': 'string',
                        'NetworkInterfaceId': 'string',
                        'OwnerId': 'string',
                        'PrivateDnsName': 'string',
                        'PrivateIpAddress': 'string',
                        'PrivateIpAddresses': [
                            {
                                'Association': {
                                    'AllocationId': 'string',
                                    'AssociationId': 'string',
                                    'IpOwnerId': 'string',
                                    'PublicDnsName': 'string',
                                    'PublicIp': 'string'
                                },
                                'Primary': True|False,
                                'PrivateDnsName': 'string',
                                'PrivateIpAddress': 'string'
                            },
                        ],
                        'RequesterId': 'string',
                        'RequesterManaged': True|False,
                        'SourceDestCheck': True|False,
                        'Status': 'available'|'associated'|'attaching'|'in-use'|'detaching',
                        'SubnetId': 'string',
                        'TagSet': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VpcId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeNetworkInterfaces.
            - **NetworkInterfaces** *(list) --* 
              Information about one or more network interfaces.
              - *(dict) --* 
                Describes a network interface.
                - **Association** *(dict) --* 
                  The association information for an Elastic IP address (IPv4) associated with the network interface.
                  - **AllocationId** *(string) --* 
                    The allocation ID.
                  - **AssociationId** *(string) --* 
                    The association ID.
                  - **IpOwnerId** *(string) --* 
                    The ID of the Elastic IP address owner.
                  - **PublicDnsName** *(string) --* 
                    The public DNS name.
                  - **PublicIp** *(string) --* 
                    The address of the Elastic IP address bound to the network interface.
                - **Attachment** *(dict) --* 
                  The network interface attachment.
                  - **AttachTime** *(datetime) --* 
                    The timestamp indicating when the attachment initiated.
                  - **AttachmentId** *(string) --* 
                    The ID of the network interface attachment.
                  - **DeleteOnTermination** *(boolean) --* 
                    Indicates whether the network interface is deleted when the instance is terminated.
                  - **DeviceIndex** *(integer) --* 
                    The device index of the network interface attachment on the instance.
                  - **InstanceId** *(string) --* 
                    The ID of the instance.
                  - **InstanceOwnerId** *(string) --* 
                    The AWS account ID of the owner of the instance.
                  - **Status** *(string) --* 
                    The attachment state.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone.
                - **Description** *(string) --* 
                  A description.
                - **Groups** *(list) --* 
                  Any security groups for the network interface.
                  - *(dict) --* 
                    Describes a security group.
                    - **GroupName** *(string) --* 
                      The name of the security group.
                    - **GroupId** *(string) --* 
                      The ID of the security group.
                - **InterfaceType** *(string) --* 
                  The type of network interface.
                - **Ipv6Addresses** *(list) --* 
                  The IPv6 addresses associated with the network interface.
                  - *(dict) --* 
                    Describes an IPv6 address associated with a network interface.
                    - **Ipv6Address** *(string) --* 
                      The IPv6 address.
                - **MacAddress** *(string) --* 
                  The MAC address.
                - **NetworkInterfaceId** *(string) --* 
                  The ID of the network interface.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the owner of the network interface.
                - **PrivateDnsName** *(string) --* 
                  The private DNS name.
                - **PrivateIpAddress** *(string) --* 
                  The IPv4 address of the network interface within the subnet.
                - **PrivateIpAddresses** *(list) --* 
                  The private IPv4 addresses associated with the network interface.
                  - *(dict) --* 
                    Describes the private IPv4 address of a network interface.
                    - **Association** *(dict) --* 
                      The association information for an Elastic IP address (IPv4) associated with the network interface.
                      - **AllocationId** *(string) --* 
                        The allocation ID.
                      - **AssociationId** *(string) --* 
                        The association ID.
                      - **IpOwnerId** *(string) --* 
                        The ID of the Elastic IP address owner.
                      - **PublicDnsName** *(string) --* 
                        The public DNS name.
                      - **PublicIp** *(string) --* 
                        The address of the Elastic IP address bound to the network interface.
                    - **Primary** *(boolean) --* 
                      Indicates whether this IPv4 address is the primary private IPv4 address of the network interface.
                    - **PrivateDnsName** *(string) --* 
                      The private DNS name.
                    - **PrivateIpAddress** *(string) --* 
                      The private IPv4 address.
                - **RequesterId** *(string) --* 
                  The ID of the entity that launched the instance on your behalf (for example, AWS Management Console or Auto Scaling).
                - **RequesterManaged** *(boolean) --* 
                  Indicates whether the network interface is being managed by AWS.
                - **SourceDestCheck** *(boolean) --* 
                  Indicates whether traffic to or from the instance is validated.
                - **Status** *(string) --* 
                  The status of the network interface.
                - **SubnetId** *(string) --* 
                  The ID of the subnet.
                - **TagSet** *(list) --* 
                  Any tags assigned to the network interface.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``addresses.private-ip-address`` - The private IPv4 addresses associated with the network interface.
          * ``addresses.primary`` - Whether the private IPv4 address is the primary IP address associated with the network interface.
          * ``addresses.association.public-ip`` - The association ID returned when the network interface was associated with the Elastic IP address (IPv4).
          * ``addresses.association.owner-id`` - The owner ID of the addresses associated with the network interface.
          * ``association.association-id`` - The association ID returned when the network interface was associated with an IPv4 address.
          * ``association.allocation-id`` - The allocation ID returned when you allocated the Elastic IP address (IPv4) for your network interface.
          * ``association.ip-owner-id`` - The owner of the Elastic IP address (IPv4) associated with the network interface.
          * ``association.public-ip`` - The address of the Elastic IP address (IPv4) bound to the network interface.
          * ``association.public-dns-name`` - The public DNS name for the network interface (IPv4).
          * ``attachment.attachment-id`` - The ID of the interface attachment.
          * ``attachment.attach.time`` - The time that the network interface was attached to an instance.
          * ``attachment.delete-on-termination`` - Indicates whether the attachment is deleted when an instance is terminated.
          * ``attachment.device-index`` - The device index to which the network interface is attached.
          * ``attachment.instance-id`` - The ID of the instance to which the network interface is attached.
          * ``attachment.instance-owner-id`` - The owner ID of the instance to which the network interface is attached.
          * ``attachment.nat-gateway-id`` - The ID of the NAT gateway to which the network interface is attached.
          * ``attachment.status`` - The status of the attachment (``attaching`` | ``attached`` | ``detaching`` | ``detached`` ).
          * ``availability-zone`` - The Availability Zone of the network interface.
          * ``description`` - The description of the network interface.
          * ``group-id`` - The ID of a security group associated with the network interface.
          * ``group-name`` - The name of a security group associated with the network interface.
          * ``ipv6-addresses.ipv6-address`` - An IPv6 address associated with the network interface.
          * ``mac-address`` - The MAC address of the network interface.
          * ``network-interface-id`` - The ID of the network interface.
          * ``owner-id`` - The AWS account ID of the network interface owner.
          * ``private-ip-address`` - The private IPv4 address or addresses of the network interface.
          * ``private-dns-name`` - The private DNS name of the network interface (IPv4).
          * ``requester-id`` - The ID of the entity that launched the instance on your behalf (for example, AWS Management Console, Auto Scaling, and so on).
          * ``requester-managed`` - Indicates whether the network interface is being managed by an AWS service (for example, AWS Management Console, Auto Scaling, and so on).
          * ``source-dest-check`` - Indicates whether the network interface performs source/destination checking. A value of ``true`` means checking is enabled, and ``false`` means checking is disabled. The value must be ``false`` for the network interface to perform network address translation (NAT) in your VPC.
          * ``status`` - The status of the network interface. If the network interface is not attached to an instance, the status is ``available`` ; if a network interface is attached to an instance the status is ``in-use`` .
          * ``subnet-id`` - The ID of the subnet for the network interface.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-id`` - The ID of the VPC for the network interface.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkInterfaceIds: list
        :param NetworkInterfaceIds:
          One or more network interface IDs.
          Default: Describes all your network interfaces.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_placement_groups(self, Filters: List = None, DryRun: bool = None, GroupNames: List = None) -> Dict:
        """
        Describes the specified placement groups or all of your placement groups. For more information, see `Placement Groups <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribePlacementGroups>`_
        
        **Request Syntax**
        ::
          response = client.describe_placement_groups(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              GroupNames=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'PlacementGroups': [
                    {
                        'GroupName': 'string',
                        'State': 'pending'|'available'|'deleting'|'deleted',
                        'Strategy': 'cluster'|'spread'|'partition',
                        'PartitionCount': 123
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **PlacementGroups** *(list) --* 
              Information about the placement groups.
              - *(dict) --* 
                Describes a placement group.
                - **GroupName** *(string) --* 
                  The name of the placement group.
                - **State** *(string) --* 
                  The state of the placement group.
                - **Strategy** *(string) --* 
                  The placement strategy.
                - **PartitionCount** *(integer) --* 
                  The number of partitions. Valid only if **strategy** is set to ``partition`` .
        :type Filters: list
        :param Filters:
          The filters.
          * ``group-name`` - The name of the placement group.
          * ``state`` - The state of the placement group (``pending`` | ``available`` | ``deleting`` | ``deleted`` ).
          * ``strategy`` - The strategy of the placement group (``cluster`` | ``spread`` | ``partition`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupNames: list
        :param GroupNames:
          The names of the placement groups.
          Default: Describes all your placement groups, or only those otherwise specified.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_prefix_lists(self, DryRun: bool = None, Filters: List = None, MaxResults: int = None, NextToken: str = None, PrefixListIds: List = None) -> Dict:
        """
        Describes available AWS services in a prefix list format, which includes the prefix list name and prefix list ID of the service and the IP address range for the service. A prefix list ID is required for creating an outbound security group rule that allows traffic from a VPC to access an AWS service through a gateway VPC endpoint. Currently, the services that support this action are Amazon S3 and Amazon DynamoDB.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribePrefixLists>`_
        
        **Request Syntax**
        ::
          response = client.describe_prefix_lists(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              PrefixListIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'PrefixLists': [
                    {
                        'Cidrs': [
                            'string',
                        ],
                        'PrefixListId': 'string',
                        'PrefixListName': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
            - **PrefixLists** *(list) --* 
              All available prefix lists.
              - *(dict) --* 
                Describes prefixes for AWS services.
                - **Cidrs** *(list) --* 
                  The IP address range of the AWS service.
                  - *(string) --* 
                - **PrefixListId** *(string) --* 
                  The ID of the prefix.
                - **PrefixListName** *(string) --* 
                  The name of the prefix.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``prefix-list-id`` : The ID of a prefix list.
          * ``prefix-list-name`` : The name of a prefix list.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type PrefixListIds: list
        :param PrefixListIds:
          One or more prefix list IDs.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_principal_id_format(self, DryRun: bool = None, Resources: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the ID format settings for the root user and all IAM roles and IAM users that have explicitly specified a longer ID (17-character ID) preference. 
        By default, all IAM roles and IAM users default to the same ID settings as the root user, unless they explicitly override the settings. This request is useful for identifying those IAM users and IAM roles that have overridden the default ID settings.
        The following resource types support longer IDs: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``instance`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``reservation`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``snapshot`` | ``subnet`` | ``subnet-cidr-block-association`` | ``volume`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` . 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribePrincipalIdFormat>`_
        
        **Request Syntax**
        ::
          response = client.describe_principal_id_format(
              DryRun=True|False,
              Resources=[
                  'string',
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'Principals': [
                    {
                        'Arn': 'string',
                        'Statuses': [
                            {
                                'Deadline': datetime(2015, 1, 1),
                                'Resource': 'string',
                                'UseLongIds': True|False
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Principals** *(list) --* 
              Information about the ID format settings for the ARN.
              - *(dict) --* 
                PrincipalIdFormat description
                - **Arn** *(string) --* 
                  PrincipalIdFormatARN description
                - **Statuses** *(list) --* 
                  PrincipalIdFormatStatuses description
                  - *(dict) --* 
                    Describes the ID format for a resource.
                    - **Deadline** *(datetime) --* 
                      The date in UTC at which you are permanently switched over to using longer IDs. If a deadline is not yet available for this resource type, this field is not returned.
                    - **Resource** *(string) --* 
                      The type of resource.
                    - **UseLongIds** *(boolean) --* 
                      Indicates whether longer IDs (17-character IDs) are enabled for the resource.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is null when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Resources: list
        :param Resources:
          The type of resource: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``instance`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``reservation`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``snapshot`` | ``subnet`` | ``subnet-cidr-block-association`` | ``volume`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway``
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value.
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_public_ipv4_pools(self, PoolIds: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes the specified IPv4 address pools.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribePublicIpv4Pools>`_
        
        **Request Syntax**
        ::
          response = client.describe_public_ipv4_pools(
              PoolIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'PublicIpv4Pools': [
                    {
                        'PoolId': 'string',
                        'Description': 'string',
                        'PoolAddressRanges': [
                            {
                                'FirstAddress': 'string',
                                'LastAddress': 'string',
                                'AddressCount': 123,
                                'AvailableAddressCount': 123
                            },
                        ],
                        'TotalAddressCount': 123,
                        'TotalAvailableAddressCount': 123
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **PublicIpv4Pools** *(list) --* 
              Information about the address pools.
              - *(dict) --* 
                Describes an address pool.
                - **PoolId** *(string) --* 
                  The ID of the IPv4 address pool.
                - **Description** *(string) --* 
                  A description of the address pool.
                - **PoolAddressRanges** *(list) --* 
                  The address ranges.
                  - *(dict) --* 
                    Describes an address range of an IPv4 address pool.
                    - **FirstAddress** *(string) --* 
                      The first IP address in the range.
                    - **LastAddress** *(string) --* 
                      The last IP address in the range.
                    - **AddressCount** *(integer) --* 
                      The number of addresses in the range.
                    - **AvailableAddressCount** *(integer) --* 
                      The number of available addresses in the range.
                - **TotalAddressCount** *(integer) --* 
                  The total number of addresses.
                - **TotalAvailableAddressCount** *(integer) --* 
                  The total number of available addresses.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type PoolIds: list
        :param PoolIds:
          The IDs of the address pools.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_regions(self, Filters: List = None, RegionNames: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the regions that are currently available to you.
        For a list of the regions supported by Amazon EC2, see `Regions and Endpoints <https://docs.aws.amazon.com/general/latest/gr/rande.html#ec2_region>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeRegions>`_
        
        **Request Syntax**
        ::
          response = client.describe_regions(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              RegionNames=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Regions': [
                    {
                        'Endpoint': 'string',
                        'RegionName': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Regions** *(list) --* 
              Information about the regions.
              - *(dict) --* 
                Describes a region.
                - **Endpoint** *(string) --* 
                  The region service endpoint.
                - **RegionName** *(string) --* 
                  The name of the region.
        :type Filters: list
        :param Filters:
          The filters.
          * ``endpoint`` - The endpoint of the region (for example, ``ec2.us-east-1.amazonaws.com`` ).
          * ``region-name`` - The name of the region (for example, ``us-east-1`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type RegionNames: list
        :param RegionNames:
          The names of the regions.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_reserved_instances(self, Filters: List = None, OfferingClass: str = None, ReservedInstancesIds: List = None, DryRun: bool = None, OfferingType: str = None) -> Dict:
        """
        Describes one or more of the Reserved Instances that you purchased.
        For more information about Reserved Instances, see `Reserved Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/concepts-on-demand-reserved-instances.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeReservedInstances>`_
        
        **Request Syntax**
        ::
          response = client.describe_reserved_instances(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              OfferingClass='standard'|'convertible',
              ReservedInstancesIds=[
                  'string',
              ],
              DryRun=True|False,
              OfferingType='Heavy Utilization'|'Medium Utilization'|'Light Utilization'|'No Upfront'|'Partial Upfront'|'All Upfront'
          )
        
        **Response Syntax**
        ::
            {
                'ReservedInstances': [
                    {
                        'AvailabilityZone': 'string',
                        'Duration': 123,
                        'End': datetime(2015, 1, 1),
                        'FixedPrice': ...,
                        'InstanceCount': 123,
                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                        'ProductDescription': 'Linux/UNIX'|'Linux/UNIX (Amazon VPC)'|'Windows'|'Windows (Amazon VPC)',
                        'ReservedInstancesId': 'string',
                        'Start': datetime(2015, 1, 1),
                        'State': 'payment-pending'|'active'|'payment-failed'|'retired',
                        'UsagePrice': ...,
                        'CurrencyCode': 'USD',
                        'InstanceTenancy': 'default'|'dedicated'|'host',
                        'OfferingClass': 'standard'|'convertible',
                        'OfferingType': 'Heavy Utilization'|'Medium Utilization'|'Light Utilization'|'No Upfront'|'Partial Upfront'|'All Upfront',
                        'RecurringCharges': [
                            {
                                'Amount': 123.0,
                                'Frequency': 'Hourly'
                            },
                        ],
                        'Scope': 'Availability Zone'|'Region',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for DescribeReservedInstances.
            - **ReservedInstances** *(list) --* 
              A list of Reserved Instances.
              - *(dict) --* 
                Describes a Reserved Instance.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone in which the Reserved Instance can be used.
                - **Duration** *(integer) --* 
                  The duration of the Reserved Instance, in seconds.
                - **End** *(datetime) --* 
                  The time when the Reserved Instance expires.
                - **FixedPrice** *(float) --* 
                  The purchase price of the Reserved Instance.
                - **InstanceCount** *(integer) --* 
                  The number of reservations purchased.
                - **InstanceType** *(string) --* 
                  The instance type on which the Reserved Instance can be used.
                - **ProductDescription** *(string) --* 
                  The Reserved Instance product platform description.
                - **ReservedInstancesId** *(string) --* 
                  The ID of the Reserved Instance.
                - **Start** *(datetime) --* 
                  The date and time the Reserved Instance started.
                - **State** *(string) --* 
                  The state of the Reserved Instance purchase.
                - **UsagePrice** *(float) --* 
                  The usage price of the Reserved Instance, per hour.
                - **CurrencyCode** *(string) --* 
                  The currency of the Reserved Instance. It's specified using ISO 4217 standard currency codes. At this time, the only supported currency is ``USD`` .
                - **InstanceTenancy** *(string) --* 
                  The tenancy of the instance.
                - **OfferingClass** *(string) --* 
                  The offering class of the Reserved Instance.
                - **OfferingType** *(string) --* 
                  The Reserved Instance offering type.
                - **RecurringCharges** *(list) --* 
                  The recurring charge tag assigned to the resource.
                  - *(dict) --* 
                    Describes a recurring charge.
                    - **Amount** *(float) --* 
                      The amount of the recurring charge.
                    - **Frequency** *(string) --* 
                      The frequency of the recurring charge.
                - **Scope** *(string) --* 
                  The scope of the Reserved Instance.
                - **Tags** *(list) --* 
                  Any tags assigned to the resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``availability-zone`` - The Availability Zone where the Reserved Instance can be used.
          * ``duration`` - The duration of the Reserved Instance (one year or three years), in seconds (``31536000`` | ``94608000`` ).
          * ``end`` - The time when the Reserved Instance expires (for example, 2015-08-07T11:54:42.000Z).
          * ``fixed-price`` - The purchase price of the Reserved Instance (for example, 9800.0).
          * ``instance-type`` - The instance type that is covered by the reservation.
          * ``scope`` - The scope of the Reserved Instance (``Region`` or ``Availability Zone`` ).
          * ``product-description`` - The Reserved Instance product platform description. Instances that include ``(Amazon VPC)`` in the product platform description will only be displayed to EC2-Classic account holders and are for use with Amazon VPC (``Linux/UNIX`` | ``Linux/UNIX (Amazon VPC)`` | ``SUSE Linux`` | ``SUSE Linux (Amazon VPC)`` | ``Red Hat Enterprise Linux`` | ``Red Hat Enterprise Linux (Amazon VPC)`` | ``Windows`` | ``Windows (Amazon VPC)`` | ``Windows with SQL Server Standard`` | ``Windows with SQL Server Standard (Amazon VPC)`` | ``Windows with SQL Server Web`` | ``Windows with SQL Server Web (Amazon VPC)`` | ``Windows with SQL Server Enterprise`` | ``Windows with SQL Server Enterprise (Amazon VPC)`` ).
          * ``reserved-instances-id`` - The ID of the Reserved Instance.
          * ``start`` - The time at which the Reserved Instance purchase request was placed (for example, 2014-08-07T11:54:42.000Z).
          * ``state`` - The state of the Reserved Instance (``payment-pending`` | ``active`` | ``payment-failed`` | ``retired`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``usage-price`` - The usage price of the Reserved Instance, per hour (for example, 0.84).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type OfferingClass: string
        :param OfferingClass:
          Describes whether the Reserved Instance is Standard or Convertible.
        :type ReservedInstancesIds: list
        :param ReservedInstancesIds:
          One or more Reserved Instance IDs.
          Default: Describes all your Reserved Instances, or only those otherwise specified.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type OfferingType: string
        :param OfferingType:
          The Reserved Instance offering type. If you are using tools that predate the 2011-11-01 API version, you only have access to the ``Medium Utilization`` Reserved Instance offering type.
        :rtype: dict
        :returns:
        """
        pass

    def describe_reserved_instances_listings(self, Filters: List = None, ReservedInstancesId: str = None, ReservedInstancesListingId: str = None) -> Dict:
        """
        Describes your account's Reserved Instance listings in the Reserved Instance Marketplace.
        The Reserved Instance Marketplace matches sellers who want to resell Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances.
        As a seller, you choose to list some or all of your Reserved Instances, and you specify the upfront price to receive for them. Your Reserved Instances are then listed in the Reserved Instance Marketplace and are available for purchase.
        As a buyer, you specify the configuration of the Reserved Instance to purchase, and the Marketplace matches what you're searching for with what's available. The Marketplace first sells the lowest priced Reserved Instances to you, and continues to sell available Reserved Instance listings to you until your demand is met. You are charged based on the total price of all of the listings that you purchase.
        For more information, see `Reserved Instance Marketplace <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeReservedInstancesListings>`_
        
        **Request Syntax**
        ::
          response = client.describe_reserved_instances_listings(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              ReservedInstancesId='string',
              ReservedInstancesListingId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ReservedInstancesListings': [
                    {
                        'ClientToken': 'string',
                        'CreateDate': datetime(2015, 1, 1),
                        'InstanceCounts': [
                            {
                                'InstanceCount': 123,
                                'State': 'available'|'sold'|'cancelled'|'pending'
                            },
                        ],
                        'PriceSchedules': [
                            {
                                'Active': True|False,
                                'CurrencyCode': 'USD',
                                'Price': 123.0,
                                'Term': 123
                            },
                        ],
                        'ReservedInstancesId': 'string',
                        'ReservedInstancesListingId': 'string',
                        'Status': 'active'|'pending'|'cancelled'|'closed',
                        'StatusMessage': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'UpdateDate': datetime(2015, 1, 1)
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeReservedInstancesListings.
            - **ReservedInstancesListings** *(list) --* 
              Information about the Reserved Instance listing.
              - *(dict) --* 
                Describes a Reserved Instance listing.
                - **ClientToken** *(string) --* 
                  A unique, case-sensitive key supplied by the client to ensure that the request is idempotent. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
                - **CreateDate** *(datetime) --* 
                  The time the listing was created.
                - **InstanceCounts** *(list) --* 
                  The number of instances in this state.
                  - *(dict) --* 
                    Describes a Reserved Instance listing state.
                    - **InstanceCount** *(integer) --* 
                      The number of listed Reserved Instances in the state specified by the ``state`` .
                    - **State** *(string) --* 
                      The states of the listed Reserved Instances.
                - **PriceSchedules** *(list) --* 
                  The price of the Reserved Instance listing.
                  - *(dict) --* 
                    Describes the price for a Reserved Instance.
                    - **Active** *(boolean) --* 
                      The current price schedule, as determined by the term remaining for the Reserved Instance in the listing.
                      A specific price schedule is always in effect, but only one price schedule can be active at any time. Take, for example, a Reserved Instance listing that has five months remaining in its term. When you specify price schedules for five months and two months, this means that schedule 1, covering the first three months of the remaining term, will be active during months 5, 4, and 3. Then schedule 2, covering the last two months of the term, will be active for months 2 and 1.
                    - **CurrencyCode** *(string) --* 
                      The currency for transacting the Reserved Instance resale. At this time, the only supported currency is ``USD`` .
                    - **Price** *(float) --* 
                      The fixed price for the term.
                    - **Term** *(integer) --* 
                      The number of months remaining in the reservation. For example, 2 is the second to the last month before the capacity reservation expires.
                - **ReservedInstancesId** *(string) --* 
                  The ID of the Reserved Instance.
                - **ReservedInstancesListingId** *(string) --* 
                  The ID of the Reserved Instance listing.
                - **Status** *(string) --* 
                  The status of the Reserved Instance listing.
                - **StatusMessage** *(string) --* 
                  The reason for the current status of the Reserved Instance listing. The response can be blank.
                - **Tags** *(list) --* 
                  Any tags assigned to the resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **UpdateDate** *(datetime) --* 
                  The last modified timestamp of the listing.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``reserved-instances-id`` - The ID of the Reserved Instances.
          * ``reserved-instances-listing-id`` - The ID of the Reserved Instances listing.
          * ``status`` - The status of the Reserved Instance listing (``pending`` | ``active`` | ``cancelled`` | ``closed`` ).
          * ``status-message`` - The reason for the status.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type ReservedInstancesId: string
        :param ReservedInstancesId:
          One or more Reserved Instance IDs.
        :type ReservedInstancesListingId: string
        :param ReservedInstancesListingId:
          One or more Reserved Instance listing IDs.
        :rtype: dict
        :returns:
        """
        pass

    def describe_reserved_instances_modifications(self, Filters: List = None, ReservedInstancesModificationIds: List = None, NextToken: str = None) -> Dict:
        """
        Describes the modifications made to your Reserved Instances. If no parameter is specified, information about all your Reserved Instances modification requests is returned. If a modification ID is specified, only information about the specific modification is returned.
        For more information, see `Modifying Reserved Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-modifying.html>`__ in the Amazon Elastic Compute Cloud User Guide.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeReservedInstancesModifications>`_
        
        **Request Syntax**
        ::
          response = client.describe_reserved_instances_modifications(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              ReservedInstancesModificationIds=[
                  'string',
              ],
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'ReservedInstancesModifications': [
                    {
                        'ClientToken': 'string',
                        'CreateDate': datetime(2015, 1, 1),
                        'EffectiveDate': datetime(2015, 1, 1),
                        'ModificationResults': [
                            {
                                'ReservedInstancesId': 'string',
                                'TargetConfiguration': {
                                    'AvailabilityZone': 'string',
                                    'InstanceCount': 123,
                                    'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                    'Platform': 'string',
                                    'Scope': 'Availability Zone'|'Region'
                                }
                            },
                        ],
                        'ReservedInstancesIds': [
                            {
                                'ReservedInstancesId': 'string'
                            },
                        ],
                        'ReservedInstancesModificationId': 'string',
                        'Status': 'string',
                        'StatusMessage': 'string',
                        'UpdateDate': datetime(2015, 1, 1)
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeReservedInstancesModifications.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
            - **ReservedInstancesModifications** *(list) --* 
              The Reserved Instance modification information.
              - *(dict) --* 
                Describes a Reserved Instance modification.
                - **ClientToken** *(string) --* 
                  A unique, case-sensitive key supplied by the client to ensure that the request is idempotent. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
                - **CreateDate** *(datetime) --* 
                  The time when the modification request was created.
                - **EffectiveDate** *(datetime) --* 
                  The time for the modification to become effective.
                - **ModificationResults** *(list) --* 
                  Contains target configurations along with their corresponding new Reserved Instance IDs.
                  - *(dict) --* 
                    Describes the modification request/s.
                    - **ReservedInstancesId** *(string) --* 
                      The ID for the Reserved Instances that were created as part of the modification request. This field is only available when the modification is fulfilled.
                    - **TargetConfiguration** *(dict) --* 
                      The target Reserved Instances configurations supplied as part of the modification request.
                      - **AvailabilityZone** *(string) --* 
                        The Availability Zone for the modified Reserved Instances.
                      - **InstanceCount** *(integer) --* 
                        The number of modified Reserved Instances.
                        .. note::
                          This is a required field for a request.
                      - **InstanceType** *(string) --* 
                        The instance type for the modified Reserved Instances.
                      - **Platform** *(string) --* 
                        The network platform of the modified Reserved Instances, which is either EC2-Classic or EC2-VPC.
                      - **Scope** *(string) --* 
                        Whether the Reserved Instance is applied to instances in a region or instances in a specific Availability Zone.
                - **ReservedInstancesIds** *(list) --* 
                  The IDs of one or more Reserved Instances.
                  - *(dict) --* 
                    Describes the ID of a Reserved Instance.
                    - **ReservedInstancesId** *(string) --* 
                      The ID of the Reserved Instance.
                - **ReservedInstancesModificationId** *(string) --* 
                  A unique ID for the Reserved Instance modification.
                - **Status** *(string) --* 
                  The status of the Reserved Instances modification request.
                - **StatusMessage** *(string) --* 
                  The reason for the status.
                - **UpdateDate** *(datetime) --* 
                  The time when the modification request was last updated.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``client-token`` - The idempotency token for the modification request.
          * ``create-date`` - The time when the modification request was created.
          * ``effective-date`` - The time when the modification becomes effective.
          * ``modification-result.reserved-instances-id`` - The ID for the Reserved Instances created as part of the modification request. This ID is only available when the status of the modification is ``fulfilled`` .
          * ``modification-result.target-configuration.availability-zone`` - The Availability Zone for the new Reserved Instances.
          * ``modification-result.target-configuration.instance-count`` - The number of new Reserved Instances.
          * ``modification-result.target-configuration.instance-type`` - The instance type of the new Reserved Instances.
          * ``modification-result.target-configuration.platform`` - The network platform of the new Reserved Instances (``EC2-Classic`` | ``EC2-VPC`` ).
          * ``reserved-instances-id`` - The ID of the Reserved Instances modified.
          * ``reserved-instances-modification-id`` - The ID of the modification request.
          * ``status`` - The status of the Reserved Instances modification request (``processing`` | ``fulfilled`` | ``failed`` ).
          * ``status-message`` - The reason for the status.
          * ``update-date`` - The time when the modification request was last updated.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type ReservedInstancesModificationIds: list
        :param ReservedInstancesModificationIds:
          IDs for the submitted modification request.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_reserved_instances_offerings(self, AvailabilityZone: str = None, Filters: List = None, IncludeMarketplace: bool = None, InstanceType: str = None, MaxDuration: int = None, MaxInstanceCount: int = None, MinDuration: int = None, OfferingClass: str = None, ProductDescription: str = None, ReservedInstancesOfferingIds: List = None, DryRun: bool = None, InstanceTenancy: str = None, MaxResults: int = None, NextToken: str = None, OfferingType: str = None) -> Dict:
        """
        Describes Reserved Instance offerings that are available for purchase. With Reserved Instances, you purchase the right to launch instances for a period of time. During that time period, you do not receive insufficient capacity errors, and you pay a lower usage rate than the rate charged for On-Demand instances for the actual time used.
        If you have listed your own Reserved Instances for sale in the Reserved Instance Marketplace, they will be excluded from these results. This is to ensure that you do not purchase your own Reserved Instances.
        For more information, see `Reserved Instance Marketplace <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeReservedInstancesOfferings>`_
        
        **Request Syntax**
        ::
          response = client.describe_reserved_instances_offerings(
              AvailabilityZone='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              IncludeMarketplace=True|False,
              InstanceType='t1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
              MaxDuration=123,
              MaxInstanceCount=123,
              MinDuration=123,
              OfferingClass='standard'|'convertible',
              ProductDescription='Linux/UNIX'|'Linux/UNIX (Amazon VPC)'|'Windows'|'Windows (Amazon VPC)',
              ReservedInstancesOfferingIds=[
                  'string',
              ],
              DryRun=True|False,
              InstanceTenancy='default'|'dedicated'|'host',
              MaxResults=123,
              NextToken='string',
              OfferingType='Heavy Utilization'|'Medium Utilization'|'Light Utilization'|'No Upfront'|'Partial Upfront'|'All Upfront'
          )
        
        **Response Syntax**
        ::
            {
                'ReservedInstancesOfferings': [
                    {
                        'AvailabilityZone': 'string',
                        'Duration': 123,
                        'FixedPrice': ...,
                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                        'ProductDescription': 'Linux/UNIX'|'Linux/UNIX (Amazon VPC)'|'Windows'|'Windows (Amazon VPC)',
                        'ReservedInstancesOfferingId': 'string',
                        'UsagePrice': ...,
                        'CurrencyCode': 'USD',
                        'InstanceTenancy': 'default'|'dedicated'|'host',
                        'Marketplace': True|False,
                        'OfferingClass': 'standard'|'convertible',
                        'OfferingType': 'Heavy Utilization'|'Medium Utilization'|'Light Utilization'|'No Upfront'|'Partial Upfront'|'All Upfront',
                        'PricingDetails': [
                            {
                                'Count': 123,
                                'Price': 123.0
                            },
                        ],
                        'RecurringCharges': [
                            {
                                'Amount': 123.0,
                                'Frequency': 'Hourly'
                            },
                        ],
                        'Scope': 'Availability Zone'|'Region'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeReservedInstancesOfferings.
            - **ReservedInstancesOfferings** *(list) --* 
              A list of Reserved Instances offerings.
              - *(dict) --* 
                Describes a Reserved Instance offering.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone in which the Reserved Instance can be used.
                - **Duration** *(integer) --* 
                  The duration of the Reserved Instance, in seconds.
                - **FixedPrice** *(float) --* 
                  The purchase price of the Reserved Instance.
                - **InstanceType** *(string) --* 
                  The instance type on which the Reserved Instance can be used.
                - **ProductDescription** *(string) --* 
                  The Reserved Instance product platform description.
                - **ReservedInstancesOfferingId** *(string) --* 
                  The ID of the Reserved Instance offering. This is the offering ID used in  GetReservedInstancesExchangeQuote to confirm that an exchange can be made.
                - **UsagePrice** *(float) --* 
                  The usage price of the Reserved Instance, per hour.
                - **CurrencyCode** *(string) --* 
                  The currency of the Reserved Instance offering you are purchasing. It's specified using ISO 4217 standard currency codes. At this time, the only supported currency is ``USD`` .
                - **InstanceTenancy** *(string) --* 
                  The tenancy of the instance.
                - **Marketplace** *(boolean) --* 
                  Indicates whether the offering is available through the Reserved Instance Marketplace (resale) or AWS. If it's a Reserved Instance Marketplace offering, this is ``true`` .
                - **OfferingClass** *(string) --* 
                  If ``convertible`` it can be exchanged for Reserved Instances of the same or higher monetary value, with different configurations. If ``standard`` , it is not possible to perform an exchange.
                - **OfferingType** *(string) --* 
                  The Reserved Instance offering type.
                - **PricingDetails** *(list) --* 
                  The pricing details of the Reserved Instance offering.
                  - *(dict) --* 
                    Describes a Reserved Instance offering.
                    - **Count** *(integer) --* 
                      The number of reservations available for the price.
                    - **Price** *(float) --* 
                      The price per instance.
                - **RecurringCharges** *(list) --* 
                  The recurring charge tag assigned to the resource.
                  - *(dict) --* 
                    Describes a recurring charge.
                    - **Amount** *(float) --* 
                      The amount of the recurring charge.
                    - **Frequency** *(string) --* 
                      The frequency of the recurring charge.
                - **Scope** *(string) --* 
                  Whether the Reserved Instance is applied to instances in a region or an Availability Zone.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type AvailabilityZone: string
        :param AvailabilityZone:
          The Availability Zone in which the Reserved Instance can be used.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``availability-zone`` - The Availability Zone where the Reserved Instance can be used.
          * ``duration`` - The duration of the Reserved Instance (for example, one year or three years), in seconds (``31536000`` | ``94608000`` ).
          * ``fixed-price`` - The purchase price of the Reserved Instance (for example, 9800.0).
          * ``instance-type`` - The instance type that is covered by the reservation.
          * ``marketplace`` - Set to ``true`` to show only Reserved Instance Marketplace offerings. When this filter is not used, which is the default behavior, all offerings from both AWS and the Reserved Instance Marketplace are listed.
          * ``product-description`` - The Reserved Instance product platform description. Instances that include ``(Amazon VPC)`` in the product platform description will only be displayed to EC2-Classic account holders and are for use with Amazon VPC. (``Linux/UNIX`` | ``Linux/UNIX (Amazon VPC)`` | ``SUSE Linux`` | ``SUSE Linux (Amazon VPC)`` | ``Red Hat Enterprise Linux`` | ``Red Hat Enterprise Linux (Amazon VPC)`` | ``Windows`` | ``Windows (Amazon VPC)`` | ``Windows with SQL Server Standard`` | ``Windows with SQL Server Standard (Amazon VPC)`` | ``Windows with SQL Server Web`` | ``Windows with SQL Server Web (Amazon VPC)`` | ``Windows with SQL Server Enterprise`` | ``Windows with SQL Server Enterprise (Amazon VPC)`` )
          * ``reserved-instances-offering-id`` - The Reserved Instances offering ID.
          * ``scope`` - The scope of the Reserved Instance (``Availability Zone`` or ``Region`` ).
          * ``usage-price`` - The usage price of the Reserved Instance, per hour (for example, 0.84).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type IncludeMarketplace: boolean
        :param IncludeMarketplace:
          Include Reserved Instance Marketplace offerings in the response.
        :type InstanceType: string
        :param InstanceType:
          The instance type that the reservation will cover (for example, ``m1.small`` ). For more information, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type MaxDuration: integer
        :param MaxDuration:
          The maximum duration (in seconds) to filter when searching for offerings.
          Default: 94608000 (3 years)
        :type MaxInstanceCount: integer
        :param MaxInstanceCount:
          The maximum number of instances to filter when searching for offerings.
          Default: 20
        :type MinDuration: integer
        :param MinDuration:
          The minimum duration (in seconds) to filter when searching for offerings.
          Default: 2592000 (1 month)
        :type OfferingClass: string
        :param OfferingClass:
          The offering class of the Reserved Instance. Can be ``standard`` or ``convertible`` .
        :type ProductDescription: string
        :param ProductDescription:
          The Reserved Instance product platform description. Instances that include ``(Amazon VPC)`` in the description are for use with Amazon VPC.
        :type ReservedInstancesOfferingIds: list
        :param ReservedInstancesOfferingIds:
          One or more Reserved Instances offering IDs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceTenancy: string
        :param InstanceTenancy:
          The tenancy of the instances covered by the reservation. A Reserved Instance with a tenancy of ``dedicated`` is applied to instances that run in a VPC on single-tenant hardware (i.e., Dedicated Instances).
           **Important:** The ``host`` value cannot be used with this parameter. Use the ``default`` or ``dedicated`` values only.
          Default: ``default``
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ``NextToken`` value. The maximum is 100.
          Default: 100
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :type OfferingType: string
        :param OfferingType:
          The Reserved Instance offering type. If you are using tools that predate the 2011-11-01 API version, you only have access to the ``Medium Utilization`` Reserved Instance offering type.
        :rtype: dict
        :returns:
        """
        pass

    def describe_route_tables(self, Filters: List = None, DryRun: bool = None, RouteTableIds: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes one or more of your route tables.
        Each subnet in your VPC must be associated with a route table. If a subnet is not explicitly associated with any route table, it is implicitly associated with the main route table. This command does not return the subnet ID for implicit associations.
        For more information, see `Route Tables <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeRouteTables>`_
        
        **Request Syntax**
        ::
          response = client.describe_route_tables(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              RouteTableIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'RouteTables': [
                    {
                        'Associations': [
                            {
                                'Main': True|False,
                                'RouteTableAssociationId': 'string',
                                'RouteTableId': 'string',
                                'SubnetId': 'string'
                            },
                        ],
                        'PropagatingVgws': [
                            {
                                'GatewayId': 'string'
                            },
                        ],
                        'RouteTableId': 'string',
                        'Routes': [
                            {
                                'DestinationCidrBlock': 'string',
                                'DestinationIpv6CidrBlock': 'string',
                                'DestinationPrefixListId': 'string',
                                'EgressOnlyInternetGatewayId': 'string',
                                'GatewayId': 'string',
                                'InstanceId': 'string',
                                'InstanceOwnerId': 'string',
                                'NatGatewayId': 'string',
                                'TransitGatewayId': 'string',
                                'NetworkInterfaceId': 'string',
                                'Origin': 'CreateRouteTable'|'CreateRoute'|'EnableVgwRoutePropagation',
                                'State': 'active'|'blackhole',
                                'VpcPeeringConnectionId': 'string'
                            },
                        ],
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VpcId': 'string',
                        'OwnerId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeRouteTables.
            - **RouteTables** *(list) --* 
              Information about one or more route tables.
              - *(dict) --* 
                Describes a route table.
                - **Associations** *(list) --* 
                  The associations between the route table and one or more subnets.
                  - *(dict) --* 
                    Describes an association between a route table and a subnet.
                    - **Main** *(boolean) --* 
                      Indicates whether this is the main route table.
                    - **RouteTableAssociationId** *(string) --* 
                      The ID of the association between a route table and a subnet.
                    - **RouteTableId** *(string) --* 
                      The ID of the route table.
                    - **SubnetId** *(string) --* 
                      The ID of the subnet. A subnet ID is not returned for an implicit association.
                - **PropagatingVgws** *(list) --* 
                  Any virtual private gateway (VGW) propagating routes.
                  - *(dict) --* 
                    Describes a virtual private gateway propagating route.
                    - **GatewayId** *(string) --* 
                      The ID of the virtual private gateway.
                - **RouteTableId** *(string) --* 
                  The ID of the route table.
                - **Routes** *(list) --* 
                  The routes in the route table.
                  - *(dict) --* 
                    Describes a route in a route table.
                    - **DestinationCidrBlock** *(string) --* 
                      The IPv4 CIDR block used for the destination match.
                    - **DestinationIpv6CidrBlock** *(string) --* 
                      The IPv6 CIDR block used for the destination match.
                    - **DestinationPrefixListId** *(string) --* 
                      The prefix of the AWS service.
                    - **EgressOnlyInternetGatewayId** *(string) --* 
                      The ID of the egress-only internet gateway.
                    - **GatewayId** *(string) --* 
                      The ID of a gateway attached to your VPC.
                    - **InstanceId** *(string) --* 
                      The ID of a NAT instance in your VPC.
                    - **InstanceOwnerId** *(string) --* 
                      The AWS account ID of the owner of the instance.
                    - **NatGatewayId** *(string) --* 
                      The ID of a NAT gateway.
                    - **TransitGatewayId** *(string) --* 
                      The ID of a transit gateway.
                    - **NetworkInterfaceId** *(string) --* 
                      The ID of the network interface.
                    - **Origin** *(string) --* 
                      Describes how the route was created.
                      * ``CreateRouteTable`` - The route was automatically created when the route table was created. 
                      * ``CreateRoute`` - The route was manually added to the route table. 
                      * ``EnableVgwRoutePropagation`` - The route was propagated by route propagation. 
                    - **State** *(string) --* 
                      The state of the route. The ``blackhole`` state indicates that the route's target isn't available (for example, the specified gateway isn't attached to the VPC, or the specified NAT instance has been terminated).
                    - **VpcPeeringConnectionId** *(string) --* 
                      The ID of a VPC peering connection.
                - **Tags** *(list) --* 
                  Any tags assigned to the route table.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account that owns the route table.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``association.route-table-association-id`` - The ID of an association ID for the route table.
          * ``association.route-table-id`` - The ID of the route table involved in the association.
          * ``association.subnet-id`` - The ID of the subnet involved in the association.
          * ``association.main`` - Indicates whether the route table is the main route table for the VPC (``true`` | ``false`` ). Route tables that do not have an association ID are not returned in the response.
          * ``owner-id`` - The ID of the AWS account that owns the route table.
          * ``route-table-id`` - The ID of the route table.
          * ``route.destination-cidr-block`` - The IPv4 CIDR range specified in a route in the table.
          * ``route.destination-ipv6-cidr-block`` - The IPv6 CIDR range specified in a route in the route table.
          * ``route.destination-prefix-list-id`` - The ID (prefix) of the AWS service specified in a route in the table.
          * ``route.egress-only-internet-gateway-id`` - The ID of an egress-only Internet gateway specified in a route in the route table.
          * ``route.gateway-id`` - The ID of a gateway specified in a route in the table.
          * ``route.instance-id`` - The ID of an instance specified in a route in the table.
          * ``route.nat-gateway-id`` - The ID of a NAT gateway.
          * ``route.transit-gateway-id`` - The ID of a transit gateway.
          * ``route.origin`` - Describes how the route was created. ``CreateRouteTable`` indicates that the route was automatically created when the route table was created; ``CreateRoute`` indicates that the route was manually added to the route table; ``EnableVgwRoutePropagation`` indicates that the route was propagated by route propagation.
          * ``route.state`` - The state of a route in the route table (``active`` | ``blackhole`` ). The blackhole state indicates that the route\'s target isn\'t available (for example, the specified gateway isn\'t attached to the VPC, the specified NAT instance has been terminated, and so on).
          * ``route.vpc-peering-connection-id`` - The ID of a VPC peering connection specified in a route in the table.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``transit-gateway-id`` - The ID of a transit gateway.
          * ``vpc-id`` - The ID of the VPC for the route table.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type RouteTableIds: list
        :param RouteTableIds:
          One or more route table IDs.
          Default: Describes all your route tables.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_scheduled_instance_availability(self, FirstSlotStartTimeRange: Dict, Recurrence: Dict, DryRun: bool = None, Filters: List = None, MaxResults: int = None, MaxSlotDurationInHours: int = None, MinSlotDurationInHours: int = None, NextToken: str = None) -> Dict:
        """
        Finds available schedules that meet the specified criteria.
        You can search for an available schedule no more than 3 months in advance. You must meet the minimum required duration of 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours.
        After you find a schedule that meets your needs, call  PurchaseScheduledInstances to purchase Scheduled Instances with that schedule.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeScheduledInstanceAvailability>`_
        
        **Request Syntax**
        ::
          response = client.describe_scheduled_instance_availability(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              FirstSlotStartTimeRange={
                  'EarliestTime': datetime(2015, 1, 1),
                  'LatestTime': datetime(2015, 1, 1)
              },
              MaxResults=123,
              MaxSlotDurationInHours=123,
              MinSlotDurationInHours=123,
              NextToken='string',
              Recurrence={
                  'Frequency': 'string',
                  'Interval': 123,
                  'OccurrenceDays': [
                      123,
                  ],
                  'OccurrenceRelativeToEnd': True|False,
                  'OccurrenceUnit': 'string'
              }
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'ScheduledInstanceAvailabilitySet': [
                    {
                        'AvailabilityZone': 'string',
                        'AvailableInstanceCount': 123,
                        'FirstSlotStartTime': datetime(2015, 1, 1),
                        'HourlyPrice': 'string',
                        'InstanceType': 'string',
                        'MaxTermDurationInDays': 123,
                        'MinTermDurationInDays': 123,
                        'NetworkPlatform': 'string',
                        'Platform': 'string',
                        'PurchaseToken': 'string',
                        'Recurrence': {
                            'Frequency': 'string',
                            'Interval': 123,
                            'OccurrenceDaySet': [
                                123,
                            ],
                            'OccurrenceRelativeToEnd': True|False,
                            'OccurrenceUnit': 'string'
                        },
                        'SlotDurationInHours': 123,
                        'TotalScheduledInstanceHours': 123
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeScheduledInstanceAvailability.
            - **NextToken** *(string) --* 
              The token required to retrieve the next set of results. This value is ``null`` when there are no more results to return.
            - **ScheduledInstanceAvailabilitySet** *(list) --* 
              Information about the available Scheduled Instances.
              - *(dict) --* 
                Describes a schedule that is available for your Scheduled Instances.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone.
                - **AvailableInstanceCount** *(integer) --* 
                  The number of available instances.
                - **FirstSlotStartTime** *(datetime) --* 
                  The time period for the first schedule to start.
                - **HourlyPrice** *(string) --* 
                  The hourly price for a single instance.
                - **InstanceType** *(string) --* 
                  The instance type. You can specify one of the C3, C4, M4, or R3 instance types.
                - **MaxTermDurationInDays** *(integer) --* 
                  The maximum term. The only possible value is 365 days.
                - **MinTermDurationInDays** *(integer) --* 
                  The minimum term. The only possible value is 365 days.
                - **NetworkPlatform** *(string) --* 
                  The network platform (``EC2-Classic`` or ``EC2-VPC`` ).
                - **Platform** *(string) --* 
                  The platform (``Linux/UNIX`` or ``Windows`` ).
                - **PurchaseToken** *(string) --* 
                  The purchase token. This token expires in two hours.
                - **Recurrence** *(dict) --* 
                  The schedule recurrence.
                  - **Frequency** *(string) --* 
                    The frequency (``Daily`` , ``Weekly`` , or ``Monthly`` ).
                  - **Interval** *(integer) --* 
                    The interval quantity. The interval unit depends on the value of ``frequency`` . For example, every 2 weeks or every 2 months.
                  - **OccurrenceDaySet** *(list) --* 
                    The days. For a monthly schedule, this is one or more days of the month (1-31). For a weekly schedule, this is one or more days of the week (1-7, where 1 is Sunday).
                    - *(integer) --* 
                  - **OccurrenceRelativeToEnd** *(boolean) --* 
                    Indicates whether the occurrence is relative to the end of the specified week or month.
                  - **OccurrenceUnit** *(string) --* 
                    The unit for ``occurrenceDaySet`` (``DayOfWeek`` or ``DayOfMonth`` ).
                - **SlotDurationInHours** *(integer) --* 
                  The number of hours in the schedule.
                - **TotalScheduledInstanceHours** *(integer) --* 
                  The total number of hours for a single instance for the entire term.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          The filters.
          * ``availability-zone`` - The Availability Zone (for example, ``us-west-2a`` ).
          * ``instance-type`` - The instance type (for example, ``c4.large`` ).
          * ``network-platform`` - The network platform (``EC2-Classic`` or ``EC2-VPC`` ).
          * ``platform`` - The platform (``Linux/UNIX`` or ``Windows`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type FirstSlotStartTimeRange: dict
        :param FirstSlotStartTimeRange: **[REQUIRED]**
          The time period for the first schedule to start.
          - **EarliestTime** *(datetime) --* **[REQUIRED]**
            The earliest date and time, in UTC, for the Scheduled Instance to start.
          - **LatestTime** *(datetime) --* **[REQUIRED]**
            The latest date and time, in UTC, for the Scheduled Instance to start. This value must be later than or equal to the earliest date and at most three months in the future.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 300. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type MaxSlotDurationInHours: integer
        :param MaxSlotDurationInHours:
          The maximum available duration, in hours. This value must be greater than ``MinSlotDurationInHours`` and less than 1,720.
        :type MinSlotDurationInHours: integer
        :param MinSlotDurationInHours:
          The minimum available duration, in hours. The minimum required duration is 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type Recurrence: dict
        :param Recurrence: **[REQUIRED]**
          The schedule recurrence.
          - **Frequency** *(string) --*
            The frequency (``Daily`` , ``Weekly`` , or ``Monthly`` ).
          - **Interval** *(integer) --*
            The interval quantity. The interval unit depends on the value of ``Frequency`` . For example, every 2 weeks or every 2 months.
          - **OccurrenceDays** *(list) --*
            The days. For a monthly schedule, this is one or more days of the month (1-31). For a weekly schedule, this is one or more days of the week (1-7, where 1 is Sunday). You can\'t specify this value with a daily schedule. If the occurrence is relative to the end of the month, you can specify only a single day.
            - *(integer) --*
          - **OccurrenceRelativeToEnd** *(boolean) --*
            Indicates whether the occurrence is relative to the end of the specified week or month. You can\'t specify this value with a daily schedule.
          - **OccurrenceUnit** *(string) --*
            The unit for ``OccurrenceDays`` (``DayOfWeek`` or ``DayOfMonth`` ). This value is required for a monthly schedule. You can\'t specify ``DayOfWeek`` with a weekly schedule. You can\'t specify this value with a daily schedule.
        :rtype: dict
        :returns:
        """
        pass

    def describe_scheduled_instances(self, DryRun: bool = None, Filters: List = None, MaxResults: int = None, NextToken: str = None, ScheduledInstanceIds: List = None, SlotStartTimeRange: Dict = None) -> Dict:
        """
        Describes the specified Scheduled Instances or all your Scheduled Instances.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeScheduledInstances>`_
        
        **Request Syntax**
        ::
          response = client.describe_scheduled_instances(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              ScheduledInstanceIds=[
                  'string',
              ],
              SlotStartTimeRange={
                  'EarliestTime': datetime(2015, 1, 1),
                  'LatestTime': datetime(2015, 1, 1)
              }
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'ScheduledInstanceSet': [
                    {
                        'AvailabilityZone': 'string',
                        'CreateDate': datetime(2015, 1, 1),
                        'HourlyPrice': 'string',
                        'InstanceCount': 123,
                        'InstanceType': 'string',
                        'NetworkPlatform': 'string',
                        'NextSlotStartTime': datetime(2015, 1, 1),
                        'Platform': 'string',
                        'PreviousSlotEndTime': datetime(2015, 1, 1),
                        'Recurrence': {
                            'Frequency': 'string',
                            'Interval': 123,
                            'OccurrenceDaySet': [
                                123,
                            ],
                            'OccurrenceRelativeToEnd': True|False,
                            'OccurrenceUnit': 'string'
                        },
                        'ScheduledInstanceId': 'string',
                        'SlotDurationInHours': 123,
                        'TermEndDate': datetime(2015, 1, 1),
                        'TermStartDate': datetime(2015, 1, 1),
                        'TotalScheduledInstanceHours': 123
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeScheduledInstances.
            - **NextToken** *(string) --* 
              The token required to retrieve the next set of results. This value is ``null`` when there are no more results to return.
            - **ScheduledInstanceSet** *(list) --* 
              Information about the Scheduled Instances.
              - *(dict) --* 
                Describes a Scheduled Instance.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone.
                - **CreateDate** *(datetime) --* 
                  The date when the Scheduled Instance was purchased.
                - **HourlyPrice** *(string) --* 
                  The hourly price for a single instance.
                - **InstanceCount** *(integer) --* 
                  The number of instances.
                - **InstanceType** *(string) --* 
                  The instance type.
                - **NetworkPlatform** *(string) --* 
                  The network platform (``EC2-Classic`` or ``EC2-VPC`` ).
                - **NextSlotStartTime** *(datetime) --* 
                  The time for the next schedule to start.
                - **Platform** *(string) --* 
                  The platform (``Linux/UNIX`` or ``Windows`` ).
                - **PreviousSlotEndTime** *(datetime) --* 
                  The time that the previous schedule ended or will end.
                - **Recurrence** *(dict) --* 
                  The schedule recurrence.
                  - **Frequency** *(string) --* 
                    The frequency (``Daily`` , ``Weekly`` , or ``Monthly`` ).
                  - **Interval** *(integer) --* 
                    The interval quantity. The interval unit depends on the value of ``frequency`` . For example, every 2 weeks or every 2 months.
                  - **OccurrenceDaySet** *(list) --* 
                    The days. For a monthly schedule, this is one or more days of the month (1-31). For a weekly schedule, this is one or more days of the week (1-7, where 1 is Sunday).
                    - *(integer) --* 
                  - **OccurrenceRelativeToEnd** *(boolean) --* 
                    Indicates whether the occurrence is relative to the end of the specified week or month.
                  - **OccurrenceUnit** *(string) --* 
                    The unit for ``occurrenceDaySet`` (``DayOfWeek`` or ``DayOfMonth`` ).
                - **ScheduledInstanceId** *(string) --* 
                  The Scheduled Instance ID.
                - **SlotDurationInHours** *(integer) --* 
                  The number of hours in the schedule.
                - **TermEndDate** *(datetime) --* 
                  The end date for the Scheduled Instance.
                - **TermStartDate** *(datetime) --* 
                  The start date for the Scheduled Instance.
                - **TotalScheduledInstanceHours** *(integer) --* 
                  The total number of hours for a single instance for the entire term.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          The filters.
          * ``availability-zone`` - The Availability Zone (for example, ``us-west-2a`` ).
          * ``instance-type`` - The instance type (for example, ``c4.large`` ).
          * ``network-platform`` - The network platform (``EC2-Classic`` or ``EC2-VPC`` ).
          * ``platform`` - The platform (``Linux/UNIX`` or ``Windows`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 100. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type ScheduledInstanceIds: list
        :param ScheduledInstanceIds:
          The Scheduled Instance IDs.
          - *(string) --*
        :type SlotStartTimeRange: dict
        :param SlotStartTimeRange:
          The time period for the first schedule to start.
          - **EarliestTime** *(datetime) --*
            The earliest date and time, in UTC, for the Scheduled Instance to start.
          - **LatestTime** *(datetime) --*
            The latest date and time, in UTC, for the Scheduled Instance to start.
        :rtype: dict
        :returns:
        """
        pass

    def describe_security_group_references(self, GroupId: List, DryRun: bool = None) -> Dict:
        """
        [VPC only] Describes the VPCs on the other side of a VPC peering connection that are referencing the security groups you've specified in this request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSecurityGroupReferences>`_
        
        **Request Syntax**
        ::
          response = client.describe_security_group_references(
              DryRun=True|False,
              GroupId=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'SecurityGroupReferenceSet': [
                    {
                        'GroupId': 'string',
                        'ReferencingVpcId': 'string',
                        'VpcPeeringConnectionId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **SecurityGroupReferenceSet** *(list) --* 
              Information about the VPCs with the referencing security groups.
              - *(dict) --* 
                Describes a VPC with a security group that references your security group.
                - **GroupId** *(string) --* 
                  The ID of your security group.
                - **ReferencingVpcId** *(string) --* 
                  The ID of the VPC with the referencing security group.
                - **VpcPeeringConnectionId** *(string) --* 
                  The ID of the VPC peering connection.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupId: list
        :param GroupId: **[REQUIRED]**
          The IDs of the security groups in your account.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_security_groups(self, Filters: List = None, GroupIds: List = None, GroupNames: List = None, DryRun: bool = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes the specified security groups or all of your security groups.
        A security group is for use with instances either in the EC2-Classic platform or in a specific VPC. For more information, see `Amazon EC2 Security Groups <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-network-security.html>`__ in the *Amazon Elastic Compute Cloud User Guide* and `Security Groups for Your VPC <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_SecurityGroups.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSecurityGroups>`_
        
        **Request Syntax**
        ::
          response = client.describe_security_groups(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              GroupIds=[
                  'string',
              ],
              GroupNames=[
                  'string',
              ],
              DryRun=True|False,
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'SecurityGroups': [
                    {
                        'Description': 'string',
                        'GroupName': 'string',
                        'IpPermissions': [
                            {
                                'FromPort': 123,
                                'IpProtocol': 'string',
                                'IpRanges': [
                                    {
                                        'CidrIp': 'string',
                                        'Description': 'string'
                                    },
                                ],
                                'Ipv6Ranges': [
                                    {
                                        'CidrIpv6': 'string',
                                        'Description': 'string'
                                    },
                                ],
                                'PrefixListIds': [
                                    {
                                        'Description': 'string',
                                        'PrefixListId': 'string'
                                    },
                                ],
                                'ToPort': 123,
                                'UserIdGroupPairs': [
                                    {
                                        'Description': 'string',
                                        'GroupId': 'string',
                                        'GroupName': 'string',
                                        'PeeringStatus': 'string',
                                        'UserId': 'string',
                                        'VpcId': 'string',
                                        'VpcPeeringConnectionId': 'string'
                                    },
                                ]
                            },
                        ],
                        'OwnerId': 'string',
                        'GroupId': 'string',
                        'IpPermissionsEgress': [
                            {
                                'FromPort': 123,
                                'IpProtocol': 'string',
                                'IpRanges': [
                                    {
                                        'CidrIp': 'string',
                                        'Description': 'string'
                                    },
                                ],
                                'Ipv6Ranges': [
                                    {
                                        'CidrIpv6': 'string',
                                        'Description': 'string'
                                    },
                                ],
                                'PrefixListIds': [
                                    {
                                        'Description': 'string',
                                        'PrefixListId': 'string'
                                    },
                                ],
                                'ToPort': 123,
                                'UserIdGroupPairs': [
                                    {
                                        'Description': 'string',
                                        'GroupId': 'string',
                                        'GroupName': 'string',
                                        'PeeringStatus': 'string',
                                        'UserId': 'string',
                                        'VpcId': 'string',
                                        'VpcPeeringConnectionId': 'string'
                                    },
                                ]
                            },
                        ],
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VpcId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **SecurityGroups** *(list) --* 
              Information about the security groups.
              - *(dict) --* 
                Describes a security group
                - **Description** *(string) --* 
                  A description of the security group.
                - **GroupName** *(string) --* 
                  The name of the security group.
                - **IpPermissions** *(list) --* 
                  The inbound rules associated with the security group.
                  - *(dict) --* 
                    Describes a set of permissions for a security group rule.
                    - **FromPort** *(integer) --* 
                      The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
                    - **IpProtocol** *(string) --* 
                      The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
                      [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
                    - **IpRanges** *(list) --* 
                      The IPv4 ranges.
                      - *(dict) --* 
                        Describes an IPv4 range.
                        - **CidrIp** *(string) --* 
                          The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this IPv4 address range.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                    - **Ipv6Ranges** *(list) --* 
                      [VPC only] The IPv6 ranges.
                      - *(dict) --* 
                        [EC2-VPC only] Describes an IPv6 range.
                        - **CidrIpv6** *(string) --* 
                          The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this IPv6 address range.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                    - **PrefixListIds** *(list) --* 
                      [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
                      - *(dict) --* 
                        Describes a prefix list ID.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this prefix list ID.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                        - **PrefixListId** *(string) --* 
                          The ID of the prefix.
                    - **ToPort** *(integer) --* 
                      The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
                    - **UserIdGroupPairs** *(list) --* 
                      The security group and AWS account ID pairs.
                      - *(dict) --* 
                        Describes a security group and AWS account ID pair.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this user ID group pair.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                        - **GroupId** *(string) --* 
                          The ID of the security group.
                        - **GroupName** *(string) --* 
                          The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID. 
                          For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                        - **PeeringStatus** *(string) --* 
                          The status of a VPC peering connection, if applicable.
                        - **UserId** *(string) --* 
                          The ID of an AWS account.
                          For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                          [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                        - **VpcId** *(string) --* 
                          The ID of the VPC for the referenced security group, if applicable.
                        - **VpcPeeringConnectionId** *(string) --* 
                          The ID of the VPC peering connection, if applicable.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the owner of the security group.
                - **GroupId** *(string) --* 
                  The ID of the security group.
                - **IpPermissionsEgress** *(list) --* 
                  [VPC only] The outbound rules associated with the security group.
                  - *(dict) --* 
                    Describes a set of permissions for a security group rule.
                    - **FromPort** *(integer) --* 
                      The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
                    - **IpProtocol** *(string) --* 
                      The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
                      [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
                    - **IpRanges** *(list) --* 
                      The IPv4 ranges.
                      - *(dict) --* 
                        Describes an IPv4 range.
                        - **CidrIp** *(string) --* 
                          The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this IPv4 address range.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                    - **Ipv6Ranges** *(list) --* 
                      [VPC only] The IPv6 ranges.
                      - *(dict) --* 
                        [EC2-VPC only] Describes an IPv6 range.
                        - **CidrIpv6** *(string) --* 
                          The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this IPv6 address range.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                    - **PrefixListIds** *(list) --* 
                      [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
                      - *(dict) --* 
                        Describes a prefix list ID.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this prefix list ID.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                        - **PrefixListId** *(string) --* 
                          The ID of the prefix.
                    - **ToPort** *(integer) --* 
                      The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
                    - **UserIdGroupPairs** *(list) --* 
                      The security group and AWS account ID pairs.
                      - *(dict) --* 
                        Describes a security group and AWS account ID pair.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this user ID group pair.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                        - **GroupId** *(string) --* 
                          The ID of the security group.
                        - **GroupName** *(string) --* 
                          The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID. 
                          For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                        - **PeeringStatus** *(string) --* 
                          The status of a VPC peering connection, if applicable.
                        - **UserId** *(string) --* 
                          The ID of an AWS account.
                          For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                          [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                        - **VpcId** *(string) --* 
                          The ID of the VPC for the referenced security group, if applicable.
                        - **VpcPeeringConnectionId** *(string) --* 
                          The ID of the VPC peering connection, if applicable.
                - **Tags** *(list) --* 
                  Any tags assigned to the security group.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VpcId** *(string) --* 
                  [VPC only] The ID of the VPC for the security group.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          The filters. If using multiple filters for rules, the results include security groups for which any combination of rules - not necessarily a single rule - match all filters.
          * ``description`` - The description of the security group.
          * ``egress.ip-permission.cidr`` - An IPv4 CIDR block for an outbound security group rule.
          * ``egress.ip-permission.from-port`` - For an outbound rule, the start of port range for the TCP and UDP protocols, or an ICMP type number.
          * ``egress.ip-permission.group-id`` - The ID of a security group that has been referenced in an outbound security group rule.
          * ``egress.ip-permission.group-name`` - The name of a security group that has been referenced in an outbound security group rule.
          * ``egress.ip-permission.ipv6-cidr`` - An IPv6 CIDR block for an outbound security group rule.
          * ``egress.ip-permission.prefix-list-id`` - The ID (prefix) of the AWS service to which a security group rule allows outbound access.
          * ``egress.ip-permission.protocol`` - The IP protocol for an outbound security group rule (``tcp`` | ``udp`` | ``icmp`` or a protocol number).
          * ``egress.ip-permission.to-port`` - For an outbound rule, the end of port range for the TCP and UDP protocols, or an ICMP code.
          * ``egress.ip-permission.user-id`` - The ID of an AWS account that has been referenced in an outbound security group rule.
          * ``group-id`` - The ID of the security group.
          * ``group-name`` - The name of the security group.
          * ``ip-permission.cidr`` - An IPv4 CIDR block for an inbound security group rule.
          * ``ip-permission.from-port`` - For an inbound rule, the start of port range for the TCP and UDP protocols, or an ICMP type number.
          * ``ip-permission.group-id`` - The ID of a security group that has been referenced in an inbound security group rule.
          * ``ip-permission.group-name`` - The name of a security group that has been referenced in an inbound security group rule.
          * ``ip-permission.ipv6-cidr`` - An IPv6 CIDR block for an inbound security group rule.
          * ``ip-permission.prefix-list-id`` - The ID (prefix) of the AWS service from which a security group rule allows inbound access.
          * ``ip-permission.protocol`` - The IP protocol for an inbound security group rule (``tcp`` | ``udp`` | ``icmp`` or a protocol number).
          * ``ip-permission.to-port`` - For an inbound rule, the end of port range for the TCP and UDP protocols, or an ICMP code.
          * ``ip-permission.user-id`` - The ID of an AWS account that has been referenced in an inbound security group rule.
          * ``owner-id`` - The AWS account ID of the owner of the security group.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-id`` - The ID of the VPC specified when the security group was created.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type GroupIds: list
        :param GroupIds:
          The IDs of the security groups. Required for security groups in a nondefault VPC.
          Default: Describes all your security groups.
          - *(string) --*
        :type GroupNames: list
        :param GroupNames:
          [EC2-Classic and default VPC only] The names of the security groups. You can specify either the security group name or the security group ID. For security groups in a nondefault VPC, use the ``group-name`` filter to describe security groups by name.
          Default: Describes all your security groups.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned ``NextToken`` value. This value can be between 5 and 1000. If this parameter is not specified, then all results are returned.
        :rtype: dict
        :returns:
        """
        pass

    def describe_snapshot_attribute(self, Attribute: str, SnapshotId: str, DryRun: bool = None) -> Dict:
        """
        Describes the specified attribute of the specified snapshot. You can specify only one attribute at a time.
        For more information about EBS snapshots, see `Amazon EBS Snapshots <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSnapshotAttribute>`_
        
        **Request Syntax**
        ::
          response = client.describe_snapshot_attribute(
              Attribute='productCodes'|'createVolumePermission',
              SnapshotId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'CreateVolumePermissions': [
                    {
                        'Group': 'all',
                        'UserId': 'string'
                    },
                ],
                'ProductCodes': [
                    {
                        'ProductCodeId': 'string',
                        'ProductCodeType': 'devpay'|'marketplace'
                    },
                ],
                'SnapshotId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeSnapshotAttribute.
            - **CreateVolumePermissions** *(list) --* 
              The users and groups that have the permissions for creating volumes from the snapshot.
              - *(dict) --* 
                Describes the user or group to be added or removed from the list of create volume permissions for a volume.
                - **Group** *(string) --* 
                  The group to be added or removed. The possible value is ``all`` .
                - **UserId** *(string) --* 
                  The AWS account ID to be added or removed.
            - **ProductCodes** *(list) --* 
              The product codes.
              - *(dict) --* 
                Describes a product code.
                - **ProductCodeId** *(string) --* 
                  The product code.
                - **ProductCodeType** *(string) --* 
                  The type of product code.
            - **SnapshotId** *(string) --* 
              The ID of the EBS snapshot.
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The snapshot attribute you would like to view.
        :type SnapshotId: string
        :param SnapshotId: **[REQUIRED]**
          The ID of the EBS snapshot.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_snapshots(self, Filters: List = None, MaxResults: int = None, NextToken: str = None, OwnerIds: List = None, RestorableByUserIds: List = None, SnapshotIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the specified EBS snapshots available to you or all of the EBS snapshots available to you.
        The snapshots available to you include public snapshots, private snapshots that you own, and private snapshots owned by other AWS accounts for which you have explicit create volume permissions.
        The create volume permissions fall into the following categories:
        * *public* : The owner of the snapshot granted create volume permissions for the snapshot to the ``all`` group. All AWS accounts have create volume permissions for these snapshots. 
        * *explicit* : The owner of the snapshot granted create volume permissions to a specific AWS account. 
        * *implicit* : An AWS account has implicit create volume permissions for all snapshots it owns. 
        The list of snapshots returned can be modified by specifying snapshot IDs, snapshot owners, or AWS accounts with create volume permissions. If no options are specified, Amazon EC2 returns all snapshots for which you have create volume permissions.
        If you specify one or more snapshot IDs, only snapshots that have the specified IDs are returned. If you specify an invalid snapshot ID, an error is returned. If you specify a snapshot ID for which you do not have access, it is not included in the returned results.
        If you specify one or more snapshot owners using the ``OwnerIds`` option, only snapshots from the specified owners and for which you have access are returned. The results can include the AWS account IDs of the specified owners, ``amazon`` for snapshots owned by Amazon, or ``self`` for snapshots that you own.
        If you specify a list of restorable users, only snapshots with create snapshot permissions for those users are returned. You can specify AWS account IDs (if you own the snapshots), ``self`` for snapshots for which you own or have explicit permissions, or ``all`` for public snapshots.
        If you are describing a long list of snapshots, you can paginate the output to make the list more manageable. The ``MaxResults`` parameter sets the maximum number of results returned in a single page. If the list of results exceeds your ``MaxResults`` value, then that number of results is returned along with a ``NextToken`` value that can be passed to a subsequent ``DescribeSnapshots`` request to retrieve the remaining results.
        For more information about EBS snapshots, see `Amazon EBS Snapshots <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSnapshots>`_
        
        **Request Syntax**
        ::
          response = client.describe_snapshots(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              OwnerIds=[
                  'string',
              ],
              RestorableByUserIds=[
                  'string',
              ],
              SnapshotIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Snapshots': [
                    {
                        'DataEncryptionKeyId': 'string',
                        'Description': 'string',
                        'Encrypted': True|False,
                        'KmsKeyId': 'string',
                        'OwnerId': 'string',
                        'Progress': 'string',
                        'SnapshotId': 'string',
                        'StartTime': datetime(2015, 1, 1),
                        'State': 'pending'|'completed'|'error',
                        'StateMessage': 'string',
                        'VolumeId': 'string',
                        'VolumeSize': 123,
                        'OwnerAlias': 'string',
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Snapshots** *(list) --* 
              Information about the snapshots.
              - *(dict) --* 
                Describes a snapshot.
                - **DataEncryptionKeyId** *(string) --* 
                  The data encryption key identifier for the snapshot. This value is a unique identifier that corresponds to the data encryption key that was used to encrypt the original volume or snapshot copy. Because data encryption keys are inherited by volumes created from snapshots, and vice versa, if snapshots share the same data encryption key identifier, then they belong to the same volume/snapshot lineage. This parameter is only returned by the  DescribeSnapshots API operation.
                - **Description** *(string) --* 
                  The description for the snapshot.
                - **Encrypted** *(boolean) --* 
                  Indicates whether the snapshot is encrypted.
                - **KmsKeyId** *(string) --* 
                  The full ARN of the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to protect the volume encryption key for the parent volume.
                - **OwnerId** *(string) --* 
                  The AWS account ID of the EBS snapshot owner.
                - **Progress** *(string) --* 
                  The progress of the snapshot, as a percentage.
                - **SnapshotId** *(string) --* 
                  The ID of the snapshot. Each snapshot receives a unique identifier when it is created.
                - **StartTime** *(datetime) --* 
                  The time stamp when the snapshot was initiated.
                - **State** *(string) --* 
                  The snapshot state.
                - **StateMessage** *(string) --* 
                  Encrypted Amazon EBS snapshots are copied asynchronously. If a snapshot copy operation fails (for example, if the proper AWS Key Management Service (AWS KMS) permissions are not obtained) this field displays error state details to help you diagnose why the error occurred. This parameter is only returned by the  DescribeSnapshots API operation.
                - **VolumeId** *(string) --* 
                  The ID of the volume that was used to create the snapshot. Snapshots created by the  CopySnapshot action have an arbitrary volume ID that should not be used for any purpose.
                - **VolumeSize** *(integer) --* 
                  The size of the volume, in GiB.
                - **OwnerAlias** *(string) --* 
                  Value from an Amazon-maintained list (``amazon`` | ``self`` | ``all`` | ``aws-marketplace`` | ``microsoft`` ) of snapshot owners. Not to be confused with the user-configured AWS account alias, which is set from the IAM console. 
                - **Tags** *(list) --* 
                  Any tags assigned to the snapshot.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The ``NextToken`` value to include in a future ``DescribeSnapshots`` request. When the results of a ``DescribeSnapshots`` request exceed ``MaxResults`` , this value can be used to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          The filters.
          * ``description`` - A description of the snapshot.
          * ``encrypted`` - Indicates whether the snapshot is encrypted (``true`` | ``false`` )
          * ``owner-alias`` - Value from an Amazon-maintained list (``amazon`` | ``self`` | ``all`` | ``aws-marketplace`` | ``microsoft`` ) of snapshot owners. Not to be confused with the user-configured AWS account alias, which is set from the IAM console.
          * ``owner-id`` - The ID of the AWS account that owns the snapshot.
          * ``progress`` - The progress of the snapshot, as a percentage (for example, 80%).
          * ``snapshot-id`` - The snapshot ID.
          * ``start-time`` - The time stamp when the snapshot was initiated.
          * ``status`` - The status of the snapshot (``pending`` | ``completed`` | ``error`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``volume-id`` - The ID of the volume the snapshot is for.
          * ``volume-size`` - The size of the volume, in GiB.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of snapshot results returned by ``DescribeSnapshots`` in paginated output. When this parameter is used, ``DescribeSnapshots`` only returns ``MaxResults`` results in a single page along with a ``NextToken`` response element. The remaining results of the initial request can be seen by sending another ``DescribeSnapshots`` request with the returned ``NextToken`` value. This value can be between 5 and 1000; if ``MaxResults`` is given a value larger than 1000, only 1000 results are returned. If this parameter is not used, then ``DescribeSnapshots`` returns all results. You cannot specify this parameter and the snapshot IDs parameter in the same request.
        :type NextToken: string
        :param NextToken:
          The ``NextToken`` value returned from a previous paginated ``DescribeSnapshots`` request where ``MaxResults`` was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the ``NextToken`` value. This value is ``null`` when there are no more results to return.
        :type OwnerIds: list
        :param OwnerIds:
          Describes the snapshots owned by these owners.
          - *(string) --*
        :type RestorableByUserIds: list
        :param RestorableByUserIds:
          The IDs of the AWS accounts that can create volumes from the snapshot.
          - *(string) --*
        :type SnapshotIds: list
        :param SnapshotIds:
          The snapshot IDs.
          Default: Describes the snapshots for which you have create volume permissions.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_spot_datafeed_subscription(self, DryRun: bool = None) -> Dict:
        """
        Describes the data feed for Spot Instances. For more information, see `Spot Instance Data Feed <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-data-feeds.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSpotDatafeedSubscription>`_
        
        **Request Syntax**
        ::
          response = client.describe_spot_datafeed_subscription(
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'SpotDatafeedSubscription': {
                    'Bucket': 'string',
                    'Fault': {
                        'Code': 'string',
                        'Message': 'string'
                    },
                    'OwnerId': 'string',
                    'Prefix': 'string',
                    'State': 'Active'|'Inactive'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeSpotDatafeedSubscription.
            - **SpotDatafeedSubscription** *(dict) --* 
              The Spot Instance data feed subscription.
              - **Bucket** *(string) --* 
                The Amazon S3 bucket where the Spot Instance data feed is located.
              - **Fault** *(dict) --* 
                The fault codes for the Spot Instance request, if any.
                - **Code** *(string) --* 
                  The reason code for the Spot Instance state change.
                - **Message** *(string) --* 
                  The message for the Spot Instance state change.
              - **OwnerId** *(string) --* 
                The AWS account ID of the account.
              - **Prefix** *(string) --* 
                The prefix that is prepended to data feed files.
              - **State** *(string) --* 
                The state of the Spot Instance data feed subscription.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_spot_fleet_instances(self, SpotFleetRequestId: str, DryRun: bool = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the running instances for the specified Spot Fleet.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSpotFleetInstances>`_
        
        **Request Syntax**
        ::
          response = client.describe_spot_fleet_instances(
              DryRun=True|False,
              MaxResults=123,
              NextToken='string',
              SpotFleetRequestId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ActiveInstances': [
                    {
                        'InstanceId': 'string',
                        'InstanceType': 'string',
                        'SpotInstanceRequestId': 'string',
                        'InstanceHealth': 'healthy'|'unhealthy'
                    },
                ],
                'NextToken': 'string',
                'SpotFleetRequestId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeSpotFleetInstances.
            - **ActiveInstances** *(list) --* 
              The running instances. This list is refreshed periodically and might be out of date.
              - *(dict) --* 
                Describes a running instance in a Spot Fleet.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **InstanceType** *(string) --* 
                  The instance type.
                - **SpotInstanceRequestId** *(string) --* 
                  The ID of the Spot Instance request.
                - **InstanceHealth** *(string) --* 
                  The health status of the instance. If the status of either the instance status check or the system status check is ``impaired`` , the health status of the instance is ``unhealthy`` . Otherwise, the health status is ``healthy`` .
            - **NextToken** *(string) --* 
              The token required to retrieve the next set of results. This value is ``null`` when there are no more results to return.
            - **SpotFleetRequestId** *(string) --* 
              The ID of the Spot Fleet request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type SpotFleetRequestId: string
        :param SpotFleetRequestId: **[REQUIRED]**
          The ID of the Spot Fleet request.
        :rtype: dict
        :returns:
        """
        pass

    def describe_spot_fleet_request_history(self, SpotFleetRequestId: str, StartTime: datetime, DryRun: bool = None, EventType: str = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the events for the specified Spot Fleet request during the specified time.
        Spot Fleet events are delayed by up to 30 seconds before they can be described. This ensures that you can query by the last evaluated time and not miss a recorded event. Spot Fleet events are available for 48 hours.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSpotFleetRequestHistory>`_
        
        **Request Syntax**
        ::
          response = client.describe_spot_fleet_request_history(
              DryRun=True|False,
              EventType='instanceChange'|'fleetRequestChange'|'error',
              MaxResults=123,
              NextToken='string',
              SpotFleetRequestId='string',
              StartTime=datetime(2015, 1, 1)
          )
        
        **Response Syntax**
        ::
            {
                'HistoryRecords': [
                    {
                        'EventInformation': {
                            'EventDescription': 'string',
                            'EventSubType': 'string',
                            'InstanceId': 'string'
                        },
                        'EventType': 'instanceChange'|'fleetRequestChange'|'error',
                        'Timestamp': datetime(2015, 1, 1)
                    },
                ],
                'LastEvaluatedTime': datetime(2015, 1, 1),
                'NextToken': 'string',
                'SpotFleetRequestId': 'string',
                'StartTime': datetime(2015, 1, 1)
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeSpotFleetRequestHistory.
            - **HistoryRecords** *(list) --* 
              Information about the events in the history of the Spot Fleet request.
              - *(dict) --* 
                Describes an event in the history of the Spot Fleet request.
                - **EventInformation** *(dict) --* 
                  Information about the event.
                  - **EventDescription** *(string) --* 
                    The description of the event.
                  - **EventSubType** *(string) --* 
                    The event.
                    The following are the ``error`` events:
                    * ``iamFleetRoleInvalid`` - The EC2 Fleet or Spot Fleet did not have the required permissions either to launch or terminate an instance. 
                    * ``spotFleetRequestConfigurationInvalid`` - The configuration is not valid. For more information, see the description of the event. 
                    * ``spotInstanceCountLimitExceeded`` - You've reached the limit on the number of Spot Instances that you can launch. 
                    The following are the ``fleetRequestChange`` events:
                    * ``active`` - The EC2 Fleet or Spot Fleet request has been validated and Amazon EC2 is attempting to maintain the target number of running Spot Instances. 
                    * ``cancelled`` - The EC2 Fleet or Spot Fleet request is canceled and has no running Spot Instances. The EC2 Fleet or Spot Fleet will be deleted two days after its instances were terminated. 
                    * ``cancelled_running`` - The EC2 Fleet or Spot Fleet request is canceled and does not launch additional Spot Instances. Existing Spot Instances continue to run until they are interrupted or terminated. 
                    * ``cancelled_terminating`` - The EC2 Fleet or Spot Fleet request is canceled and its Spot Instances are terminating. 
                    * ``expired`` - The EC2 Fleet or Spot Fleet request has expired. A subsequent event indicates that the instances were terminated, if the request was created with ``TerminateInstancesWithExpiration`` set. 
                    * ``modify_in_progress`` - A request to modify the EC2 Fleet or Spot Fleet request was accepted and is in progress. 
                    * ``modify_successful`` - The EC2 Fleet or Spot Fleet request was modified. 
                    * ``price_update`` - The price for a launch configuration was adjusted because it was too high. This change is permanent. 
                    * ``submitted`` - The EC2 Fleet or Spot Fleet request is being evaluated and Amazon EC2 is preparing to launch the target number of Spot Instances. 
                    The following are the ``instanceChange`` events:
                    * ``launched`` - A request was fulfilled and a new instance was launched. 
                    * ``terminated`` - An instance was terminated by the user. 
                    The following are the ``Information`` events:
                    * ``launchSpecTemporarilyBlacklisted`` - The configuration is not valid and several attempts to launch instances have failed. For more information, see the description of the event. 
                    * ``launchSpecUnusable`` - The price in a launch specification is not valid because it is below the Spot price or the Spot price is above the On-Demand price. 
                    * ``fleetProgressHalted`` - The price in every launch specification is not valid. A launch specification might become valid if the Spot price changes. 
                  - **InstanceId** *(string) --* 
                    The ID of the instance. This information is available only for ``instanceChange`` events.
                - **EventType** *(string) --* 
                  The event type.
                  * ``error`` - An error with the Spot Fleet request. 
                  * ``fleetRequestChange`` - A change in the status or configuration of the Spot Fleet request. 
                  * ``instanceChange`` - An instance was launched or terminated. 
                  * ``Information`` - An informational event. 
                - **Timestamp** *(datetime) --* 
                  The date and time of the event, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
            - **LastEvaluatedTime** *(datetime) --* 
              The last date and time for the events, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). All records up to this time were retrieved.
              If ``nextToken`` indicates that there are more results, this value is not present.
            - **NextToken** *(string) --* 
              The token required to retrieve the next set of results. This value is ``null`` when there are no more results to return.
            - **SpotFleetRequestId** *(string) --* 
              The ID of the Spot Fleet request.
            - **StartTime** *(datetime) --* 
              The starting date and time for the events, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EventType: string
        :param EventType:
          The type of events to describe. By default, all events are described.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type SpotFleetRequestId: string
        :param SpotFleetRequestId: **[REQUIRED]**
          The ID of the Spot Fleet request.
        :type StartTime: datetime
        :param StartTime: **[REQUIRED]**
          The starting date and time for the events, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
        :rtype: dict
        :returns:
        """
        pass

    def describe_spot_fleet_requests(self, DryRun: bool = None, MaxResults: int = None, NextToken: str = None, SpotFleetRequestIds: List = None) -> Dict:
        """
        Describes your Spot Fleet requests.
        Spot Fleet requests are deleted 48 hours after they are canceled and their instances are terminated.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSpotFleetRequests>`_
        
        **Request Syntax**
        ::
          response = client.describe_spot_fleet_requests(
              DryRun=True|False,
              MaxResults=123,
              NextToken='string',
              SpotFleetRequestIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'SpotFleetRequestConfigs': [
                    {
                        'ActivityStatus': 'error'|'pending_fulfillment'|'pending_termination'|'fulfilled',
                        'CreateTime': datetime(2015, 1, 1),
                        'SpotFleetRequestConfig': {
                            'AllocationStrategy': 'lowestPrice'|'diversified',
                            'OnDemandAllocationStrategy': 'lowestPrice'|'prioritized',
                            'ClientToken': 'string',
                            'ExcessCapacityTerminationPolicy': 'noTermination'|'default',
                            'FulfilledCapacity': 123.0,
                            'OnDemandFulfilledCapacity': 123.0,
                            'IamFleetRole': 'string',
                            'LaunchSpecifications': [
                                {
                                    'SecurityGroups': [
                                        {
                                            'GroupName': 'string',
                                            'GroupId': 'string'
                                        },
                                    ],
                                    'AddressingType': 'string',
                                    'BlockDeviceMappings': [
                                        {
                                            'DeviceName': 'string',
                                            'VirtualName': 'string',
                                            'Ebs': {
                                                'DeleteOnTermination': True|False,
                                                'Iops': 123,
                                                'SnapshotId': 'string',
                                                'VolumeSize': 123,
                                                'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                                                'Encrypted': True|False,
                                                'KmsKeyId': 'string'
                                            },
                                            'NoDevice': 'string'
                                        },
                                    ],
                                    'EbsOptimized': True|False,
                                    'IamInstanceProfile': {
                                        'Arn': 'string',
                                        'Name': 'string'
                                    },
                                    'ImageId': 'string',
                                    'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                    'KernelId': 'string',
                                    'KeyName': 'string',
                                    'Monitoring': {
                                        'Enabled': True|False
                                    },
                                    'NetworkInterfaces': [
                                        {
                                            'AssociatePublicIpAddress': True|False,
                                            'DeleteOnTermination': True|False,
                                            'Description': 'string',
                                            'DeviceIndex': 123,
                                            'Groups': [
                                                'string',
                                            ],
                                            'Ipv6AddressCount': 123,
                                            'Ipv6Addresses': [
                                                {
                                                    'Ipv6Address': 'string'
                                                },
                                            ],
                                            'NetworkInterfaceId': 'string',
                                            'PrivateIpAddress': 'string',
                                            'PrivateIpAddresses': [
                                                {
                                                    'Primary': True|False,
                                                    'PrivateIpAddress': 'string'
                                                },
                                            ],
                                            'SecondaryPrivateIpAddressCount': 123,
                                            'SubnetId': 'string',
                                            'InterfaceType': 'string'
                                        },
                                    ],
                                    'Placement': {
                                        'AvailabilityZone': 'string',
                                        'GroupName': 'string',
                                        'Tenancy': 'default'|'dedicated'|'host'
                                    },
                                    'RamdiskId': 'string',
                                    'SpotPrice': 'string',
                                    'SubnetId': 'string',
                                    'UserData': 'string',
                                    'WeightedCapacity': 123.0,
                                    'TagSpecifications': [
                                        {
                                            'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                                            'Tags': [
                                                {
                                                    'Key': 'string',
                                                    'Value': 'string'
                                                },
                                            ]
                                        },
                                    ]
                                },
                            ],
                            'LaunchTemplateConfigs': [
                                {
                                    'LaunchTemplateSpecification': {
                                        'LaunchTemplateId': 'string',
                                        'LaunchTemplateName': 'string',
                                        'Version': 'string'
                                    },
                                    'Overrides': [
                                        {
                                            'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                            'SpotPrice': 'string',
                                            'SubnetId': 'string',
                                            'AvailabilityZone': 'string',
                                            'WeightedCapacity': 123.0,
                                            'Priority': 123.0
                                        },
                                    ]
                                },
                            ],
                            'SpotPrice': 'string',
                            'TargetCapacity': 123,
                            'OnDemandTargetCapacity': 123,
                            'TerminateInstancesWithExpiration': True|False,
                            'Type': 'request'|'maintain'|'instant',
                            'ValidFrom': datetime(2015, 1, 1),
                            'ValidUntil': datetime(2015, 1, 1),
                            'ReplaceUnhealthyInstances': True|False,
                            'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate',
                            'LoadBalancersConfig': {
                                'ClassicLoadBalancersConfig': {
                                    'ClassicLoadBalancers': [
                                        {
                                            'Name': 'string'
                                        },
                                    ]
                                },
                                'TargetGroupsConfig': {
                                    'TargetGroups': [
                                        {
                                            'Arn': 'string'
                                        },
                                    ]
                                }
                            },
                            'InstancePoolsToUseCount': 123
                        },
                        'SpotFleetRequestId': 'string',
                        'SpotFleetRequestState': 'submitted'|'active'|'cancelled'|'failed'|'cancelled_running'|'cancelled_terminating'|'modifying'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeSpotFleetRequests.
            - **NextToken** *(string) --* 
              The token required to retrieve the next set of results. This value is ``null`` when there are no more results to return.
            - **SpotFleetRequestConfigs** *(list) --* 
              Information about the configuration of your Spot Fleet.
              - *(dict) --* 
                Describes a Spot Fleet request.
                - **ActivityStatus** *(string) --* 
                  The progress of the Spot Fleet request. If there is an error, the status is ``error`` . After all requests are placed, the status is ``pending_fulfillment`` . If the size of the fleet is equal to or greater than its target capacity, the status is ``fulfilled`` . If the size of the fleet is decreased, the status is ``pending_termination`` while Spot Instances are terminating.
                - **CreateTime** *(datetime) --* 
                  The creation date and time of the request.
                - **SpotFleetRequestConfig** *(dict) --* 
                  The configuration of the Spot Fleet request.
                  - **AllocationStrategy** *(string) --* 
                    Indicates how to allocate the target capacity across the Spot pools specified by the Spot Fleet request. The default is ``lowestPrice`` .
                  - **OnDemandAllocationStrategy** *(string) --* 
                    The order of the launch template overrides to use in fulfilling On-Demand capacity. If you specify ``lowestPrice`` , Spot Fleet uses price to determine the order, launching the lowest price first. If you specify ``prioritized`` , Spot Fleet uses the priority that you assign to each Spot Fleet launch template override, launching the highest priority first. If you do not specify a value, Spot Fleet defaults to ``lowestPrice`` .
                  - **ClientToken** *(string) --* 
                    A unique, case-sensitive identifier that you provide to ensure the idempotency of your listings. This helps to avoid duplicate listings. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
                  - **ExcessCapacityTerminationPolicy** *(string) --* 
                    Indicates whether running Spot Instances should be terminated if the target capacity of the Spot Fleet request is decreased below the current size of the Spot Fleet.
                  - **FulfilledCapacity** *(float) --* 
                    The number of units fulfilled by this request compared to the set target capacity. You cannot set this value.
                  - **OnDemandFulfilledCapacity** *(float) --* 
                    The number of On-Demand units fulfilled by this request compared to the set target On-Demand capacity.
                  - **IamFleetRole** *(string) --* 
                    Grants the Spot Fleet permission to terminate Spot Instances on your behalf when you cancel its Spot Fleet request using  CancelSpotFleetRequests or when the Spot Fleet request expires, if you set ``terminateInstancesWithExpiration`` .
                  - **LaunchSpecifications** *(list) --* 
                    The launch specifications for the Spot Fleet request. If you specify ``LaunchSpecifications`` , you can't specify ``LaunchTemplateConfigs`` .
                    - *(dict) --* 
                      Describes the launch specification for one or more Spot Instances.
                      - **SecurityGroups** *(list) --* 
                        One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
                        - *(dict) --* 
                          Describes a security group.
                          - **GroupName** *(string) --* 
                            The name of the security group.
                          - **GroupId** *(string) --* 
                            The ID of the security group.
                      - **AddressingType** *(string) --* 
                        Deprecated.
                      - **BlockDeviceMappings** *(list) --* 
                        One or more block device mapping entries. You can't specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
                        - *(dict) --* 
                          Describes a block device mapping.
                          - **DeviceName** *(string) --* 
                            The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                          - **VirtualName** *(string) --* 
                            The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                            NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
                            Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
                          - **Ebs** *(dict) --* 
                            Parameters used to automatically set up EBS volumes when the instance is launched.
                            - **DeleteOnTermination** *(boolean) --* 
                              Indicates whether the EBS volume is deleted on instance termination.
                            - **Iops** *(integer) --* 
                              The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                              Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                              Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                            - **SnapshotId** *(string) --* 
                              The ID of the snapshot.
                            - **VolumeSize** *(integer) --* 
                              The size of the volume, in GiB.
                              Default: If you're creating the volume from a snapshot and don't specify a volume size, the default is the snapshot size.
                              Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
                            - **VolumeType** *(string) --* 
                              The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                              Default: ``standard``  
                            - **Encrypted** *(boolean) --* 
                              Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                              If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
                            - **KmsKeyId** *(string) --* 
                              Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                              This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
                          - **NoDevice** *(string) --* 
                            Suppresses the specified device included in the block device mapping of the AMI.
                      - **EbsOptimized** *(boolean) --* 
                        Indicates whether the instances are optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
                        Default: ``false``  
                      - **IamInstanceProfile** *(dict) --* 
                        The IAM instance profile.
                        - **Arn** *(string) --* 
                          The Amazon Resource Name (ARN) of the instance profile.
                        - **Name** *(string) --* 
                          The name of the instance profile.
                      - **ImageId** *(string) --* 
                        The ID of the AMI.
                      - **InstanceType** *(string) --* 
                        The instance type.
                      - **KernelId** *(string) --* 
                        The ID of the kernel.
                      - **KeyName** *(string) --* 
                        The name of the key pair.
                      - **Monitoring** *(dict) --* 
                        Enable or disable monitoring for the instances.
                        - **Enabled** *(boolean) --* 
                          Enables monitoring for the instance.
                          Default: ``false``  
                      - **NetworkInterfaces** *(list) --* 
                        One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
                        - *(dict) --* 
                          Describes a network interface.
                          - **AssociatePublicIpAddress** *(boolean) --* 
                            Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ``true`` .
                          - **DeleteOnTermination** *(boolean) --* 
                            If set to ``true`` , the interface is deleted when the instance is terminated. You can specify ``true`` only if creating a new network interface when launching an instance.
                          - **Description** *(string) --* 
                            The description of the network interface. Applies only if creating a network interface when launching an instance.
                          - **DeviceIndex** *(integer) --* 
                            The index of the device on the instance for the network interface attachment. If you are specifying a network interface in a  RunInstances request, you must provide the device index.
                          - **Groups** *(list) --* 
                            The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
                            - *(string) --* 
                          - **Ipv6AddressCount** *(integer) --* 
                            A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you've specified a minimum number of instances to launch.
                          - **Ipv6Addresses** *(list) --* 
                            One or more IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you've specified a minimum number of instances to launch.
                            - *(dict) --* 
                              Describes an IPv6 address.
                              - **Ipv6Address** *(string) --* 
                                The IPv6 address.
                          - **NetworkInterfaceId** *(string) --* 
                            The ID of the network interface.
                          - **PrivateIpAddress** *(string) --* 
                            The private IPv4 address of the network interface. Applies only if creating a network interface when launching an instance. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                          - **PrivateIpAddresses** *(list) --* 
                            One or more private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                            - *(dict) --* 
                              Describes a secondary private IPv4 address for a network interface.
                              - **Primary** *(boolean) --* 
                                Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                              - **PrivateIpAddress** *(string) --* 
                                The private IPv4 addresses.
                          - **SecondaryPrivateIpAddressCount** *(integer) --* 
                            The number of secondary private IPv4 addresses. You can't specify this option and specify more than one private IP address using the private IP addresses option. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                          - **SubnetId** *(string) --* 
                            The ID of the subnet associated with the network string. Applies only if creating a network interface when launching an instance.
                          - **InterfaceType** *(string) --* 
                            The type of interface.
                      - **Placement** *(dict) --* 
                        The placement information.
                        - **AvailabilityZone** *(string) --* 
                          The Availability Zone.
                          [Spot Fleet only] To specify multiple Availability Zones, separate them using commas; for example, "us-west-2a, us-west-2b".
                        - **GroupName** *(string) --* 
                          The name of the placement group.
                        - **Tenancy** *(string) --* 
                          The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for Spot Instances.
                      - **RamdiskId** *(string) --* 
                        The ID of the RAM disk.
                      - **SpotPrice** *(string) --* 
                        The maximum price per unit hour that you are willing to pay for a Spot Instance. If this value is not specified, the default is the Spot price specified for the fleet. To determine the Spot price per unit hour, divide the Spot price by the value of ``WeightedCapacity`` .
                      - **SubnetId** *(string) --* 
                        The ID of the subnet in which to launch the instances. To specify multiple subnets, separate them using commas; for example, "subnet-a61dafcf, subnet-65ea5f08".
                      - **UserData** *(string) --* 
                        The Base64-encoded user data to make available to the instances.
                      - **WeightedCapacity** *(float) --* 
                        The number of units provided by the specified instance type. These are the same units that you chose to set the target capacity in terms (instances or a performance characteristic such as vCPUs, memory, or I/O).
                        If the target capacity divided by this value is not a whole number, we round the number of instances to the next whole number. If this value is not specified, the default is 1.
                      - **TagSpecifications** *(list) --* 
                        The tags to apply during creation.
                        - *(dict) --* 
                          The tags for a Spot Fleet resource.
                          - **ResourceType** *(string) --* 
                            The type of resource. Currently, the only resource type that is supported is ``instance`` .
                          - **Tags** *(list) --* 
                            The tags.
                            - *(dict) --* 
                              Describes a tag.
                              - **Key** *(string) --* 
                                The key of the tag.
                                Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                              - **Value** *(string) --* 
                                The value of the tag.
                                Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                  - **LaunchTemplateConfigs** *(list) --* 
                    The launch template and overrides. If you specify ``LaunchTemplateConfigs`` , you can't specify ``LaunchSpecifications`` .
                    - *(dict) --* 
                      Describes a launch template and overrides.
                      - **LaunchTemplateSpecification** *(dict) --* 
                        The launch template.
                        - **LaunchTemplateId** *(string) --* 
                          The ID of the launch template. You must specify either a template ID or a template name.
                        - **LaunchTemplateName** *(string) --* 
                          The name of the launch template. You must specify either a template name or a template ID.
                        - **Version** *(string) --* 
                          The version number of the launch template. You must specify a version number.
                      - **Overrides** *(list) --* 
                        Any parameters that you specify override the same parameters in the launch template.
                        - *(dict) --* 
                          Describes overrides for a launch template.
                          - **InstanceType** *(string) --* 
                            The instance type.
                          - **SpotPrice** *(string) --* 
                            The maximum price per unit hour that you are willing to pay for a Spot Instance.
                          - **SubnetId** *(string) --* 
                            The ID of the subnet in which to launch the instances.
                          - **AvailabilityZone** *(string) --* 
                            The Availability Zone in which to launch the instances.
                          - **WeightedCapacity** *(float) --* 
                            The number of units provided by the specified instance type.
                          - **Priority** *(float) --* 
                            The priority for the launch template override. If **OnDemandAllocationStrategy** is set to ``prioritized`` , Spot Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority.
                  - **SpotPrice** *(string) --* 
                    The maximum price per unit hour that you are willing to pay for a Spot Instance. The default is the On-Demand price.
                  - **TargetCapacity** *(integer) --* 
                    The number of units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is ``maintain`` , you can specify a target capacity of 0 and add capacity later.
                  - **OnDemandTargetCapacity** *(integer) --* 
                    The number of On-Demand units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is ``maintain`` , you can specify a target capacity of 0 and add capacity later.
                  - **TerminateInstancesWithExpiration** *(boolean) --* 
                    Indicates whether running Spot Instances should be terminated when the Spot Fleet request expires.
                  - **Type** *(string) --* 
                    The type of request. Indicates whether the Spot Fleet only requests the target capacity or also attempts to maintain it. When this value is ``request`` , the Spot Fleet only places the required requests. It does not attempt to replenish Spot Instances if capacity is diminished, nor does it submit requests in alternative Spot pools if capacity is not available. When this value is ``maintain`` , the Spot Fleet maintains the target capacity. The Spot Fleet places the required requests to meet capacity and automatically replenishes any interrupted instances. Default: ``maintain`` . ``instant`` is listed but is not used by Spot Fleet.
                  - **ValidFrom** *(datetime) --* 
                    The start date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). The default is to start fulfilling the request immediately.
                  - **ValidUntil** *(datetime) --* 
                    The end date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). At this point, no new Spot Instance requests are placed or able to fulfill the request. If no value is specified, the Spot Fleet request remains until you cancel it.
                  - **ReplaceUnhealthyInstances** *(boolean) --* 
                    Indicates whether Spot Fleet should replace unhealthy instances.
                  - **InstanceInterruptionBehavior** *(string) --* 
                    The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
                  - **LoadBalancersConfig** *(dict) --* 
                    One or more Classic Load Balancers and target groups to attach to the Spot Fleet request. Spot Fleet registers the running Spot Instances with the specified Classic Load Balancers and target groups.
                    With Network Load Balancers, Spot Fleet cannot register instances that have the following instance types: C1, CC1, CC2, CG1, CG2, CR1, CS1, G1, G2, HI1, HS1, M1, M2, M3, and T1.
                    - **ClassicLoadBalancersConfig** *(dict) --* 
                      The Classic Load Balancers.
                      - **ClassicLoadBalancers** *(list) --* 
                        One or more Classic Load Balancers.
                        - *(dict) --* 
                          Describes a Classic Load Balancer.
                          - **Name** *(string) --* 
                            The name of the load balancer.
                    - **TargetGroupsConfig** *(dict) --* 
                      The target groups.
                      - **TargetGroups** *(list) --* 
                        One or more target groups.
                        - *(dict) --* 
                          Describes a load balancer target group.
                          - **Arn** *(string) --* 
                            The Amazon Resource Name (ARN) of the target group.
                  - **InstancePoolsToUseCount** *(integer) --* 
                    The number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot **AllocationStrategy** is set to ``lowest-price`` . Spot Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify.
                - **SpotFleetRequestId** *(string) --* 
                  The ID of the Spot Fleet request.
                - **SpotFleetRequestState** *(string) --* 
                  The state of the Spot Fleet request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type SpotFleetRequestIds: list
        :param SpotFleetRequestIds:
          The IDs of the Spot Fleet requests.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_spot_instance_requests(self, Filters: List = None, DryRun: bool = None, SpotInstanceRequestIds: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes the specified Spot Instance requests.
        You can use ``DescribeSpotInstanceRequests`` to find a running Spot Instance by examining the response. If the status of the Spot Instance is ``fulfilled`` , the instance ID appears in the response and contains the identifier of the instance. Alternatively, you can use  DescribeInstances with a filter to look for instances where the instance lifecycle is ``spot`` .
        We recommend that you set ``MaxResults`` to a value between 5 and 1000 to limit the number of results returned. This paginates the output, which makes the list more manageable and returns the results faster. If the list of results exceeds your ``MaxResults`` value, then that number of results is returned along with a ``NextToken`` value that can be passed to a subsequent ``DescribeSpotInstanceRequests`` request to retrieve the remaining results.
        Spot Instance requests are deleted four hours after they are canceled and their instances are terminated.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSpotInstanceRequests>`_
        
        **Request Syntax**
        ::
          response = client.describe_spot_instance_requests(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              SpotInstanceRequestIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'SpotInstanceRequests': [
                    {
                        'ActualBlockHourlyPrice': 'string',
                        'AvailabilityZoneGroup': 'string',
                        'BlockDurationMinutes': 123,
                        'CreateTime': datetime(2015, 1, 1),
                        'Fault': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'InstanceId': 'string',
                        'LaunchGroup': 'string',
                        'LaunchSpecification': {
                            'UserData': 'string',
                            'SecurityGroups': [
                                {
                                    'GroupName': 'string',
                                    'GroupId': 'string'
                                },
                            ],
                            'AddressingType': 'string',
                            'BlockDeviceMappings': [
                                {
                                    'DeviceName': 'string',
                                    'VirtualName': 'string',
                                    'Ebs': {
                                        'DeleteOnTermination': True|False,
                                        'Iops': 123,
                                        'SnapshotId': 'string',
                                        'VolumeSize': 123,
                                        'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                                        'Encrypted': True|False,
                                        'KmsKeyId': 'string'
                                    },
                                    'NoDevice': 'string'
                                },
                            ],
                            'EbsOptimized': True|False,
                            'IamInstanceProfile': {
                                'Arn': 'string',
                                'Name': 'string'
                            },
                            'ImageId': 'string',
                            'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                            'KernelId': 'string',
                            'KeyName': 'string',
                            'NetworkInterfaces': [
                                {
                                    'AssociatePublicIpAddress': True|False,
                                    'DeleteOnTermination': True|False,
                                    'Description': 'string',
                                    'DeviceIndex': 123,
                                    'Groups': [
                                        'string',
                                    ],
                                    'Ipv6AddressCount': 123,
                                    'Ipv6Addresses': [
                                        {
                                            'Ipv6Address': 'string'
                                        },
                                    ],
                                    'NetworkInterfaceId': 'string',
                                    'PrivateIpAddress': 'string',
                                    'PrivateIpAddresses': [
                                        {
                                            'Primary': True|False,
                                            'PrivateIpAddress': 'string'
                                        },
                                    ],
                                    'SecondaryPrivateIpAddressCount': 123,
                                    'SubnetId': 'string',
                                    'InterfaceType': 'string'
                                },
                            ],
                            'Placement': {
                                'AvailabilityZone': 'string',
                                'GroupName': 'string',
                                'Tenancy': 'default'|'dedicated'|'host'
                            },
                            'RamdiskId': 'string',
                            'SubnetId': 'string',
                            'Monitoring': {
                                'Enabled': True|False
                            }
                        },
                        'LaunchedAvailabilityZone': 'string',
                        'ProductDescription': 'Linux/UNIX'|'Linux/UNIX (Amazon VPC)'|'Windows'|'Windows (Amazon VPC)',
                        'SpotInstanceRequestId': 'string',
                        'SpotPrice': 'string',
                        'State': 'open'|'active'|'closed'|'cancelled'|'failed',
                        'Status': {
                            'Code': 'string',
                            'Message': 'string',
                            'UpdateTime': datetime(2015, 1, 1)
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'Type': 'one-time'|'persistent',
                        'ValidFrom': datetime(2015, 1, 1),
                        'ValidUntil': datetime(2015, 1, 1),
                        'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeSpotInstanceRequests.
            - **SpotInstanceRequests** *(list) --* 
              One or more Spot Instance requests.
              - *(dict) --* 
                Describes a Spot Instance request.
                - **ActualBlockHourlyPrice** *(string) --* 
                  If you specified a duration and your Spot Instance request was fulfilled, this is the fixed hourly price in effect for the Spot Instance while it runs.
                - **AvailabilityZoneGroup** *(string) --* 
                  The Availability Zone group. If you specify the same Availability Zone group for all Spot Instance requests, all Spot Instances are launched in the same Availability Zone.
                - **BlockDurationMinutes** *(integer) --* 
                  The duration for the Spot Instance, in minutes.
                - **CreateTime** *(datetime) --* 
                  The date and time when the Spot Instance request was created, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
                - **Fault** *(dict) --* 
                  The fault codes for the Spot Instance request, if any.
                  - **Code** *(string) --* 
                    The reason code for the Spot Instance state change.
                  - **Message** *(string) --* 
                    The message for the Spot Instance state change.
                - **InstanceId** *(string) --* 
                  The instance ID, if an instance has been launched to fulfill the Spot Instance request.
                - **LaunchGroup** *(string) --* 
                  The instance launch group. Launch groups are Spot Instances that launch together and terminate together.
                - **LaunchSpecification** *(dict) --* 
                  Additional information for launching instances.
                  - **UserData** *(string) --* 
                    The Base64-encoded user data for the instance.
                  - **SecurityGroups** *(list) --* 
                    One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
                    - *(dict) --* 
                      Describes a security group.
                      - **GroupName** *(string) --* 
                        The name of the security group.
                      - **GroupId** *(string) --* 
                        The ID of the security group.
                  - **AddressingType** *(string) --* 
                    Deprecated.
                  - **BlockDeviceMappings** *(list) --* 
                    One or more block device mapping entries.
                    - *(dict) --* 
                      Describes a block device mapping.
                      - **DeviceName** *(string) --* 
                        The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                      - **VirtualName** *(string) --* 
                        The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                        NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
                        Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
                      - **Ebs** *(dict) --* 
                        Parameters used to automatically set up EBS volumes when the instance is launched.
                        - **DeleteOnTermination** *(boolean) --* 
                          Indicates whether the EBS volume is deleted on instance termination.
                        - **Iops** *(integer) --* 
                          The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                          Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                          Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                        - **SnapshotId** *(string) --* 
                          The ID of the snapshot.
                        - **VolumeSize** *(integer) --* 
                          The size of the volume, in GiB.
                          Default: If you're creating the volume from a snapshot and don't specify a volume size, the default is the snapshot size.
                          Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
                        - **VolumeType** *(string) --* 
                          The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                          Default: ``standard``  
                        - **Encrypted** *(boolean) --* 
                          Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                          If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
                        - **KmsKeyId** *(string) --* 
                          Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                          This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
                      - **NoDevice** *(string) --* 
                        Suppresses the specified device included in the block device mapping of the AMI.
                  - **EbsOptimized** *(boolean) --* 
                    Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
                    Default: ``false``  
                  - **IamInstanceProfile** *(dict) --* 
                    The IAM instance profile.
                    - **Arn** *(string) --* 
                      The Amazon Resource Name (ARN) of the instance profile.
                    - **Name** *(string) --* 
                      The name of the instance profile.
                  - **ImageId** *(string) --* 
                    The ID of the AMI.
                  - **InstanceType** *(string) --* 
                    The instance type.
                  - **KernelId** *(string) --* 
                    The ID of the kernel.
                  - **KeyName** *(string) --* 
                    The name of the key pair.
                  - **NetworkInterfaces** *(list) --* 
                    One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
                    - *(dict) --* 
                      Describes a network interface.
                      - **AssociatePublicIpAddress** *(boolean) --* 
                        Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ``true`` .
                      - **DeleteOnTermination** *(boolean) --* 
                        If set to ``true`` , the interface is deleted when the instance is terminated. You can specify ``true`` only if creating a new network interface when launching an instance.
                      - **Description** *(string) --* 
                        The description of the network interface. Applies only if creating a network interface when launching an instance.
                      - **DeviceIndex** *(integer) --* 
                        The index of the device on the instance for the network interface attachment. If you are specifying a network interface in a  RunInstances request, you must provide the device index.
                      - **Groups** *(list) --* 
                        The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
                        - *(string) --* 
                      - **Ipv6AddressCount** *(integer) --* 
                        A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you've specified a minimum number of instances to launch.
                      - **Ipv6Addresses** *(list) --* 
                        One or more IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you've specified a minimum number of instances to launch.
                        - *(dict) --* 
                          Describes an IPv6 address.
                          - **Ipv6Address** *(string) --* 
                            The IPv6 address.
                      - **NetworkInterfaceId** *(string) --* 
                        The ID of the network interface.
                      - **PrivateIpAddress** *(string) --* 
                        The private IPv4 address of the network interface. Applies only if creating a network interface when launching an instance. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                      - **PrivateIpAddresses** *(list) --* 
                        One or more private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                        - *(dict) --* 
                          Describes a secondary private IPv4 address for a network interface.
                          - **Primary** *(boolean) --* 
                            Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                          - **PrivateIpAddress** *(string) --* 
                            The private IPv4 addresses.
                      - **SecondaryPrivateIpAddressCount** *(integer) --* 
                        The number of secondary private IPv4 addresses. You can't specify this option and specify more than one private IP address using the private IP addresses option. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                      - **SubnetId** *(string) --* 
                        The ID of the subnet associated with the network string. Applies only if creating a network interface when launching an instance.
                      - **InterfaceType** *(string) --* 
                        The type of interface.
                  - **Placement** *(dict) --* 
                    The placement information for the instance.
                    - **AvailabilityZone** *(string) --* 
                      The Availability Zone.
                      [Spot Fleet only] To specify multiple Availability Zones, separate them using commas; for example, "us-west-2a, us-west-2b".
                    - **GroupName** *(string) --* 
                      The name of the placement group.
                    - **Tenancy** *(string) --* 
                      The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for Spot Instances.
                  - **RamdiskId** *(string) --* 
                    The ID of the RAM disk.
                  - **SubnetId** *(string) --* 
                    The ID of the subnet in which to launch the instance.
                  - **Monitoring** *(dict) --* 
                    Describes the monitoring of an instance.
                    - **Enabled** *(boolean) --* 
                      Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
                - **LaunchedAvailabilityZone** *(string) --* 
                  The Availability Zone in which the request is launched.
                - **ProductDescription** *(string) --* 
                  The product description associated with the Spot Instance.
                - **SpotInstanceRequestId** *(string) --* 
                  The ID of the Spot Instance request.
                - **SpotPrice** *(string) --* 
                  The maximum price per hour that you are willing to pay for a Spot Instance.
                - **State** *(string) --* 
                  The state of the Spot Instance request. Spot status information helps track your Spot Instance requests. For more information, see `Spot Status <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-bid-status.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
                - **Status** *(dict) --* 
                  The status code and status message describing the Spot Instance request.
                  - **Code** *(string) --* 
                    The status code. For a list of status codes, see `Spot Status Codes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-bid-status.html#spot-instance-bid-status-understand>`__ in the *Amazon EC2 User Guide for Linux Instances* .
                  - **Message** *(string) --* 
                    The description for the status code.
                  - **UpdateTime** *(datetime) --* 
                    The date and time of the most recent status update, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
                - **Tags** *(list) --* 
                  Any tags assigned to the resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **Type** *(string) --* 
                  The Spot Instance request type.
                - **ValidFrom** *(datetime) --* 
                  The start date of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). The request becomes active at this date and time.
                - **ValidUntil** *(datetime) --* 
                  The end date of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). If this is a one-time request, it remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date is reached. The default end date is 7 days from the current date.
                - **InstanceInterruptionBehavior** *(string) --* 
                  The behavior when a Spot Instance is interrupted.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next set of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``availability-zone-group`` - The Availability Zone group.
          * ``create-time`` - The time stamp when the Spot Instance request was created.
          * ``fault-code`` - The fault code related to the request.
          * ``fault-message`` - The fault message related to the request.
          * ``instance-id`` - The ID of the instance that fulfilled the request.
          * ``launch-group`` - The Spot Instance launch group.
          * ``launch.block-device-mapping.delete-on-termination`` - Indicates whether the EBS volume is deleted on instance termination.
          * ``launch.block-device-mapping.device-name`` - The device name for the volume in the block device mapping (for example, ``/dev/sdh`` or ``xvdh`` ).
          * ``launch.block-device-mapping.snapshot-id`` - The ID of the snapshot for the EBS volume.
          * ``launch.block-device-mapping.volume-size`` - The size of the EBS volume, in GiB.
          * ``launch.block-device-mapping.volume-type`` - The type of EBS volume: ``gp2`` for General Purpose SSD, ``io1`` for Provisioned IOPS SSD, ``st1`` for Throughput Optimized HDD, ``sc1`` for Cold HDD, or ``standard`` for Magnetic.
          * ``launch.group-id`` - The ID of the security group for the instance.
          * ``launch.group-name`` - The name of the security group for the instance.
          * ``launch.image-id`` - The ID of the AMI.
          * ``launch.instance-type`` - The type of instance (for example, ``m3.medium`` ).
          * ``launch.kernel-id`` - The kernel ID.
          * ``launch.key-name`` - The name of the key pair the instance launched with.
          * ``launch.monitoring-enabled`` - Whether detailed monitoring is enabled for the Spot Instance.
          * ``launch.ramdisk-id`` - The RAM disk ID.
          * ``launched-availability-zone`` - The Availability Zone in which the request is launched.
          * ``network-interface.addresses.primary`` - Indicates whether the IP address is the primary private IP address.
          * ``network-interface.delete-on-termination`` - Indicates whether the network interface is deleted when the instance is terminated.
          * ``network-interface.description`` - A description of the network interface.
          * ``network-interface.device-index`` - The index of the device for the network interface attachment on the instance.
          * ``network-interface.group-id`` - The ID of the security group associated with the network interface.
          * ``network-interface.network-interface-id`` - The ID of the network interface.
          * ``network-interface.private-ip-address`` - The primary private IP address of the network interface.
          * ``network-interface.subnet-id`` - The ID of the subnet for the instance.
          * ``product-description`` - The product description associated with the instance (``Linux/UNIX`` | ``Windows`` ).
          * ``spot-instance-request-id`` - The Spot Instance request ID.
          * ``spot-price`` - The maximum hourly price for any Spot Instance launched to fulfill the request.
          * ``state`` - The state of the Spot Instance request (``open`` | ``active`` | ``closed`` | ``cancelled`` | ``failed`` ). Spot request status information can help you track your Amazon EC2 Spot Instance requests. For more information, see `Spot Request Status <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-bid-status.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
          * ``status-code`` - The short code describing the most recent evaluation of your Spot Instance request.
          * ``status-message`` - The message explaining the status of the Spot Instance request.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``type`` - The type of Spot Instance request (``one-time`` | ``persistent`` ).
          * ``valid-from`` - The start date of the request.
          * ``valid-until`` - The end date of the request.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type SpotInstanceRequestIds: list
        :param SpotInstanceRequestIds:
          One or more Spot Instance request IDs.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token to request the next set of results. This value is ``null`` when there are no more results to return.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 5 and 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_spot_price_history(self, Filters: List = None, AvailabilityZone: str = None, DryRun: bool = None, EndTime: datetime = None, InstanceTypes: List = None, MaxResults: int = None, NextToken: str = None, ProductDescriptions: List = None, StartTime: datetime = None) -> Dict:
        """
        Describes the Spot price history. For more information, see `Spot Instance Pricing History <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-spot-instances-history.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
        When you specify a start and end time, this operation returns the prices of the instance types within the time range that you specified and the time when the price changed. The price is valid within the time period that you specified; the response merely indicates the last time that the price changed.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSpotPriceHistory>`_
        
        **Request Syntax**
        ::
          response = client.describe_spot_price_history(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              AvailabilityZone='string',
              DryRun=True|False,
              EndTime=datetime(2015, 1, 1),
              InstanceTypes=[
                  't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
              ],
              MaxResults=123,
              NextToken='string',
              ProductDescriptions=[
                  'string',
              ],
              StartTime=datetime(2015, 1, 1)
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'SpotPriceHistory': [
                    {
                        'AvailabilityZone': 'string',
                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                        'ProductDescription': 'Linux/UNIX'|'Linux/UNIX (Amazon VPC)'|'Windows'|'Windows (Amazon VPC)',
                        'SpotPrice': 'string',
                        'Timestamp': datetime(2015, 1, 1)
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeSpotPriceHistory.
            - **NextToken** *(string) --* 
              The token required to retrieve the next set of results. This value is null or an empty string when there are no more results to return.
            - **SpotPriceHistory** *(list) --* 
              The historical Spot prices.
              - *(dict) --* 
                Describes the maximum price per hour that you are willing to pay for a Spot Instance.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone.
                - **InstanceType** *(string) --* 
                  The instance type.
                - **ProductDescription** *(string) --* 
                  A general description of the AMI.
                - **SpotPrice** *(string) --* 
                  The maximum price per hour that you are willing to pay for a Spot Instance.
                - **Timestamp** *(datetime) --* 
                  The date and time the request was created, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``availability-zone`` - The Availability Zone for which prices should be returned.
          * ``instance-type`` - The type of instance (for example, ``m3.medium`` ).
          * ``product-description`` - The product description for the Spot price (``Linux/UNIX`` | ``SUSE Linux`` | ``Windows`` | ``Linux/UNIX (Amazon VPC)`` | ``SUSE Linux (Amazon VPC)`` | ``Windows (Amazon VPC)`` ).
          * ``spot-price`` - The Spot price. The value must match exactly (or use wildcards; greater than or less than comparison is not supported).
          * ``timestamp`` - The time stamp of the Spot price history, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). You can use wildcards (* and ?). Greater than or less than comparison is not supported.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type AvailabilityZone: string
        :param AvailabilityZone:
          Filters the results by the specified Availability Zone.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EndTime: datetime
        :param EndTime:
          The date and time, up to the current date, from which to stop retrieving the price history data, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
        :type InstanceTypes: list
        :param InstanceTypes:
          Filters the results by the specified instance types.
          - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next set of results.
        :type ProductDescriptions: list
        :param ProductDescriptions:
          Filters the results by the specified basic product descriptions.
          - *(string) --*
        :type StartTime: datetime
        :param StartTime:
          The date and time, up to the past 90 days, from which to start retrieving the price history data, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
        :rtype: dict
        :returns:
        """
        pass

    def describe_stale_security_groups(self, VpcId: str, DryRun: bool = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        [VPC only] Describes the stale security group rules for security groups in a specified VPC. Rules are stale when they reference a deleted security group in a peer VPC, or a security group in a peer VPC for which the VPC peering connection has been deleted.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeStaleSecurityGroups>`_
        
        **Request Syntax**
        ::
          response = client.describe_stale_security_groups(
              DryRun=True|False,
              MaxResults=123,
              NextToken='string',
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'StaleSecurityGroupSet': [
                    {
                        'Description': 'string',
                        'GroupId': 'string',
                        'GroupName': 'string',
                        'StaleIpPermissions': [
                            {
                                'FromPort': 123,
                                'IpProtocol': 'string',
                                'IpRanges': [
                                    'string',
                                ],
                                'PrefixListIds': [
                                    'string',
                                ],
                                'ToPort': 123,
                                'UserIdGroupPairs': [
                                    {
                                        'Description': 'string',
                                        'GroupId': 'string',
                                        'GroupName': 'string',
                                        'PeeringStatus': 'string',
                                        'UserId': 'string',
                                        'VpcId': 'string',
                                        'VpcPeeringConnectionId': 'string'
                                    },
                                ]
                            },
                        ],
                        'StaleIpPermissionsEgress': [
                            {
                                'FromPort': 123,
                                'IpProtocol': 'string',
                                'IpRanges': [
                                    'string',
                                ],
                                'PrefixListIds': [
                                    'string',
                                ],
                                'ToPort': 123,
                                'UserIdGroupPairs': [
                                    {
                                        'Description': 'string',
                                        'GroupId': 'string',
                                        'GroupName': 'string',
                                        'PeeringStatus': 'string',
                                        'UserId': 'string',
                                        'VpcId': 'string',
                                        'VpcPeeringConnectionId': 'string'
                                    },
                                ]
                            },
                        ],
                        'VpcId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
            - **StaleSecurityGroupSet** *(list) --* 
              Information about the stale security groups.
              - *(dict) --* 
                Describes a stale security group (a security group that contains stale rules).
                - **Description** *(string) --* 
                  The description of the security group.
                - **GroupId** *(string) --* 
                  The ID of the security group.
                - **GroupName** *(string) --* 
                  The name of the security group.
                - **StaleIpPermissions** *(list) --* 
                  Information about the stale inbound rules in the security group.
                  - *(dict) --* 
                    Describes a stale rule in a security group.
                    - **FromPort** *(integer) --* 
                      The start of the port range for the TCP and UDP protocols, or an ICMP type number. A value of ``-1`` indicates all ICMP types. 
                    - **IpProtocol** *(string) --* 
                      The IP protocol name (for ``tcp`` , ``udp`` , and ``icmp`` ) or number (see `Protocol Numbers) <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ .
                    - **IpRanges** *(list) --* 
                      The IP ranges. Not applicable for stale security group rules.
                      - *(string) --* 
                    - **PrefixListIds** *(list) --* 
                      The prefix list IDs for an AWS service. Not applicable for stale security group rules.
                      - *(string) --* 
                    - **ToPort** *(integer) --* 
                      The end of the port range for the TCP and UDP protocols, or an ICMP type number. A value of ``-1`` indicates all ICMP types. 
                    - **UserIdGroupPairs** *(list) --* 
                      The security group pairs. Returns the ID of the referenced security group and VPC, and the ID and status of the VPC peering connection.
                      - *(dict) --* 
                        Describes a security group and AWS account ID pair.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this user ID group pair.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                        - **GroupId** *(string) --* 
                          The ID of the security group.
                        - **GroupName** *(string) --* 
                          The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID. 
                          For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                        - **PeeringStatus** *(string) --* 
                          The status of a VPC peering connection, if applicable.
                        - **UserId** *(string) --* 
                          The ID of an AWS account.
                          For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                          [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                        - **VpcId** *(string) --* 
                          The ID of the VPC for the referenced security group, if applicable.
                        - **VpcPeeringConnectionId** *(string) --* 
                          The ID of the VPC peering connection, if applicable.
                - **StaleIpPermissionsEgress** *(list) --* 
                  Information about the stale outbound rules in the security group.
                  - *(dict) --* 
                    Describes a stale rule in a security group.
                    - **FromPort** *(integer) --* 
                      The start of the port range for the TCP and UDP protocols, or an ICMP type number. A value of ``-1`` indicates all ICMP types. 
                    - **IpProtocol** *(string) --* 
                      The IP protocol name (for ``tcp`` , ``udp`` , and ``icmp`` ) or number (see `Protocol Numbers) <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ .
                    - **IpRanges** *(list) --* 
                      The IP ranges. Not applicable for stale security group rules.
                      - *(string) --* 
                    - **PrefixListIds** *(list) --* 
                      The prefix list IDs for an AWS service. Not applicable for stale security group rules.
                      - *(string) --* 
                    - **ToPort** *(integer) --* 
                      The end of the port range for the TCP and UDP protocols, or an ICMP type number. A value of ``-1`` indicates all ICMP types. 
                    - **UserIdGroupPairs** *(list) --* 
                      The security group pairs. Returns the ID of the referenced security group and VPC, and the ID and status of the VPC peering connection.
                      - *(dict) --* 
                        Describes a security group and AWS account ID pair.
                        - **Description** *(string) --* 
                          A description for the security group rule that references this user ID group pair.
                          Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                        - **GroupId** *(string) --* 
                          The ID of the security group.
                        - **GroupName** *(string) --* 
                          The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID. 
                          For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                        - **PeeringStatus** *(string) --* 
                          The status of a VPC peering connection, if applicable.
                        - **UserId** *(string) --* 
                          The ID of an AWS account.
                          For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                          [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                        - **VpcId** *(string) --* 
                          The ID of the VPC for the referenced security group, if applicable.
                        - **VpcPeeringConnectionId** *(string) --* 
                          The ID of the VPC peering connection, if applicable.
                - **VpcId** *(string) --* 
                  The ID of the VPC for the security group.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results.
        :type NextToken: string
        :param NextToken:
          The token for the next set of items to return. (You received this token from a prior call.)
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def describe_subnets(self, Filters: List = None, SubnetIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more of your subnets.
        For more information, see `Your VPC and Subnets <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Subnets.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeSubnets>`_
        
        **Request Syntax**
        ::
          response = client.describe_subnets(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              SubnetIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Subnets': [
                    {
                        'AvailabilityZone': 'string',
                        'AvailabilityZoneId': 'string',
                        'AvailableIpAddressCount': 123,
                        'CidrBlock': 'string',
                        'DefaultForAz': True|False,
                        'MapPublicIpOnLaunch': True|False,
                        'State': 'pending'|'available',
                        'SubnetId': 'string',
                        'VpcId': 'string',
                        'OwnerId': 'string',
                        'AssignIpv6AddressOnCreation': True|False,
                        'Ipv6CidrBlockAssociationSet': [
                            {
                                'AssociationId': 'string',
                                'Ipv6CidrBlock': 'string',
                                'Ipv6CidrBlockState': {
                                    'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                    'StatusMessage': 'string'
                                }
                            },
                        ],
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'SubnetArn': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Subnets** *(list) --* 
              Information about one or more subnets.
              - *(dict) --* 
                Describes a subnet.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone of the subnet.
                - **AvailabilityZoneId** *(string) --* 
                  The AZ ID of the subnet.
                - **AvailableIpAddressCount** *(integer) --* 
                  The number of unused private IPv4 addresses in the subnet. The IPv4 addresses for any stopped instances are considered unavailable.
                - **CidrBlock** *(string) --* 
                  The IPv4 CIDR block assigned to the subnet.
                - **DefaultForAz** *(boolean) --* 
                  Indicates whether this is the default subnet for the Availability Zone.
                - **MapPublicIpOnLaunch** *(boolean) --* 
                  Indicates whether instances launched in this subnet receive a public IPv4 address.
                - **State** *(string) --* 
                  The current state of the subnet.
                - **SubnetId** *(string) --* 
                  The ID of the subnet.
                - **VpcId** *(string) --* 
                  The ID of the VPC the subnet is in.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account that owns the subnet.
                - **AssignIpv6AddressOnCreation** *(boolean) --* 
                  Indicates whether a network interface created in this subnet (including a network interface created by  RunInstances ) receives an IPv6 address.
                - **Ipv6CidrBlockAssociationSet** *(list) --* 
                  Information about the IPv6 CIDR blocks associated with the subnet.
                  - *(dict) --* 
                    Describes an IPv6 CIDR block associated with a subnet.
                    - **AssociationId** *(string) --* 
                      The association ID for the CIDR block.
                    - **Ipv6CidrBlock** *(string) --* 
                      The IPv6 CIDR block.
                    - **Ipv6CidrBlockState** *(dict) --* 
                      Information about the state of the CIDR block.
                      - **State** *(string) --* 
                        The state of a CIDR block.
                      - **StatusMessage** *(string) --* 
                        A message about the status of the CIDR block, if applicable.
                - **Tags** *(list) --* 
                  Any tags assigned to the subnet.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **SubnetArn** *(string) --* 
                  The Amazon Resource Name (ARN) of the subnet.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``availability-zone`` - The Availability Zone for the subnet. You can also use ``availabilityZone`` as the filter name.
          * ``availability-zone-id`` - The ID of the Availability Zone for the subnet. You can also use ``availabilityZoneId`` as the filter name.
          * ``available-ip-address-count`` - The number of IPv4 addresses in the subnet that are available.
          * ``cidr-block`` - The IPv4 CIDR block of the subnet. The CIDR block you specify must exactly match the subnet\'s CIDR block for information to be returned for the subnet. You can also use ``cidr`` or ``cidrBlock`` as the filter names.
          * ``default-for-az`` - Indicates whether this is the default subnet for the Availability Zone. You can also use ``defaultForAz`` as the filter name.
          * ``ipv6-cidr-block-association.ipv6-cidr-block`` - An IPv6 CIDR block associated with the subnet.
          * ``ipv6-cidr-block-association.association-id`` - An association ID for an IPv6 CIDR block associated with the subnet.
          * ``ipv6-cidr-block-association.state`` - The state of an IPv6 CIDR block associated with the subnet.
          * ``owner-id`` - The ID of the AWS account that owns the subnet.
          * ``state`` - The state of the subnet (``pending`` | ``available`` ).
          * ``subnet-arn`` - The Amazon Resource Name (ARN) of the subnet.
          * ``subnet-id`` - The ID of the subnet.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-id`` - The ID of the VPC for the subnet.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type SubnetIds: list
        :param SubnetIds:
          One or more subnet IDs.
          Default: Describes all your subnets.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_tags(self, DryRun: bool = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the specified tags for your EC2 resources.
        For more information about tags, see `Tagging Your Resources <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeTags>`_
        
        **Request Syntax**
        ::
          response = client.describe_tags(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'Tags': [
                    {
                        'Key': 'string',
                        'ResourceId': 'string',
                        'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                        'Value': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
            - **Tags** *(list) --* 
              The tags.
              - *(dict) --* 
                Describes a tag.
                - **Key** *(string) --* 
                  The tag key.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
                - **ResourceType** *(string) --* 
                  The resource type.
                - **Value** *(string) --* 
                  The tag value.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          The filters.
          * ``key`` - The tag key.
          * ``resource-id`` - The ID of the resource.
          * ``resource-type`` - The resource type (``customer-gateway`` | ``dedicated-host`` | ``dhcp-options`` | ``elastic-ip`` | ``fleet`` | ``fpga-image`` | ``image`` | ``instance`` | ``host-reservation`` | ``internet-gateway`` | ``launch-template`` | ``natgateway`` | ``network-acl`` | ``network-interface`` | ``reserved-instances`` | ``route-table`` | ``security-group`` | ``snapshot`` | ``spot-instances-request`` | ``subnet`` | ``volume`` | ``vpc`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` ).
          * ``tag`` :<key> - The key/value combination of the tag. For example, specify \"tag:Owner\" for the filter name and \"TeamA\" for the filter value to find resources with the tag \"Owner=TeamA\".
          * ``value`` - The tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. This value can be between 5 and 1000. To retrieve the remaining results, make another call with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_transit_gateway_attachments(self, TransitGatewayAttachmentIds: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more attachments between resources and transit gateways. By default, all attachments are described. Alternatively, you can filter the results by attachment ID, attachment state, resource ID, or resource owner.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeTransitGatewayAttachments>`_
        
        **Request Syntax**
        ::
          response = client.describe_transit_gateway_attachments(
              TransitGatewayAttachmentIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayAttachments': [
                    {
                        'TransitGatewayAttachmentId': 'string',
                        'TransitGatewayId': 'string',
                        'TransitGatewayOwnerId': 'string',
                        'ResourceOwnerId': 'string',
                        'ResourceType': 'vpc'|'vpn',
                        'ResourceId': 'string',
                        'State': 'pendingAcceptance'|'rollingBack'|'pending'|'available'|'modifying'|'deleting'|'deleted'|'failed'|'rejected'|'rejecting'|'failing',
                        'Association': {
                            'TransitGatewayRouteTableId': 'string',
                            'State': 'associating'|'associated'|'disassociating'|'disassociated'
                        },
                        'CreationTime': datetime(2015, 1, 1),
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayAttachments** *(list) --* 
              Information about the attachments.
              - *(dict) --* 
                Describes an attachment between a resource and a transit gateway.
                - **TransitGatewayAttachmentId** *(string) --* 
                  The ID of the attachment.
                - **TransitGatewayId** *(string) --* 
                  The ID of the transit gateway.
                - **TransitGatewayOwnerId** *(string) --* 
                  The ID of the AWS account that owns the transit gateway.
                - **ResourceOwnerId** *(string) --* 
                  The ID of the AWS account that owns the resource.
                - **ResourceType** *(string) --* 
                  The resource type.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
                - **State** *(string) --* 
                  The attachment state.
                - **Association** *(dict) --* 
                  The association.
                  - **TransitGatewayRouteTableId** *(string) --* 
                    The ID of the route table for the transit gateway.
                  - **State** *(string) --* 
                    The state of the association.
                - **CreationTime** *(datetime) --* 
                  The creation time.
                - **Tags** *(list) --* 
                  The tags for the attachment.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type TransitGatewayAttachmentIds: list
        :param TransitGatewayAttachmentIds:
          The IDs of the attachments.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``association.state`` - The state of the association (``associating`` | ``associated`` | ``disassociating`` ).
          * ``association.transit-gateway-route-table-id`` - The ID of the route table for the transit gateway.
          * ``resource-id`` - The ID of the resource.
          * ``resource-owner-id`` - The ID of the AWS account that owns the resource.
          * ``resource-type`` - The resource type (``vpc`` | ``vpn`` ).
          * ``state`` - The state of the attachment (``available`` | ``deleted`` | ``deleting`` | ``failed`` | ``modifying`` | ``pendingAcceptance`` | ``pending`` | ``rollingBack`` | ``rejected`` | ``rejecting`` ).
          * ``transit-gateway-attachment-id`` - The ID of the attachment.
          * ``transit-gateway-id`` - The ID of the transit gateway.
          * ``transit-gateway-owner-id`` - The ID of the AWS account that owns the transit gateway.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_transit_gateway_route_tables(self, TransitGatewayRouteTableIds: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more transit gateway route tables. By default, all transit gateway route tables are described. Alternatively, you can filter the results.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeTransitGatewayRouteTables>`_
        
        **Request Syntax**
        ::
          response = client.describe_transit_gateway_route_tables(
              TransitGatewayRouteTableIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayRouteTables': [
                    {
                        'TransitGatewayRouteTableId': 'string',
                        'TransitGatewayId': 'string',
                        'State': 'pending'|'available'|'deleting'|'deleted',
                        'DefaultAssociationRouteTable': True|False,
                        'DefaultPropagationRouteTable': True|False,
                        'CreationTime': datetime(2015, 1, 1),
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayRouteTables** *(list) --* 
              Information about the transit gateway route tables.
              - *(dict) --* 
                Describes a transit gateway route table.
                - **TransitGatewayRouteTableId** *(string) --* 
                  The ID of the transit gateway route table.
                - **TransitGatewayId** *(string) --* 
                  The ID of the transit gateway.
                - **State** *(string) --* 
                  The state of the transit gateway route table.
                - **DefaultAssociationRouteTable** *(boolean) --* 
                  Indicates whether this is the default association route table for the transit gateway.
                - **DefaultPropagationRouteTable** *(boolean) --* 
                  Indicates whether this is the default propagation route table for the transit gateway.
                - **CreationTime** *(datetime) --* 
                  The creation time.
                - **Tags** *(list) --* 
                  Any tags assigned to the route table.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type TransitGatewayRouteTableIds: list
        :param TransitGatewayRouteTableIds:
          The IDs of the transit gateway route tables.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``default-association-route-table`` - Indicates whether this is the default association route table for the transit gateway (``true`` | ``false`` ).
          * ``default-propagation-route-table`` - Indicates whether this is the default propagation route table for the transit gateway (``true`` | ``false`` ).
          * ``state`` - The state of the attachment (``available`` | ``deleted`` | ``deleting`` | ``failed`` | ``modifying`` | ``pendingAcceptance`` | ``pending`` | ``rollingBack`` | ``rejected`` | ``rejecting`` ).
          * ``transit-gateway-id`` - The ID of the transit gateway.
          * ``transit-gateway-route-table-id`` - The ID of the transit gateway route table.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_transit_gateway_vpc_attachments(self, TransitGatewayAttachmentIds: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more VPC attachments. By default, all VPC attachments are described. Alternatively, you can filter the results.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeTransitGatewayVpcAttachments>`_
        
        **Request Syntax**
        ::
          response = client.describe_transit_gateway_vpc_attachments(
              TransitGatewayAttachmentIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayVpcAttachments': [
                    {
                        'TransitGatewayAttachmentId': 'string',
                        'TransitGatewayId': 'string',
                        'VpcId': 'string',
                        'VpcOwnerId': 'string',
                        'State': 'pendingAcceptance'|'rollingBack'|'pending'|'available'|'modifying'|'deleting'|'deleted'|'failed'|'rejected'|'rejecting'|'failing',
                        'SubnetIds': [
                            'string',
                        ],
                        'CreationTime': datetime(2015, 1, 1),
                        'Options': {
                            'DnsSupport': 'enable'|'disable',
                            'Ipv6Support': 'enable'|'disable'
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayVpcAttachments** *(list) --* 
              Information about the VPC attachments.
              - *(dict) --* 
                Describes a VPC attachment.
                - **TransitGatewayAttachmentId** *(string) --* 
                  The ID of the attachment.
                - **TransitGatewayId** *(string) --* 
                  The ID of the transit gateway.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
                - **VpcOwnerId** *(string) --* 
                  The ID of the AWS account that owns the VPC.
                - **State** *(string) --* 
                  The state of the VPC attachment.
                - **SubnetIds** *(list) --* 
                  The IDs of the subnets.
                  - *(string) --* 
                - **CreationTime** *(datetime) --* 
                  The creation time.
                - **Options** *(dict) --* 
                  The VPC attachment options.
                  - **DnsSupport** *(string) --* 
                    Indicates whether DNS support is enabled.
                  - **Ipv6Support** *(string) --* 
                    Indicates whether IPv6 support is enabled.
                - **Tags** *(list) --* 
                  The tags for the VPC attachment.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type TransitGatewayAttachmentIds: list
        :param TransitGatewayAttachmentIds:
          The IDs of the attachments.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``state`` - The state of the attachment (``available`` | ``deleted`` | ``deleting`` | ``failed`` | ``modifying`` | ``pendingAcceptance`` | ``pending`` | ``rollingBack`` | ``rejected`` | ``rejecting`` ).
          * ``transit-gateway-attachment-id`` - The ID of the attachment.
          * ``transit-gateway-id`` - The ID of the transit gateway.
          * ``vpc-id`` - The ID of the VPC.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_transit_gateways(self, TransitGatewayIds: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more transit gateways. By default, all transit gateways are described. Alternatively, you can filter the results.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeTransitGateways>`_
        
        **Request Syntax**
        ::
          response = client.describe_transit_gateways(
              TransitGatewayIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGateways': [
                    {
                        'TransitGatewayId': 'string',
                        'TransitGatewayArn': 'string',
                        'State': 'pending'|'available'|'modifying'|'deleting'|'deleted',
                        'OwnerId': 'string',
                        'Description': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'Options': {
                            'AmazonSideAsn': 123,
                            'AutoAcceptSharedAttachments': 'enable'|'disable',
                            'DefaultRouteTableAssociation': 'enable'|'disable',
                            'AssociationDefaultRouteTableId': 'string',
                            'DefaultRouteTablePropagation': 'enable'|'disable',
                            'PropagationDefaultRouteTableId': 'string',
                            'VpnEcmpSupport': 'enable'|'disable',
                            'DnsSupport': 'enable'|'disable'
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGateways** *(list) --* 
              Information about the transit gateways.
              - *(dict) --* 
                Describes a transit gateway.
                - **TransitGatewayId** *(string) --* 
                  The ID of the transit gateway.
                - **TransitGatewayArn** *(string) --* 
                  The Amazon Resource Name (ARN) of the transit gateway.
                - **State** *(string) --* 
                  The state of the transit gateway.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account ID that owns the transit gateway.
                - **Description** *(string) --* 
                  The description of the transit gateway.
                - **CreationTime** *(datetime) --* 
                  The creation time.
                - **Options** *(dict) --* 
                  The transit gateway options.
                  - **AmazonSideAsn** *(integer) --* 
                    A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.
                  - **AutoAcceptSharedAttachments** *(string) --* 
                    Indicates whether attachment requests are automatically accepted.
                  - **DefaultRouteTableAssociation** *(string) --* 
                    Indicates whether resource attachments are automatically associated with the default association route table.
                  - **AssociationDefaultRouteTableId** *(string) --* 
                    The ID of the default association route table.
                  - **DefaultRouteTablePropagation** *(string) --* 
                    Indicates whether resource attachments automatically propagate routes to the default propagation route table.
                  - **PropagationDefaultRouteTableId** *(string) --* 
                    The ID of the default propagation route table.
                  - **VpnEcmpSupport** *(string) --* 
                    Indicates whether Equal Cost Multipath Protocol support is enabled.
                  - **DnsSupport** *(string) --* 
                    Indicates whether DNS support is enabled.
                - **Tags** *(list) --* 
                  The tags for the transit gateway.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type TransitGatewayIds: list
        :param TransitGatewayIds:
          The IDs of the transit gateways.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``options.propagation-default-route-table-id`` - The ID of the default propagation route table.
          * ``options.amazon-side-asn`` - The private ASN for the Amazon side of a BGP session.
          * ``options.association-default-route-table-id`` - The ID of the default association route table.
          * ``options.auto-accept-shared-attachments`` - Indicates whether there is automatic acceptance of attachment requests (``enable`` | ``disable`` ).
          * ``options.default-route-table-association`` - Indicates whether resource attachments are automatically associated with the default association route table (``enable`` | ``disable`` ).
          * ``options.default-route-table-propagation`` - Indicates whether resource attachments automatically propagate routes to the default propagation route table (``enable`` | ``disable`` ).
          * ``options.dns-support`` - Indicates whether DNS support is enabled (``enable`` | ``disable`` ).
          * ``options.vpn-ecmp-support`` - Indicates whether Equal Cost Multipath Protocol support is enabled (``enable`` | ``disable`` ).
          * ``owner-id`` - The ID of the AWS account that owns the transit gateway.
          * ``state`` - The state of the attachment (``available`` | ``deleted`` | ``deleting`` | ``failed`` | ``modifying`` | ``pendingAcceptance`` | ``pending`` | ``rollingBack`` | ``rejected`` | ``rejecting`` ).
          * ``transit-gateway-id`` - The ID of the transit gateway.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_volume_attribute(self, Attribute: str, VolumeId: str, DryRun: bool = None) -> Dict:
        """
        Describes the specified attribute of the specified volume. You can specify only one attribute at a time.
        For more information about EBS volumes, see `Amazon EBS Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVolumeAttribute>`_
        
        **Request Syntax**
        ::
          response = client.describe_volume_attribute(
              Attribute='autoEnableIO'|'productCodes',
              VolumeId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'AutoEnableIO': {
                    'Value': True|False
                },
                'ProductCodes': [
                    {
                        'ProductCodeId': 'string',
                        'ProductCodeType': 'devpay'|'marketplace'
                    },
                ],
                'VolumeId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeVolumeAttribute.
            - **AutoEnableIO** *(dict) --* 
              The state of ``autoEnableIO`` attribute.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
            - **ProductCodes** *(list) --* 
              A list of product codes.
              - *(dict) --* 
                Describes a product code.
                - **ProductCodeId** *(string) --* 
                  The product code.
                - **ProductCodeType** *(string) --* 
                  The type of product code.
            - **VolumeId** *(string) --* 
              The ID of the volume.
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The attribute of the volume. This parameter is required.
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the volume.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_volume_status(self, Filters: List = None, MaxResults: int = None, NextToken: str = None, VolumeIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes the status of the specified volumes. Volume status provides the result of the checks performed on your volumes to determine events that can impair the performance of your volumes. The performance of a volume can be affected if an issue occurs on the volume's underlying host. If the volume's underlying host experiences a power outage or system issue, after the system is restored, there could be data inconsistencies on the volume. Volume events notify you if this occurs. Volume actions notify you if any action needs to be taken in response to the event.
        The ``DescribeVolumeStatus`` operation provides the following information about the specified volumes:
         *Status* : Reflects the current status of the volume. The possible values are ``ok`` , ``impaired`` , ``warning`` , or ``insufficient-data`` . If all checks pass, the overall status of the volume is ``ok`` . If the check fails, the overall status is ``impaired`` . If the status is ``insufficient-data`` , then the checks may still be taking place on your volume at the time. We recommend that you retry the request. For more information about volume status, see `Monitoring the Status of Your Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-volume-status.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
         *Events* : Reflect the cause of a volume status and may require you to take action. For example, if your volume returns an ``impaired`` status, then the volume event might be ``potential-data-inconsistency`` . This means that your volume has been affected by an issue with the underlying host, has all I/O operations disabled, and may have inconsistent data.
         *Actions* : Reflect the actions you may have to take in response to an event. For example, if the status of the volume is ``impaired`` and the volume event shows ``potential-data-inconsistency`` , then the action shows ``enable-volume-io`` . This means that you may want to enable the I/O operations for the volume by calling the  EnableVolumeIO action and then check the volume for data consistency.
        Volume status is based on the volume status checks, and does not reflect the volume state. Therefore, volume status does not indicate volumes in the ``error`` state (for example, when a volume is incapable of accepting I/O.)
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVolumeStatus>`_
        
        **Request Syntax**
        ::
          response = client.describe_volume_status(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              VolumeIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'VolumeStatuses': [
                    {
                        'Actions': [
                            {
                                'Code': 'string',
                                'Description': 'string',
                                'EventId': 'string',
                                'EventType': 'string'
                            },
                        ],
                        'AvailabilityZone': 'string',
                        'Events': [
                            {
                                'Description': 'string',
                                'EventId': 'string',
                                'EventType': 'string',
                                'NotAfter': datetime(2015, 1, 1),
                                'NotBefore': datetime(2015, 1, 1)
                            },
                        ],
                        'VolumeId': 'string',
                        'VolumeStatus': {
                            'Details': [
                                {
                                    'Name': 'io-enabled'|'io-performance',
                                    'Status': 'string'
                                },
                            ],
                            'Status': 'ok'|'impaired'|'insufficient-data'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
            - **VolumeStatuses** *(list) --* 
              Information about the status of the volumes.
              - *(dict) --* 
                Describes the volume status.
                - **Actions** *(list) --* 
                  The details of the operation.
                  - *(dict) --* 
                    Describes a volume status operation code.
                    - **Code** *(string) --* 
                      The code identifying the operation, for example, ``enable-volume-io`` .
                    - **Description** *(string) --* 
                      A description of the operation.
                    - **EventId** *(string) --* 
                      The ID of the event associated with this operation.
                    - **EventType** *(string) --* 
                      The event type associated with this operation.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone of the volume.
                - **Events** *(list) --* 
                  A list of events associated with the volume.
                  - *(dict) --* 
                    Describes a volume status event.
                    - **Description** *(string) --* 
                      A description of the event.
                    - **EventId** *(string) --* 
                      The ID of this event.
                    - **EventType** *(string) --* 
                      The type of this event.
                    - **NotAfter** *(datetime) --* 
                      The latest end time of the event.
                    - **NotBefore** *(datetime) --* 
                      The earliest start time of the event.
                - **VolumeId** *(string) --* 
                  The volume ID.
                - **VolumeStatus** *(dict) --* 
                  The volume status.
                  - **Details** *(list) --* 
                    The details of the volume status.
                    - *(dict) --* 
                      Describes a volume status.
                      - **Name** *(string) --* 
                        The name of the volume status.
                      - **Status** *(string) --* 
                        The intended status of the volume status.
                  - **Status** *(string) --* 
                    The status of the volume.
        :type Filters: list
        :param Filters:
          The filters.
          * ``action.code`` - The action code for the event (for example, ``enable-volume-io`` ).
          * ``action.description`` - A description of the action.
          * ``action.event-id`` - The event ID associated with the action.
          * ``availability-zone`` - The Availability Zone of the instance.
          * ``event.description`` - A description of the event.
          * ``event.event-id`` - The event ID.
          * ``event.event-type`` - The event type (for ``io-enabled`` : ``passed`` | ``failed`` ; for ``io-performance`` : ``io-performance:degraded`` | ``io-performance:severely-degraded`` | ``io-performance:stalled`` ).
          * ``event.not-after`` - The latest end time for the event.
          * ``event.not-before`` - The earliest start time for the event.
          * ``volume-status.details-name`` - The cause for ``volume-status.status`` (``io-enabled`` | ``io-performance`` ).
          * ``volume-status.details-status`` - The status of ``volume-status.details-name`` (for ``io-enabled`` : ``passed`` | ``failed`` ; for ``io-performance`` : ``normal`` | ``degraded`` | ``severely-degraded`` | ``stalled`` ).
          * ``volume-status.status`` - The status of the volume (``ok`` | ``impaired`` | ``warning`` | ``insufficient-data`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of volume results returned by ``DescribeVolumeStatus`` in paginated output. When this parameter is used, the request only returns ``MaxResults`` results in a single page along with a ``NextToken`` response element. The remaining results of the initial request can be seen by sending another request with the returned ``NextToken`` value. This value can be between 5 and 1000; if ``MaxResults`` is given a value larger than 1000, only 1000 results are returned. If this parameter is not used, then ``DescribeVolumeStatus`` returns all results. You cannot specify this parameter and the volume IDs parameter in the same request.
        :type NextToken: string
        :param NextToken:
          The ``NextToken`` value to include in a future ``DescribeVolumeStatus`` request. When the results of the request exceed ``MaxResults`` , this value can be used to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type VolumeIds: list
        :param VolumeIds:
          The IDs of the volumes.
          Default: Describes all your volumes.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_volumes(self, Filters: List = None, VolumeIds: List = None, DryRun: bool = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the specified EBS volumes or all of your EBS volumes.
        If you are describing a long list of volumes, you can paginate the output to make the list more manageable. The ``MaxResults`` parameter sets the maximum number of results returned in a single page. If the list of results exceeds your ``MaxResults`` value, then that number of results is returned along with a ``NextToken`` value that can be passed to a subsequent ``DescribeVolumes`` request to retrieve the remaining results.
        For more information about EBS volumes, see `Amazon EBS Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVolumes>`_
        
        **Request Syntax**
        ::
          response = client.describe_volumes(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              VolumeIds=[
                  'string',
              ],
              DryRun=True|False,
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'Volumes': [
                    {
                        'Attachments': [
                            {
                                'AttachTime': datetime(2015, 1, 1),
                                'Device': 'string',
                                'InstanceId': 'string',
                                'State': 'attaching'|'attached'|'detaching'|'detached'|'busy',
                                'VolumeId': 'string',
                                'DeleteOnTermination': True|False
                            },
                        ],
                        'AvailabilityZone': 'string',
                        'CreateTime': datetime(2015, 1, 1),
                        'Encrypted': True|False,
                        'KmsKeyId': 'string',
                        'Size': 123,
                        'SnapshotId': 'string',
                        'State': 'creating'|'available'|'in-use'|'deleting'|'deleted'|'error',
                        'VolumeId': 'string',
                        'Iops': 123,
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Volumes** *(list) --* 
              Information about the volumes.
              - *(dict) --* 
                Describes a volume.
                - **Attachments** *(list) --* 
                  Information about the volume attachments.
                  - *(dict) --* 
                    Describes volume attachment details.
                    - **AttachTime** *(datetime) --* 
                      The time stamp when the attachment initiated.
                    - **Device** *(string) --* 
                      The device name.
                    - **InstanceId** *(string) --* 
                      The ID of the instance.
                    - **State** *(string) --* 
                      The attachment state of the volume.
                    - **VolumeId** *(string) --* 
                      The ID of the volume.
                    - **DeleteOnTermination** *(boolean) --* 
                      Indicates whether the EBS volume is deleted on instance termination.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone for the volume.
                - **CreateTime** *(datetime) --* 
                  The time stamp when volume creation was initiated.
                - **Encrypted** *(boolean) --* 
                  Indicates whether the volume will be encrypted.
                - **KmsKeyId** *(string) --* 
                  The full ARN of the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to protect the volume encryption key for the volume.
                - **Size** *(integer) --* 
                  The size of the volume, in GiBs.
                - **SnapshotId** *(string) --* 
                  The snapshot from which the volume was created, if applicable.
                - **State** *(string) --* 
                  The volume state.
                - **VolumeId** *(string) --* 
                  The ID of the volume.
                - **Iops** *(integer) --* 
                  The number of I/O operations per second (IOPS) that the volume supports. For Provisioned IOPS SSD volumes, this represents the number of IOPS that are provisioned for the volume. For General Purpose SSD volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                  Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                  Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                - **Tags** *(list) --* 
                  Any tags assigned to the volume.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VolumeType** *(string) --* 
                  The volume type. This can be ``gp2`` for General Purpose SSD, ``io1`` for Provisioned IOPS SSD, ``st1`` for Throughput Optimized HDD, ``sc1`` for Cold HDD, or ``standard`` for Magnetic volumes.
            - **NextToken** *(string) --* 
              The ``NextToken`` value to include in a future ``DescribeVolumes`` request. When the results of a ``DescribeVolumes`` request exceed ``MaxResults`` , this value can be used to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          The filters.
          * ``attachment.attach-time`` - The time stamp when the attachment initiated.
          * ``attachment.delete-on-termination`` - Whether the volume is deleted on instance termination.
          * ``attachment.device`` - The device name specified in the block device mapping (for example, ``/dev/sda1`` ).
          * ``attachment.instance-id`` - The ID of the instance the volume is attached to.
          * ``attachment.status`` - The attachment state (``attaching`` | ``attached`` | ``detaching`` ).
          * ``availability-zone`` - The Availability Zone in which the volume was created.
          * ``create-time`` - The time stamp when the volume was created.
          * ``encrypted`` - Indicates whether the volume is encrypted (``true`` | ``false`` )
          * ``size`` - The size of the volume, in GiB.
          * ``snapshot-id`` - The snapshot from which the volume was created.
          * ``status`` - The status of the volume (``creating`` | ``available`` | ``in-use`` | ``deleting`` | ``deleted`` | ``error`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``volume-id`` - The volume ID.
          * ``volume-type`` - The Amazon EBS volume type. This can be ``gp2`` for General Purpose SSD, ``io1`` for Provisioned IOPS SSD, ``st1`` for Throughput Optimized HDD, ``sc1`` for Cold HDD, or ``standard`` for Magnetic volumes.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type VolumeIds: list
        :param VolumeIds:
          The volume IDs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of volume results returned by ``DescribeVolumes`` in paginated output. When this parameter is used, ``DescribeVolumes`` only returns ``MaxResults`` results in a single page along with a ``NextToken`` response element. The remaining results of the initial request can be seen by sending another ``DescribeVolumes`` request with the returned ``NextToken`` value. This value can be between 5 and 500; if ``MaxResults`` is given a value larger than 500, only 500 results are returned. If this parameter is not used, then ``DescribeVolumes`` returns all results. You cannot specify this parameter and the volume IDs parameter in the same request.
        :type NextToken: string
        :param NextToken:
          The ``NextToken`` value returned from a previous paginated ``DescribeVolumes`` request where ``MaxResults`` was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the ``NextToken`` value. This value is ``null`` when there are no more results to return.
        :rtype: dict
        :returns:
        """
        pass

    def describe_volumes_modifications(self, DryRun: bool = None, VolumeIds: List = None, Filters: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Reports the current modification status of EBS volumes.
        Current-generation EBS volumes support modification of attributes including type, size, and (for ``io1`` volumes) IOPS provisioning while either attached to or detached from an instance. Following an action from the API or the console to modify a volume, the status of the modification may be ``modifying`` , ``optimizing`` , ``completed`` , or ``failed`` . If a volume has never been modified, then certain elements of the returned ``VolumeModification`` objects are null. 
        You can also use CloudWatch Events to check the status of a modification to an EBS volume. For information about CloudWatch Events, see the `Amazon CloudWatch Events User Guide <https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/>`__ . For more information, see `Monitoring Volume Modifications" <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-expand-volume.html#monitoring_mods>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVolumesModifications>`_
        
        **Request Syntax**
        ::
          response = client.describe_volumes_modifications(
              DryRun=True|False,
              VolumeIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'VolumesModifications': [
                    {
                        'VolumeId': 'string',
                        'ModificationState': 'modifying'|'optimizing'|'completed'|'failed',
                        'StatusMessage': 'string',
                        'TargetSize': 123,
                        'TargetIops': 123,
                        'TargetVolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                        'OriginalSize': 123,
                        'OriginalIops': 123,
                        'OriginalVolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                        'Progress': 123,
                        'StartTime': datetime(2015, 1, 1),
                        'EndTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VolumesModifications** *(list) --* 
              Information about the volume modifications.
              - *(dict) --* 
                Describes the modification status of an EBS volume.
                If the volume has never been modified, some element values will be null.
                - **VolumeId** *(string) --* 
                  The ID of the volume.
                - **ModificationState** *(string) --* 
                  The current modification state. The modification state is null for unmodified volumes.
                - **StatusMessage** *(string) --* 
                  A status message about the modification progress or failure.
                - **TargetSize** *(integer) --* 
                  The target size of the volume, in GiB.
                - **TargetIops** *(integer) --* 
                  The target IOPS rate of the volume.
                - **TargetVolumeType** *(string) --* 
                  The target EBS volume type of the volume.
                - **OriginalSize** *(integer) --* 
                  The original size of the volume.
                - **OriginalIops** *(integer) --* 
                  The original IOPS rate of the volume.
                - **OriginalVolumeType** *(string) --* 
                  The original EBS volume type of the volume.
                - **Progress** *(integer) --* 
                  The modification progress, from 0 to 100 percent complete.
                - **StartTime** *(datetime) --* 
                  The modification start time.
                - **EndTime** *(datetime) --* 
                  The modification completion or failure time.
            - **NextToken** *(string) --* 
              Token for pagination, null if there are no more results 
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VolumeIds: list
        :param VolumeIds:
          The IDs of the volumes for which in-progress modifications will be described.
          - *(string) --*
        :type Filters: list
        :param Filters:
          The filters. Supported filters: ``volume-id`` , ``modification-state`` , ``target-size`` , ``target-iops`` , ``target-volume-type`` , ``original-size`` , ``original-iops`` , ``original-volume-type`` , ``start-time`` .
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type NextToken: string
        :param NextToken:
          The ``nextToken`` value returned by a previous paginated request.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results (up to a limit of 500) to be returned in a paginated request.
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_attribute(self, Attribute: str, VpcId: str, DryRun: bool = None) -> Dict:
        """
        Describes the specified attribute of the specified VPC. You can specify only one attribute at a time.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcAttribute>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_attribute(
              Attribute='enableDnsSupport'|'enableDnsHostnames',
              VpcId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'VpcId': 'string',
                'EnableDnsHostnames': {
                    'Value': True|False
                },
                'EnableDnsSupport': {
                    'Value': True|False
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VpcId** *(string) --* 
              The ID of the VPC.
            - **EnableDnsHostnames** *(dict) --* 
              Indicates whether the instances launched in the VPC get DNS hostnames. If this attribute is ``true`` , instances in the VPC get DNS hostnames; otherwise, they do not.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
            - **EnableDnsSupport** *(dict) --* 
              Indicates whether DNS resolution is enabled for the VPC. If this attribute is ``true`` , the Amazon DNS server resolves DNS hostnames for your instances to their corresponding IP addresses; otherwise, it does not.
              - **Value** *(boolean) --* 
                The attribute value. The valid values are ``true`` or ``false`` .
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The VPC attribute.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_classic_link(self, Filters: List = None, DryRun: bool = None, VpcIds: List = None) -> Dict:
        """
        Describes the ClassicLink status of one or more VPCs.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcClassicLink>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_classic_link(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              VpcIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Vpcs': [
                    {
                        'ClassicLinkEnabled': True|False,
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VpcId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Vpcs** *(list) --* 
              The ClassicLink status of one or more VPCs.
              - *(dict) --* 
                Describes whether a VPC is enabled for ClassicLink.
                - **ClassicLinkEnabled** *(boolean) --* 
                  Indicates whether the VPC is enabled for ClassicLink.
                - **Tags** *(list) --* 
                  Any tags assigned to the VPC.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``is-classic-link-enabled`` - Whether the VPC is enabled for ClassicLink (``true`` | ``false`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcIds: list
        :param VpcIds:
          One or more VPCs for which you want to describe the ClassicLink status.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_classic_link_dns_support(self, MaxResults: int = None, NextToken: str = None, VpcIds: List = None) -> Dict:
        """
        Describes the ClassicLink DNS support status of one or more VPCs. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see `ClassicLink <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-classiclink.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcClassicLinkDnsSupport>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_classic_link_dns_support(
              MaxResults=123,
              NextToken='string',
              VpcIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'NextToken': 'string',
                'Vpcs': [
                    {
                        'ClassicLinkDnsSupported': True|False,
                        'VpcId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
            - **Vpcs** *(list) --* 
              Information about the ClassicLink DNS support status of the VPCs.
              - *(dict) --* 
                Describes the ClassicLink DNS support status of a VPC.
                - **ClassicLinkDnsSupported** *(boolean) --* 
                  Indicates whether ClassicLink DNS support is enabled for the VPC.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type VpcIds: list
        :param VpcIds:
          One or more VPC IDs.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_endpoint_connection_notifications(self, DryRun: bool = None, ConnectionNotificationId: str = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the connection notifications for VPC endpoints and VPC endpoint services.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcEndpointConnectionNotifications>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_endpoint_connection_notifications(
              DryRun=True|False,
              ConnectionNotificationId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ConnectionNotificationSet': [
                    {
                        'ConnectionNotificationId': 'string',
                        'ServiceId': 'string',
                        'VpcEndpointId': 'string',
                        'ConnectionNotificationType': 'Topic',
                        'ConnectionNotificationArn': 'string',
                        'ConnectionEvents': [
                            'string',
                        ],
                        'ConnectionNotificationState': 'Enabled'|'Disabled'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ConnectionNotificationSet** *(list) --* 
              One or more notifications.
              - *(dict) --* 
                Describes a connection notification for a VPC endpoint or VPC endpoint service.
                - **ConnectionNotificationId** *(string) --* 
                  The ID of the notification.
                - **ServiceId** *(string) --* 
                  The ID of the endpoint service.
                - **VpcEndpointId** *(string) --* 
                  The ID of the VPC endpoint.
                - **ConnectionNotificationType** *(string) --* 
                  The type of notification.
                - **ConnectionNotificationArn** *(string) --* 
                  The ARN of the SNS topic for the notification.
                - **ConnectionEvents** *(list) --* 
                  The events for the notification. Valid values are ``Accept`` , ``Connect`` , ``Delete`` , and ``Reject`` .
                  - *(string) --* 
                - **ConnectionNotificationState** *(string) --* 
                  The state of the notification.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ConnectionNotificationId: string
        :param ConnectionNotificationId:
          The ID of the notification.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``connection-notification-arn`` - The ARN of SNS topic for the notification.
          * ``connection-notification-id`` - The ID of the notification.
          * ``connection-notification-state`` - The state of the notification (``Enabled`` | ``Disabled`` ).
          * ``connection-notification-type`` - The type of notification (``Topic`` ).
          * ``service-id`` - The ID of the endpoint service.
          * ``vpc-endpoint-id`` - The ID of the VPC endpoint.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned ``NextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token to request the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_endpoint_connections(self, DryRun: bool = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the VPC endpoint connections to your VPC endpoint services, including any endpoints that are pending your acceptance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcEndpointConnections>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_endpoint_connections(
              DryRun=True|False,
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'VpcEndpointConnections': [
                    {
                        'ServiceId': 'string',
                        'VpcEndpointId': 'string',
                        'VpcEndpointOwner': 'string',
                        'VpcEndpointState': 'PendingAcceptance'|'Pending'|'Available'|'Deleting'|'Deleted'|'Rejected'|'Failed'|'Expired',
                        'CreationTimestamp': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VpcEndpointConnections** *(list) --* 
              Information about one or more VPC endpoint connections.
              - *(dict) --* 
                Describes a VPC endpoint connection to a service.
                - **ServiceId** *(string) --* 
                  The ID of the service to which the endpoint is connected.
                - **VpcEndpointId** *(string) --* 
                  The ID of the VPC endpoint.
                - **VpcEndpointOwner** *(string) --* 
                  The AWS account ID of the owner of the VPC endpoint.
                - **VpcEndpointState** *(string) --* 
                  The state of the VPC endpoint.
                - **CreationTimestamp** *(datetime) --* 
                  The date and time the VPC endpoint was created.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``service-id`` - The ID of the service.
          * ``vpc-endpoint-owner`` - The AWS account number of the owner of the endpoint.
          * ``vpc-endpoint-state`` - The state of the endpoint (``pendingAcceptance`` | ``pending`` | ``available`` | ``deleting`` | ``deleted`` | ``rejected`` | ``failed`` ).
          * ``vpc-endpoint-id`` - The ID of the endpoint.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ``NextToken`` value. This value can be between 5 and 1000; if ``MaxResults`` is given a value larger than 1000, only 1000 results are returned.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_endpoint_service_configurations(self, DryRun: bool = None, ServiceIds: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the VPC endpoint service configurations in your account (your services).
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcEndpointServiceConfigurations>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_endpoint_service_configurations(
              DryRun=True|False,
              ServiceIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ServiceConfigurations': [
                    {
                        'ServiceType': [
                            {
                                'ServiceType': 'Interface'|'Gateway'
                            },
                        ],
                        'ServiceId': 'string',
                        'ServiceName': 'string',
                        'ServiceState': 'Pending'|'Available'|'Deleting'|'Deleted'|'Failed',
                        'AvailabilityZones': [
                            'string',
                        ],
                        'AcceptanceRequired': True|False,
                        'ManagesVpcEndpoints': True|False,
                        'NetworkLoadBalancerArns': [
                            'string',
                        ],
                        'BaseEndpointDnsNames': [
                            'string',
                        ],
                        'PrivateDnsName': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ServiceConfigurations** *(list) --* 
              Information about one or more services.
              - *(dict) --* 
                Describes a service configuration for a VPC endpoint service.
                - **ServiceType** *(list) --* 
                  The type of service.
                  - *(dict) --* 
                    Describes the type of service for a VPC endpoint.
                    - **ServiceType** *(string) --* 
                      The type of service.
                - **ServiceId** *(string) --* 
                  The ID of the service.
                - **ServiceName** *(string) --* 
                  The name of the service.
                - **ServiceState** *(string) --* 
                  The service state.
                - **AvailabilityZones** *(list) --* 
                  In the Availability Zones in which the service is available.
                  - *(string) --* 
                - **AcceptanceRequired** *(boolean) --* 
                  Indicates whether requests from other AWS accounts to create an endpoint to the service must first be accepted.
                - **ManagesVpcEndpoints** *(boolean) --* 
                  Indicates whether the service manages it's VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.
                - **NetworkLoadBalancerArns** *(list) --* 
                  The Amazon Resource Names (ARNs) of the Network Load Balancers for the service.
                  - *(string) --* 
                - **BaseEndpointDnsNames** *(list) --* 
                  The DNS names for the service.
                  - *(string) --* 
                - **PrivateDnsName** *(string) --* 
                  The private DNS name for the service.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceIds: list
        :param ServiceIds:
          The IDs of one or more services.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``service-name`` - The name of the service.
          * ``service-id`` - The ID of the service.
          * ``service-state`` - The state of the service (``Pending`` | ``Available`` | ``Deleting`` | ``Deleted`` | ``Failed`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ``NextToken`` value. This value can be between 5 and 1000; if ``MaxResults`` is given a value larger than 1000, only 1000 results are returned.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_endpoint_service_permissions(self, ServiceId: str, DryRun: bool = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes the principals (service consumers) that are permitted to discover your VPC endpoint service.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcEndpointServicePermissions>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_endpoint_service_permissions(
              DryRun=True|False,
              ServiceId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'AllowedPrincipals': [
                    {
                        'PrincipalType': 'All'|'Service'|'OrganizationUnit'|'Account'|'User'|'Role',
                        'Principal': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AllowedPrincipals** *(list) --* 
              Information about one or more allowed principals.
              - *(dict) --* 
                Describes a principal.
                - **PrincipalType** *(string) --* 
                  The type of principal.
                - **Principal** *(string) --* 
                  The Amazon Resource Name (ARN) of the principal.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceId: string
        :param ServiceId: **[REQUIRED]**
          The ID of the service.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``principal`` - The ARN of the principal.
          * ``principal-type`` - The principal type (``All`` | ``Service`` | ``OrganizationUnit`` | ``Account`` | ``User`` | ``Role`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ``NextToken`` value. This value can be between 5 and 1000; if ``MaxResults`` is given a value larger than 1000, only 1000 results are returned.
        :type NextToken: string
        :param NextToken:
          The token to retrieve the next page of results.
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_endpoint_services(self, DryRun: bool = None, ServiceNames: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes available services to which you can create a VPC endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcEndpointServices>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_endpoint_services(
              DryRun=True|False,
              ServiceNames=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'ServiceNames': [
                    'string',
                ],
                'ServiceDetails': [
                    {
                        'ServiceName': 'string',
                        'ServiceType': [
                            {
                                'ServiceType': 'Interface'|'Gateway'
                            },
                        ],
                        'AvailabilityZones': [
                            'string',
                        ],
                        'Owner': 'string',
                        'BaseEndpointDnsNames': [
                            'string',
                        ],
                        'PrivateDnsName': 'string',
                        'VpcEndpointPolicySupported': True|False,
                        'AcceptanceRequired': True|False,
                        'ManagesVpcEndpoints': True|False
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeVpcEndpointServices.
            - **ServiceNames** *(list) --* 
              A list of supported services.
              - *(string) --* 
            - **ServiceDetails** *(list) --* 
              Information about the service.
              - *(dict) --* 
                Describes a VPC endpoint service.
                - **ServiceName** *(string) --* 
                  The Amazon Resource Name (ARN) of the service.
                - **ServiceType** *(list) --* 
                  The type of service.
                  - *(dict) --* 
                    Describes the type of service for a VPC endpoint.
                    - **ServiceType** *(string) --* 
                      The type of service.
                - **AvailabilityZones** *(list) --* 
                  The Availability Zones in which the service is available.
                  - *(string) --* 
                - **Owner** *(string) --* 
                  The AWS account ID of the service owner.
                - **BaseEndpointDnsNames** *(list) --* 
                  The DNS names for the service.
                  - *(string) --* 
                - **PrivateDnsName** *(string) --* 
                  The private DNS name for the service.
                - **VpcEndpointPolicySupported** *(boolean) --* 
                  Indicates whether the service supports endpoint policies.
                - **AcceptanceRequired** *(boolean) --* 
                  Indicates whether VPC endpoint connection requests to the service must be accepted by the service owner.
                - **ManagesVpcEndpoints** *(boolean) --* 
                  Indicates whether the service manages it's VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.
            - **NextToken** *(string) --* 
              The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceNames: list
        :param ServiceNames:
          One or more service names.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``service-name`` : The name of the service.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results.
          Constraint: If the value is greater than 1000, we return only 1000 items.
        :type NextToken: string
        :param NextToken:
          The token for the next set of items to return. (You received this token from a prior call.)
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_endpoints(self, DryRun: bool = None, VpcEndpointIds: List = None, Filters: List = None, MaxResults: int = None, NextToken: str = None) -> Dict:
        """
        Describes one or more of your VPC endpoints.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcEndpoints>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_endpoints(
              DryRun=True|False,
              VpcEndpointIds=[
                  'string',
              ],
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string'
          )
        
        **Response Syntax**
        ::
            {
                'VpcEndpoints': [
                    {
                        'VpcEndpointId': 'string',
                        'VpcEndpointType': 'Interface'|'Gateway',
                        'VpcId': 'string',
                        'ServiceName': 'string',
                        'State': 'PendingAcceptance'|'Pending'|'Available'|'Deleting'|'Deleted'|'Rejected'|'Failed'|'Expired',
                        'PolicyDocument': 'string',
                        'RouteTableIds': [
                            'string',
                        ],
                        'SubnetIds': [
                            'string',
                        ],
                        'Groups': [
                            {
                                'GroupId': 'string',
                                'GroupName': 'string'
                            },
                        ],
                        'PrivateDnsEnabled': True|False,
                        'RequesterManaged': True|False,
                        'NetworkInterfaceIds': [
                            'string',
                        ],
                        'DnsEntries': [
                            {
                                'DnsName': 'string',
                                'HostedZoneId': 'string'
                            },
                        ],
                        'CreationTimestamp': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeVpcEndpoints.
            - **VpcEndpoints** *(list) --* 
              Information about the endpoints.
              - *(dict) --* 
                Describes a VPC endpoint.
                - **VpcEndpointId** *(string) --* 
                  The ID of the VPC endpoint.
                - **VpcEndpointType** *(string) --* 
                  The type of endpoint.
                - **VpcId** *(string) --* 
                  The ID of the VPC to which the endpoint is associated.
                - **ServiceName** *(string) --* 
                  The name of the service to which the endpoint is associated.
                - **State** *(string) --* 
                  The state of the VPC endpoint.
                - **PolicyDocument** *(string) --* 
                  The policy document associated with the endpoint, if applicable.
                - **RouteTableIds** *(list) --* 
                  (Gateway endpoint) One or more route tables associated with the endpoint.
                  - *(string) --* 
                - **SubnetIds** *(list) --* 
                  (Interface endpoint) One or more subnets in which the endpoint is located.
                  - *(string) --* 
                - **Groups** *(list) --* 
                  (Interface endpoint) Information about the security groups associated with the network interface.
                  - *(dict) --* 
                    Describes a security group.
                    - **GroupId** *(string) --* 
                      The ID of the security group.
                    - **GroupName** *(string) --* 
                      The name of the security group.
                - **PrivateDnsEnabled** *(boolean) --* 
                  (Interface endpoint) Indicates whether the VPC is associated with a private hosted zone.
                - **RequesterManaged** *(boolean) --* 
                  Indicates whether the VPC endpoint is being managed by its service.
                - **NetworkInterfaceIds** *(list) --* 
                  (Interface endpoint) One or more network interfaces for the endpoint.
                  - *(string) --* 
                - **DnsEntries** *(list) --* 
                  (Interface endpoint) The DNS entries for the endpoint.
                  - *(dict) --* 
                    Describes a DNS entry.
                    - **DnsName** *(string) --* 
                      The DNS name.
                    - **HostedZoneId** *(string) --* 
                      The ID of the private hosted zone.
                - **CreationTimestamp** *(datetime) --* 
                  The date and time the VPC endpoint was created.
            - **NextToken** *(string) --* 
              The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcEndpointIds: list
        :param VpcEndpointIds:
          One or more endpoint IDs.
          - *(string) --*
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``service-name`` : The name of the service.
          * ``vpc-id`` : The ID of the VPC in which the endpoint resides.
          * ``vpc-endpoint-id`` : The ID of the endpoint.
          * ``vpc-endpoint-state`` : The state of the endpoint. (``pending`` | ``available`` | ``deleting`` | ``deleted`` )
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results.
          Constraint: If the value is greater than 1000, we return only 1000 items.
        :type NextToken: string
        :param NextToken:
          The token for the next set of items to return. (You received this token from a prior call.)
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpc_peering_connections(self, Filters: List = None, DryRun: bool = None, VpcPeeringConnectionIds: List = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes one or more of your VPC peering connections.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcPeeringConnections>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpc_peering_connections(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              DryRun=True|False,
              VpcPeeringConnectionIds=[
                  'string',
              ],
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'VpcPeeringConnections': [
                    {
                        'AccepterVpcInfo': {
                            'CidrBlock': 'string',
                            'Ipv6CidrBlockSet': [
                                {
                                    'Ipv6CidrBlock': 'string'
                                },
                            ],
                            'CidrBlockSet': [
                                {
                                    'CidrBlock': 'string'
                                },
                            ],
                            'OwnerId': 'string',
                            'PeeringOptions': {
                                'AllowDnsResolutionFromRemoteVpc': True|False,
                                'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                                'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                            },
                            'VpcId': 'string',
                            'Region': 'string'
                        },
                        'ExpirationTime': datetime(2015, 1, 1),
                        'RequesterVpcInfo': {
                            'CidrBlock': 'string',
                            'Ipv6CidrBlockSet': [
                                {
                                    'Ipv6CidrBlock': 'string'
                                },
                            ],
                            'CidrBlockSet': [
                                {
                                    'CidrBlock': 'string'
                                },
                            ],
                            'OwnerId': 'string',
                            'PeeringOptions': {
                                'AllowDnsResolutionFromRemoteVpc': True|False,
                                'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                                'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                            },
                            'VpcId': 'string',
                            'Region': 'string'
                        },
                        'Status': {
                            'Code': 'initiating-request'|'pending-acceptance'|'active'|'deleted'|'rejected'|'failed'|'expired'|'provisioning'|'deleting',
                            'Message': 'string'
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VpcPeeringConnectionId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VpcPeeringConnections** *(list) --* 
              Information about the VPC peering connections.
              - *(dict) --* 
                Describes a VPC peering connection.
                - **AccepterVpcInfo** *(dict) --* 
                  Information about the accepter VPC. CIDR block information is only returned when describing an active VPC peering connection.
                  - **CidrBlock** *(string) --* 
                    The IPv4 CIDR block for the VPC.
                  - **Ipv6CidrBlockSet** *(list) --* 
                    The IPv6 CIDR block for the VPC.
                    - *(dict) --* 
                      Describes an IPv6 CIDR block.
                      - **Ipv6CidrBlock** *(string) --* 
                        The IPv6 CIDR block.
                  - **CidrBlockSet** *(list) --* 
                    Information about the IPv4 CIDR blocks for the VPC.
                    - *(dict) --* 
                      Describes an IPv4 CIDR block.
                      - **CidrBlock** *(string) --* 
                        The IPv4 CIDR block.
                  - **OwnerId** *(string) --* 
                    The AWS account ID of the VPC owner.
                  - **PeeringOptions** *(dict) --* 
                    Information about the VPC peering connection options for the accepter or requester VPC.
                    - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                      Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
                    - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                      Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
                    - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                      Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
                  - **VpcId** *(string) --* 
                    The ID of the VPC.
                  - **Region** *(string) --* 
                    The region in which the VPC is located.
                - **ExpirationTime** *(datetime) --* 
                  The time that an unaccepted VPC peering connection will expire.
                - **RequesterVpcInfo** *(dict) --* 
                  Information about the requester VPC. CIDR block information is only returned when describing an active VPC peering connection.
                  - **CidrBlock** *(string) --* 
                    The IPv4 CIDR block for the VPC.
                  - **Ipv6CidrBlockSet** *(list) --* 
                    The IPv6 CIDR block for the VPC.
                    - *(dict) --* 
                      Describes an IPv6 CIDR block.
                      - **Ipv6CidrBlock** *(string) --* 
                        The IPv6 CIDR block.
                  - **CidrBlockSet** *(list) --* 
                    Information about the IPv4 CIDR blocks for the VPC.
                    - *(dict) --* 
                      Describes an IPv4 CIDR block.
                      - **CidrBlock** *(string) --* 
                        The IPv4 CIDR block.
                  - **OwnerId** *(string) --* 
                    The AWS account ID of the VPC owner.
                  - **PeeringOptions** *(dict) --* 
                    Information about the VPC peering connection options for the accepter or requester VPC.
                    - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                      Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
                    - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                      Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
                    - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                      Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
                  - **VpcId** *(string) --* 
                    The ID of the VPC.
                  - **Region** *(string) --* 
                    The region in which the VPC is located.
                - **Status** *(dict) --* 
                  The status of the VPC peering connection.
                  - **Code** *(string) --* 
                    The status of the VPC peering connection.
                  - **Message** *(string) --* 
                    A message that provides more information about the status, if applicable.
                - **Tags** *(list) --* 
                  Any tags assigned to the resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VpcPeeringConnectionId** *(string) --* 
                  The ID of the VPC peering connection.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``accepter-vpc-info.cidr-block`` - The IPv4 CIDR block of the accepter VPC.
          * ``accepter-vpc-info.owner-id`` - The AWS account ID of the owner of the accepter VPC.
          * ``accepter-vpc-info.vpc-id`` - The ID of the accepter VPC.
          * ``expiration-time`` - The expiration date and time for the VPC peering connection.
          * ``requester-vpc-info.cidr-block`` - The IPv4 CIDR block of the requester\'s VPC.
          * ``requester-vpc-info.owner-id`` - The AWS account ID of the owner of the requester VPC.
          * ``requester-vpc-info.vpc-id`` - The ID of the requester VPC.
          * ``status-code`` - The status of the VPC peering connection (``pending-acceptance`` | ``failed`` | ``expired`` | ``provisioning`` | ``active`` | ``deleting`` | ``deleted`` | ``rejected`` ).
          * ``status-message`` - A message that provides more information about the status of the VPC peering connection, if applicable.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-peering-connection-id`` - The ID of the VPC peering connection.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcPeeringConnectionIds: list
        :param VpcPeeringConnectionIds:
          One or more VPC peering connection IDs.
          Default: Describes all your VPC peering connections.
          - *(string) --*
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpcs(self, Filters: List = None, VpcIds: List = None, DryRun: bool = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        """
        Describes one or more of your VPCs.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpcs>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpcs(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              VpcIds=[
                  'string',
              ],
              DryRun=True|False,
              NextToken='string',
              MaxResults=123
          )
        
        **Response Syntax**
        ::
            {
                'Vpcs': [
                    {
                        'CidrBlock': 'string',
                        'DhcpOptionsId': 'string',
                        'State': 'pending'|'available',
                        'VpcId': 'string',
                        'OwnerId': 'string',
                        'InstanceTenancy': 'default'|'dedicated'|'host',
                        'Ipv6CidrBlockAssociationSet': [
                            {
                                'AssociationId': 'string',
                                'Ipv6CidrBlock': 'string',
                                'Ipv6CidrBlockState': {
                                    'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                    'StatusMessage': 'string'
                                }
                            },
                        ],
                        'CidrBlockAssociationSet': [
                            {
                                'AssociationId': 'string',
                                'CidrBlock': 'string',
                                'CidrBlockState': {
                                    'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                                    'StatusMessage': 'string'
                                }
                            },
                        ],
                        'IsDefault': True|False,
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Vpcs** *(list) --* 
              Information about one or more VPCs.
              - *(dict) --* 
                Describes a VPC.
                - **CidrBlock** *(string) --* 
                  The primary IPv4 CIDR block for the VPC.
                - **DhcpOptionsId** *(string) --* 
                  The ID of the set of DHCP options you've associated with the VPC (or ``default`` if the default options are associated with the VPC).
                - **State** *(string) --* 
                  The current state of the VPC.
                - **VpcId** *(string) --* 
                  The ID of the VPC.
                - **OwnerId** *(string) --* 
                  The ID of the AWS account that owns the VPC.
                - **InstanceTenancy** *(string) --* 
                  The allowed tenancy of instances launched into the VPC.
                - **Ipv6CidrBlockAssociationSet** *(list) --* 
                  Information about the IPv6 CIDR blocks associated with the VPC.
                  - *(dict) --* 
                    Describes an IPv6 CIDR block associated with a VPC.
                    - **AssociationId** *(string) --* 
                      The association ID for the IPv6 CIDR block.
                    - **Ipv6CidrBlock** *(string) --* 
                      The IPv6 CIDR block.
                    - **Ipv6CidrBlockState** *(dict) --* 
                      Information about the state of the CIDR block.
                      - **State** *(string) --* 
                        The state of the CIDR block.
                      - **StatusMessage** *(string) --* 
                        A message about the status of the CIDR block, if applicable.
                - **CidrBlockAssociationSet** *(list) --* 
                  Information about the IPv4 CIDR blocks associated with the VPC.
                  - *(dict) --* 
                    Describes an IPv4 CIDR block associated with a VPC.
                    - **AssociationId** *(string) --* 
                      The association ID for the IPv4 CIDR block.
                    - **CidrBlock** *(string) --* 
                      The IPv4 CIDR block.
                    - **CidrBlockState** *(dict) --* 
                      Information about the state of the CIDR block.
                      - **State** *(string) --* 
                        The state of the CIDR block.
                      - **StatusMessage** *(string) --* 
                        A message about the status of the CIDR block, if applicable.
                - **IsDefault** *(boolean) --* 
                  Indicates whether the VPC is the default VPC.
                - **Tags** *(list) --* 
                  Any tags assigned to the VPC.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``cidr`` - The primary IPv4 CIDR block of the VPC. The CIDR block you specify must exactly match the VPC\'s CIDR block for information to be returned for the VPC. Must contain the slash followed by one or two digits (for example, ``/28`` ).
          * ``cidr-block-association.cidr-block`` - An IPv4 CIDR block associated with the VPC.
          * ``cidr-block-association.association-id`` - The association ID for an IPv4 CIDR block associated with the VPC.
          * ``cidr-block-association.state`` - The state of an IPv4 CIDR block associated with the VPC.
          * ``dhcp-options-id`` - The ID of a set of DHCP options.
          * ``ipv6-cidr-block-association.ipv6-cidr-block`` - An IPv6 CIDR block associated with the VPC.
          * ``ipv6-cidr-block-association.association-id`` - The association ID for an IPv6 CIDR block associated with the VPC.
          * ``ipv6-cidr-block-association.state`` - The state of an IPv6 CIDR block associated with the VPC.
          * ``isDefault`` - Indicates whether the VPC is the default VPC.
          * ``owner-id`` - The ID of the AWS account that owns the VPC.
          * ``state`` - The state of the VPC (``pending`` | ``available`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``vpc-id`` - The ID of the VPC.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type VpcIds: list
        :param VpcIds:
          One or more VPC IDs.
          Default: Describes all your VPCs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpn_connections(self, Filters: List = None, VpnConnectionIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more of your VPN connections.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpnConnections>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpn_connections(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              VpnConnectionIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'VpnConnections': [
                    {
                        'CustomerGatewayConfiguration': 'string',
                        'CustomerGatewayId': 'string',
                        'Category': 'string',
                        'State': 'pending'|'available'|'deleting'|'deleted',
                        'Type': 'ipsec.1',
                        'VpnConnectionId': 'string',
                        'VpnGatewayId': 'string',
                        'TransitGatewayId': 'string',
                        'Options': {
                            'StaticRoutesOnly': True|False
                        },
                        'Routes': [
                            {
                                'DestinationCidrBlock': 'string',
                                'Source': 'Static',
                                'State': 'pending'|'available'|'deleting'|'deleted'
                            },
                        ],
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VgwTelemetry': [
                            {
                                'AcceptedRouteCount': 123,
                                'LastStatusChange': datetime(2015, 1, 1),
                                'OutsideIpAddress': 'string',
                                'Status': 'UP'|'DOWN',
                                'StatusMessage': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeVpnConnections.
            - **VpnConnections** *(list) --* 
              Information about one or more VPN connections.
              - *(dict) --* 
                Describes a VPN connection.
                - **CustomerGatewayConfiguration** *(string) --* 
                  The configuration information for the VPN connection's customer gateway (in the native XML format). This element is always present in the  CreateVpnConnection response; however, it's present in the  DescribeVpnConnections response only if the VPN connection is in the ``pending`` or ``available`` state.
                - **CustomerGatewayId** *(string) --* 
                  The ID of the customer gateway at your end of the VPN connection.
                - **Category** *(string) --* 
                  The category of the VPN connection. A value of ``VPN`` indicates an AWS VPN connection. A value of ``VPN-Classic`` indicates an AWS Classic VPN connection.
                - **State** *(string) --* 
                  The current state of the VPN connection.
                - **Type** *(string) --* 
                  The type of VPN connection.
                - **VpnConnectionId** *(string) --* 
                  The ID of the VPN connection.
                - **VpnGatewayId** *(string) --* 
                  The ID of the virtual private gateway at the AWS side of the VPN connection.
                - **TransitGatewayId** *(string) --* 
                  The ID of the transit gateway associated with the VPN connection.
                - **Options** *(dict) --* 
                  The VPN connection options.
                  - **StaticRoutesOnly** *(boolean) --* 
                    Indicates whether the VPN connection uses static routes only. Static routes must be used for devices that don't support BGP.
                - **Routes** *(list) --* 
                  The static routes associated with the VPN connection.
                  - *(dict) --* 
                    Describes a static route for a VPN connection.
                    - **DestinationCidrBlock** *(string) --* 
                      The CIDR block associated with the local subnet of the customer data center.
                    - **Source** *(string) --* 
                      Indicates how the routes were provided.
                    - **State** *(string) --* 
                      The current state of the static route.
                - **Tags** *(list) --* 
                  Any tags assigned to the VPN connection.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VgwTelemetry** *(list) --* 
                  Information about the VPN tunnel.
                  - *(dict) --* 
                    Describes telemetry for a VPN tunnel.
                    - **AcceptedRouteCount** *(integer) --* 
                      The number of accepted routes.
                    - **LastStatusChange** *(datetime) --* 
                      The date and time of the last change in status.
                    - **OutsideIpAddress** *(string) --* 
                      The Internet-routable IP address of the virtual private gateway's outside interface.
                    - **Status** *(string) --* 
                      The status of the VPN tunnel.
                    - **StatusMessage** *(string) --* 
                      If an error occurs, a description of the error.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``customer-gateway-configuration`` - The configuration information for the customer gateway.
          * ``customer-gateway-id`` - The ID of a customer gateway associated with the VPN connection.
          * ``state`` - The state of the VPN connection (``pending`` | ``available`` | ``deleting`` | ``deleted`` ).
          * ``option.static-routes-only`` - Indicates whether the connection has static routes only. Used for devices that do not support Border Gateway Protocol (BGP).
          * ``route.destination-cidr-block`` - The destination CIDR block. This corresponds to the subnet used in a customer data center.
          * ``bgp-asn`` - The BGP Autonomous System Number (ASN) associated with a BGP device.
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``type`` - The type of VPN connection. Currently the only supported type is ``ipsec.1`` .
          * ``vpn-connection-id`` - The ID of the VPN connection.
          * ``vpn-gateway-id`` - The ID of a virtual private gateway associated with the VPN connection.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type VpnConnectionIds: list
        :param VpnConnectionIds:
          One or more VPN connection IDs.
          Default: Describes your VPN connections.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def describe_vpn_gateways(self, Filters: List = None, VpnGatewayIds: List = None, DryRun: bool = None) -> Dict:
        """
        Describes one or more of your virtual private gateways.
        For more information, see `AWS Site-to-Site VPN <https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html>`__ in the *AWS Site-to-Site VPN User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DescribeVpnGateways>`_
        
        **Request Syntax**
        ::
          response = client.describe_vpn_gateways(
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              VpnGatewayIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'VpnGateways': [
                    {
                        'AvailabilityZone': 'string',
                        'State': 'pending'|'available'|'deleting'|'deleted',
                        'Type': 'ipsec.1',
                        'VpcAttachments': [
                            {
                                'State': 'attaching'|'attached'|'detaching'|'detached',
                                'VpcId': 'string'
                            },
                        ],
                        'VpnGatewayId': 'string',
                        'AmazonSideAsn': 123,
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of DescribeVpnGateways.
            - **VpnGateways** *(list) --* 
              Information about one or more virtual private gateways.
              - *(dict) --* 
                Describes a virtual private gateway.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone where the virtual private gateway was created, if applicable. This field may be empty or not returned.
                - **State** *(string) --* 
                  The current state of the virtual private gateway.
                - **Type** *(string) --* 
                  The type of VPN connection the virtual private gateway supports.
                - **VpcAttachments** *(list) --* 
                  Any VPCs attached to the virtual private gateway.
                  - *(dict) --* 
                    Describes an attachment between a virtual private gateway and a VPC.
                    - **State** *(string) --* 
                      The current state of the attachment.
                    - **VpcId** *(string) --* 
                      The ID of the VPC.
                - **VpnGatewayId** *(string) --* 
                  The ID of the virtual private gateway.
                - **AmazonSideAsn** *(integer) --* 
                  The private Autonomous System Number (ASN) for the Amazon side of a BGP session.
                - **Tags** *(list) --* 
                  Any tags assigned to the virtual private gateway.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type Filters: list
        :param Filters:
          One or more filters.
          * ``amazon-side-asn`` - The Autonomous System Number (ASN) for the Amazon side of the gateway.
          * ``attachment.state`` - The current state of the attachment between the gateway and the VPC (``attaching`` | ``attached`` | ``detaching`` | ``detached`` ).
          * ``attachment.vpc-id`` - The ID of an attached VPC.
          * ``availability-zone`` - The Availability Zone for the virtual private gateway (if applicable).
          * ``state`` - The state of the virtual private gateway (``pending`` | ``available`` | ``deleting`` | ``deleted`` ).
          * ``tag`` :<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ``Owner`` and the value ``TeamA`` , specify ``tag:Owner`` for the filter name and ``TeamA`` for the filter value.
          * ``tag-key`` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
          * ``type`` - The type of virtual private gateway. Currently the only supported type is ``ipsec.1`` .
          * ``vpn-gateway-id`` - The ID of the virtual private gateway.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type VpnGatewayIds: list
        :param VpnGatewayIds:
          One or more virtual private gateway IDs.
          Default: Describes all your virtual private gateways.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def detach_classic_link_vpc(self, InstanceId: str, VpcId: str, DryRun: bool = None) -> Dict:
        """
        Unlinks (detaches) a linked EC2-Classic instance from a VPC. After the instance has been unlinked, the VPC security groups are no longer associated with it. An instance is automatically unlinked from a VPC when it's stopped.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DetachClassicLinkVpc>`_
        
        **Request Syntax**
        ::
          response = client.detach_classic_link_vpc(
              DryRun=True|False,
              InstanceId='string',
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance to unlink from the VPC.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC to which the instance is linked.
        :rtype: dict
        :returns:
        """
        pass

    def detach_internet_gateway(self, InternetGatewayId: str, VpcId: str, DryRun: bool = None):
        """
        Detaches an internet gateway from a VPC, disabling connectivity between the internet and the VPC. The VPC must not contain any running instances with Elastic IP addresses or public IPv4 addresses.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DetachInternetGateway>`_
        
        **Request Syntax**
        ::
          response = client.detach_internet_gateway(
              DryRun=True|False,
              InternetGatewayId='string',
              VpcId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InternetGatewayId: string
        :param InternetGatewayId: **[REQUIRED]**
          The ID of the internet gateway.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :returns: None
        """
        pass

    def detach_network_interface(self, AttachmentId: str, DryRun: bool = None, Force: bool = None):
        """
        Detaches a network interface from an instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DetachNetworkInterface>`_
        
        **Request Syntax**
        ::
          response = client.detach_network_interface(
              AttachmentId='string',
              DryRun=True|False,
              Force=True|False
          )
        :type AttachmentId: string
        :param AttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Force: boolean
        :param Force:
          Specifies whether to force a detachment.
        :returns: None
        """
        pass

    def detach_volume(self, VolumeId: str, Device: str = None, Force: bool = None, InstanceId: str = None, DryRun: bool = None) -> Dict:
        """
        Detaches an EBS volume from an instance. Make sure to unmount any file systems on the device within your operating system before detaching the volume. Failure to do so can result in the volume becoming stuck in the ``busy`` state while detaching. If this happens, detachment can be delayed indefinitely until you unmount the volume, force detachment, reboot the instance, or all three. If an EBS volume is the root device of an instance, it can't be detached while the instance is running. To detach the root volume, stop the instance first.
        When a volume with an AWS Marketplace product code is detached from an instance, the product code is no longer associated with the instance.
        For more information, see `Detaching an Amazon EBS Volume <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-detaching-volume.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DetachVolume>`_
        
        **Request Syntax**
        ::
          response = client.detach_volume(
              Device='string',
              Force=True|False,
              InstanceId='string',
              VolumeId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'AttachTime': datetime(2015, 1, 1),
                'Device': 'string',
                'InstanceId': 'string',
                'State': 'attaching'|'attached'|'detaching'|'detached'|'busy',
                'VolumeId': 'string',
                'DeleteOnTermination': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes volume attachment details.
            - **AttachTime** *(datetime) --* 
              The time stamp when the attachment initiated.
            - **Device** *(string) --* 
              The device name.
            - **InstanceId** *(string) --* 
              The ID of the instance.
            - **State** *(string) --* 
              The attachment state of the volume.
            - **VolumeId** *(string) --* 
              The ID of the volume.
            - **DeleteOnTermination** *(boolean) --* 
              Indicates whether the EBS volume is deleted on instance termination.
        :type Device: string
        :param Device:
          The device name.
        :type Force: boolean
        :param Force:
          Forces detachment if the previous detachment attempt did not occur cleanly (for example, logging into an instance, unmounting the volume, and detaching normally). This option can lead to data loss or a corrupted file system. Use this option only as a last resort to detach a volume from a failed instance. The instance won\'t have an opportunity to flush file system caches or file system metadata. If you use this option, you must perform file system check and repair procedures.
        :type InstanceId: string
        :param InstanceId:
          The ID of the instance.
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the volume.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def detach_vpn_gateway(self, VpcId: str, VpnGatewayId: str, DryRun: bool = None):
        """
        Detaches a virtual private gateway from a VPC. You do this if you're planning to turn off the VPC and not use it anymore. You can confirm a virtual private gateway has been completely detached from a VPC by describing the virtual private gateway (any attachments to the virtual private gateway are also described).
        You must wait for the attachment's state to switch to ``detached`` before you can delete the VPC or attach a different VPC to the virtual private gateway.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DetachVpnGateway>`_
        
        **Request Syntax**
        ::
          response = client.detach_vpn_gateway(
              VpcId='string',
              VpnGatewayId='string',
              DryRun=True|False
          )
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type VpnGatewayId: string
        :param VpnGatewayId: **[REQUIRED]**
          The ID of the virtual private gateway.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def disable_transit_gateway_route_table_propagation(self, TransitGatewayRouteTableId: str, TransitGatewayAttachmentId: str, DryRun: bool = None) -> Dict:
        """
        Disables the specified resource attachment from propagating routes to the specified propagation route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisableTransitGatewayRouteTablePropagation>`_
        
        **Request Syntax**
        ::
          response = client.disable_transit_gateway_route_table_propagation(
              TransitGatewayRouteTableId='string',
              TransitGatewayAttachmentId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Propagation': {
                    'TransitGatewayAttachmentId': 'string',
                    'ResourceId': 'string',
                    'ResourceType': 'vpc'|'vpn',
                    'TransitGatewayRouteTableId': 'string',
                    'State': 'enabling'|'enabled'|'disabling'|'disabled'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Propagation** *(dict) --* 
              Information about route propagation.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **ResourceId** *(string) --* 
                The ID of the resource.
              - **ResourceType** *(string) --* 
                The resource type.
              - **TransitGatewayRouteTableId** *(string) --* 
                The ID of the transit gateway route table.
              - **State** *(string) --* 
                The state.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the propagation route table.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def disable_vgw_route_propagation(self, GatewayId: str, RouteTableId: str):
        """
        Disables a virtual private gateway (VGW) from propagating routes to a specified route table of a VPC.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisableVgwRoutePropagation>`_
        
        **Request Syntax**
        ::
          response = client.disable_vgw_route_propagation(
              GatewayId='string',
              RouteTableId='string'
          )
        :type GatewayId: string
        :param GatewayId: **[REQUIRED]**
          The ID of the virtual private gateway.
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the route table.
        :returns: None
        """
        pass

    def disable_vpc_classic_link(self, VpcId: str, DryRun: bool = None) -> Dict:
        """
        Disables ClassicLink for a VPC. You cannot disable ClassicLink for a VPC that has EC2-Classic instances linked to it.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisableVpcClassicLink>`_
        
        **Request Syntax**
        ::
          response = client.disable_vpc_classic_link(
              DryRun=True|False,
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def disable_vpc_classic_link_dns_support(self, VpcId: str = None) -> Dict:
        """
        Disables ClassicLink DNS support for a VPC. If disabled, DNS hostnames resolve to public IP addresses when addressed between a linked EC2-Classic instance and instances in the VPC to which it's linked. For more information, see `ClassicLink <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-classiclink.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisableVpcClassicLinkDnsSupport>`_
        
        **Request Syntax**
        ::
          response = client.disable_vpc_classic_link_dns_support(
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type VpcId: string
        :param VpcId:
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def disassociate_address(self, AssociationId: str = None, PublicIp: str = None, DryRun: bool = None):
        """
        Disassociates an Elastic IP address from the instance or network interface it's associated with.
        An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see `Elastic IP Addresses <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisassociateAddress>`_
        
        **Request Syntax**
        ::
          response = client.disassociate_address(
              AssociationId='string',
              PublicIp='string',
              DryRun=True|False
          )
        :type AssociationId: string
        :param AssociationId:
          [EC2-VPC] The association ID. Required for EC2-VPC.
        :type PublicIp: string
        :param PublicIp:
          [EC2-Classic] The Elastic IP address. Required for EC2-Classic.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def disassociate_client_vpn_target_network(self, ClientVpnEndpointId: str, AssociationId: str, DryRun: bool = None) -> Dict:
        """
        Disassociates a target network from the specified Client VPN endpoint. When you disassociate the last target network from a Client VPN, the following happens:
        * The route that was automatically added for the VPC is deleted 
        * All active client connections are terminated 
        * New client connections are disallowed 
        * The Client VPN endpoint's status changes to ``pending-associate``   
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisassociateClientVpnTargetNetwork>`_
        
        **Request Syntax**
        ::
          response = client.disassociate_client_vpn_target_network(
              ClientVpnEndpointId='string',
              AssociationId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'AssociationId': 'string',
                'Status': {
                    'Code': 'associating'|'associated'|'association-failed'|'disassociating'|'disassociated',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AssociationId** *(string) --* 
              The ID of the target network association.
            - **Status** *(dict) --* 
              The current state of the target network association.
              - **Code** *(string) --* 
                The state of the target network association.
              - **Message** *(string) --* 
                A message about the status of the target network association, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint from which to disassociate the target network.
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The ID of the target network association.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def disassociate_iam_instance_profile(self, AssociationId: str) -> Dict:
        """
        Disassociates an IAM instance profile from a running or stopped instance.
        Use  DescribeIamInstanceProfileAssociations to get the association ID.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisassociateIamInstanceProfile>`_
        
        **Request Syntax**
        ::
          response = client.disassociate_iam_instance_profile(
              AssociationId='string'
          )
        
        **Response Syntax**
        ::
            {
                'IamInstanceProfileAssociation': {
                    'AssociationId': 'string',
                    'InstanceId': 'string',
                    'IamInstanceProfile': {
                        'Arn': 'string',
                        'Id': 'string'
                    },
                    'State': 'associating'|'associated'|'disassociating'|'disassociated',
                    'Timestamp': datetime(2015, 1, 1)
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **IamInstanceProfileAssociation** *(dict) --* 
              Information about the IAM instance profile association.
              - **AssociationId** *(string) --* 
                The ID of the association.
              - **InstanceId** *(string) --* 
                The ID of the instance.
              - **IamInstanceProfile** *(dict) --* 
                The IAM instance profile.
                - **Arn** *(string) --* 
                  The Amazon Resource Name (ARN) of the instance profile.
                - **Id** *(string) --* 
                  The ID of the instance profile.
              - **State** *(string) --* 
                The state of the association.
              - **Timestamp** *(datetime) --* 
                The time the IAM instance profile was associated with the instance.
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The ID of the IAM instance profile association.
        :rtype: dict
        :returns:
        """
        pass

    def disassociate_route_table(self, AssociationId: str, DryRun: bool = None):
        """
        Disassociates a subnet from a route table.
        After you perform this action, the subnet no longer uses the routes in the route table. Instead, it uses the routes in the VPC's main route table. For more information about route tables, see `Route Tables <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisassociateRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.disassociate_route_table(
              AssociationId='string',
              DryRun=True|False
          )
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The association ID representing the current association between the route table and subnet.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def disassociate_subnet_cidr_block(self, AssociationId: str) -> Dict:
        """
        Disassociates a CIDR block from a subnet. Currently, you can disassociate an IPv6 CIDR block only. You must detach or delete all gateways and resources that are associated with the CIDR block before you can disassociate it. 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisassociateSubnetCidrBlock>`_
        
        **Request Syntax**
        ::
          response = client.disassociate_subnet_cidr_block(
              AssociationId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Ipv6CidrBlockAssociation': {
                    'AssociationId': 'string',
                    'Ipv6CidrBlock': 'string',
                    'Ipv6CidrBlockState': {
                        'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                        'StatusMessage': 'string'
                    }
                },
                'SubnetId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Ipv6CidrBlockAssociation** *(dict) --* 
              Information about the IPv6 CIDR block association.
              - **AssociationId** *(string) --* 
                The association ID for the CIDR block.
              - **Ipv6CidrBlock** *(string) --* 
                The IPv6 CIDR block.
              - **Ipv6CidrBlockState** *(dict) --* 
                Information about the state of the CIDR block.
                - **State** *(string) --* 
                  The state of a CIDR block.
                - **StatusMessage** *(string) --* 
                  A message about the status of the CIDR block, if applicable.
            - **SubnetId** *(string) --* 
              The ID of the subnet.
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The association ID for the CIDR block.
        :rtype: dict
        :returns:
        """
        pass

    def disassociate_transit_gateway_route_table(self, TransitGatewayRouteTableId: str, TransitGatewayAttachmentId: str, DryRun: bool = None) -> Dict:
        """
        Disassociates a resource attachment from a transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisassociateTransitGatewayRouteTable>`_
        
        **Request Syntax**
        ::
          response = client.disassociate_transit_gateway_route_table(
              TransitGatewayRouteTableId='string',
              TransitGatewayAttachmentId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Association': {
                    'TransitGatewayRouteTableId': 'string',
                    'TransitGatewayAttachmentId': 'string',
                    'ResourceId': 'string',
                    'ResourceType': 'vpc'|'vpn',
                    'State': 'associating'|'associated'|'disassociating'|'disassociated'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Association** *(dict) --* 
              Information about the association.
              - **TransitGatewayRouteTableId** *(string) --* 
                The ID of the transit gateway route table.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **ResourceId** *(string) --* 
                The ID of the resource.
              - **ResourceType** *(string) --* 
                The resource type.
              - **State** *(string) --* 
                The state of the association.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def disassociate_vpc_cidr_block(self, AssociationId: str) -> Dict:
        """
        Disassociates a CIDR block from a VPC. To disassociate the CIDR block, you must specify its association ID. You can get the association ID by using  DescribeVpcs . You must detach or delete all gateways and resources that are associated with the CIDR block before you can disassociate it. 
        You cannot disassociate the CIDR block with which you originally created the VPC (the primary CIDR block).
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/DisassociateVpcCidrBlock>`_
        
        **Request Syntax**
        ::
          response = client.disassociate_vpc_cidr_block(
              AssociationId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Ipv6CidrBlockAssociation': {
                    'AssociationId': 'string',
                    'Ipv6CidrBlock': 'string',
                    'Ipv6CidrBlockState': {
                        'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                        'StatusMessage': 'string'
                    }
                },
                'CidrBlockAssociation': {
                    'AssociationId': 'string',
                    'CidrBlock': 'string',
                    'CidrBlockState': {
                        'State': 'associating'|'associated'|'disassociating'|'disassociated'|'failing'|'failed',
                        'StatusMessage': 'string'
                    }
                },
                'VpcId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Ipv6CidrBlockAssociation** *(dict) --* 
              Information about the IPv6 CIDR block association.
              - **AssociationId** *(string) --* 
                The association ID for the IPv6 CIDR block.
              - **Ipv6CidrBlock** *(string) --* 
                The IPv6 CIDR block.
              - **Ipv6CidrBlockState** *(dict) --* 
                Information about the state of the CIDR block.
                - **State** *(string) --* 
                  The state of the CIDR block.
                - **StatusMessage** *(string) --* 
                  A message about the status of the CIDR block, if applicable.
            - **CidrBlockAssociation** *(dict) --* 
              Information about the IPv4 CIDR block association.
              - **AssociationId** *(string) --* 
                The association ID for the IPv4 CIDR block.
              - **CidrBlock** *(string) --* 
                The IPv4 CIDR block.
              - **CidrBlockState** *(dict) --* 
                Information about the state of the CIDR block.
                - **State** *(string) --* 
                  The state of the CIDR block.
                - **StatusMessage** *(string) --* 
                  A message about the status of the CIDR block, if applicable.
            - **VpcId** *(string) --* 
              The ID of the VPC.
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The association ID for the CIDR block.
        :rtype: dict
        :returns:
        """
        pass

    def enable_transit_gateway_route_table_propagation(self, TransitGatewayRouteTableId: str, TransitGatewayAttachmentId: str, DryRun: bool = None) -> Dict:
        """
        Enables the specified attachment to propagate routes to the specified propagation route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/EnableTransitGatewayRouteTablePropagation>`_
        
        **Request Syntax**
        ::
          response = client.enable_transit_gateway_route_table_propagation(
              TransitGatewayRouteTableId='string',
              TransitGatewayAttachmentId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Propagation': {
                    'TransitGatewayAttachmentId': 'string',
                    'ResourceId': 'string',
                    'ResourceType': 'vpc'|'vpn',
                    'TransitGatewayRouteTableId': 'string',
                    'State': 'enabling'|'enabled'|'disabling'|'disabled'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Propagation** *(dict) --* 
              Information about route propagation.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **ResourceId** *(string) --* 
                The ID of the resource.
              - **ResourceType** *(string) --* 
                The resource type.
              - **TransitGatewayRouteTableId** *(string) --* 
                The ID of the transit gateway route table.
              - **State** *(string) --* 
                The state.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the propagation route table.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def enable_vgw_route_propagation(self, GatewayId: str, RouteTableId: str):
        """
        Enables a virtual private gateway (VGW) to propagate routes to the specified route table of a VPC.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/EnableVgwRoutePropagation>`_
        
        **Request Syntax**
        ::
          response = client.enable_vgw_route_propagation(
              GatewayId='string',
              RouteTableId='string'
          )
        :type GatewayId: string
        :param GatewayId: **[REQUIRED]**
          The ID of the virtual private gateway that is attached to a VPC. The virtual private gateway must be attached to the same VPC that the routing tables are associated with.
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the route table. The routing table must be associated with the same VPC that the virtual private gateway is attached to.
        :returns: None
        """
        pass

    def enable_volume_io(self, VolumeId: str, DryRun: bool = None):
        """
        Enables I/O operations for a volume that had I/O operations disabled because the data on the volume was potentially inconsistent.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/EnableVolumeIO>`_
        
        **Request Syntax**
        ::
          response = client.enable_volume_io(
              DryRun=True|False,
              VolumeId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the volume.
        :returns: None
        """
        pass

    def enable_vpc_classic_link(self, VpcId: str, DryRun: bool = None) -> Dict:
        """
        Enables a VPC for ClassicLink. You can then link EC2-Classic instances to your ClassicLink-enabled VPC to allow communication over private IP addresses. You cannot enable your VPC for ClassicLink if any of your VPC route tables have existing routes for address ranges within the ``10.0.0.0/8`` IP address range, excluding local routes for VPCs in the ``10.0.0.0/16`` and ``10.1.0.0/16`` IP address ranges. For more information, see `ClassicLink <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-classiclink.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/EnableVpcClassicLink>`_
        
        **Request Syntax**
        ::
          response = client.enable_vpc_classic_link(
              DryRun=True|False,
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def enable_vpc_classic_link_dns_support(self, VpcId: str = None) -> Dict:
        """
        Enables a VPC to support DNS hostname resolution for ClassicLink. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see `ClassicLink <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-classiclink.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/EnableVpcClassicLinkDnsSupport>`_
        
        **Request Syntax**
        ::
          response = client.enable_vpc_classic_link_dns_support(
              VpcId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type VpcId: string
        :param VpcId:
          The ID of the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def export_client_vpn_client_certificate_revocation_list(self, ClientVpnEndpointId: str, DryRun: bool = None) -> Dict:
        """
        Downloads the client certificate revocation list for the specified Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ExportClientVpnClientCertificateRevocationList>`_
        
        **Request Syntax**
        ::
          response = client.export_client_vpn_client_certificate_revocation_list(
              ClientVpnEndpointId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'CertificateRevocationList': 'string',
                'Status': {
                    'Code': 'pending'|'active',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **CertificateRevocationList** *(string) --* 
              Information about the client certificate revocation list.
            - **Status** *(dict) --* 
              The current state of the client certificate revocation list.
              - **Code** *(string) --* 
                The state of the client certificate revocation list.
              - **Message** *(string) --* 
                A message about the status of the client certificate revocation list, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def export_client_vpn_client_configuration(self, ClientVpnEndpointId: str, DryRun: bool = None) -> Dict:
        """
        Downloads the contents of the Client VPN endpoint configuration file for the specified Client VPN endpoint. The Client VPN endpoint configuration file includes the Client VPN endpoint and certificate information clients need to establish a connection with the Client VPN endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ExportClientVpnClientConfiguration>`_
        
        **Request Syntax**
        ::
          response = client.export_client_vpn_client_configuration(
              ClientVpnEndpointId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ClientConfiguration': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientConfiguration** *(string) --* 
              The contents of the Client VPN endpoint configuration file.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def export_transit_gateway_routes(self, TransitGatewayRouteTableId: str, S3Bucket: str, Filters: List = None, DryRun: bool = None) -> Dict:
        """
        Exports routes from the specified transit gateway route table to the specified S3 bucket. By default, all routes are exported. Alternatively, you can filter by CIDR range.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ExportTransitGatewayRoutes>`_
        
        **Request Syntax**
        ::
          response = client.export_transit_gateway_routes(
              TransitGatewayRouteTableId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              S3Bucket='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'S3Location': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **S3Location** *(string) --* 
              The URL of the exported file in Amazon S3. For example, s3://*bucket_name* /VPCTransitGateway/TransitGatewayRouteTables/*file_name* .
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the route table.
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``attachment.transit-gateway-attachment-id`` - The id of the transit gateway attachment.
          * ``attachment.resource-id`` - The resource id of the transit gateway attachment.
          * ``route-search.exact-match`` - The exact match of the specified filter.
          * ``route-search.longest-prefix-match`` - The longest prefix that matches the route.
          * ``route-search.subnet-of-match`` - The routes with a subnet that match the specified CIDR filter.
          * ``route-search.supernet-of-match`` - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify supernet-of-match as 10.0.1.0/30, then the result returns 10.0.1.0/29.
          * ``state`` - The state of the attachment (``available`` | ``deleted`` | ``deleting`` | ``failed`` | ``modifying`` | ``pendingAcceptance`` | ``pending`` | ``rollingBack`` | ``rejected`` | ``rejecting`` ).
          * ``transit-gateway-route-destination-cidr-block`` - The CIDR range.
          * ``type`` - The type of roue (``active`` | ``blackhole`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type S3Bucket: string
        :param S3Bucket: **[REQUIRED]**
          The name of the S3 bucket.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def generate_presigned_url(self, ClientMethod: str = None, Params: Dict = None, ExpiresIn: int = None, HttpMethod: str = None):
        """
        Generate a presigned url given a client, its method, and arguments
        :type ClientMethod: string
        :param ClientMethod: The client method to presign for
        :type Params: dict
        :param Params: The parameters normally passed to
            ``ClientMethod``.
        :type ExpiresIn: int
        :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
        :type HttpMethod: string
        :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method\'s model.
        :returns: The presigned url
        """
        pass

    def get_console_output(self, InstanceId: str, DryRun: bool = None, Latest: bool = None) -> Dict:
        """
        Gets the console output for the specified instance. For Linux instances, the instance console output displays the exact console output that would normally be displayed on a physical monitor attached to a computer. For Windows instances, the instance console output includes the last three system event log errors.
        By default, the console output returns buffered information that was posted shortly after an instance transition state (start, stop, reboot, or terminate). This information is available for at least one hour after the most recent post. Only the most recent 64 KB of console output is available.
        You can optionally retrieve the latest serial console output at any time during the instance lifecycle. This option is supported on instance types that use the Nitro hypervisor.
        For more information, see `Instance Console Output <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-console.html#instance-console-console-output>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetConsoleOutput>`_
        
        **Request Syntax**
        ::
          response = client.get_console_output(
              InstanceId='string',
              DryRun=True|False,
              Latest=True|False
          )
        
        **Response Syntax**
        ::
            {
                'InstanceId': 'string',
                'Output': 'string',
                'Timestamp': datetime(2015, 1, 1)
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InstanceId** *(string) --* 
              The ID of the instance.
            - **Output** *(string) --* 
              The console output, base64-encoded. If you are using a command line tool, the tool decodes the output for you.
            - **Timestamp** *(datetime) --* 
              The time at which the output was last updated.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Latest: boolean
        :param Latest:
          When enabled, retrieves the latest console output for the instance.
          Default: disabled (``false`` )
        :rtype: dict
        :returns:
        """
        pass

    def get_console_screenshot(self, InstanceId: str, DryRun: bool = None, WakeUp: bool = None) -> Dict:
        """
        Retrieve a JPG-format screenshot of a running instance to help with troubleshooting.
        The returned content is Base64-encoded.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetConsoleScreenshot>`_
        
        **Request Syntax**
        ::
          response = client.get_console_screenshot(
              DryRun=True|False,
              InstanceId='string',
              WakeUp=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ImageData': 'string',
                'InstanceId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ImageData** *(string) --* 
              The data that comprises the image.
            - **InstanceId** *(string) --* 
              The ID of the instance.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type WakeUp: boolean
        :param WakeUp:
          When set to ``true`` , acts as keystroke input and wakes up an instance that\'s in standby or \"sleep\" mode.
        :rtype: dict
        :returns:
        """
        pass

    def get_host_reservation_purchase_preview(self, HostIdSet: List, OfferingId: str) -> Dict:
        """
        Preview a reservation purchase with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation.
        This is a preview of the  PurchaseHostReservation action and does not result in the offering being purchased.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetHostReservationPurchasePreview>`_
        
        **Request Syntax**
        ::
          response = client.get_host_reservation_purchase_preview(
              HostIdSet=[
                  'string',
              ],
              OfferingId='string'
          )
        
        **Response Syntax**
        ::
            {
                'CurrencyCode': 'USD',
                'Purchase': [
                    {
                        'CurrencyCode': 'USD',
                        'Duration': 123,
                        'HostIdSet': [
                            'string',
                        ],
                        'HostReservationId': 'string',
                        'HourlyPrice': 'string',
                        'InstanceFamily': 'string',
                        'PaymentOption': 'AllUpfront'|'PartialUpfront'|'NoUpfront',
                        'UpfrontPrice': 'string'
                    },
                ],
                'TotalHourlyPrice': 'string',
                'TotalUpfrontPrice': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **CurrencyCode** *(string) --* 
              The currency in which the ``totalUpfrontPrice`` and ``totalHourlyPrice`` amounts are specified. At this time, the only supported currency is ``USD`` .
            - **Purchase** *(list) --* 
              The purchase information of the Dedicated Host reservation and the Dedicated Hosts associated with it.
              - *(dict) --* 
                Describes the result of the purchase.
                - **CurrencyCode** *(string) --* 
                  The currency in which the ``UpfrontPrice`` and ``HourlyPrice`` amounts are specified. At this time, the only supported currency is ``USD`` .
                - **Duration** *(integer) --* 
                  The duration of the reservation's term in seconds.
                - **HostIdSet** *(list) --* 
                  The IDs of the Dedicated Hosts associated with the reservation.
                  - *(string) --* 
                - **HostReservationId** *(string) --* 
                  The ID of the reservation.
                - **HourlyPrice** *(string) --* 
                  The hourly price of the reservation per hour.
                - **InstanceFamily** *(string) --* 
                  The instance family on the Dedicated Host that the reservation can be associated with.
                - **PaymentOption** *(string) --* 
                  The payment option for the reservation.
                - **UpfrontPrice** *(string) --* 
                  The upfront price of the reservation.
            - **TotalHourlyPrice** *(string) --* 
              The potential total hourly price of the reservation per hour.
            - **TotalUpfrontPrice** *(string) --* 
              The potential total upfront price. This is billed immediately.
        :type HostIdSet: list
        :param HostIdSet: **[REQUIRED]**
          The IDs of the Dedicated Hosts with which the reservation is associated.
          - *(string) --*
        :type OfferingId: string
        :param OfferingId: **[REQUIRED]**
          The offering ID of the reservation.
        :rtype: dict
        :returns:
        """
        pass

    def get_launch_template_data(self, InstanceId: str, DryRun: bool = None) -> Dict:
        """
        Retrieves the configuration data of the specified instance. You can use this data to create a launch template.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetLaunchTemplateData>`_
        
        **Request Syntax**
        ::
          response = client.get_launch_template_data(
              DryRun=True|False,
              InstanceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'LaunchTemplateData': {
                    'KernelId': 'string',
                    'EbsOptimized': True|False,
                    'IamInstanceProfile': {
                        'Arn': 'string',
                        'Name': 'string'
                    },
                    'BlockDeviceMappings': [
                        {
                            'DeviceName': 'string',
                            'VirtualName': 'string',
                            'Ebs': {
                                'Encrypted': True|False,
                                'DeleteOnTermination': True|False,
                                'Iops': 123,
                                'KmsKeyId': 'string',
                                'SnapshotId': 'string',
                                'VolumeSize': 123,
                                'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1'
                            },
                            'NoDevice': 'string'
                        },
                    ],
                    'NetworkInterfaces': [
                        {
                            'AssociatePublicIpAddress': True|False,
                            'DeleteOnTermination': True|False,
                            'Description': 'string',
                            'DeviceIndex': 123,
                            'Groups': [
                                'string',
                            ],
                            'InterfaceType': 'string',
                            'Ipv6AddressCount': 123,
                            'Ipv6Addresses': [
                                {
                                    'Ipv6Address': 'string'
                                },
                            ],
                            'NetworkInterfaceId': 'string',
                            'PrivateIpAddress': 'string',
                            'PrivateIpAddresses': [
                                {
                                    'Primary': True|False,
                                    'PrivateIpAddress': 'string'
                                },
                            ],
                            'SecondaryPrivateIpAddressCount': 123,
                            'SubnetId': 'string'
                        },
                    ],
                    'ImageId': 'string',
                    'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                    'KeyName': 'string',
                    'Monitoring': {
                        'Enabled': True|False
                    },
                    'Placement': {
                        'AvailabilityZone': 'string',
                        'Affinity': 'string',
                        'GroupName': 'string',
                        'HostId': 'string',
                        'Tenancy': 'default'|'dedicated'|'host',
                        'SpreadDomain': 'string'
                    },
                    'RamDiskId': 'string',
                    'DisableApiTermination': True|False,
                    'InstanceInitiatedShutdownBehavior': 'stop'|'terminate',
                    'UserData': 'string',
                    'TagSpecifications': [
                        {
                            'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                            'Tags': [
                                {
                                    'Key': 'string',
                                    'Value': 'string'
                                },
                            ]
                        },
                    ],
                    'ElasticGpuSpecifications': [
                        {
                            'Type': 'string'
                        },
                    ],
                    'ElasticInferenceAccelerators': [
                        {
                            'Type': 'string'
                        },
                    ],
                    'SecurityGroupIds': [
                        'string',
                    ],
                    'SecurityGroups': [
                        'string',
                    ],
                    'InstanceMarketOptions': {
                        'MarketType': 'spot',
                        'SpotOptions': {
                            'MaxPrice': 'string',
                            'SpotInstanceType': 'one-time'|'persistent',
                            'BlockDurationMinutes': 123,
                            'ValidUntil': datetime(2015, 1, 1),
                            'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                        }
                    },
                    'CreditSpecification': {
                        'CpuCredits': 'string'
                    },
                    'CpuOptions': {
                        'CoreCount': 123,
                        'ThreadsPerCore': 123
                    },
                    'CapacityReservationSpecification': {
                        'CapacityReservationPreference': 'open'|'none',
                        'CapacityReservationTarget': {
                            'CapacityReservationId': 'string'
                        }
                    },
                    'LicenseSpecifications': [
                        {
                            'LicenseConfigurationArn': 'string'
                        },
                    ],
                    'HibernationOptions': {
                        'Configured': True|False
                    }
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **LaunchTemplateData** *(dict) --* 
              The instance data.
              - **KernelId** *(string) --* 
                The ID of the kernel, if applicable.
              - **EbsOptimized** *(boolean) --* 
                Indicates whether the instance is optimized for Amazon EBS I/O. 
              - **IamInstanceProfile** *(dict) --* 
                The IAM instance profile.
                - **Arn** *(string) --* 
                  The Amazon Resource Name (ARN) of the instance profile.
                - **Name** *(string) --* 
                  The name of the instance profile.
              - **BlockDeviceMappings** *(list) --* 
                The block device mappings.
                - *(dict) --* 
                  Describes a block device mapping.
                  - **DeviceName** *(string) --* 
                    The device name.
                  - **VirtualName** *(string) --* 
                    The virtual device name (ephemeralN).
                  - **Ebs** *(dict) --* 
                    Information about the block device for an EBS volume.
                    - **Encrypted** *(boolean) --* 
                      Indicates whether the EBS volume is encrypted.
                    - **DeleteOnTermination** *(boolean) --* 
                      Indicates whether the EBS volume is deleted on instance termination.
                    - **Iops** *(integer) --* 
                      The number of I/O operations per second (IOPS) that the volume supports. 
                    - **KmsKeyId** *(string) --* 
                      The ARN of the AWS Key Management Service (AWS KMS) CMK used for encryption.
                    - **SnapshotId** *(string) --* 
                      The ID of the snapshot.
                    - **VolumeSize** *(integer) --* 
                      The size of the volume, in GiB.
                    - **VolumeType** *(string) --* 
                      The volume type.
                  - **NoDevice** *(string) --* 
                    Suppresses the specified device included in the block device mapping of the AMI.
              - **NetworkInterfaces** *(list) --* 
                The network interfaces.
                - *(dict) --* 
                  Describes a network interface.
                  - **AssociatePublicIpAddress** *(boolean) --* 
                    Indicates whether to associate a public IPv4 address with eth0 for a new network interface.
                  - **DeleteOnTermination** *(boolean) --* 
                    Indicates whether the network interface is deleted when the instance is terminated.
                  - **Description** *(string) --* 
                    A description for the network interface.
                  - **DeviceIndex** *(integer) --* 
                    The device index for the network interface attachment.
                  - **Groups** *(list) --* 
                    The IDs of one or more security groups.
                    - *(string) --* 
                  - **InterfaceType** *(string) --* 
                    The type of network interface.
                  - **Ipv6AddressCount** *(integer) --* 
                    The number of IPv6 addresses for the network interface.
                  - **Ipv6Addresses** *(list) --* 
                    The IPv6 addresses for the network interface.
                    - *(dict) --* 
                      Describes an IPv6 address.
                      - **Ipv6Address** *(string) --* 
                        The IPv6 address.
                  - **NetworkInterfaceId** *(string) --* 
                    The ID of the network interface.
                  - **PrivateIpAddress** *(string) --* 
                    The primary private IPv4 address of the network interface.
                  - **PrivateIpAddresses** *(list) --* 
                    One or more private IPv4 addresses.
                    - *(dict) --* 
                      Describes a secondary private IPv4 address for a network interface.
                      - **Primary** *(boolean) --* 
                        Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                      - **PrivateIpAddress** *(string) --* 
                        The private IPv4 addresses.
                  - **SecondaryPrivateIpAddressCount** *(integer) --* 
                    The number of secondary private IPv4 addresses for the network interface.
                  - **SubnetId** *(string) --* 
                    The ID of the subnet for the network interface.
              - **ImageId** *(string) --* 
                The ID of the AMI that was used to launch the instance.
              - **InstanceType** *(string) --* 
                The instance type.
              - **KeyName** *(string) --* 
                The name of the key pair.
              - **Monitoring** *(dict) --* 
                The monitoring for the instance.
                - **Enabled** *(boolean) --* 
                  Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
              - **Placement** *(dict) --* 
                The placement of the instance.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone of the instance.
                - **Affinity** *(string) --* 
                  The affinity setting for the instance on the Dedicated Host.
                - **GroupName** *(string) --* 
                  The name of the placement group for the instance.
                - **HostId** *(string) --* 
                  The ID of the Dedicated Host for the instance.
                - **Tenancy** *(string) --* 
                  The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. 
                - **SpreadDomain** *(string) --* 
                  Reserved for future use.
              - **RamDiskId** *(string) --* 
                The ID of the RAM disk, if applicable.
              - **DisableApiTermination** *(boolean) --* 
                If set to ``true`` , indicates that the instance cannot be terminated using the Amazon EC2 console, command line tool, or API.
              - **InstanceInitiatedShutdownBehavior** *(string) --* 
                Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
              - **UserData** *(string) --* 
                The user data for the instance. 
              - **TagSpecifications** *(list) --* 
                The tags.
                - *(dict) --* 
                  The tag specification for the launch template.
                  - **ResourceType** *(string) --* 
                    The type of resource.
                  - **Tags** *(list) --* 
                    The tags for the resource.
                    - *(dict) --* 
                      Describes a tag.
                      - **Key** *(string) --* 
                        The key of the tag.
                        Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                      - **Value** *(string) --* 
                        The value of the tag.
                        Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **ElasticGpuSpecifications** *(list) --* 
                The elastic GPU specification.
                - *(dict) --* 
                  Describes an elastic GPU.
                  - **Type** *(string) --* 
                    The elastic GPU type.
              - **ElasticInferenceAccelerators** *(list) --* 
                The elastic inference accelerator for the instance. 
                - *(dict) --* 
                  Describes an elastic inference accelerator. 
                  - **Type** *(string) --* 
                    The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge. 
              - **SecurityGroupIds** *(list) --* 
                The security group IDs.
                - *(string) --* 
              - **SecurityGroups** *(list) --* 
                The security group names.
                - *(string) --* 
              - **InstanceMarketOptions** *(dict) --* 
                The market (purchasing) option for the instances.
                - **MarketType** *(string) --* 
                  The market type.
                - **SpotOptions** *(dict) --* 
                  The options for Spot Instances.
                  - **MaxPrice** *(string) --* 
                    The maximum hourly price you're willing to pay for the Spot Instances.
                  - **SpotInstanceType** *(string) --* 
                    The Spot Instance request type.
                  - **BlockDurationMinutes** *(integer) --* 
                    The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
                  - **ValidUntil** *(datetime) --* 
                    The end date of the request. For a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date and time is reached.
                  - **InstanceInterruptionBehavior** *(string) --* 
                    The behavior when a Spot Instance is interrupted.
              - **CreditSpecification** *(dict) --* 
                The credit option for CPU usage of the instance.
                - **CpuCredits** *(string) --* 
                  The credit option for CPU usage of a T2 or T3 instance. Valid values are ``standard`` and ``unlimited`` .
              - **CpuOptions** *(dict) --* 
                The CPU options for the instance. For more information, see `Optimizing CPU Options <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                - **CoreCount** *(integer) --* 
                  The number of CPU cores for the instance.
                - **ThreadsPerCore** *(integer) --* 
                  The number of threads per CPU core.
              - **CapacityReservationSpecification** *(dict) --* 
                Information about the Capacity Reservation targeting option.
                - **CapacityReservationPreference** *(string) --* 
                  Indicates the instance's Capacity Reservation preferences. Possible preferences include:
                  * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone). 
                  * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity. 
                - **CapacityReservationTarget** *(dict) --* 
                  Information about the target Capacity Reservation.
                  - **CapacityReservationId** *(string) --* 
                    The ID of the Capacity Reservation.
              - **LicenseSpecifications** *(list) --* 
                The license configurations.
                - *(dict) --* 
                  Describes a license configuration.
                  - **LicenseConfigurationArn** *(string) --* 
                    The Amazon Resource Name (ARN) of the license configuration.
              - **HibernationOptions** *(dict) --* 
                Indicates whether an instance is configured for hibernation. For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                - **Configured** *(boolean) --* 
                  If this parameter is set to ``true`` , the instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :rtype: dict
        :returns:
        """
        pass

    def get_paginator(self, operation_name: str = None) -> Paginator:
        """
        Create a paginator for an operation.
        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you\'d normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator(\"create_foo\")``.
        :raise OperationNotPageableError: Raised if the operation is not
            pageable.  You can use the ``client.can_paginate`` method to
            check if an operation is pageable.
        :rtype: L{botocore.paginate.Paginator}
        :return: A paginator object.
        """
        pass

    def get_password_data(self, InstanceId: str, DryRun: bool = None) -> Dict:
        """
        Retrieves the encrypted administrator password for a running Windows instance.
        The Windows password is generated at boot by the ``EC2Config`` service or ``EC2Launch`` scripts (Windows Server 2016 and later). This usually only happens the first time an instance is launched. For more information, see `EC2Config <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/UsingConfig_WinAMI.html>`__ and `EC2Launch <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2launch.html>`__ in the Amazon Elastic Compute Cloud User Guide.
        For the ``EC2Config`` service, the password is not generated for rebundled AMIs unless ``Ec2SetPassword`` is enabled before bundling.
        The password is encrypted using the key pair that you specified when you launched the instance. You must provide the corresponding key pair file.
        When you launch an instance, password generation and encryption may take a few minutes. If you try to retrieve the password before it's available, the output returns an empty string. We recommend that you wait up to 15 minutes after launching an instance before trying to retrieve the generated password.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetPasswordData>`_
        
        **Request Syntax**
        ::
          response = client.get_password_data(
              InstanceId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'InstanceId': 'string',
                'PasswordData': 'string',
                'Timestamp': datetime(2015, 1, 1)
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InstanceId** *(string) --* 
              The ID of the Windows instance.
            - **PasswordData** *(string) --* 
              The password of the instance. Returns an empty string if the password is not available.
            - **Timestamp** *(datetime) --* 
              The time the data was last updated.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the Windows instance.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def get_reserved_instances_exchange_quote(self, ReservedInstanceIds: List, DryRun: bool = None, TargetConfigurations: List = None) -> Dict:
        """
        Returns a quote and exchange information for exchanging one or more specified Convertible Reserved Instances for a new Convertible Reserved Instance. If the exchange cannot be performed, the reason is returned in the response. Use  AcceptReservedInstancesExchangeQuote to perform the exchange.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetReservedInstancesExchangeQuote>`_
        
        **Request Syntax**
        ::
          response = client.get_reserved_instances_exchange_quote(
              DryRun=True|False,
              ReservedInstanceIds=[
                  'string',
              ],
              TargetConfigurations=[
                  {
                      'InstanceCount': 123,
                      'OfferingId': 'string'
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'CurrencyCode': 'string',
                'IsValidExchange': True|False,
                'OutputReservedInstancesWillExpireAt': datetime(2015, 1, 1),
                'PaymentDue': 'string',
                'ReservedInstanceValueRollup': {
                    'HourlyPrice': 'string',
                    'RemainingTotalValue': 'string',
                    'RemainingUpfrontValue': 'string'
                },
                'ReservedInstanceValueSet': [
                    {
                        'ReservationValue': {
                            'HourlyPrice': 'string',
                            'RemainingTotalValue': 'string',
                            'RemainingUpfrontValue': 'string'
                        },
                        'ReservedInstanceId': 'string'
                    },
                ],
                'TargetConfigurationValueRollup': {
                    'HourlyPrice': 'string',
                    'RemainingTotalValue': 'string',
                    'RemainingUpfrontValue': 'string'
                },
                'TargetConfigurationValueSet': [
                    {
                        'ReservationValue': {
                            'HourlyPrice': 'string',
                            'RemainingTotalValue': 'string',
                            'RemainingUpfrontValue': 'string'
                        },
                        'TargetConfiguration': {
                            'InstanceCount': 123,
                            'OfferingId': 'string'
                        }
                    },
                ],
                'ValidationFailureReason': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of GetReservedInstancesExchangeQuote.
            - **CurrencyCode** *(string) --* 
              The currency of the transaction.
            - **IsValidExchange** *(boolean) --* 
              If ``true`` , the exchange is valid. If ``false`` , the exchange cannot be completed.
            - **OutputReservedInstancesWillExpireAt** *(datetime) --* 
              The new end date of the reservation term.
            - **PaymentDue** *(string) --* 
              The total true upfront charge for the exchange.
            - **ReservedInstanceValueRollup** *(dict) --* 
              The cost associated with the Reserved Instance.
              - **HourlyPrice** *(string) --* 
                The hourly rate of the reservation.
              - **RemainingTotalValue** *(string) --* 
                The balance of the total value (the sum of remainingUpfrontValue + hourlyPrice * number of hours remaining).
              - **RemainingUpfrontValue** *(string) --* 
                The remaining upfront cost of the reservation.
            - **ReservedInstanceValueSet** *(list) --* 
              The configuration of your Convertible Reserved Instances.
              - *(dict) --* 
                The total value of the Convertible Reserved Instance.
                - **ReservationValue** *(dict) --* 
                  The total value of the Convertible Reserved Instance that you are exchanging.
                  - **HourlyPrice** *(string) --* 
                    The hourly rate of the reservation.
                  - **RemainingTotalValue** *(string) --* 
                    The balance of the total value (the sum of remainingUpfrontValue + hourlyPrice * number of hours remaining).
                  - **RemainingUpfrontValue** *(string) --* 
                    The remaining upfront cost of the reservation.
                - **ReservedInstanceId** *(string) --* 
                  The ID of the Convertible Reserved Instance that you are exchanging.
            - **TargetConfigurationValueRollup** *(dict) --* 
              The cost associated with the Reserved Instance.
              - **HourlyPrice** *(string) --* 
                The hourly rate of the reservation.
              - **RemainingTotalValue** *(string) --* 
                The balance of the total value (the sum of remainingUpfrontValue + hourlyPrice * number of hours remaining).
              - **RemainingUpfrontValue** *(string) --* 
                The remaining upfront cost of the reservation.
            - **TargetConfigurationValueSet** *(list) --* 
              The values of the target Convertible Reserved Instances.
              - *(dict) --* 
                The total value of the new Convertible Reserved Instances.
                - **ReservationValue** *(dict) --* 
                  The total value of the Convertible Reserved Instances that make up the exchange. This is the sum of the list value, remaining upfront price, and additional upfront cost of the exchange.
                  - **HourlyPrice** *(string) --* 
                    The hourly rate of the reservation.
                  - **RemainingTotalValue** *(string) --* 
                    The balance of the total value (the sum of remainingUpfrontValue + hourlyPrice * number of hours remaining).
                  - **RemainingUpfrontValue** *(string) --* 
                    The remaining upfront cost of the reservation.
                - **TargetConfiguration** *(dict) --* 
                  The configuration of the Convertible Reserved Instances that make up the exchange.
                  - **InstanceCount** *(integer) --* 
                    The number of instances the Convertible Reserved Instance offering can be applied to. This parameter is reserved and cannot be specified in a request
                  - **OfferingId** *(string) --* 
                    The ID of the Convertible Reserved Instance offering.
            - **ValidationFailureReason** *(string) --* 
              Describes the reason why the exchange cannot be completed.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ReservedInstanceIds: list
        :param ReservedInstanceIds: **[REQUIRED]**
          The IDs of the Convertible Reserved Instances to exchange.
          - *(string) --*
        :type TargetConfigurations: list
        :param TargetConfigurations:
          The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances.
          - *(dict) --*
            Details about the target configuration.
            - **InstanceCount** *(integer) --*
              The number of instances the Covertible Reserved Instance offering can be applied to. This parameter is reserved and cannot be specified in a request
            - **OfferingId** *(string) --* **[REQUIRED]**
              The Convertible Reserved Instance offering ID.
        :rtype: dict
        :returns:
        """
        pass

    def get_transit_gateway_attachment_propagations(self, TransitGatewayAttachmentId: str, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Lists the route tables to which the specified resource attachment propagates routes.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetTransitGatewayAttachmentPropagations>`_
        
        **Request Syntax**
        ::
          response = client.get_transit_gateway_attachment_propagations(
              TransitGatewayAttachmentId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayAttachmentPropagations': [
                    {
                        'TransitGatewayRouteTableId': 'string',
                        'State': 'enabling'|'enabled'|'disabling'|'disabled'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayAttachmentPropagations** *(list) --* 
              Information about the propagation route tables.
              - *(dict) --* 
                Describes a propagation route table.
                - **TransitGatewayRouteTableId** *(string) --* 
                  The ID of the propagation route table.
                - **State** *(string) --* 
                  The state of the propagation route table.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``transit-gateway-route-table-id`` - The ID of the transit gateway route table.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def get_transit_gateway_route_table_associations(self, TransitGatewayRouteTableId: str, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Gets information about the associations for the specified transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetTransitGatewayRouteTableAssociations>`_
        
        **Request Syntax**
        ::
          response = client.get_transit_gateway_route_table_associations(
              TransitGatewayRouteTableId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Associations': [
                    {
                        'TransitGatewayAttachmentId': 'string',
                        'ResourceId': 'string',
                        'ResourceType': 'vpc'|'vpn',
                        'State': 'associating'|'associated'|'disassociating'|'disassociated'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Associations** *(list) --* 
              Information about the associations.
              - *(dict) --* 
                Describes an association between a route table and a resource attachment.
                - **TransitGatewayAttachmentId** *(string) --* 
                  The ID of the attachment.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
                - **ResourceType** *(string) --* 
                  The resource type.
                - **State** *(string) --* 
                  The state of the association.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``resource-id`` - The ID of the resource.
          * ``resource-type`` - The resource type (``vpc`` | ``vpn`` ).
          * ``transit-gateway-attachment-id`` - The ID of the attachment.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def get_transit_gateway_route_table_propagations(self, TransitGatewayRouteTableId: str, Filters: List = None, MaxResults: int = None, NextToken: str = None, DryRun: bool = None) -> Dict:
        """
        Gets information about the route table propagations for the specified transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/GetTransitGatewayRouteTablePropagations>`_
        
        **Request Syntax**
        ::
          response = client.get_transit_gateway_route_table_propagations(
              TransitGatewayRouteTableId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              NextToken='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayRouteTablePropagations': [
                    {
                        'TransitGatewayAttachmentId': 'string',
                        'ResourceId': 'string',
                        'ResourceType': 'vpc'|'vpn',
                        'State': 'enabling'|'enabled'|'disabling'|'disabled'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayRouteTablePropagations** *(list) --* 
              Information about the route table propagations.
              - *(dict) --* 
                Describes a route table propagation.
                - **TransitGatewayAttachmentId** *(string) --* 
                  The ID of the attachment.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
                - **ResourceType** *(string) --* 
                  The type of resource.
                - **State** *(string) --* 
                  The state of the resource.
            - **NextToken** *(string) --* 
              The token to use to retrieve the next page of results. This value is ``null`` when there are no more results to return.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type Filters: list
        :param Filters:
          One or more filters. The possible values are:
          * ``resource-id`` - The ID of the resource.
          * ``resource-type`` - The resource type (``vpc`` | ``vpn`` ).
          * ``transit-gateway-attachment-id`` - The ID of the attachment.
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ``nextToken`` value.
        :type NextToken: string
        :param NextToken:
          The token for the next page of results.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def get_waiter(self, waiter_name: str = None) -> Waiter:
        """
        Returns an object that can wait for some condition.
        :type waiter_name: str
        :param waiter_name: The name of the waiter to get. See the waiters
            section of the service docs for a list of available waiters.
        :returns: The specified waiter object.
        :rtype: botocore.waiter.Waiter
        """
        pass

    def import_client_vpn_client_certificate_revocation_list(self, ClientVpnEndpointId: str, CertificateRevocationList: str, DryRun: bool = None) -> Dict:
        """
        Uploads a client certificate revocation list to the specified Client VPN endpoint. Uploading a client certificate revocation list overwrites the existing client certificate revocation list.
        Uploading a client certificate revocation list resets existing client connections.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ImportClientVpnClientCertificateRevocationList>`_
        
        **Request Syntax**
        ::
          response = client.import_client_vpn_client_certificate_revocation_list(
              ClientVpnEndpointId='string',
              CertificateRevocationList='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint to which the client certificate revocation list applies.
        :type CertificateRevocationList: string
        :param CertificateRevocationList: **[REQUIRED]**
          The client certificate revocation list file. For more information, see `Generate a Client Certificate Revocation List <https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/cvpn-working-certificates.html#cvpn-working-certificates-generate>`__ in the *AWS Client VPN Administrator Guide* .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def import_image(self, Architecture: str = None, ClientData: Dict = None, ClientToken: str = None, Description: str = None, DiskContainers: List = None, DryRun: bool = None, Encrypted: bool = None, Hypervisor: str = None, KmsKeyId: str = None, LicenseType: str = None, Platform: str = None, RoleName: str = None) -> Dict:
        """
        Import single or multi-volume disk images or EBS snapshots into an Amazon Machine Image (AMI). For more information, see `Importing a VM as an Image Using VM Import/Export <https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-image-import.html>`__ in the *VM Import/Export User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ImportImage>`_
        
        **Request Syntax**
        ::
          response = client.import_image(
              Architecture='string',
              ClientData={
                  'Comment': 'string',
                  'UploadEnd': datetime(2015, 1, 1),
                  'UploadSize': 123.0,
                  'UploadStart': datetime(2015, 1, 1)
              },
              ClientToken='string',
              Description='string',
              DiskContainers=[
                  {
                      'Description': 'string',
                      'DeviceName': 'string',
                      'Format': 'string',
                      'SnapshotId': 'string',
                      'Url': 'string',
                      'UserBucket': {
                          'S3Bucket': 'string',
                          'S3Key': 'string'
                      }
                  },
              ],
              DryRun=True|False,
              Encrypted=True|False,
              Hypervisor='string',
              KmsKeyId='string',
              LicenseType='string',
              Platform='string',
              RoleName='string'
          )
        
        **Response Syntax**
        ::
            {
                'Architecture': 'string',
                'Description': 'string',
                'Encrypted': True|False,
                'Hypervisor': 'string',
                'ImageId': 'string',
                'ImportTaskId': 'string',
                'KmsKeyId': 'string',
                'LicenseType': 'string',
                'Platform': 'string',
                'Progress': 'string',
                'SnapshotDetails': [
                    {
                        'Description': 'string',
                        'DeviceName': 'string',
                        'DiskImageSize': 123.0,
                        'Format': 'string',
                        'Progress': 'string',
                        'SnapshotId': 'string',
                        'Status': 'string',
                        'StatusMessage': 'string',
                        'Url': 'string',
                        'UserBucket': {
                            'S3Bucket': 'string',
                            'S3Key': 'string'
                        }
                    },
                ],
                'Status': 'string',
                'StatusMessage': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for ImportImage.
            - **Architecture** *(string) --* 
              The architecture of the virtual machine.
            - **Description** *(string) --* 
              A description of the import task.
            - **Encrypted** *(boolean) --* 
              Indicates whether the AMI is encypted.
            - **Hypervisor** *(string) --* 
              The target hypervisor of the import task.
            - **ImageId** *(string) --* 
              The ID of the Amazon Machine Image (AMI) created by the import task.
            - **ImportTaskId** *(string) --* 
              The task ID of the import image task.
            - **KmsKeyId** *(string) --* 
              The identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to create the encrypted AMI.
            - **LicenseType** *(string) --* 
              The license type of the virtual machine.
            - **Platform** *(string) --* 
              The operating system of the virtual machine.
            - **Progress** *(string) --* 
              The progress of the task.
            - **SnapshotDetails** *(list) --* 
              Information about the snapshots.
              - *(dict) --* 
                Describes the snapshot created from the imported disk.
                - **Description** *(string) --* 
                  A description for the snapshot.
                - **DeviceName** *(string) --* 
                  The block device mapping for the snapshot.
                - **DiskImageSize** *(float) --* 
                  The size of the disk in the snapshot, in GiB.
                - **Format** *(string) --* 
                  The format of the disk image from which the snapshot is created.
                - **Progress** *(string) --* 
                  The percentage of progress for the task.
                - **SnapshotId** *(string) --* 
                  The snapshot ID of the disk being imported.
                - **Status** *(string) --* 
                  A brief status of the snapshot creation.
                - **StatusMessage** *(string) --* 
                  A detailed status message for the snapshot creation.
                - **Url** *(string) --* 
                  The URL used to access the disk image.
                - **UserBucket** *(dict) --* 
                  The S3 bucket for the disk image.
                  - **S3Bucket** *(string) --* 
                    The S3 bucket from which the disk image was created.
                  - **S3Key** *(string) --* 
                    The file name of the disk image.
            - **Status** *(string) --* 
              A brief status of the task.
            - **StatusMessage** *(string) --* 
              A detailed status message of the import task.
        :type Architecture: string
        :param Architecture:
          The architecture of the virtual machine.
          Valid values: ``i386`` | ``x86_64``
        :type ClientData: dict
        :param ClientData:
          The client-specific data.
          - **Comment** *(string) --*
            A user-defined comment about the disk upload.
          - **UploadEnd** *(datetime) --*
            The time that the disk upload ends.
          - **UploadSize** *(float) --*
            The size of the uploaded disk image, in GiB.
          - **UploadStart** *(datetime) --*
            The time that the disk upload starts.
        :type ClientToken: string
        :param ClientToken:
          The token to enable idempotency for VM import requests.
        :type Description: string
        :param Description:
          A description string for the import image task.
        :type DiskContainers: list
        :param DiskContainers:
          Information about the disk containers.
          - *(dict) --*
            Describes the disk container object for an import image task.
            - **Description** *(string) --*
              The description of the disk image.
            - **DeviceName** *(string) --*
              The block device mapping for the disk.
            - **Format** *(string) --*
              The format of the disk image being imported.
              Valid values: ``VHD`` | ``VMDK`` | ``OVA``
            - **SnapshotId** *(string) --*
              The ID of the EBS snapshot to be used for importing the snapshot.
            - **Url** *(string) --*
              The URL to the Amazon S3-based disk image being imported. The URL can either be a https URL (https://..) or an Amazon S3 URL (s3://..)
            - **UserBucket** *(dict) --*
              The S3 bucket for the disk image.
              - **S3Bucket** *(string) --*
                The name of the S3 bucket where the disk image is located.
              - **S3Key** *(string) --*
                The file name of the disk image.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Encrypted: boolean
        :param Encrypted:
          Specifies whether the destination AMI of the imported image should be encrypted. The default CMK for EBS is used unless you specify a non-default AWS Key Management Service (AWS KMS) CMK using ``KmsKeyId`` . For more information, see `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type Hypervisor: string
        :param Hypervisor:
          The target hypervisor platform.
          Valid values: ``xen``
        :type KmsKeyId: string
        :param KmsKeyId:
          An identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) to use when creating the encrypted AMI. This parameter is only required if you want to use a non-default CMK; if this parameter is not specified, the default CMK for EBS is used. If a ``KmsKeyId`` is specified, the ``Encrypted`` flag must also be set.
          The CMK identifier may be provided in any of the following formats:
          * Key ID
          * Key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          * ARN using key ID. The ID ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``key`` namespace, and then the CMK ID. For example, arn:aws:kms:*us-east-1* :*012345678910* :key/*abcd1234-a123-456a-a12b-a123b4cd56ef* .
          * ARN using key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          AWS parses ``KmsKeyId`` asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. This action will eventually report failure.
          The specified CMK must exist in the region that the AMI is being copied to.
        :type LicenseType: string
        :param LicenseType:
          The license type to be used for the Amazon Machine Image (AMI) after importing.
           **Note:** You may only use BYOL if you have existing licenses with rights to use these licenses in a third party cloud like AWS. For more information, see `Prerequisites <https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-image-import.html#prerequisites-image>`__ in the VM Import/Export User Guide.
          Valid values include:
          * ``Auto`` - Detects the source-system operating system (OS) and applies the appropriate license.
          * ``AWS`` - Replaces the source-system license with an AWS license, if appropriate.
          * ``BYOL`` - Retains the source-system license, if appropriate.
          Default value: ``Auto``
        :type Platform: string
        :param Platform:
          The operating system of the virtual machine.
          Valid values: ``Windows`` | ``Linux``
        :type RoleName: string
        :param RoleName:
          The name of the role to use when not using the default role, \'vmimport\'.
        :rtype: dict
        :returns:
        """
        pass

    def import_instance(self, Platform: str, Description: str = None, DiskImages: List = None, DryRun: bool = None, LaunchSpecification: Dict = None) -> Dict:
        """
        Creates an import instance task using metadata from the specified disk image. ``ImportInstance`` only supports single-volume VMs. To import multi-volume VMs, use  ImportImage . For more information, see `Importing a Virtual Machine Using the Amazon EC2 CLI <https://docs.aws.amazon.com/AWSEC2/latest/CommandLineReference/ec2-cli-vmimport-export.html>`__ .
        For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ImportInstance>`_
        
        **Request Syntax**
        ::
          response = client.import_instance(
              Description='string',
              DiskImages=[
                  {
                      'Description': 'string',
                      'Image': {
                          'Bytes': 123,
                          'Format': 'VMDK'|'RAW'|'VHD',
                          'ImportManifestUrl': 'string'
                      },
                      'Volume': {
                          'Size': 123
                      }
                  },
              ],
              DryRun=True|False,
              LaunchSpecification={
                  'AdditionalInfo': 'string',
                  'Architecture': 'i386'|'x86_64'|'arm64',
                  'GroupIds': [
                      'string',
                  ],
                  'GroupNames': [
                      'string',
                  ],
                  'InstanceInitiatedShutdownBehavior': 'stop'|'terminate',
                  'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                  'Monitoring': True|False,
                  'Placement': {
                      'AvailabilityZone': 'string',
                      'Affinity': 'string',
                      'GroupName': 'string',
                      'PartitionNumber': 123,
                      'HostId': 'string',
                      'Tenancy': 'default'|'dedicated'|'host',
                      'SpreadDomain': 'string'
                  },
                  'PrivateIpAddress': 'string',
                  'SubnetId': 'string',
                  'UserData': {
                      'Data': 'string'
                  }
              },
              Platform='Windows'
          )
        
        **Response Syntax**
        ::
            {
                'ConversionTask': {
                    'ConversionTaskId': 'string',
                    'ExpirationTime': 'string',
                    'ImportInstance': {
                        'Description': 'string',
                        'InstanceId': 'string',
                        'Platform': 'Windows',
                        'Volumes': [
                            {
                                'AvailabilityZone': 'string',
                                'BytesConverted': 123,
                                'Description': 'string',
                                'Image': {
                                    'Checksum': 'string',
                                    'Format': 'VMDK'|'RAW'|'VHD',
                                    'ImportManifestUrl': 'string',
                                    'Size': 123
                                },
                                'Status': 'string',
                                'StatusMessage': 'string',
                                'Volume': {
                                    'Id': 'string',
                                    'Size': 123
                                }
                            },
                        ]
                    },
                    'ImportVolume': {
                        'AvailabilityZone': 'string',
                        'BytesConverted': 123,
                        'Description': 'string',
                        'Image': {
                            'Checksum': 'string',
                            'Format': 'VMDK'|'RAW'|'VHD',
                            'ImportManifestUrl': 'string',
                            'Size': 123
                        },
                        'Volume': {
                            'Id': 'string',
                            'Size': 123
                        }
                    },
                    'State': 'active'|'cancelling'|'cancelled'|'completed',
                    'StatusMessage': 'string',
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for ImportInstance.
            - **ConversionTask** *(dict) --* 
              Information about the conversion task.
              - **ConversionTaskId** *(string) --* 
                The ID of the conversion task.
              - **ExpirationTime** *(string) --* 
                The time when the task expires. If the upload isn't complete before the expiration time, we automatically cancel the task.
              - **ImportInstance** *(dict) --* 
                If the task is for importing an instance, this contains information about the import instance task.
                - **Description** *(string) --* 
                  A description of the task.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **Platform** *(string) --* 
                  The instance operating system.
                - **Volumes** *(list) --* 
                  The volumes.
                  - *(dict) --* 
                    Describes an import volume task.
                    - **AvailabilityZone** *(string) --* 
                      The Availability Zone where the resulting instance will reside.
                    - **BytesConverted** *(integer) --* 
                      The number of bytes converted so far.
                    - **Description** *(string) --* 
                      A description of the task.
                    - **Image** *(dict) --* 
                      The image.
                      - **Checksum** *(string) --* 
                        The checksum computed for the disk image.
                      - **Format** *(string) --* 
                        The disk image format.
                      - **ImportManifestUrl** *(string) --* 
                        A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
                        For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
                      - **Size** *(integer) --* 
                        The size of the disk image, in GiB.
                    - **Status** *(string) --* 
                      The status of the import of this particular disk image.
                    - **StatusMessage** *(string) --* 
                      The status information or errors related to the disk image.
                    - **Volume** *(dict) --* 
                      The volume.
                      - **Id** *(string) --* 
                        The volume identifier.
                      - **Size** *(integer) --* 
                        The size of the volume, in GiB.
              - **ImportVolume** *(dict) --* 
                If the task is for importing a volume, this contains information about the import volume task.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone where the resulting volume will reside.
                - **BytesConverted** *(integer) --* 
                  The number of bytes converted so far.
                - **Description** *(string) --* 
                  The description you provided when starting the import volume task.
                - **Image** *(dict) --* 
                  The image.
                  - **Checksum** *(string) --* 
                    The checksum computed for the disk image.
                  - **Format** *(string) --* 
                    The disk image format.
                  - **ImportManifestUrl** *(string) --* 
                    A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
                    For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
                  - **Size** *(integer) --* 
                    The size of the disk image, in GiB.
                - **Volume** *(dict) --* 
                  The volume.
                  - **Id** *(string) --* 
                    The volume identifier.
                  - **Size** *(integer) --* 
                    The size of the volume, in GiB.
              - **State** *(string) --* 
                The state of the conversion task.
              - **StatusMessage** *(string) --* 
                The status message related to the conversion task.
              - **Tags** *(list) --* 
                Any tags assigned to the task.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type Description: string
        :param Description:
          A description for the instance being imported.
        :type DiskImages: list
        :param DiskImages:
          The disk image.
          - *(dict) --*
            Describes a disk image.
            - **Description** *(string) --*
              A description of the disk image.
            - **Image** *(dict) --*
              Information about the disk image.
              - **Bytes** *(integer) --* **[REQUIRED]**
                The size of the disk image, in GiB.
              - **Format** *(string) --* **[REQUIRED]**
                The disk image format.
              - **ImportManifestUrl** *(string) --* **[REQUIRED]**
                A presigned URL for the import manifest stored in Amazon S3 and presented here as an Amazon S3 presigned URL. For information about creating a presigned URL for an Amazon S3 object, read the \"Query String Request Authentication Alternative\" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
                For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
            - **Volume** *(dict) --*
              Information about the volume.
              - **Size** *(integer) --* **[REQUIRED]**
                The size of the volume, in GiB.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type LaunchSpecification: dict
        :param LaunchSpecification:
          The launch specification.
          - **AdditionalInfo** *(string) --*
            Reserved.
          - **Architecture** *(string) --*
            The architecture of the instance.
          - **GroupIds** *(list) --*
            The security group IDs.
            - *(string) --*
          - **GroupNames** *(list) --*
            The security group names.
            - *(string) --*
          - **InstanceInitiatedShutdownBehavior** *(string) --*
            Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
          - **InstanceType** *(string) --*
            The instance type. For more information about the instance types that you can import, see `Instance Types <https://docs.aws.amazon.com/vm-import/latest/userguide/vmie_prereqs.html#vmimport-instance-types>`__ in the VM Import/Export User Guide.
          - **Monitoring** *(boolean) --*
            Indicates whether monitoring is enabled.
          - **Placement** *(dict) --*
            The placement information for the instance.
            - **AvailabilityZone** *(string) --*
              The Availability Zone of the instance.
              If not specified, an Availability Zone will be automatically chosen for you based on the load balancing criteria for the region.
            - **Affinity** *(string) --*
              The affinity setting for the instance on the Dedicated Host. This parameter is not supported for the  ImportInstance command.
            - **GroupName** *(string) --*
              The name of the placement group the instance is in.
            - **PartitionNumber** *(integer) --*
              The number of the partition the instance is in. Valid only if the placement group strategy is set to ``partition`` .
            - **HostId** *(string) --*
              The ID of the Dedicated Host on which the instance resides. This parameter is not supported for the  ImportInstance command.
            - **Tenancy** *(string) --*
              The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for the  ImportInstance command.
            - **SpreadDomain** *(string) --*
              Reserved for future use.
          - **PrivateIpAddress** *(string) --*
            [EC2-VPC] An available IP address from the IP address range of the subnet.
          - **SubnetId** *(string) --*
            [EC2-VPC] The ID of the subnet in which to launch the instance.
          - **UserData** *(dict) --*
            The Base64-encoded user data to make available to the instance.
            - **Data** *(string) --*
              The user data. If you are using an AWS SDK or command line tool, Base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide Base64-encoded text.
        :type Platform: string
        :param Platform: **[REQUIRED]**
          The instance operating system.
        :rtype: dict
        :returns:
        """
        pass

    def import_key_pair(self, KeyName: str, PublicKeyMaterial: bytes, DryRun: bool = None) -> Dict:
        """
        Imports the public key from an RSA key pair that you created with a third-party tool. Compare this with  CreateKeyPair , in which AWS creates the key pair and gives the keys to you (AWS keeps a copy of the public key). With ImportKeyPair, you create the key pair and give AWS just the public key. The private key is never transferred between you and AWS.
        For more information about key pairs, see `Key Pairs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ImportKeyPair>`_
        
        **Request Syntax**
        ::
          response = client.import_key_pair(
              DryRun=True|False,
              KeyName='string',
              PublicKeyMaterial=b'bytes'
          )
        
        **Response Syntax**
        ::
            {
                'KeyFingerprint': 'string',
                'KeyName': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **KeyFingerprint** *(string) --* 
              The MD5 public key fingerprint as specified in section 4 of RFC 4716.
            - **KeyName** *(string) --* 
              The key pair name you provided.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type KeyName: string
        :param KeyName: **[REQUIRED]**
          A unique name for the key pair.
        :type PublicKeyMaterial: bytes
        :param PublicKeyMaterial: **[REQUIRED]**
          The public key. For API calls, the text must be base64-encoded. For command line tools, base64 encoding is performed for you.
        :rtype: dict
        :returns:
        """
        pass

    def import_snapshot(self, ClientData: Dict = None, ClientToken: str = None, Description: str = None, DiskContainer: Dict = None, DryRun: bool = None, Encrypted: bool = None, KmsKeyId: str = None, RoleName: str = None) -> Dict:
        """
        Imports a disk into an EBS snapshot.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ImportSnapshot>`_
        
        **Request Syntax**
        ::
          response = client.import_snapshot(
              ClientData={
                  'Comment': 'string',
                  'UploadEnd': datetime(2015, 1, 1),
                  'UploadSize': 123.0,
                  'UploadStart': datetime(2015, 1, 1)
              },
              ClientToken='string',
              Description='string',
              DiskContainer={
                  'Description': 'string',
                  'Format': 'string',
                  'Url': 'string',
                  'UserBucket': {
                      'S3Bucket': 'string',
                      'S3Key': 'string'
                  }
              },
              DryRun=True|False,
              Encrypted=True|False,
              KmsKeyId='string',
              RoleName='string'
          )
        
        **Response Syntax**
        ::
            {
                'Description': 'string',
                'ImportTaskId': 'string',
                'SnapshotTaskDetail': {
                    'Description': 'string',
                    'DiskImageSize': 123.0,
                    'Encrypted': True|False,
                    'Format': 'string',
                    'KmsKeyId': 'string',
                    'Progress': 'string',
                    'SnapshotId': 'string',
                    'Status': 'string',
                    'StatusMessage': 'string',
                    'Url': 'string',
                    'UserBucket': {
                        'S3Bucket': 'string',
                        'S3Key': 'string'
                    }
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for ImportSnapshot.
            - **Description** *(string) --* 
              A description of the import snapshot task.
            - **ImportTaskId** *(string) --* 
              The ID of the import snapshot task.
            - **SnapshotTaskDetail** *(dict) --* 
              Information about the import snapshot task.
              - **Description** *(string) --* 
                The description of the snapshot.
              - **DiskImageSize** *(float) --* 
                The size of the disk in the snapshot, in GiB.
              - **Encrypted** *(boolean) --* 
                Indicates whether the snapshot is encrypted.
              - **Format** *(string) --* 
                The format of the disk image from which the snapshot is created.
              - **KmsKeyId** *(string) --* 
                The identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) that was used to create the encrypted snapshot.
              - **Progress** *(string) --* 
                The percentage of completion for the import snapshot task.
              - **SnapshotId** *(string) --* 
                The snapshot ID of the disk being imported.
              - **Status** *(string) --* 
                A brief status for the import snapshot task.
              - **StatusMessage** *(string) --* 
                A detailed status message for the import snapshot task.
              - **Url** *(string) --* 
                The URL of the disk image from which the snapshot is created.
              - **UserBucket** *(dict) --* 
                The S3 bucket for the disk image.
                - **S3Bucket** *(string) --* 
                  The S3 bucket from which the disk image was created.
                - **S3Key** *(string) --* 
                  The file name of the disk image.
        :type ClientData: dict
        :param ClientData:
          The client-specific data.
          - **Comment** *(string) --*
            A user-defined comment about the disk upload.
          - **UploadEnd** *(datetime) --*
            The time that the disk upload ends.
          - **UploadSize** *(float) --*
            The size of the uploaded disk image, in GiB.
          - **UploadStart** *(datetime) --*
            The time that the disk upload starts.
        :type ClientToken: string
        :param ClientToken:
          Token to enable idempotency for VM import requests.
        :type Description: string
        :param Description:
          The description string for the import snapshot task.
        :type DiskContainer: dict
        :param DiskContainer:
          Information about the disk container.
          - **Description** *(string) --*
            The description of the disk image being imported.
          - **Format** *(string) --*
            The format of the disk image being imported.
            Valid values: ``VHD`` | ``VMDK``
          - **Url** *(string) --*
            The URL to the Amazon S3-based disk image being imported. It can either be a https URL (https://..) or an Amazon S3 URL (s3://..).
          - **UserBucket** *(dict) --*
            The S3 bucket for the disk image.
            - **S3Bucket** *(string) --*
              The name of the S3 bucket where the disk image is located.
            - **S3Key** *(string) --*
              The file name of the disk image.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Encrypted: boolean
        :param Encrypted:
          Specifies whether the destination snapshot of the imported image should be encrypted. The default CMK for EBS is used unless you specify a non-default AWS Key Management Service (AWS KMS) CMK using ``KmsKeyId`` . For more information, see `Amazon EBS Encryption <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type KmsKeyId: string
        :param KmsKeyId:
          An identifier for the AWS Key Management Service (AWS KMS) customer master key (CMK) to use when creating the encrypted snapshot. This parameter is only required if you want to use a non-default CMK; if this parameter is not specified, the default CMK for EBS is used. If a ``KmsKeyId`` is specified, the ``Encrypted`` flag must also be set.
          The CMK identifier may be provided in any of the following formats:
          * Key ID
          * Key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          * ARN using key ID. The ID ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``key`` namespace, and then the CMK ID. For example, arn:aws:kms:*us-east-1* :*012345678910* :key/*abcd1234-a123-456a-a12b-a123b4cd56ef* .
          * ARN using key alias. The alias ARN contains the ``arn:aws:kms`` namespace, followed by the region of the CMK, the AWS account ID of the CMK owner, the ``alias`` namespace, and then the CMK alias. For example, arn:aws:kms:*us-east-1* :*012345678910* :alias/*ExampleAlias* .
          AWS parses ``KmsKeyId`` asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. This action will eventually report failure.
          The specified CMK must exist in the region that the snapshot is being copied to.
        :type RoleName: string
        :param RoleName:
          The name of the role to use when not using the default role, \'vmimport\'.
        :rtype: dict
        :returns:
        """
        pass

    def import_volume(self, AvailabilityZone: str, Image: Dict, Volume: Dict, Description: str = None, DryRun: bool = None) -> Dict:
        """
        Creates an import volume task using metadata from the specified disk image.For more information, see `Importing Disks to Amazon EBS <https://docs.aws.amazon.com/AWSEC2/latest/CommandLineReference/importing-your-volumes-into-amazon-ebs.html>`__ .
        For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ImportVolume>`_
        
        **Request Syntax**
        ::
          response = client.import_volume(
              AvailabilityZone='string',
              Description='string',
              DryRun=True|False,
              Image={
                  'Bytes': 123,
                  'Format': 'VMDK'|'RAW'|'VHD',
                  'ImportManifestUrl': 'string'
              },
              Volume={
                  'Size': 123
              }
          )
        
        **Response Syntax**
        ::
            {
                'ConversionTask': {
                    'ConversionTaskId': 'string',
                    'ExpirationTime': 'string',
                    'ImportInstance': {
                        'Description': 'string',
                        'InstanceId': 'string',
                        'Platform': 'Windows',
                        'Volumes': [
                            {
                                'AvailabilityZone': 'string',
                                'BytesConverted': 123,
                                'Description': 'string',
                                'Image': {
                                    'Checksum': 'string',
                                    'Format': 'VMDK'|'RAW'|'VHD',
                                    'ImportManifestUrl': 'string',
                                    'Size': 123
                                },
                                'Status': 'string',
                                'StatusMessage': 'string',
                                'Volume': {
                                    'Id': 'string',
                                    'Size': 123
                                }
                            },
                        ]
                    },
                    'ImportVolume': {
                        'AvailabilityZone': 'string',
                        'BytesConverted': 123,
                        'Description': 'string',
                        'Image': {
                            'Checksum': 'string',
                            'Format': 'VMDK'|'RAW'|'VHD',
                            'ImportManifestUrl': 'string',
                            'Size': 123
                        },
                        'Volume': {
                            'Id': 'string',
                            'Size': 123
                        }
                    },
                    'State': 'active'|'cancelling'|'cancelled'|'completed',
                    'StatusMessage': 'string',
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output for ImportVolume.
            - **ConversionTask** *(dict) --* 
              Information about the conversion task.
              - **ConversionTaskId** *(string) --* 
                The ID of the conversion task.
              - **ExpirationTime** *(string) --* 
                The time when the task expires. If the upload isn't complete before the expiration time, we automatically cancel the task.
              - **ImportInstance** *(dict) --* 
                If the task is for importing an instance, this contains information about the import instance task.
                - **Description** *(string) --* 
                  A description of the task.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **Platform** *(string) --* 
                  The instance operating system.
                - **Volumes** *(list) --* 
                  The volumes.
                  - *(dict) --* 
                    Describes an import volume task.
                    - **AvailabilityZone** *(string) --* 
                      The Availability Zone where the resulting instance will reside.
                    - **BytesConverted** *(integer) --* 
                      The number of bytes converted so far.
                    - **Description** *(string) --* 
                      A description of the task.
                    - **Image** *(dict) --* 
                      The image.
                      - **Checksum** *(string) --* 
                        The checksum computed for the disk image.
                      - **Format** *(string) --* 
                        The disk image format.
                      - **ImportManifestUrl** *(string) --* 
                        A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
                        For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
                      - **Size** *(integer) --* 
                        The size of the disk image, in GiB.
                    - **Status** *(string) --* 
                      The status of the import of this particular disk image.
                    - **StatusMessage** *(string) --* 
                      The status information or errors related to the disk image.
                    - **Volume** *(dict) --* 
                      The volume.
                      - **Id** *(string) --* 
                        The volume identifier.
                      - **Size** *(integer) --* 
                        The size of the volume, in GiB.
              - **ImportVolume** *(dict) --* 
                If the task is for importing a volume, this contains information about the import volume task.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone where the resulting volume will reside.
                - **BytesConverted** *(integer) --* 
                  The number of bytes converted so far.
                - **Description** *(string) --* 
                  The description you provided when starting the import volume task.
                - **Image** *(dict) --* 
                  The image.
                  - **Checksum** *(string) --* 
                    The checksum computed for the disk image.
                  - **Format** *(string) --* 
                    The disk image format.
                  - **ImportManifestUrl** *(string) --* 
                    A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
                    For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
                  - **Size** *(integer) --* 
                    The size of the disk image, in GiB.
                - **Volume** *(dict) --* 
                  The volume.
                  - **Id** *(string) --* 
                    The volume identifier.
                  - **Size** *(integer) --* 
                    The size of the volume, in GiB.
              - **State** *(string) --* 
                The state of the conversion task.
              - **StatusMessage** *(string) --* 
                The status message related to the conversion task.
              - **Tags** *(list) --* 
                Any tags assigned to the task.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type AvailabilityZone: string
        :param AvailabilityZone: **[REQUIRED]**
          The Availability Zone for the resulting EBS volume.
        :type Description: string
        :param Description:
          A description of the volume.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Image: dict
        :param Image: **[REQUIRED]**
          The disk image.
          - **Bytes** *(integer) --* **[REQUIRED]**
            The size of the disk image, in GiB.
          - **Format** *(string) --* **[REQUIRED]**
            The disk image format.
          - **ImportManifestUrl** *(string) --* **[REQUIRED]**
            A presigned URL for the import manifest stored in Amazon S3 and presented here as an Amazon S3 presigned URL. For information about creating a presigned URL for an Amazon S3 object, read the \"Query String Request Authentication Alternative\" section of the `Authenticating REST Requests <https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html>`__ topic in the *Amazon Simple Storage Service Developer Guide* .
            For information about the import manifest referenced by this API action, see `VM Import Manifest <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html>`__ .
        :type Volume: dict
        :param Volume: **[REQUIRED]**
          The volume size.
          - **Size** *(integer) --* **[REQUIRED]**
            The size of the volume, in GiB.
        :rtype: dict
        :returns:
        """
        pass

    def modify_capacity_reservation(self, CapacityReservationId: str, InstanceCount: int = None, EndDate: datetime = None, EndDateType: str = None, DryRun: bool = None) -> Dict:
        """
        Modifies a Capacity Reservation's capacity and the conditions under which it is to be released. You cannot change a Capacity Reservation's instance type, EBS optimization, instance store settings, platform, Availability Zone, or instance eligibility. If you need to modify any of these attributes, we recommend that you cancel the Capacity Reservation, and then create a new one with the required attributes.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyCapacityReservation>`_
        
        **Request Syntax**
        ::
          response = client.modify_capacity_reservation(
              CapacityReservationId='string',
              InstanceCount=123,
              EndDate=datetime(2015, 1, 1),
              EndDateType='unlimited'|'limited',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Information about the Capacity Reservation.
        :type CapacityReservationId: string
        :param CapacityReservationId: **[REQUIRED]**
          The ID of the Capacity Reservation.
        :type InstanceCount: integer
        :param InstanceCount:
          The number of instances for which to reserve capacity.
        :type EndDate: datetime
        :param EndDate:
          The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation\'s state changes to ``expired`` when it reaches its end date and time.
          The Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019.
          You must provide an ``EndDate`` value if ``EndDateType`` is ``limited`` . Omit ``EndDate`` if ``EndDateType`` is ``unlimited`` .
        :type EndDateType: string
        :param EndDateType:
          Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:
          * ``unlimited`` - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an ``EndDate`` value if ``EndDateType`` is ``unlimited`` .
          * ``limited`` - The Capacity Reservation expires automatically at a specified date and time. You must provide an ``EndDate`` value if ``EndDateType`` is ``limited`` .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def modify_client_vpn_endpoint(self, ClientVpnEndpointId: str, ServerCertificateArn: str = None, ConnectionLogOptions: Dict = None, DnsServers: Dict = None, Description: str = None, DryRun: bool = None) -> Dict:
        """
        Modifies the specified Client VPN endpoint. You can only modify an endpoint's server certificate information, client connection logging information, DNS server, and description. Modifying the DNS server resets existing client connections.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyClientVpnEndpoint>`_
        
        **Request Syntax**
        ::
          response = client.modify_client_vpn_endpoint(
              ClientVpnEndpointId='string',
              ServerCertificateArn='string',
              ConnectionLogOptions={
                  'Enabled': True|False,
                  'CloudwatchLogGroup': 'string',
                  'CloudwatchLogStream': 'string'
              },
              DnsServers={
                  'CustomDnsServers': [
                      'string',
                  ],
                  'Enabled': True|False
              },
              Description='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint to modify.
        :type ServerCertificateArn: string
        :param ServerCertificateArn:
          The ARN of the server certificate to be used. The server certificate must be provisioned in AWS Certificate Manager (ACM).
        :type ConnectionLogOptions: dict
        :param ConnectionLogOptions:
          Information about the client connection logging options.
          If you enable client connection logging, data about client connections is sent to a Cloudwatch Logs log stream. The following information is logged:
          * Client connection requests
          * Client connection results (successful and unsuccessful)
          * Reasons for unsuccessful client connection requests
          * Client connection termination time
          - **Enabled** *(boolean) --*
            Indicates whether connection logging is enabled.
          - **CloudwatchLogGroup** *(string) --*
            The name of the CloudWatch Logs log group.
          - **CloudwatchLogStream** *(string) --*
            The name of the CloudWatch Logs log stream to which the connection data is published.
        :type DnsServers: dict
        :param DnsServers:
          Information about the DNS servers to be used by Client VPN connections. A Client VPN endpoint can have up to two DNS servers.
          - **CustomDnsServers** *(list) --*
            The IPv4 address range, in CIDR notation, of the DNS servers to be used. You can specify up to two DNS servers. Ensure that the DNS servers can be reached by the clients. The specified values overwrite the existing values.
            - *(string) --*
          - **Enabled** *(boolean) --*
            Indicates whether DNS servers should be used. Specify ``False`` to delete the existing DNS servers.
        :type Description: string
        :param Description:
          A brief description of the Client VPN endpoint.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def modify_fleet(self, FleetId: str, TargetCapacitySpecification: Dict, DryRun: bool = None, ExcessCapacityTerminationPolicy: str = None) -> Dict:
        """
        Modifies the specified EC2 Fleet.
        While the EC2 Fleet is being modified, it is in the ``modifying`` state.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyFleet>`_
        
        **Request Syntax**
        ::
          response = client.modify_fleet(
              DryRun=True|False,
              ExcessCapacityTerminationPolicy='no-termination'|'termination',
              FleetId='string',
              TargetCapacitySpecification={
                  'TotalTargetCapacity': 123,
                  'OnDemandTargetCapacity': 123,
                  'SpotTargetCapacity': 123,
                  'DefaultTargetCapacityType': 'spot'|'on-demand'
              }
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Is ``true`` if the request succeeds, and an error otherwise.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ExcessCapacityTerminationPolicy: string
        :param ExcessCapacityTerminationPolicy:
          Indicates whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet.
        :type FleetId: string
        :param FleetId: **[REQUIRED]**
          The ID of the EC2 Fleet.
        :type TargetCapacitySpecification: dict
        :param TargetCapacitySpecification: **[REQUIRED]**
          The size of the EC2 Fleet.
          - **TotalTargetCapacity** *(integer) --* **[REQUIRED]**
            The number of units to request, filled using ``DefaultTargetCapacityType`` .
          - **OnDemandTargetCapacity** *(integer) --*
            The number of On-Demand units to request.
          - **SpotTargetCapacity** *(integer) --*
            The number of Spot units to request.
          - **DefaultTargetCapacityType** *(string) --*
            The default ``TotalTargetCapacity`` , which is either ``Spot`` or ``On-Demand`` .
        :rtype: dict
        :returns:
        """
        pass

    def modify_fpga_image_attribute(self, FpgaImageId: str, DryRun: bool = None, Attribute: str = None, OperationType: str = None, UserIds: List = None, UserGroups: List = None, ProductCodes: List = None, LoadPermission: Dict = None, Description: str = None, Name: str = None) -> Dict:
        """
        Modifies the specified attribute of the specified Amazon FPGA Image (AFI).
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyFpgaImageAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_fpga_image_attribute(
              DryRun=True|False,
              FpgaImageId='string',
              Attribute='description'|'name'|'loadPermission'|'productCodes',
              OperationType='add'|'remove',
              UserIds=[
                  'string',
              ],
              UserGroups=[
                  'string',
              ],
              ProductCodes=[
                  'string',
              ],
              LoadPermission={
                  'Add': [
                      {
                          'Group': 'all',
                          'UserId': 'string'
                      },
                  ],
                  'Remove': [
                      {
                          'Group': 'all',
                          'UserId': 'string'
                      },
                  ]
              },
              Description='string',
              Name='string'
          )
        
        **Response Syntax**
        ::
            {
                'FpgaImageAttribute': {
                    'FpgaImageId': 'string',
                    'Name': 'string',
                    'Description': 'string',
                    'LoadPermissions': [
                        {
                            'UserId': 'string',
                            'Group': 'all'
                        },
                    ],
                    'ProductCodes': [
                        {
                            'ProductCodeId': 'string',
                            'ProductCodeType': 'devpay'|'marketplace'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **FpgaImageAttribute** *(dict) --* 
              Information about the attribute.
              - **FpgaImageId** *(string) --* 
                The ID of the AFI.
              - **Name** *(string) --* 
                The name of the AFI.
              - **Description** *(string) --* 
                The description of the AFI.
              - **LoadPermissions** *(list) --* 
                The load permissions.
                - *(dict) --* 
                  Describes a load permission.
                  - **UserId** *(string) --* 
                    The AWS account ID.
                  - **Group** *(string) --* 
                    The name of the group.
              - **ProductCodes** *(list) --* 
                The product codes.
                - *(dict) --* 
                  Describes a product code.
                  - **ProductCodeId** *(string) --* 
                    The product code.
                  - **ProductCodeType** *(string) --* 
                    The type of product code.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type FpgaImageId: string
        :param FpgaImageId: **[REQUIRED]**
          The ID of the AFI.
        :type Attribute: string
        :param Attribute:
          The name of the attribute.
        :type OperationType: string
        :param OperationType:
          The operation type.
        :type UserIds: list
        :param UserIds:
          The AWS account IDs. This parameter is valid only when modifying the ``loadPermission`` attribute.
          - *(string) --*
        :type UserGroups: list
        :param UserGroups:
          The user groups. This parameter is valid only when modifying the ``loadPermission`` attribute.
          - *(string) --*
        :type ProductCodes: list
        :param ProductCodes:
          The product codes. After you add a product code to an AFI, it can\'t be removed. This parameter is valid only when modifying the ``productCodes`` attribute.
          - *(string) --*
        :type LoadPermission: dict
        :param LoadPermission:
          The load permission for the AFI.
          - **Add** *(list) --*
            The load permissions to add.
            - *(dict) --*
              Describes a load permission.
              - **Group** *(string) --*
                The name of the group.
              - **UserId** *(string) --*
                The AWS account ID.
          - **Remove** *(list) --*
            The load permissions to remove.
            - *(dict) --*
              Describes a load permission.
              - **Group** *(string) --*
                The name of the group.
              - **UserId** *(string) --*
                The AWS account ID.
        :type Description: string
        :param Description:
          A description for the AFI.
        :type Name: string
        :param Name:
          A name for the AFI.
        :rtype: dict
        :returns:
        """
        pass

    def modify_hosts(self, AutoPlacement: str, HostIds: List) -> Dict:
        """
        Modify the auto-placement setting of a Dedicated Host. When auto-placement is enabled, any instances that you launch with a tenancy of ``host`` but without a specific host ID are placed onto any available Dedicated Host in your account that has auto-placement enabled. When auto-placement is disabled, you need to provide a host ID to have the instance launch onto a specific host. If no host ID is provided, the instance is launched onto a suitable host with auto-placement enabled.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyHosts>`_
        
        **Request Syntax**
        ::
          response = client.modify_hosts(
              AutoPlacement='on'|'off',
              HostIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Successful': [
                    'string',
                ],
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Successful** *(list) --* 
              The IDs of the Dedicated Hosts that were successfully modified.
              - *(string) --* 
            - **Unsuccessful** *(list) --* 
              The IDs of the Dedicated Hosts that could not be modified. Check whether the setting you requested can be used.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type AutoPlacement: string
        :param AutoPlacement: **[REQUIRED]**
          Specify whether to enable or disable auto-placement.
        :type HostIds: list
        :param HostIds: **[REQUIRED]**
          The IDs of the Dedicated Hosts to modify.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def modify_id_format(self, Resource: str, UseLongIds: bool):
        """
        Modifies the ID format for the specified resource on a per-region basis. You can specify that resources should receive longer IDs (17-character IDs) when they are created.
        This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``subnet`` | ``subnet-cidr-block-association`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` .
        This setting applies to the IAM user who makes the request; it does not apply to the entire AWS account. By default, an IAM user defaults to the same settings as the root user. If you're using this action as the root user, then these settings apply to the entire account, unless an IAM user explicitly overrides these settings for themselves. For more information, see `Resource IDs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/resource-ids.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant ``Describe`` command for the resource type.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyIdFormat>`_
        
        **Request Syntax**
        ::
          response = client.modify_id_format(
              Resource='string',
              UseLongIds=True|False
          )
        :type Resource: string
        :param Resource: **[REQUIRED]**
          The type of resource: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``subnet`` | ``subnet-cidr-block-association`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` .
          Alternatively, use the ``all-current`` option to include all resource types that are currently within their opt-in period for longer IDs.
        :type UseLongIds: boolean
        :param UseLongIds: **[REQUIRED]**
          Indicate whether the resource should use longer IDs (17-character IDs).
        :returns: None
        """
        pass

    def modify_identity_id_format(self, PrincipalArn: str, Resource: str, UseLongIds: bool):
        """
        Modifies the ID format of a resource for a specified IAM user, IAM role, or the root user for an account; or all IAM users, IAM roles, and the root user for an account. You can specify that resources should receive longer IDs (17-character IDs) when they are created. 
        This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``subnet`` | ``subnet-cidr-block-association`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` . 
        For more information, see `Resource IDs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/resource-ids.html>`__ in the *Amazon Elastic Compute Cloud User Guide* . 
        This setting applies to the principal specified in the request; it does not apply to the principal that makes the request. 
        Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant ``Describe`` command for the resource type.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyIdentityIdFormat>`_
        
        **Request Syntax**
        ::
          response = client.modify_identity_id_format(
              PrincipalArn='string',
              Resource='string',
              UseLongIds=True|False
          )
        :type PrincipalArn: string
        :param PrincipalArn: **[REQUIRED]**
          The ARN of the principal, which can be an IAM user, IAM role, or the root user. Specify ``all`` to modify the ID format for all IAM users, IAM roles, and the root user of the account.
        :type Resource: string
        :param Resource: **[REQUIRED]**
          The type of resource: ``bundle`` | ``conversion-task`` | ``customer-gateway`` | ``dhcp-options`` | ``elastic-ip-allocation`` | ``elastic-ip-association`` | ``export-task`` | ``flow-log`` | ``image`` | ``import-task`` | ``internet-gateway`` | ``network-acl`` | ``network-acl-association`` | ``network-interface`` | ``network-interface-attachment`` | ``prefix-list`` | ``route-table`` | ``route-table-association`` | ``security-group`` | ``subnet`` | ``subnet-cidr-block-association`` | ``vpc`` | ``vpc-cidr-block-association`` | ``vpc-endpoint`` | ``vpc-peering-connection`` | ``vpn-connection`` | ``vpn-gateway`` .
          Alternatively, use the ``all-current`` option to include all resource types that are currently within their opt-in period for longer IDs.
        :type UseLongIds: boolean
        :param UseLongIds: **[REQUIRED]**
          Indicates whether the resource should use longer IDs (17-character IDs)
        :returns: None
        """
        pass

    def modify_image_attribute(self, ImageId: str, Attribute: str = None, Description: Dict = None, LaunchPermission: Dict = None, OperationType: str = None, ProductCodes: List = None, UserGroups: List = None, UserIds: List = None, Value: str = None, DryRun: bool = None):
        """
        Modifies the specified attribute of the specified AMI. You can specify only one attribute at a time. You can use the ``Attribute`` parameter to specify the attribute or one of the following parameters: ``Description`` , ``LaunchPermission`` , or ``ProductCode`` .
        AWS Marketplace product codes cannot be modified. Images with an AWS Marketplace product code cannot be made public.
        To enable the SriovNetSupport enhanced networking attribute of an image, enable SriovNetSupport on an instance and create an AMI from the instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyImageAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_image_attribute(
              Attribute='string',
              Description={
                  'Value': 'string'
              },
              ImageId='string',
              LaunchPermission={
                  'Add': [
                      {
                          'Group': 'all',
                          'UserId': 'string'
                      },
                  ],
                  'Remove': [
                      {
                          'Group': 'all',
                          'UserId': 'string'
                      },
                  ]
              },
              OperationType='add'|'remove',
              ProductCodes=[
                  'string',
              ],
              UserGroups=[
                  'string',
              ],
              UserIds=[
                  'string',
              ],
              Value='string',
              DryRun=True|False
          )
        :type Attribute: string
        :param Attribute:
          The name of the attribute to modify. The valid values are ``description`` , ``launchPermission`` , and ``productCodes`` .
        :type Description: dict
        :param Description:
          A new description for the AMI.
          - **Value** *(string) --*
            The attribute value. The value is case-sensitive.
        :type ImageId: string
        :param ImageId: **[REQUIRED]**
          The ID of the AMI.
        :type LaunchPermission: dict
        :param LaunchPermission:
          A new launch permission for the AMI.
          - **Add** *(list) --*
            The AWS account ID to add to the list of launch permissions for the AMI.
            - *(dict) --*
              Describes a launch permission.
              - **Group** *(string) --*
                The name of the group.
              - **UserId** *(string) --*
                The AWS account ID.
          - **Remove** *(list) --*
            The AWS account ID to remove from the list of launch permissions for the AMI.
            - *(dict) --*
              Describes a launch permission.
              - **Group** *(string) --*
                The name of the group.
              - **UserId** *(string) --*
                The AWS account ID.
        :type OperationType: string
        :param OperationType:
          The operation type. This parameter can be used only when the ``Attribute`` parameter is ``launchPermission`` .
        :type ProductCodes: list
        :param ProductCodes:
          The DevPay product codes. After you add a product code to an AMI, it can\'t be removed.
          - *(string) --*
        :type UserGroups: list
        :param UserGroups:
          The user groups. This parameter can be used only when the ``Attribute`` parameter is ``launchPermission`` .
          - *(string) --*
        :type UserIds: list
        :param UserIds:
          The AWS account IDs. This parameter can be used only when the ``Attribute`` parameter is ``launchPermission`` .
          - *(string) --*
        :type Value: string
        :param Value:
          The value of the attribute being modified. This parameter can be used only when the ``Attribute`` parameter is ``description`` or ``productCodes`` .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def modify_instance_attribute(self, InstanceId: str, SourceDestCheck: Dict = None, Attribute: str = None, BlockDeviceMappings: List = None, DisableApiTermination: Dict = None, DryRun: bool = None, EbsOptimized: Dict = None, EnaSupport: Dict = None, Groups: List = None, InstanceInitiatedShutdownBehavior: Dict = None, InstanceType: Dict = None, Kernel: Dict = None, Ramdisk: Dict = None, SriovNetSupport: Dict = None, UserData: Dict = None, Value: str = None):
        """
        Modifies the specified attribute of the specified instance. You can specify only one attribute at a time.
         **Note:** Using this action to change the security groups associated with an elastic network interface (ENI) attached to an instance in a VPC can result in an error if the instance has more than one ENI. To change the security groups associated with an ENI attached to an instance that has multiple ENIs, we recommend that you use the  ModifyNetworkInterfaceAttribute action.
        To modify some attributes, the instance must be stopped. For more information, see `Modifying Attributes of a Stopped Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_ChangingAttributesWhileInstanceStopped.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyInstanceAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_instance_attribute(
              SourceDestCheck={
                  'Value': True|False
              },
              Attribute='instanceType'|'kernel'|'ramdisk'|'userData'|'disableApiTermination'|'instanceInitiatedShutdownBehavior'|'rootDeviceName'|'blockDeviceMapping'|'productCodes'|'sourceDestCheck'|'groupSet'|'ebsOptimized'|'sriovNetSupport'|'enaSupport',
              BlockDeviceMappings=[
                  {
                      'DeviceName': 'string',
                      'Ebs': {
                          'DeleteOnTermination': True|False,
                          'VolumeId': 'string'
                      },
                      'NoDevice': 'string',
                      'VirtualName': 'string'
                  },
              ],
              DisableApiTermination={
                  'Value': True|False
              },
              DryRun=True|False,
              EbsOptimized={
                  'Value': True|False
              },
              EnaSupport={
                  'Value': True|False
              },
              Groups=[
                  'string',
              ],
              InstanceId='string',
              InstanceInitiatedShutdownBehavior={
                  'Value': 'string'
              },
              InstanceType={
                  'Value': 'string'
              },
              Kernel={
                  'Value': 'string'
              },
              Ramdisk={
                  'Value': 'string'
              },
              SriovNetSupport={
                  'Value': 'string'
              },
              UserData={
                  'Value': b'bytes'
              },
              Value='string'
          )
        :type SourceDestCheck: dict
        :param SourceDestCheck:
          Specifies whether source/destination checking is enabled. A value of ``true`` means that checking is enabled, and ``false`` means that checking is disabled. This value must be ``false`` for a NAT instance to perform NAT.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type Attribute: string
        :param Attribute:
          The name of the attribute.
        :type BlockDeviceMappings: list
        :param BlockDeviceMappings:
          Modifies the ``DeleteOnTermination`` attribute for volumes that are currently attached. The volume must be owned by the caller. If no value is specified for ``DeleteOnTermination`` , the default is ``true`` and the volume is deleted when the instance is terminated.
          To add instance store volumes to an Amazon EBS-backed instance, you must add them when you launch the instance. For more information, see `Updating the Block Device Mapping when Launching an Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/block-device-mapping-concepts.html#Using_OverridingAMIBDM>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - *(dict) --*
            Describes a block device mapping entry.
            - **DeviceName** *(string) --*
              The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
            - **Ebs** *(dict) --*
              Parameters used to automatically set up EBS volumes when the instance is launched.
              - **DeleteOnTermination** *(boolean) --*
                Indicates whether the volume is deleted on instance termination.
              - **VolumeId** *(string) --*
                The ID of the EBS volume.
            - **NoDevice** *(string) --*
              suppress the specified device included in the block device mapping.
            - **VirtualName** *(string) --*
              The virtual device name.
        :type DisableApiTermination: dict
        :param DisableApiTermination:
          If the value is ``true`` , you can\'t terminate the instance using the Amazon EC2 console, CLI, or API; otherwise, you can. You cannot use this parameter for Spot Instances.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EbsOptimized: dict
        :param EbsOptimized:
          Specifies whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type EnaSupport: dict
        :param EnaSupport:
          Set to ``true`` to enable enhanced networking with ENA for the instance.
          This option is supported only for HVM instances. Specifying this option with a PV instance can make it unreachable.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type Groups: list
        :param Groups:
          [EC2-VPC] Changes the security groups of the instance. You must specify at least one security group, even if it\'s just the default security group for the VPC. You must specify the security group ID, not the security group name.
          - *(string) --*
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :type InstanceInitiatedShutdownBehavior: dict
        :param InstanceInitiatedShutdownBehavior:
          Specifies whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
          - **Value** *(string) --*
            The attribute value. The value is case-sensitive.
        :type InstanceType: dict
        :param InstanceType:
          Changes the instance type to the specified value. For more information, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ . If the instance type is not valid, the error returned is ``InvalidInstanceAttributeValue`` .
          - **Value** *(string) --*
            The attribute value. The value is case-sensitive.
        :type Kernel: dict
        :param Kernel:
          Changes the instance\'s kernel to the specified value. We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `PV-GRUB <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedKernels.html>`__ .
          - **Value** *(string) --*
            The attribute value. The value is case-sensitive.
        :type Ramdisk: dict
        :param Ramdisk:
          Changes the instance\'s RAM disk to the specified value. We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `PV-GRUB <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedKernels.html>`__ .
          - **Value** *(string) --*
            The attribute value. The value is case-sensitive.
        :type SriovNetSupport: dict
        :param SriovNetSupport:
          Set to ``simple`` to enable enhanced networking with the Intel 82599 Virtual Function interface for the instance.
          There is no way to disable enhanced networking with the Intel 82599 Virtual Function interface at this time.
          This option is supported only for HVM instances. Specifying this option with a PV instance can make it unreachable.
          - **Value** *(string) --*
            The attribute value. The value is case-sensitive.
        :type UserData: dict
        :param UserData:
          Changes the instance\'s user data to the specified value. If you are using an AWS SDK or command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text.
          - **Value** *(bytes) --*
        :type Value: string
        :param Value:
          A new value for the attribute. Use only with the ``kernel`` , ``ramdisk`` , ``userData`` , ``disableApiTermination`` , or ``instanceInitiatedShutdownBehavior`` attribute.
        :returns: None
        """
        pass

    def modify_instance_capacity_reservation_attributes(self, InstanceId: str, CapacityReservationSpecification: Dict, DryRun: bool = None) -> Dict:
        """
        Modifies the Capacity Reservation settings for a stopped instance. Use this action to configure an instance to target a specific Capacity Reservation, run in any ``open`` Capacity Reservation with matching attributes, or run On-Demand Instance capacity.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyInstanceCapacityReservationAttributes>`_
        
        **Request Syntax**
        ::
          response = client.modify_instance_capacity_reservation_attributes(
              InstanceId='string',
              CapacityReservationSpecification={
                  'CapacityReservationPreference': 'open'|'none',
                  'CapacityReservationTarget': {
                      'CapacityReservationId': 'string'
                  }
              },
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance to be modified.
        :type CapacityReservationSpecification: dict
        :param CapacityReservationSpecification: **[REQUIRED]**
          Information about the Capacity Reservation targeting option.
          - **CapacityReservationPreference** *(string) --*
            Indicates the instance\'s Capacity Reservation preferences. Possible preferences include:
            * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
            * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs as an On-Demand Instance.
          - **CapacityReservationTarget** *(dict) --*
            Information about the target Capacity Reservation.
            - **CapacityReservationId** *(string) --*
              The ID of the Capacity Reservation.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def modify_instance_credit_specification(self, InstanceCreditSpecifications: List, DryRun: bool = None, ClientToken: str = None) -> Dict:
        """
        Modifies the credit option for CPU usage on a running or stopped T2 or T3 instance. The credit options are ``standard`` and ``unlimited`` .
        For more information, see `Burstable Performance Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyInstanceCreditSpecification>`_
        
        **Request Syntax**
        ::
          response = client.modify_instance_credit_specification(
              DryRun=True|False,
              ClientToken='string',
              InstanceCreditSpecifications=[
                  {
                      'InstanceId': 'string',
                      'CpuCredits': 'string'
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'SuccessfulInstanceCreditSpecifications': [
                    {
                        'InstanceId': 'string'
                    },
                ],
                'UnsuccessfulInstanceCreditSpecifications': [
                    {
                        'InstanceId': 'string',
                        'Error': {
                            'Code': 'InvalidInstanceID.Malformed'|'InvalidInstanceID.NotFound'|'IncorrectInstanceState'|'InstanceCreditSpecification.NotSupported',
                            'Message': 'string'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **SuccessfulInstanceCreditSpecifications** *(list) --* 
              Information about the instances whose credit option for CPU usage was successfully modified.
              - *(dict) --* 
                Describes the T2 or T3 instance whose credit option for CPU usage was successfully modified.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
            - **UnsuccessfulInstanceCreditSpecifications** *(list) --* 
              Information about the instances whose credit option for CPU usage was not modified.
              - *(dict) --* 
                Describes the T2 or T3 instance whose credit option for CPU usage was not modified.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **Error** *(dict) --* 
                  The applicable error for the T2 or T3 instance whose credit option for CPU usage was not modified.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The applicable error message.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ClientToken: string
        :param ClientToken:
          A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
        :type InstanceCreditSpecifications: list
        :param InstanceCreditSpecifications: **[REQUIRED]**
          Information about the credit option for CPU usage.
          - *(dict) --*
            Describes the credit option for CPU usage of a T2 or T3 instance.
            - **InstanceId** *(string) --*
              The ID of the instance.
            - **CpuCredits** *(string) --*
              The credit option for CPU usage of the instance. Valid values are ``standard`` and ``unlimited`` .
        :rtype: dict
        :returns:
        """
        pass

    def modify_instance_event_start_time(self, InstanceId: str, InstanceEventId: str, NotBefore: datetime, DryRun: bool = None) -> Dict:
        """
        Modifies the start time for a scheduled Amazon EC2 instance event.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyInstanceEventStartTime>`_
        
        **Request Syntax**
        ::
          response = client.modify_instance_event_start_time(
              DryRun=True|False,
              InstanceId='string',
              InstanceEventId='string',
              NotBefore=datetime(2015, 1, 1)
          )
        
        **Response Syntax**
        ::
            {
                'Event': {
                    'InstanceEventId': 'string',
                    'Code': 'instance-reboot'|'system-reboot'|'system-maintenance'|'instance-retirement'|'instance-stop',
                    'Description': 'string',
                    'NotAfter': datetime(2015, 1, 1),
                    'NotBefore': datetime(2015, 1, 1),
                    'NotBeforeDeadline': datetime(2015, 1, 1)
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Event** *(dict) --* 
              Describes a scheduled event for an instance.
              - **InstanceEventId** *(string) --* 
                The ID of the event.
              - **Code** *(string) --* 
                The event code.
              - **Description** *(string) --* 
                A description of the event.
                After a scheduled event is completed, it can still be described for up to a week. If the event has been completed, this description starts with the following text: [Completed].
              - **NotAfter** *(datetime) --* 
                The latest scheduled end time for the event.
              - **NotBefore** *(datetime) --* 
                The earliest scheduled start time for the event.
              - **NotBeforeDeadline** *(datetime) --* 
                The deadline for starting the event.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance with the scheduled event.
        :type InstanceEventId: string
        :param InstanceEventId: **[REQUIRED]**
          The ID of the event whose date and time you are modifying.
        :type NotBefore: datetime
        :param NotBefore: **[REQUIRED]**
          The new date and time when the event will take place.
        :rtype: dict
        :returns:
        """
        pass

    def modify_instance_placement(self, InstanceId: str, Affinity: str = None, GroupName: str = None, HostId: str = None, Tenancy: str = None, PartitionNumber: int = None) -> Dict:
        """
        Modifies the placement attributes for a specified instance. You can do the following:
        * Modify the affinity between an instance and a `Dedicated Host <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-hosts-overview.html>`__ . When affinity is set to ``host`` and the instance is not associated with a specific Dedicated Host, the next time the instance is launched, it is automatically associated with the host on which it lands. If the instance is restarted or rebooted, this relationship persists. 
        * Change the Dedicated Host with which an instance is associated. 
        * Change the instance tenancy of an instance from ``host`` to ``dedicated`` , or from ``dedicated`` to ``host`` . 
        * Move an instance to or from a `placement group <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html>`__ . 
        At least one attribute for affinity, host ID, tenancy, or placement group name must be specified in the request. Affinity and tenancy can be modified in the same request.
        To modify the host ID, tenancy, placement group, or partition for an instance, the instance must be in the ``stopped`` state.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyInstancePlacement>`_
        
        **Request Syntax**
        ::
          response = client.modify_instance_placement(
              Affinity='default'|'host',
              GroupName='string',
              HostId='string',
              InstanceId='string',
              Tenancy='dedicated'|'host',
              PartitionNumber=123
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Is ``true`` if the request succeeds, and an error otherwise.
        :type Affinity: string
        :param Affinity:
          The affinity setting for the instance.
        :type GroupName: string
        :param GroupName:
          The name of the placement group in which to place the instance. For spread placement groups, the instance must have a tenancy of ``default`` . For cluster and partition placement groups, the instance must have a tenancy of ``default`` or ``dedicated`` .
          To remove an instance from a placement group, specify an empty string (\"\").
        :type HostId: string
        :param HostId:
          The ID of the Dedicated Host with which to associate the instance.
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance that you are modifying.
        :type Tenancy: string
        :param Tenancy:
          The tenancy for the instance.
        :type PartitionNumber: integer
        :param PartitionNumber:
          Reserved for future use.
        :rtype: dict
        :returns:
        """
        pass

    def modify_launch_template(self, DryRun: bool = None, ClientToken: str = None, LaunchTemplateId: str = None, LaunchTemplateName: str = None, DefaultVersion: str = None) -> Dict:
        """
        Modifies a launch template. You can specify which version of the launch template to set as the default version. When launching an instance, the default version applies when a launch template version is not specified.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyLaunchTemplate>`_
        
        **Request Syntax**
        ::
          response = client.modify_launch_template(
              DryRun=True|False,
              ClientToken='string',
              LaunchTemplateId='string',
              LaunchTemplateName='string',
              DefaultVersion='string'
          )
        
        **Response Syntax**
        ::
            {
                'LaunchTemplate': {
                    'LaunchTemplateId': 'string',
                    'LaunchTemplateName': 'string',
                    'CreateTime': datetime(2015, 1, 1),
                    'CreatedBy': 'string',
                    'DefaultVersionNumber': 123,
                    'LatestVersionNumber': 123,
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **LaunchTemplate** *(dict) --* 
              Information about the launch template.
              - **LaunchTemplateId** *(string) --* 
                The ID of the launch template.
              - **LaunchTemplateName** *(string) --* 
                The name of the launch template.
              - **CreateTime** *(datetime) --* 
                The time launch template was created.
              - **CreatedBy** *(string) --* 
                The principal that created the launch template. 
              - **DefaultVersionNumber** *(integer) --* 
                The version number of the default version of the launch template.
              - **LatestVersionNumber** *(integer) --* 
                The version number of the latest version of the launch template.
              - **Tags** *(list) --* 
                The tags for the launch template.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          Constraint: Maximum 128 ASCII characters.
        :type LaunchTemplateId: string
        :param LaunchTemplateId:
          The ID of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type LaunchTemplateName: string
        :param LaunchTemplateName:
          The name of the launch template. You must specify either the launch template ID or launch template name in the request.
        :type DefaultVersion: string
        :param DefaultVersion:
          The version number of the launch template to set as the default version.
        :rtype: dict
        :returns:
        """
        pass

    def modify_network_interface_attribute(self, NetworkInterfaceId: str, Attachment: Dict = None, Description: Dict = None, DryRun: bool = None, Groups: List = None, SourceDestCheck: Dict = None):
        """
        Modifies the specified network interface attribute. You can specify only one attribute at a time. You can use this action to attach and detach security groups from an existing EC2 instance.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyNetworkInterfaceAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_network_interface_attribute(
              Attachment={
                  'AttachmentId': 'string',
                  'DeleteOnTermination': True|False
              },
              Description={
                  'Value': 'string'
              },
              DryRun=True|False,
              Groups=[
                  'string',
              ],
              NetworkInterfaceId='string',
              SourceDestCheck={
                  'Value': True|False
              }
          )
        :type Attachment: dict
        :param Attachment:
          Information about the interface attachment. If modifying the \'delete on termination\' attribute, you must specify the ID of the interface attachment.
          - **AttachmentId** *(string) --*
            The ID of the network interface attachment.
          - **DeleteOnTermination** *(boolean) --*
            Indicates whether the network interface is deleted when the instance is terminated.
        :type Description: dict
        :param Description:
          A description for the network interface.
          - **Value** *(string) --*
            The attribute value. The value is case-sensitive.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Groups: list
        :param Groups:
          Changes the security groups for the network interface. The new set of groups you specify replaces the current set. You must specify at least one group, even if it\'s just the default security group in the VPC. You must specify the ID of the security group, not the name.
          - *(string) --*
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :type SourceDestCheck: dict
        :param SourceDestCheck:
          Indicates whether source/destination checking is enabled. A value of ``true`` means checking is enabled, and ``false`` means checking is disabled. This value must be ``false`` for a NAT instance to perform NAT. For more information, see `NAT Instances <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_NAT_Instance.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :returns: None
        """
        pass

    def modify_reserved_instances(self, ReservedInstancesIds: List, TargetConfigurations: List, ClientToken: str = None) -> Dict:
        """
        Modifies the Availability Zone, instance count, instance type, or network platform (EC2-Classic or EC2-VPC) of your Reserved Instances. The Reserved Instances to be modified must be identical, except for Availability Zone, network platform, and instance type.
        For more information, see `Modifying Reserved Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-modifying.html>`__ in the Amazon Elastic Compute Cloud User Guide.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyReservedInstances>`_
        
        **Request Syntax**
        ::
          response = client.modify_reserved_instances(
              ReservedInstancesIds=[
                  'string',
              ],
              ClientToken='string',
              TargetConfigurations=[
                  {
                      'AvailabilityZone': 'string',
                      'InstanceCount': 123,
                      'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                      'Platform': 'string',
                      'Scope': 'Availability Zone'|'Region'
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ReservedInstancesModificationId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of ModifyReservedInstances.
            - **ReservedInstancesModificationId** *(string) --* 
              The ID for the modification.
        :type ReservedInstancesIds: list
        :param ReservedInstancesIds: **[REQUIRED]**
          The IDs of the Reserved Instances to modify.
          - *(string) --*
        :type ClientToken: string
        :param ClientToken:
          A unique, case-sensitive token you provide to ensure idempotency of your modification request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
        :type TargetConfigurations: list
        :param TargetConfigurations: **[REQUIRED]**
          The configuration settings for the Reserved Instances to modify.
          - *(dict) --*
            Describes the configuration settings for the modified Reserved Instances.
            - **AvailabilityZone** *(string) --*
              The Availability Zone for the modified Reserved Instances.
            - **InstanceCount** *(integer) --*
              The number of modified Reserved Instances.
              .. note::
                This is a required field for a request.
            - **InstanceType** *(string) --*
              The instance type for the modified Reserved Instances.
            - **Platform** *(string) --*
              The network platform of the modified Reserved Instances, which is either EC2-Classic or EC2-VPC.
            - **Scope** *(string) --*
              Whether the Reserved Instance is applied to instances in a region or instances in a specific Availability Zone.
        :rtype: dict
        :returns:
        """
        pass

    def modify_snapshot_attribute(self, SnapshotId: str, Attribute: str = None, CreateVolumePermission: Dict = None, GroupNames: List = None, OperationType: str = None, UserIds: List = None, DryRun: bool = None):
        """
        Adds or removes permission settings for the specified snapshot. You may add or remove specified AWS account IDs from a snapshot's list of create volume permissions, but you cannot do both in a single API call. If you need to both add and remove account IDs for a snapshot, you must use multiple API calls.
        Encrypted snapshots and snapshots with AWS Marketplace product codes cannot be made public. Snapshots encrypted with your default CMK cannot be shared with other accounts.
        For more information about modifying snapshot permissions, see `Sharing Snapshots <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-modifying-snapshot-permissions.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifySnapshotAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_snapshot_attribute(
              Attribute='productCodes'|'createVolumePermission',
              CreateVolumePermission={
                  'Add': [
                      {
                          'Group': 'all',
                          'UserId': 'string'
                      },
                  ],
                  'Remove': [
                      {
                          'Group': 'all',
                          'UserId': 'string'
                      },
                  ]
              },
              GroupNames=[
                  'string',
              ],
              OperationType='add'|'remove',
              SnapshotId='string',
              UserIds=[
                  'string',
              ],
              DryRun=True|False
          )
        :type Attribute: string
        :param Attribute:
          The snapshot attribute to modify. Only volume creation permissions can be modified.
        :type CreateVolumePermission: dict
        :param CreateVolumePermission:
          A JSON representation of the snapshot attribute modification.
          - **Add** *(list) --*
            Adds the specified AWS account ID or group to the list.
            - *(dict) --*
              Describes the user or group to be added or removed from the list of create volume permissions for a volume.
              - **Group** *(string) --*
                The group to be added or removed. The possible value is ``all`` .
              - **UserId** *(string) --*
                The AWS account ID to be added or removed.
          - **Remove** *(list) --*
            Removes the specified AWS account ID or group from the list.
            - *(dict) --*
              Describes the user or group to be added or removed from the list of create volume permissions for a volume.
              - **Group** *(string) --*
                The group to be added or removed. The possible value is ``all`` .
              - **UserId** *(string) --*
                The AWS account ID to be added or removed.
        :type GroupNames: list
        :param GroupNames:
          The group to modify for the snapshot.
          - *(string) --*
        :type OperationType: string
        :param OperationType:
          The type of operation to perform to the attribute.
        :type SnapshotId: string
        :param SnapshotId: **[REQUIRED]**
          The ID of the snapshot.
        :type UserIds: list
        :param UserIds:
          The account ID to modify for the snapshot.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def modify_spot_fleet_request(self, SpotFleetRequestId: str, ExcessCapacityTerminationPolicy: str = None, TargetCapacity: int = None) -> Dict:
        """
        Modifies the specified Spot Fleet request.
        While the Spot Fleet request is being modified, it is in the ``modifying`` state.
        To scale up your Spot Fleet, increase its target capacity. The Spot Fleet launches the additional Spot Instances according to the allocation strategy for the Spot Fleet request. If the allocation strategy is ``lowestPrice`` , the Spot Fleet launches instances using the Spot pool with the lowest price. If the allocation strategy is ``diversified`` , the Spot Fleet distributes the instances across the Spot pools.
        To scale down your Spot Fleet, decrease its target capacity. First, the Spot Fleet cancels any open requests that exceed the new target capacity. You can request that the Spot Fleet terminate Spot Instances until the size of the fleet no longer exceeds the new target capacity. If the allocation strategy is ``lowestPrice`` , the Spot Fleet terminates the instances with the highest price per unit. If the allocation strategy is ``diversified`` , the Spot Fleet terminates instances across the Spot pools. Alternatively, you can request that the Spot Fleet keep the fleet at its current size, but not replace any Spot Instances that are interrupted or that you terminate manually.
        If you are finished with your Spot Fleet for now, but will use it again later, you can set the target capacity to 0.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifySpotFleetRequest>`_
        
        **Request Syntax**
        ::
          response = client.modify_spot_fleet_request(
              ExcessCapacityTerminationPolicy='noTermination'|'default',
              SpotFleetRequestId='string',
              TargetCapacity=123
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of ModifySpotFleetRequest.
            - **Return** *(boolean) --* 
              Is ``true`` if the request succeeds, and an error otherwise.
        :type ExcessCapacityTerminationPolicy: string
        :param ExcessCapacityTerminationPolicy:
          Indicates whether running Spot Instances should be terminated if the target capacity of the Spot Fleet request is decreased below the current size of the Spot Fleet.
        :type SpotFleetRequestId: string
        :param SpotFleetRequestId: **[REQUIRED]**
          The ID of the Spot Fleet request.
        :type TargetCapacity: integer
        :param TargetCapacity:
          The size of the fleet.
        :rtype: dict
        :returns:
        """
        pass

    def modify_subnet_attribute(self, SubnetId: str, AssignIpv6AddressOnCreation: Dict = None, MapPublicIpOnLaunch: Dict = None):
        """
        Modifies a subnet attribute. You can only modify one attribute at a time.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifySubnetAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_subnet_attribute(
              AssignIpv6AddressOnCreation={
                  'Value': True|False
              },
              MapPublicIpOnLaunch={
                  'Value': True|False
              },
              SubnetId='string'
          )
        :type AssignIpv6AddressOnCreation: dict
        :param AssignIpv6AddressOnCreation:
          Specify ``true`` to indicate that network interfaces created in the specified subnet should be assigned an IPv6 address. This includes a network interface that\'s created when launching an instance into the subnet (the instance therefore receives an IPv6 address).
          If you enable the IPv6 addressing feature for your subnet, your network interface or instance only receives an IPv6 address if it\'s created using version ``2016-11-15`` or later of the Amazon EC2 API.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type MapPublicIpOnLaunch: dict
        :param MapPublicIpOnLaunch:
          Specify ``true`` to indicate that network interfaces created in the specified subnet should be assigned a public IPv4 address. This includes a network interface that\'s created when launching an instance into the subnet (the instance therefore receives a public IPv4 address).
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type SubnetId: string
        :param SubnetId: **[REQUIRED]**
          The ID of the subnet.
        :returns: None
        """
        pass

    def modify_transit_gateway_vpc_attachment(self, TransitGatewayAttachmentId: str, AddSubnetIds: List = None, RemoveSubnetIds: List = None, Options: Dict = None, DryRun: bool = None) -> Dict:
        """
        Modifies the specified VPC attachment.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyTransitGatewayVpcAttachment>`_
        
        **Request Syntax**
        ::
          response = client.modify_transit_gateway_vpc_attachment(
              TransitGatewayAttachmentId='string',
              AddSubnetIds=[
                  'string',
              ],
              RemoveSubnetIds=[
                  'string',
              ],
              Options={
                  'DnsSupport': 'enable'|'disable',
                  'Ipv6Support': 'enable'|'disable'
              },
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayVpcAttachment': {
                    'TransitGatewayAttachmentId': 'string',
                    'TransitGatewayId': 'string',
                    'VpcId': 'string',
                    'VpcOwnerId': 'string',
                    'State': 'pendingAcceptance'|'rollingBack'|'pending'|'available'|'modifying'|'deleting'|'deleted'|'failed'|'rejected'|'rejecting'|'failing',
                    'SubnetIds': [
                        'string',
                    ],
                    'CreationTime': datetime(2015, 1, 1),
                    'Options': {
                        'DnsSupport': 'enable'|'disable',
                        'Ipv6Support': 'enable'|'disable'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayVpcAttachment** *(dict) --* 
              Information about the modified attachment.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **VpcOwnerId** *(string) --* 
                The ID of the AWS account that owns the VPC.
              - **State** *(string) --* 
                The state of the VPC attachment.
              - **SubnetIds** *(list) --* 
                The IDs of the subnets.
                - *(string) --* 
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Options** *(dict) --* 
                The VPC attachment options.
                - **DnsSupport** *(string) --* 
                  Indicates whether DNS support is enabled.
                - **Ipv6Support** *(string) --* 
                  Indicates whether IPv6 support is enabled.
              - **Tags** *(list) --* 
                The tags for the VPC attachment.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type AddSubnetIds: list
        :param AddSubnetIds:
          The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone.
          - *(string) --*
        :type RemoveSubnetIds: list
        :param RemoveSubnetIds:
          The IDs of one or more subnets to remove.
          - *(string) --*
        :type Options: dict
        :param Options:
          The new VPC attachment options.
          - **DnsSupport** *(string) --*
            Enable or disable DNS support. The default is ``enable`` .
          - **Ipv6Support** *(string) --*
            Enable or disable IPv6 support. The default is ``enable`` .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def modify_volume(self, VolumeId: str, DryRun: bool = None, Size: int = None, VolumeType: str = None, Iops: int = None) -> Dict:
        """
        You can modify several parameters of an existing EBS volume, including volume size, volume type, and IOPS capacity. If your EBS volume is attached to a current-generation EC2 instance type, you may be able to apply these changes without stopping the instance or detaching the volume from it. For more information about modifying an EBS volume running Linux, see `Modifying the Size, IOPS, or Type of an EBS Volume on Linux <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-expand-volume.html>`__ . For more information about modifying an EBS volume running Windows, see `Modifying the Size, IOPS, or Type of an EBS Volume on Windows <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ebs-expand-volume.html>`__ . 
        When you complete a resize operation on your volume, you need to extend the volume's file-system size to take advantage of the new storage capacity. For information about extending a Linux file system, see `Extending a Linux File System <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-expand-volume.html#recognize-expanded-volume-linux>`__ . For information about extending a Windows file system, see `Extending a Windows File System <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ebs-expand-volume.html#recognize-expanded-volume-windows>`__ . 
        You can use CloudWatch Events to check the status of a modification to an EBS volume. For information about CloudWatch Events, see the `Amazon CloudWatch Events User Guide <https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/>`__ . You can also track the status of a modification using the  DescribeVolumesModifications API. For information about tracking status changes using either method, see `Monitoring Volume Modifications <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-expand-volume.html#monitoring_mods>`__ . 
        With previous-generation instance types, resizing an EBS volume may require detaching and reattaching the volume or stopping and restarting the instance. For more information, see `Modifying the Size, IOPS, or Type of an EBS Volume on Linux <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-expand-volume.html>`__ and `Modifying the Size, IOPS, or Type of an EBS Volume on Windows <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ebs-expand-volume.html>`__ .
        If you reach the maximum volume modification rate per volume limit, you will need to wait at least six hours before applying further modifications to the affected EBS volume.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVolume>`_
        
        **Request Syntax**
        ::
          response = client.modify_volume(
              DryRun=True|False,
              VolumeId='string',
              Size=123,
              VolumeType='standard'|'io1'|'gp2'|'sc1'|'st1',
              Iops=123
          )
        
        **Response Syntax**
        ::
            {
                'VolumeModification': {
                    'VolumeId': 'string',
                    'ModificationState': 'modifying'|'optimizing'|'completed'|'failed',
                    'StatusMessage': 'string',
                    'TargetSize': 123,
                    'TargetIops': 123,
                    'TargetVolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                    'OriginalSize': 123,
                    'OriginalIops': 123,
                    'OriginalVolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                    'Progress': 123,
                    'StartTime': datetime(2015, 1, 1),
                    'EndTime': datetime(2015, 1, 1)
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VolumeModification** *(dict) --* 
              Information about the volume modification.
              - **VolumeId** *(string) --* 
                The ID of the volume.
              - **ModificationState** *(string) --* 
                The current modification state. The modification state is null for unmodified volumes.
              - **StatusMessage** *(string) --* 
                A status message about the modification progress or failure.
              - **TargetSize** *(integer) --* 
                The target size of the volume, in GiB.
              - **TargetIops** *(integer) --* 
                The target IOPS rate of the volume.
              - **TargetVolumeType** *(string) --* 
                The target EBS volume type of the volume.
              - **OriginalSize** *(integer) --* 
                The original size of the volume.
              - **OriginalIops** *(integer) --* 
                The original IOPS rate of the volume.
              - **OriginalVolumeType** *(string) --* 
                The original EBS volume type of the volume.
              - **Progress** *(integer) --* 
                The modification progress, from 0 to 100 percent complete.
              - **StartTime** *(datetime) --* 
                The modification start time.
              - **EndTime** *(datetime) --* 
                The modification completion or failure time.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the volume.
        :type Size: integer
        :param Size:
          The target size of the volume, in GiB. The target volume size must be greater than or equal to than the existing size of the volume. For information about available EBS volume sizes, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ .
          Default: If no size is specified, the existing size is retained.
        :type VolumeType: string
        :param VolumeType:
          The target EBS volume type of the volume.
          Default: If no type is specified, the existing type is retained.
        :type Iops: integer
        :param Iops:
          The target IOPS rate of the volume.
          This is only valid for Provisioned IOPS SSD (``io1`` ) volumes. For more information, see `Provisioned IOPS SSD (io1) Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html#EBSVolumeTypes_piops>`__ .
          Default: If no IOPS value is specified, the existing value is retained.
        :rtype: dict
        :returns:
        """
        pass

    def modify_volume_attribute(self, VolumeId: str, AutoEnableIO: Dict = None, DryRun: bool = None):
        """
        Modifies a volume attribute.
        By default, all I/O operations for the volume are suspended when the data on the volume is determined to be potentially inconsistent, to prevent undetectable, latent data corruption. The I/O access to the volume can be resumed by first enabling I/O access and then checking the data consistency on your volume.
        You can change the default behavior to resume I/O operations. We recommend that you change this only for boot volumes or for volumes that are stateless or disposable.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVolumeAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_volume_attribute(
              AutoEnableIO={
                  'Value': True|False
              },
              VolumeId='string',
              DryRun=True|False
          )
        :type AutoEnableIO: dict
        :param AutoEnableIO:
          Indicates whether the volume should be auto-enabled for I/O operations.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type VolumeId: string
        :param VolumeId: **[REQUIRED]**
          The ID of the volume.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def modify_vpc_attribute(self, VpcId: str, EnableDnsHostnames: Dict = None, EnableDnsSupport: Dict = None):
        """
        Modifies the specified attribute of the specified VPC.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpcAttribute>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpc_attribute(
              EnableDnsHostnames={
                  'Value': True|False
              },
              EnableDnsSupport={
                  'Value': True|False
              },
              VpcId='string'
          )
        :type EnableDnsHostnames: dict
        :param EnableDnsHostnames:
          Indicates whether the instances launched in the VPC get DNS hostnames. If enabled, instances in the VPC get DNS hostnames; otherwise, they do not.
          You cannot modify the DNS resolution and DNS hostnames attributes in the same request. Use separate requests for each attribute. You can only enable DNS hostnames if you\'ve enabled DNS support.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type EnableDnsSupport: dict
        :param EnableDnsSupport:
          Indicates whether the DNS resolution is supported for the VPC. If enabled, queries to the Amazon provided DNS server at the 169.254.169.253 IP address, or the reserved IP address at the base of the VPC network range \"plus two\" succeed. If disabled, the Amazon provided DNS service in the VPC that resolves public DNS hostnames to IP addresses is not enabled.
          You cannot modify the DNS resolution and DNS hostnames attributes in the same request. Use separate requests for each attribute.
          - **Value** *(boolean) --*
            The attribute value. The valid values are ``true`` or ``false`` .
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :returns: None
        """
        pass

    def modify_vpc_endpoint(self, VpcEndpointId: str, DryRun: bool = None, ResetPolicy: bool = None, PolicyDocument: str = None, AddRouteTableIds: List = None, RemoveRouteTableIds: List = None, AddSubnetIds: List = None, RemoveSubnetIds: List = None, AddSecurityGroupIds: List = None, RemoveSecurityGroupIds: List = None, PrivateDnsEnabled: bool = None) -> Dict:
        """
        Modifies attributes of a specified VPC endpoint. The attributes that you can modify depend on the type of VPC endpoint (interface or gateway). For more information, see `VPC Endpoints <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-endpoints.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpcEndpoint>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpc_endpoint(
              DryRun=True|False,
              VpcEndpointId='string',
              ResetPolicy=True|False,
              PolicyDocument='string',
              AddRouteTableIds=[
                  'string',
              ],
              RemoveRouteTableIds=[
                  'string',
              ],
              AddSubnetIds=[
                  'string',
              ],
              RemoveSubnetIds=[
                  'string',
              ],
              AddSecurityGroupIds=[
                  'string',
              ],
              RemoveSecurityGroupIds=[
                  'string',
              ],
              PrivateDnsEnabled=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcEndpointId: string
        :param VpcEndpointId: **[REQUIRED]**
          The ID of the endpoint.
        :type ResetPolicy: boolean
        :param ResetPolicy:
          (Gateway endpoint) Specify ``true`` to reset the policy document to the default policy. The default policy allows full access to the service.
        :type PolicyDocument: string
        :param PolicyDocument:
          A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format. If this parameter is not specified, we attach a default policy that allows full access to the service.
        :type AddRouteTableIds: list
        :param AddRouteTableIds:
          (Gateway endpoint) One or more route tables IDs to associate with the endpoint.
          - *(string) --*
        :type RemoveRouteTableIds: list
        :param RemoveRouteTableIds:
          (Gateway endpoint) One or more route table IDs to disassociate from the endpoint.
          - *(string) --*
        :type AddSubnetIds: list
        :param AddSubnetIds:
          (Interface endpoint) One or more subnet IDs in which to serve the endpoint.
          - *(string) --*
        :type RemoveSubnetIds: list
        :param RemoveSubnetIds:
          (Interface endpoint) One or more subnets IDs in which to remove the endpoint.
          - *(string) --*
        :type AddSecurityGroupIds: list
        :param AddSecurityGroupIds:
          (Interface endpoint) One or more security group IDs to associate with the network interface.
          - *(string) --*
        :type RemoveSecurityGroupIds: list
        :param RemoveSecurityGroupIds:
          (Interface endpoint) One or more security group IDs to disassociate from the network interface.
          - *(string) --*
        :type PrivateDnsEnabled: boolean
        :param PrivateDnsEnabled:
          (Interface endpoint) Indicate whether a private hosted zone is associated with the VPC.
        :rtype: dict
        :returns:
        """
        pass

    def modify_vpc_endpoint_connection_notification(self, ConnectionNotificationId: str, DryRun: bool = None, ConnectionNotificationArn: str = None, ConnectionEvents: List = None) -> Dict:
        """
        Modifies a connection notification for VPC endpoint or VPC endpoint service. You can change the SNS topic for the notification, or the events for which to be notified. 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpcEndpointConnectionNotification>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpc_endpoint_connection_notification(
              DryRun=True|False,
              ConnectionNotificationId='string',
              ConnectionNotificationArn='string',
              ConnectionEvents=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ReturnValue': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ReturnValue** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ConnectionNotificationId: string
        :param ConnectionNotificationId: **[REQUIRED]**
          The ID of the notification.
        :type ConnectionNotificationArn: string
        :param ConnectionNotificationArn:
          The ARN for the SNS topic for the notification.
        :type ConnectionEvents: list
        :param ConnectionEvents:
          One or more events for the endpoint. Valid values are ``Accept`` , ``Connect`` , ``Delete`` , and ``Reject`` .
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def modify_vpc_endpoint_service_configuration(self, ServiceId: str, DryRun: bool = None, AcceptanceRequired: bool = None, AddNetworkLoadBalancerArns: List = None, RemoveNetworkLoadBalancerArns: List = None) -> Dict:
        """
        Modifies the attributes of your VPC endpoint service configuration. You can change the Network Load Balancers for your service, and you can specify whether acceptance is required for requests to connect to your endpoint service through an interface VPC endpoint.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpcEndpointServiceConfiguration>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpc_endpoint_service_configuration(
              DryRun=True|False,
              ServiceId='string',
              AcceptanceRequired=True|False,
              AddNetworkLoadBalancerArns=[
                  'string',
              ],
              RemoveNetworkLoadBalancerArns=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceId: string
        :param ServiceId: **[REQUIRED]**
          The ID of the service.
        :type AcceptanceRequired: boolean
        :param AcceptanceRequired:
          Indicate whether requests to create an endpoint to your service must be accepted.
        :type AddNetworkLoadBalancerArns: list
        :param AddNetworkLoadBalancerArns:
          The Amazon Resource Names (ARNs) of Network Load Balancers to add to your service configuration.
          - *(string) --*
        :type RemoveNetworkLoadBalancerArns: list
        :param RemoveNetworkLoadBalancerArns:
          The Amazon Resource Names (ARNs) of Network Load Balancers to remove from your service configuration.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def modify_vpc_endpoint_service_permissions(self, ServiceId: str, DryRun: bool = None, AddAllowedPrincipals: List = None, RemoveAllowedPrincipals: List = None) -> Dict:
        """
        Modifies the permissions for your `VPC endpoint service <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/endpoint-service.html>`__ . You can add or remove permissions for service consumers (IAM users, IAM roles, and AWS accounts) to connect to your endpoint service.
        If you grant permissions to all principals, the service is public. Any users who know the name of a public service can send a request to attach an endpoint. If the service does not require manual approval, attachments are automatically approved.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpcEndpointServicePermissions>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpc_endpoint_service_permissions(
              DryRun=True|False,
              ServiceId='string',
              AddAllowedPrincipals=[
                  'string',
              ],
              RemoveAllowedPrincipals=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ReturnValue': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ReturnValue** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceId: string
        :param ServiceId: **[REQUIRED]**
          The ID of the service.
        :type AddAllowedPrincipals: list
        :param AddAllowedPrincipals:
          The Amazon Resource Names (ARN) of one or more principals. Permissions are granted to the principals in this list. To grant permissions to all principals, specify an asterisk (*).
          - *(string) --*
        :type RemoveAllowedPrincipals: list
        :param RemoveAllowedPrincipals:
          The Amazon Resource Names (ARN) of one or more principals. Permissions are revoked for principals in this list.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def modify_vpc_peering_connection_options(self, VpcPeeringConnectionId: str, AccepterPeeringConnectionOptions: Dict = None, DryRun: bool = None, RequesterPeeringConnectionOptions: Dict = None) -> Dict:
        """
        Modifies the VPC peering connection options on one side of a VPC peering connection. You can do the following:
        * Enable/disable communication over the peering connection between an EC2-Classic instance that's linked to your VPC (using ClassicLink) and instances in the peer VPC. 
        * Enable/disable communication over the peering connection between instances in your VPC and an EC2-Classic instance that's linked to the peer VPC. 
        * Enable/disable the ability to resolve public DNS hostnames to private IP addresses when queried from instances in the peer VPC. 
        If the peered VPCs are in the same AWS account, you can enable DNS resolution for queries from the local VPC. This ensures that queries from the local VPC resolve to private IP addresses in the peer VPC. This option is not available if the peered VPCs are in different AWS accounts or different regions. For peered VPCs in different AWS accounts, each AWS account owner must initiate a separate request to modify the peering connection options. For inter-region peering connections, you must use the region for the requester VPC to modify the requester VPC peering options and the region for the accepter VPC to modify the accepter VPC peering options. To verify which VPCs are the accepter and the requester for a VPC peering connection, use the  DescribeVpcPeeringConnections command.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpcPeeringConnectionOptions>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpc_peering_connection_options(
              AccepterPeeringConnectionOptions={
                  'AllowDnsResolutionFromRemoteVpc': True|False,
                  'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                  'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
              },
              DryRun=True|False,
              RequesterPeeringConnectionOptions={
                  'AllowDnsResolutionFromRemoteVpc': True|False,
                  'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                  'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
              },
              VpcPeeringConnectionId='string'
          )
        
        **Response Syntax**
        ::
            {
                'AccepterPeeringConnectionOptions': {
                    'AllowDnsResolutionFromRemoteVpc': True|False,
                    'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                    'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                },
                'RequesterPeeringConnectionOptions': {
                    'AllowDnsResolutionFromRemoteVpc': True|False,
                    'AllowEgressFromLocalClassicLinkToRemoteVpc': True|False,
                    'AllowEgressFromLocalVpcToRemoteClassicLink': True|False
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AccepterPeeringConnectionOptions** *(dict) --* 
              Information about the VPC peering connection options for the accepter VPC.
              - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                If true, the public DNS hostnames of instances in the specified VPC resolve to private IP addresses when queried from instances in the peer VPC.
              - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                If true, enables outbound communication from an EC2-Classic instance that's linked to a local VPC using ClassicLink to instances in a peer VPC.
              - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                If true, enables outbound communication from instances in a local VPC to an EC2-Classic instance that's linked to a peer VPC using ClassicLink.
            - **RequesterPeeringConnectionOptions** *(dict) --* 
              Information about the VPC peering connection options for the requester VPC.
              - **AllowDnsResolutionFromRemoteVpc** *(boolean) --* 
                If true, the public DNS hostnames of instances in the specified VPC resolve to private IP addresses when queried from instances in the peer VPC.
              - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --* 
                If true, enables outbound communication from an EC2-Classic instance that's linked to a local VPC using ClassicLink to instances in a peer VPC.
              - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --* 
                If true, enables outbound communication from instances in a local VPC to an EC2-Classic instance that's linked to a peer VPC using ClassicLink.
        :type AccepterPeeringConnectionOptions: dict
        :param AccepterPeeringConnectionOptions:
          The VPC peering connection options for the accepter VPC.
          - **AllowDnsResolutionFromRemoteVpc** *(boolean) --*
            If true, enables a local VPC to resolve public DNS hostnames to private IP addresses when queried from instances in the peer VPC.
          - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --*
            If true, enables outbound communication from an EC2-Classic instance that\'s linked to a local VPC using ClassicLink to instances in a peer VPC.
          - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --*
            If true, enables outbound communication from instances in a local VPC to an EC2-Classic instance that\'s linked to a peer VPC using ClassicLink.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type RequesterPeeringConnectionOptions: dict
        :param RequesterPeeringConnectionOptions:
          The VPC peering connection options for the requester VPC.
          - **AllowDnsResolutionFromRemoteVpc** *(boolean) --*
            If true, enables a local VPC to resolve public DNS hostnames to private IP addresses when queried from instances in the peer VPC.
          - **AllowEgressFromLocalClassicLinkToRemoteVpc** *(boolean) --*
            If true, enables outbound communication from an EC2-Classic instance that\'s linked to a local VPC using ClassicLink to instances in a peer VPC.
          - **AllowEgressFromLocalVpcToRemoteClassicLink** *(boolean) --*
            If true, enables outbound communication from instances in a local VPC to an EC2-Classic instance that\'s linked to a peer VPC using ClassicLink.
        :type VpcPeeringConnectionId: string
        :param VpcPeeringConnectionId: **[REQUIRED]**
          The ID of the VPC peering connection.
        :rtype: dict
        :returns:
        """
        pass

    def modify_vpc_tenancy(self, VpcId: str, InstanceTenancy: str, DryRun: bool = None) -> Dict:
        """
        Modifies the instance tenancy attribute of the specified VPC. You can change the instance tenancy attribute of a VPC to ``default`` only. You cannot change the instance tenancy attribute to ``dedicated`` .
        After you modify the tenancy of the VPC, any new instances that you launch into the VPC have a tenancy of ``default`` , unless you specify otherwise during launch. The tenancy of any existing instances in the VPC is not affected.
        For more information, see `Dedicated Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-instance.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpcTenancy>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpc_tenancy(
              VpcId='string',
              InstanceTenancy='default',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ReturnValue': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ReturnValue** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, returns an error.
        :type VpcId: string
        :param VpcId: **[REQUIRED]**
          The ID of the VPC.
        :type InstanceTenancy: string
        :param InstanceTenancy: **[REQUIRED]**
          The instance tenancy attribute for the VPC.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def modify_vpn_connection(self, VpnConnectionId: str, TransitGatewayId: str = None, VpnGatewayId: str = None, DryRun: bool = None) -> Dict:
        """
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ModifyVpnConnection>`_
        
        **Request Syntax**
        ::
          response = client.modify_vpn_connection(
              VpnConnectionId='string',
              TransitGatewayId='string',
              VpnGatewayId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'VpnConnection': {
                    'CustomerGatewayConfiguration': 'string',
                    'CustomerGatewayId': 'string',
                    'Category': 'string',
                    'State': 'pending'|'available'|'deleting'|'deleted',
                    'Type': 'ipsec.1',
                    'VpnConnectionId': 'string',
                    'VpnGatewayId': 'string',
                    'TransitGatewayId': 'string',
                    'Options': {
                        'StaticRoutesOnly': True|False
                    },
                    'Routes': [
                        {
                            'DestinationCidrBlock': 'string',
                            'Source': 'Static',
                            'State': 'pending'|'available'|'deleting'|'deleted'
                        },
                    ],
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ],
                    'VgwTelemetry': [
                        {
                            'AcceptedRouteCount': 123,
                            'LastStatusChange': datetime(2015, 1, 1),
                            'OutsideIpAddress': 'string',
                            'Status': 'UP'|'DOWN',
                            'StatusMessage': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **VpnConnection** *(dict) --* 
              Describes a VPN connection.
              - **CustomerGatewayConfiguration** *(string) --* 
                The configuration information for the VPN connection's customer gateway (in the native XML format). This element is always present in the  CreateVpnConnection response; however, it's present in the  DescribeVpnConnections response only if the VPN connection is in the ``pending`` or ``available`` state.
              - **CustomerGatewayId** *(string) --* 
                The ID of the customer gateway at your end of the VPN connection.
              - **Category** *(string) --* 
                The category of the VPN connection. A value of ``VPN`` indicates an AWS VPN connection. A value of ``VPN-Classic`` indicates an AWS Classic VPN connection.
              - **State** *(string) --* 
                The current state of the VPN connection.
              - **Type** *(string) --* 
                The type of VPN connection.
              - **VpnConnectionId** *(string) --* 
                The ID of the VPN connection.
              - **VpnGatewayId** *(string) --* 
                The ID of the virtual private gateway at the AWS side of the VPN connection.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway associated with the VPN connection.
              - **Options** *(dict) --* 
                The VPN connection options.
                - **StaticRoutesOnly** *(boolean) --* 
                  Indicates whether the VPN connection uses static routes only. Static routes must be used for devices that don't support BGP.
              - **Routes** *(list) --* 
                The static routes associated with the VPN connection.
                - *(dict) --* 
                  Describes a static route for a VPN connection.
                  - **DestinationCidrBlock** *(string) --* 
                    The CIDR block associated with the local subnet of the customer data center.
                  - **Source** *(string) --* 
                    Indicates how the routes were provided.
                  - **State** *(string) --* 
                    The current state of the static route.
              - **Tags** *(list) --* 
                Any tags assigned to the VPN connection.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
              - **VgwTelemetry** *(list) --* 
                Information about the VPN tunnel.
                - *(dict) --* 
                  Describes telemetry for a VPN tunnel.
                  - **AcceptedRouteCount** *(integer) --* 
                    The number of accepted routes.
                  - **LastStatusChange** *(datetime) --* 
                    The date and time of the last change in status.
                  - **OutsideIpAddress** *(string) --* 
                    The Internet-routable IP address of the virtual private gateway's outside interface.
                  - **Status** *(string) --* 
                    The status of the VPN tunnel.
                  - **StatusMessage** *(string) --* 
                    If an error occurs, a description of the error.
        :type VpnConnectionId: string
        :param VpnConnectionId: **[REQUIRED]**
        :type TransitGatewayId: string
        :param TransitGatewayId:
        :type VpnGatewayId: string
        :param VpnGatewayId:
        :type DryRun: boolean
        :param DryRun:
        :rtype: dict
        :returns:
        """
        pass

    def monitor_instances(self, InstanceIds: List, DryRun: bool = None) -> Dict:
        """
        Enables detailed monitoring for a running instance. Otherwise, basic monitoring is enabled. For more information, see `Monitoring Your Instances and Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-cloudwatch.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        To disable detailed monitoring, see .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/MonitorInstances>`_
        
        **Request Syntax**
        ::
          response = client.monitor_instances(
              InstanceIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'InstanceMonitorings': [
                    {
                        'InstanceId': 'string',
                        'Monitoring': {
                            'State': 'disabled'|'disabling'|'enabled'|'pending'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InstanceMonitorings** *(list) --* 
              The monitoring information.
              - *(dict) --* 
                Describes the monitoring of an instance.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **Monitoring** *(dict) --* 
                  The monitoring for the instance.
                  - **State** *(string) --* 
                    Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
        :type InstanceIds: list
        :param InstanceIds: **[REQUIRED]**
          The IDs of the instances.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def move_address_to_vpc(self, PublicIp: str, DryRun: bool = None) -> Dict:
        """
        Moves an Elastic IP address from the EC2-Classic platform to the EC2-VPC platform. The Elastic IP address must be allocated to your account for more than 24 hours, and it must not be associated with an instance. After the Elastic IP address is moved, it is no longer available for use in the EC2-Classic platform, unless you move it back using the  RestoreAddressToClassic request. You cannot move an Elastic IP address that was originally allocated for use in the EC2-VPC platform to the EC2-Classic platform. 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/MoveAddressToVpc>`_
        
        **Request Syntax**
        ::
          response = client.move_address_to_vpc(
              DryRun=True|False,
              PublicIp='string'
          )
        
        **Response Syntax**
        ::
            {
                'AllocationId': 'string',
                'Status': 'MoveInProgress'|'InVpc'|'InClassic'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **AllocationId** *(string) --* 
              The allocation ID for the Elastic IP address.
            - **Status** *(string) --* 
              The status of the move of the IP address.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type PublicIp: string
        :param PublicIp: **[REQUIRED]**
          The Elastic IP address.
        :rtype: dict
        :returns:
        """
        pass

    def provision_byoip_cidr(self, Cidr: str, CidrAuthorizationContext: Dict = None, Description: str = None, DryRun: bool = None) -> Dict:
        """
        Provisions an address range for use with your AWS resources through bring your own IP addresses (BYOIP) and creates a corresponding address pool. After the address range is provisioned, it is ready to be advertised using  AdvertiseByoipCidr .
        AWS verifies that you own the address range and are authorized to advertise it. You must ensure that the address range is registered to you and that you created an RPKI ROA to authorize Amazon ASNs 16509 and 14618 to advertise the address range. For more information, see `Bring Your Own IP Addresses (BYOIP) <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        Provisioning an address range is an asynchronous operation, so the call returns immediately, but the address range is not ready to use until its status changes from ``pending-provision`` to ``provisioned`` . To monitor the status of an address range, use  DescribeByoipCidrs . To allocate an Elastic IP address from your address pool, use  AllocateAddress with either the specific address from the address pool or the ID of the address pool.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ProvisionByoipCidr>`_
        
        **Request Syntax**
        ::
          response = client.provision_byoip_cidr(
              Cidr='string',
              CidrAuthorizationContext={
                  'Message': 'string',
                  'Signature': 'string'
              },
              Description='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ByoipCidr': {
                    'Cidr': 'string',
                    'Description': 'string',
                    'StatusMessage': 'string',
                    'State': 'advertised'|'deprovisioned'|'failed-deprovision'|'failed-provision'|'pending-deprovision'|'pending-provision'|'provisioned'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ByoipCidr** *(dict) --* 
              Information about the address pool.
              - **Cidr** *(string) --* 
                The public IPv4 address range, in CIDR notation.
              - **Description** *(string) --* 
                The description of the address range.
              - **StatusMessage** *(string) --* 
                Upon success, contains the ID of the address pool. Otherwise, contains an error message.
              - **State** *(string) --* 
                The state of the address pool.
        :type Cidr: string
        :param Cidr: **[REQUIRED]**
          The public IPv4 address range, in CIDR notation. The most specific prefix that you can specify is /24. The address range cannot overlap with another address range that you\'ve brought to this or another region.
        :type CidrAuthorizationContext: dict
        :param CidrAuthorizationContext:
          A signed document that proves that you are authorized to bring the specified IP address range to Amazon using BYOIP.
          - **Message** *(string) --* **[REQUIRED]**
            The plain-text authorization message for the prefix and account.
          - **Signature** *(string) --* **[REQUIRED]**
            The signed authorization message for the prefix and account.
        :type Description: string
        :param Description:
          A description for the address range and the address pool.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def purchase_host_reservation(self, HostIdSet: List, OfferingId: str, ClientToken: str = None, CurrencyCode: str = None, LimitPrice: str = None) -> Dict:
        """
        Purchase a reservation with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation. This action results in the specified reservation being purchased and charged to your account.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/PurchaseHostReservation>`_
        
        **Request Syntax**
        ::
          response = client.purchase_host_reservation(
              ClientToken='string',
              CurrencyCode='USD',
              HostIdSet=[
                  'string',
              ],
              LimitPrice='string',
              OfferingId='string'
          )
        
        **Response Syntax**
        ::
            {
                'ClientToken': 'string',
                'CurrencyCode': 'USD',
                'Purchase': [
                    {
                        'CurrencyCode': 'USD',
                        'Duration': 123,
                        'HostIdSet': [
                            'string',
                        ],
                        'HostReservationId': 'string',
                        'HourlyPrice': 'string',
                        'InstanceFamily': 'string',
                        'PaymentOption': 'AllUpfront'|'PartialUpfront'|'NoUpfront',
                        'UpfrontPrice': 'string'
                    },
                ],
                'TotalHourlyPrice': 'string',
                'TotalUpfrontPrice': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientToken** *(string) --* 
              Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
            - **CurrencyCode** *(string) --* 
              The currency in which the ``totalUpfrontPrice`` and ``totalHourlyPrice`` amounts are specified. At this time, the only supported currency is ``USD`` .
            - **Purchase** *(list) --* 
              Describes the details of the purchase.
              - *(dict) --* 
                Describes the result of the purchase.
                - **CurrencyCode** *(string) --* 
                  The currency in which the ``UpfrontPrice`` and ``HourlyPrice`` amounts are specified. At this time, the only supported currency is ``USD`` .
                - **Duration** *(integer) --* 
                  The duration of the reservation's term in seconds.
                - **HostIdSet** *(list) --* 
                  The IDs of the Dedicated Hosts associated with the reservation.
                  - *(string) --* 
                - **HostReservationId** *(string) --* 
                  The ID of the reservation.
                - **HourlyPrice** *(string) --* 
                  The hourly price of the reservation per hour.
                - **InstanceFamily** *(string) --* 
                  The instance family on the Dedicated Host that the reservation can be associated with.
                - **PaymentOption** *(string) --* 
                  The payment option for the reservation.
                - **UpfrontPrice** *(string) --* 
                  The upfront price of the reservation.
            - **TotalHourlyPrice** *(string) --* 
              The total hourly price of the reservation calculated per hour.
            - **TotalUpfrontPrice** *(string) --* 
              The total amount charged to your account when you purchase the reservation.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type CurrencyCode: string
        :param CurrencyCode:
          The currency in which the ``totalUpfrontPrice`` , ``LimitPrice`` , and ``totalHourlyPrice`` amounts are specified. At this time, the only supported currency is ``USD`` .
        :type HostIdSet: list
        :param HostIdSet: **[REQUIRED]**
          The IDs of the Dedicated Hosts with which the reservation will be associated.
          - *(string) --*
        :type LimitPrice: string
        :param LimitPrice:
          The specified limit is checked against the total upfront cost of the reservation (calculated as the offering\'s upfront cost multiplied by the host count). If the total upfront cost is greater than the specified price limit, the request fails. This is used to ensure that the purchase does not exceed the expected upfront cost of the purchase. At this time, the only supported currency is ``USD`` . For example, to indicate a limit price of USD 100, specify 100.00.
        :type OfferingId: string
        :param OfferingId: **[REQUIRED]**
          The ID of the offering.
        :rtype: dict
        :returns:
        """
        pass

    def purchase_reserved_instances_offering(self, InstanceCount: int, ReservedInstancesOfferingId: str, DryRun: bool = None, LimitPrice: Dict = None) -> Dict:
        """
        Purchases a Reserved Instance for use with your account. With Reserved Instances, you pay a lower hourly rate compared to On-Demand instance pricing.
        Use  DescribeReservedInstancesOfferings to get a list of Reserved Instance offerings that match your specifications. After you've purchased a Reserved Instance, you can check for your new Reserved Instance with  DescribeReservedInstances .
        For more information, see `Reserved Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/concepts-on-demand-reserved-instances.html>`__ and `Reserved Instance Marketplace <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/PurchaseReservedInstancesOffering>`_
        
        **Request Syntax**
        ::
          response = client.purchase_reserved_instances_offering(
              InstanceCount=123,
              ReservedInstancesOfferingId='string',
              DryRun=True|False,
              LimitPrice={
                  'Amount': 123.0,
                  'CurrencyCode': 'USD'
              }
          )
        
        **Response Syntax**
        ::
            {
                'ReservedInstancesId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of PurchaseReservedInstancesOffering.
            - **ReservedInstancesId** *(string) --* 
              The IDs of the purchased Reserved Instances.
        :type InstanceCount: integer
        :param InstanceCount: **[REQUIRED]**
          The number of Reserved Instances to purchase.
        :type ReservedInstancesOfferingId: string
        :param ReservedInstancesOfferingId: **[REQUIRED]**
          The ID of the Reserved Instance offering to purchase.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type LimitPrice: dict
        :param LimitPrice:
          Specified for Reserved Instance Marketplace offerings to limit the total order and ensure that the Reserved Instances are not purchased at unexpected prices.
          - **Amount** *(float) --*
            Used for Reserved Instance Marketplace offerings. Specifies the limit price on the total order (instanceCount * price).
          - **CurrencyCode** *(string) --*
            The currency in which the ``limitPrice`` amount is specified. At this time, the only supported currency is ``USD`` .
        :rtype: dict
        :returns:
        """
        pass

    def purchase_scheduled_instances(self, PurchaseRequests: List, ClientToken: str = None, DryRun: bool = None) -> Dict:
        """
        Purchases the Scheduled Instances with the specified schedule.
        Scheduled Instances enable you to purchase Amazon EC2 compute capacity by the hour for a one-year term. Before you can purchase a Scheduled Instance, you must call  DescribeScheduledInstanceAvailability to check for available schedules and obtain a purchase token. After you purchase a Scheduled Instance, you must call  RunScheduledInstances during each scheduled time period.
        After you purchase a Scheduled Instance, you can't cancel, modify, or resell your purchase.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/PurchaseScheduledInstances>`_
        
        **Request Syntax**
        ::
          response = client.purchase_scheduled_instances(
              ClientToken='string',
              DryRun=True|False,
              PurchaseRequests=[
                  {
                      'InstanceCount': 123,
                      'PurchaseToken': 'string'
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'ScheduledInstanceSet': [
                    {
                        'AvailabilityZone': 'string',
                        'CreateDate': datetime(2015, 1, 1),
                        'HourlyPrice': 'string',
                        'InstanceCount': 123,
                        'InstanceType': 'string',
                        'NetworkPlatform': 'string',
                        'NextSlotStartTime': datetime(2015, 1, 1),
                        'Platform': 'string',
                        'PreviousSlotEndTime': datetime(2015, 1, 1),
                        'Recurrence': {
                            'Frequency': 'string',
                            'Interval': 123,
                            'OccurrenceDaySet': [
                                123,
                            ],
                            'OccurrenceRelativeToEnd': True|False,
                            'OccurrenceUnit': 'string'
                        },
                        'ScheduledInstanceId': 'string',
                        'SlotDurationInHours': 123,
                        'TermEndDate': datetime(2015, 1, 1),
                        'TermStartDate': datetime(2015, 1, 1),
                        'TotalScheduledInstanceHours': 123
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of PurchaseScheduledInstances.
            - **ScheduledInstanceSet** *(list) --* 
              Information about the Scheduled Instances.
              - *(dict) --* 
                Describes a Scheduled Instance.
                - **AvailabilityZone** *(string) --* 
                  The Availability Zone.
                - **CreateDate** *(datetime) --* 
                  The date when the Scheduled Instance was purchased.
                - **HourlyPrice** *(string) --* 
                  The hourly price for a single instance.
                - **InstanceCount** *(integer) --* 
                  The number of instances.
                - **InstanceType** *(string) --* 
                  The instance type.
                - **NetworkPlatform** *(string) --* 
                  The network platform (``EC2-Classic`` or ``EC2-VPC`` ).
                - **NextSlotStartTime** *(datetime) --* 
                  The time for the next schedule to start.
                - **Platform** *(string) --* 
                  The platform (``Linux/UNIX`` or ``Windows`` ).
                - **PreviousSlotEndTime** *(datetime) --* 
                  The time that the previous schedule ended or will end.
                - **Recurrence** *(dict) --* 
                  The schedule recurrence.
                  - **Frequency** *(string) --* 
                    The frequency (``Daily`` , ``Weekly`` , or ``Monthly`` ).
                  - **Interval** *(integer) --* 
                    The interval quantity. The interval unit depends on the value of ``frequency`` . For example, every 2 weeks or every 2 months.
                  - **OccurrenceDaySet** *(list) --* 
                    The days. For a monthly schedule, this is one or more days of the month (1-31). For a weekly schedule, this is one or more days of the week (1-7, where 1 is Sunday).
                    - *(integer) --* 
                  - **OccurrenceRelativeToEnd** *(boolean) --* 
                    Indicates whether the occurrence is relative to the end of the specified week or month.
                  - **OccurrenceUnit** *(string) --* 
                    The unit for ``occurrenceDaySet`` (``DayOfWeek`` or ``DayOfMonth`` ).
                - **ScheduledInstanceId** *(string) --* 
                  The Scheduled Instance ID.
                - **SlotDurationInHours** *(integer) --* 
                  The number of hours in the schedule.
                - **TermEndDate** *(datetime) --* 
                  The end date for the Scheduled Instance.
                - **TermStartDate** *(datetime) --* 
                  The start date for the Scheduled Instance.
                - **TotalScheduledInstanceHours** *(integer) --* 
                  The total number of hours for a single instance for the entire term.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          This field is autopopulated if not provided.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type PurchaseRequests: list
        :param PurchaseRequests: **[REQUIRED]**
          The purchase requests.
          - *(dict) --*
            Describes a request to purchase Scheduled Instances.
            - **InstanceCount** *(integer) --* **[REQUIRED]**
              The number of instances.
            - **PurchaseToken** *(string) --* **[REQUIRED]**
              The purchase token.
        :rtype: dict
        :returns:
        """
        pass

    def reboot_instances(self, InstanceIds: List, DryRun: bool = None):
        """
        Requests a reboot of the specified instances. This operation is asynchronous; it only queues a request to reboot the specified instances. The operation succeeds if the instances are valid and belong to you. Requests to reboot terminated instances are ignored.
        If an instance does not cleanly shut down within four minutes, Amazon EC2 performs a hard reboot.
        For more information about troubleshooting, see `Getting Console Output and Rebooting Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-console.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RebootInstances>`_
        
        **Request Syntax**
        ::
          response = client.reboot_instances(
              InstanceIds=[
                  'string',
              ],
              DryRun=True|False
          )
        :type InstanceIds: list
        :param InstanceIds: **[REQUIRED]**
          The instance IDs.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def register_image(self, Name: str, ImageLocation: str = None, Architecture: str = None, BlockDeviceMappings: List = None, Description: str = None, DryRun: bool = None, EnaSupport: bool = None, KernelId: str = None, BillingProducts: List = None, RamdiskId: str = None, RootDeviceName: str = None, SriovNetSupport: str = None, VirtualizationType: str = None) -> Dict:
        """
        Registers an AMI. When you're creating an AMI, this is the final step you must complete before you can launch an instance from the AMI. For more information about creating AMIs, see `Creating Your Own AMIs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/creating-an-ami.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        .. note::
          For Amazon EBS-backed instances,  CreateImage creates and registers the AMI in a single request, so you don't have to register the AMI yourself.
        You can also use ``RegisterImage`` to create an Amazon EBS-backed Linux AMI from a snapshot of a root device volume. You specify the snapshot using the block device mapping. For more information, see `Launching a Linux Instance from a Backup <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-launch-snapshot.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        You can't register an image where a secondary (non-root) snapshot has AWS Marketplace product codes.
        Some Linux distributions, such as Red Hat Enterprise Linux (RHEL) and SUSE Linux Enterprise Server (SLES), use the EC2 billing product code associated with an AMI to verify the subscription status for package updates. Creating an AMI from an EBS snapshot does not maintain this billing code, and instances launched from such an AMI are not able to connect to package update infrastructure. If you purchase a Reserved Instance offering for one of these Linux distributions and launch instances using an AMI that does not contain the required billing code, your Reserved Instance is not applied to these instances.
        To create an AMI for operating systems that require a billing code, see  CreateImage .
        If needed, you can deregister an AMI at any time. Any modifications you make to an AMI backed by an instance store volume invalidates its registration. If you make changes to an image, deregister the previous image and register the new image.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RegisterImage>`_
        
        **Request Syntax**
        ::
          response = client.register_image(
              ImageLocation='string',
              Architecture='i386'|'x86_64'|'arm64',
              BlockDeviceMappings=[
                  {
                      'DeviceName': 'string',
                      'VirtualName': 'string',
                      'Ebs': {
                          'DeleteOnTermination': True|False,
                          'Iops': 123,
                          'SnapshotId': 'string',
                          'VolumeSize': 123,
                          'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                          'Encrypted': True|False,
                          'KmsKeyId': 'string'
                      },
                      'NoDevice': 'string'
                  },
              ],
              Description='string',
              DryRun=True|False,
              EnaSupport=True|False,
              KernelId='string',
              Name='string',
              BillingProducts=[
                  'string',
              ],
              RamdiskId='string',
              RootDeviceName='string',
              SriovNetSupport='string',
              VirtualizationType='string'
          )
        
        **Response Syntax**
        ::
            {
                'ImageId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of RegisterImage.
            - **ImageId** *(string) --* 
              The ID of the newly registered AMI.
        :type ImageLocation: string
        :param ImageLocation:
          The full path to your AMI manifest in Amazon S3 storage.
        :type Architecture: string
        :param Architecture:
          The architecture of the AMI.
          Default: For Amazon EBS-backed AMIs, ``i386`` . For instance store-backed AMIs, the architecture specified in the manifest file.
        :type BlockDeviceMappings: list
        :param BlockDeviceMappings:
          The block device mapping entries.
          - *(dict) --*
            Describes a block device mapping.
            - **DeviceName** *(string) --*
              The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
            - **VirtualName** *(string) --*
              The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
              NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
              Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
            - **Ebs** *(dict) --*
              Parameters used to automatically set up EBS volumes when the instance is launched.
              - **DeleteOnTermination** *(boolean) --*
                Indicates whether the EBS volume is deleted on instance termination.
              - **Iops** *(integer) --*
                The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
              - **SnapshotId** *(string) --*
                The ID of the snapshot.
              - **VolumeSize** *(integer) --*
                The size of the volume, in GiB.
                Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
              - **VolumeType** *(string) --*
                The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                Default: ``standard``
              - **Encrypted** *(boolean) --*
                Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
              - **KmsKeyId** *(string) --*
                Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
            - **NoDevice** *(string) --*
              Suppresses the specified device included in the block device mapping of the AMI.
        :type Description: string
        :param Description:
          A description for your AMI.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EnaSupport: boolean
        :param EnaSupport:
          Set to ``true`` to enable enhanced networking with ENA for the AMI and any instances that you launch from the AMI.
          This option is supported only for HVM AMIs. Specifying this option with a PV AMI can make instances launched from the AMI unreachable.
        :type KernelId: string
        :param KernelId:
          The ID of the kernel.
        :type Name: string
        :param Name: **[REQUIRED]**
          A name for your AMI.
          Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes (\'), at-signs (@), or underscores(_)
        :type BillingProducts: list
        :param BillingProducts:
          The billing product codes. Your account must be authorized to specify billing product codes. Otherwise, you can use the AWS Marketplace to bill for the use of an AMI.
          - *(string) --*
        :type RamdiskId: string
        :param RamdiskId:
          The ID of the RAM disk.
        :type RootDeviceName: string
        :param RootDeviceName:
          The device name of the root device volume (for example, ``/dev/sda1`` ).
        :type SriovNetSupport: string
        :param SriovNetSupport:
          Set to ``simple`` to enable enhanced networking with the Intel 82599 Virtual Function interface for the AMI and any instances that you launch from the AMI.
          There is no way to disable ``sriovNetSupport`` at this time.
          This option is supported only for HVM AMIs. Specifying this option with a PV AMI can make instances launched from the AMI unreachable.
        :type VirtualizationType: string
        :param VirtualizationType:
          The type of virtualization (``hvm`` | ``paravirtual`` ).
          Default: ``paravirtual``
        :rtype: dict
        :returns:
        """
        pass

    def reject_transit_gateway_vpc_attachment(self, TransitGatewayAttachmentId: str, DryRun: bool = None) -> Dict:
        """
        Rejects a request to attach a VPC to a transit gateway.
        The VPC attachment must be in the ``pendingAcceptance`` state. Use  DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use  AcceptTransitGatewayVpcAttachment to accept a VPC attachment request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RejectTransitGatewayVpcAttachment>`_
        
        **Request Syntax**
        ::
          response = client.reject_transit_gateway_vpc_attachment(
              TransitGatewayAttachmentId='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TransitGatewayVpcAttachment': {
                    'TransitGatewayAttachmentId': 'string',
                    'TransitGatewayId': 'string',
                    'VpcId': 'string',
                    'VpcOwnerId': 'string',
                    'State': 'pendingAcceptance'|'rollingBack'|'pending'|'available'|'modifying'|'deleting'|'deleted'|'failed'|'rejected'|'rejecting'|'failing',
                    'SubnetIds': [
                        'string',
                    ],
                    'CreationTime': datetime(2015, 1, 1),
                    'Options': {
                        'DnsSupport': 'enable'|'disable',
                        'Ipv6Support': 'enable'|'disable'
                    },
                    'Tags': [
                        {
                            'Key': 'string',
                            'Value': 'string'
                        },
                    ]
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TransitGatewayVpcAttachment** *(dict) --* 
              Information about the attachment.
              - **TransitGatewayAttachmentId** *(string) --* 
                The ID of the attachment.
              - **TransitGatewayId** *(string) --* 
                The ID of the transit gateway.
              - **VpcId** *(string) --* 
                The ID of the VPC.
              - **VpcOwnerId** *(string) --* 
                The ID of the AWS account that owns the VPC.
              - **State** *(string) --* 
                The state of the VPC attachment.
              - **SubnetIds** *(list) --* 
                The IDs of the subnets.
                - *(string) --* 
              - **CreationTime** *(datetime) --* 
                The creation time.
              - **Options** *(dict) --* 
                The VPC attachment options.
                - **DnsSupport** *(string) --* 
                  Indicates whether DNS support is enabled.
                - **Ipv6Support** *(string) --* 
                  Indicates whether IPv6 support is enabled.
              - **Tags** *(list) --* 
                The tags for the VPC attachment.
                - *(dict) --* 
                  Describes a tag.
                  - **Key** *(string) --* 
                    The key of the tag.
                    Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                  - **Value** *(string) --* 
                    The value of the tag.
                    Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId: **[REQUIRED]**
          The ID of the attachment.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def reject_vpc_endpoint_connections(self, ServiceId: str, VpcEndpointIds: List, DryRun: bool = None) -> Dict:
        """
        Rejects one or more VPC endpoint connection requests to your VPC endpoint service.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RejectVpcEndpointConnections>`_
        
        **Request Syntax**
        ::
          response = client.reject_vpc_endpoint_connections(
              DryRun=True|False,
              ServiceId='string',
              VpcEndpointIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Unsuccessful** *(list) --* 
              Information about the endpoints that were not rejected, if applicable.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type ServiceId: string
        :param ServiceId: **[REQUIRED]**
          The ID of the service.
        :type VpcEndpointIds: list
        :param VpcEndpointIds: **[REQUIRED]**
          The IDs of one or more VPC endpoints.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def reject_vpc_peering_connection(self, VpcPeeringConnectionId: str, DryRun: bool = None) -> Dict:
        """
        Rejects a VPC peering connection request. The VPC peering connection must be in the ``pending-acceptance`` state. Use the  DescribeVpcPeeringConnections request to view your outstanding VPC peering connection requests. To delete an active VPC peering connection, or to delete a VPC peering connection request that you initiated, use  DeleteVpcPeeringConnection .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RejectVpcPeeringConnection>`_
        
        **Request Syntax**
        ::
          response = client.reject_vpc_peering_connection(
              DryRun=True|False,
              VpcPeeringConnectionId='string'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, it returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type VpcPeeringConnectionId: string
        :param VpcPeeringConnectionId: **[REQUIRED]**
          The ID of the VPC peering connection.
        :rtype: dict
        :returns:
        """
        pass

    def release_address(self, AllocationId: str = None, PublicIp: str = None, DryRun: bool = None):
        """
        Releases the specified Elastic IP address.
        [EC2-Classic, default VPC] Releasing an Elastic IP address automatically disassociates it from any instance that it's associated with. To disassociate an Elastic IP address without releasing it, use  DisassociateAddress .
        [Nondefault VPC] You must use  DisassociateAddress to disassociate the Elastic IP address before you can release it. Otherwise, Amazon EC2 returns an error (``InvalidIPAddress.InUse`` ).
        After releasing an Elastic IP address, it is released to the IP address pool. Be sure to update your DNS records and any servers or devices that communicate with the address. If you attempt to release an Elastic IP address that you already released, you'll get an ``AuthFailure`` error if the address is already allocated to another AWS account.
        [EC2-VPC] After you release an Elastic IP address for use in a VPC, you might be able to recover it. For more information, see  AllocateAddress .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReleaseAddress>`_
        
        **Request Syntax**
        ::
          response = client.release_address(
              AllocationId='string',
              PublicIp='string',
              DryRun=True|False
          )
        :type AllocationId: string
        :param AllocationId:
          [EC2-VPC] The allocation ID. Required for EC2-VPC.
        :type PublicIp: string
        :param PublicIp:
          [EC2-Classic] The Elastic IP address. Required for EC2-Classic.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def release_hosts(self, HostIds: List) -> Dict:
        """
        When you no longer want to use an On-Demand Dedicated Host it can be released. On-Demand billing is stopped and the host goes into ``released`` state. The host ID of Dedicated Hosts that have been released can no longer be specified in another request, for example, to modify the host. You must stop or terminate all instances on a host before it can be released.
        When Dedicated Hosts are released, it may take some time for them to stop counting toward your limit and you may receive capacity errors when trying to allocate new Dedicated Hosts. Wait a few minutes and then try again.
        Released hosts still appear in a  DescribeHosts response.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReleaseHosts>`_
        
        **Request Syntax**
        ::
          response = client.release_hosts(
              HostIds=[
                  'string',
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Successful': [
                    'string',
                ],
                'Unsuccessful': [
                    {
                        'Error': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'ResourceId': 'string'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Successful** *(list) --* 
              The IDs of the Dedicated Hosts that were successfully released.
              - *(string) --* 
            - **Unsuccessful** *(list) --* 
              The IDs of the Dedicated Hosts that could not be released, including an error message.
              - *(dict) --* 
                Information about items that were not successfully processed in a batch call.
                - **Error** *(dict) --* 
                  Information about the error.
                  - **Code** *(string) --* 
                    The error code.
                  - **Message** *(string) --* 
                    The error message accompanying the error code.
                - **ResourceId** *(string) --* 
                  The ID of the resource.
        :type HostIds: list
        :param HostIds: **[REQUIRED]**
          The IDs of the Dedicated Hosts to release.
          - *(string) --*
        :rtype: dict
        :returns:
        """
        pass

    def replace_iam_instance_profile_association(self, IamInstanceProfile: Dict, AssociationId: str) -> Dict:
        """
        Replaces an IAM instance profile for the specified running instance. You can use this action to change the IAM instance profile that's associated with an instance without having to disassociate the existing IAM instance profile first.
        Use  DescribeIamInstanceProfileAssociations to get the association ID.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReplaceIamInstanceProfileAssociation>`_
        
        **Request Syntax**
        ::
          response = client.replace_iam_instance_profile_association(
              IamInstanceProfile={
                  'Arn': 'string',
                  'Name': 'string'
              },
              AssociationId='string'
          )
        
        **Response Syntax**
        ::
            {
                'IamInstanceProfileAssociation': {
                    'AssociationId': 'string',
                    'InstanceId': 'string',
                    'IamInstanceProfile': {
                        'Arn': 'string',
                        'Id': 'string'
                    },
                    'State': 'associating'|'associated'|'disassociating'|'disassociated',
                    'Timestamp': datetime(2015, 1, 1)
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **IamInstanceProfileAssociation** *(dict) --* 
              Information about the IAM instance profile association.
              - **AssociationId** *(string) --* 
                The ID of the association.
              - **InstanceId** *(string) --* 
                The ID of the instance.
              - **IamInstanceProfile** *(dict) --* 
                The IAM instance profile.
                - **Arn** *(string) --* 
                  The Amazon Resource Name (ARN) of the instance profile.
                - **Id** *(string) --* 
                  The ID of the instance profile.
              - **State** *(string) --* 
                The state of the association.
              - **Timestamp** *(datetime) --* 
                The time the IAM instance profile was associated with the instance.
        :type IamInstanceProfile: dict
        :param IamInstanceProfile: **[REQUIRED]**
          The IAM instance profile.
          - **Arn** *(string) --*
            The Amazon Resource Name (ARN) of the instance profile.
          - **Name** *(string) --*
            The name of the instance profile.
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The ID of the existing IAM instance profile association.
        :rtype: dict
        :returns:
        """
        pass

    def replace_network_acl_association(self, AssociationId: str, NetworkAclId: str, DryRun: bool = None) -> Dict:
        """
        Changes which network ACL a subnet is associated with. By default when you create a subnet, it's automatically associated with the default network ACL. For more information, see `Network ACLs <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_ACLs.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        This is an idempotent operation.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReplaceNetworkAclAssociation>`_
        
        **Request Syntax**
        ::
          response = client.replace_network_acl_association(
              AssociationId='string',
              DryRun=True|False,
              NetworkAclId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NewAssociationId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NewAssociationId** *(string) --* 
              The ID of the new association.
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The ID of the current association between the original network ACL and the subnet.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkAclId: string
        :param NetworkAclId: **[REQUIRED]**
          The ID of the new network ACL to associate with the subnet.
        :rtype: dict
        :returns:
        """
        pass

    def replace_network_acl_entry(self, Egress: bool, NetworkAclId: str, Protocol: str, RuleAction: str, RuleNumber: int, CidrBlock: str = None, DryRun: bool = None, IcmpTypeCode: Dict = None, Ipv6CidrBlock: str = None, PortRange: Dict = None):
        """
        Replaces an entry (rule) in a network ACL. For more information, see `Network ACLs <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_ACLs.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReplaceNetworkAclEntry>`_
        
        **Request Syntax**
        ::
          response = client.replace_network_acl_entry(
              CidrBlock='string',
              DryRun=True|False,
              Egress=True|False,
              IcmpTypeCode={
                  'Code': 123,
                  'Type': 123
              },
              Ipv6CidrBlock='string',
              NetworkAclId='string',
              PortRange={
                  'From': 123,
                  'To': 123
              },
              Protocol='string',
              RuleAction='allow'|'deny',
              RuleNumber=123
          )
        :type CidrBlock: string
        :param CidrBlock:
          The IPv4 network range to allow or deny, in CIDR notation (for example ``172.16.0.0/24`` ).
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Egress: boolean
        :param Egress: **[REQUIRED]**
          Indicates whether to replace the egress rule.
          Default: If no value is specified, we replace the ingress rule.
        :type IcmpTypeCode: dict
        :param IcmpTypeCode:
          ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.
          - **Code** *(integer) --*
            The ICMP code. A value of -1 means all codes for the specified ICMP type.
          - **Type** *(integer) --*
            The ICMP type. A value of -1 means all types.
        :type Ipv6CidrBlock: string
        :param Ipv6CidrBlock:
          The IPv6 network range to allow or deny, in CIDR notation (for example ``2001:bd8:1234:1a00::/64`` ).
        :type NetworkAclId: string
        :param NetworkAclId: **[REQUIRED]**
          The ID of the ACL.
        :type PortRange: dict
        :param PortRange:
          TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).
          - **From** *(integer) --*
            The first port in the range.
          - **To** *(integer) --*
            The last port in the range.
        :type Protocol: string
        :param Protocol: **[REQUIRED]**
          The protocol number. A value of \"-1\" means all protocols. If you specify \"-1\" or a protocol number other than \"6\" (TCP), \"17\" (UDP), or \"1\" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol \"58\" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol \"58\" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.
        :type RuleAction: string
        :param RuleAction: **[REQUIRED]**
          Indicates whether to allow or deny the traffic that matches the rule.
        :type RuleNumber: integer
        :param RuleNumber: **[REQUIRED]**
          The rule number of the entry to replace.
        :returns: None
        """
        pass

    def replace_route(self, RouteTableId: str, DestinationCidrBlock: str = None, DestinationIpv6CidrBlock: str = None, DryRun: bool = None, EgressOnlyInternetGatewayId: str = None, GatewayId: str = None, InstanceId: str = None, NatGatewayId: str = None, TransitGatewayId: str = None, NetworkInterfaceId: str = None, VpcPeeringConnectionId: str = None):
        """
        Replaces an existing route within a route table in a VPC. You must provide only one of the following: internet gateway or virtual private gateway, NAT instance, NAT gateway, VPC peering connection, network interface, or egress-only internet gateway.
        For more information, see `Route Tables <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReplaceRoute>`_
        
        **Request Syntax**
        ::
          response = client.replace_route(
              DestinationCidrBlock='string',
              DestinationIpv6CidrBlock='string',
              DryRun=True|False,
              EgressOnlyInternetGatewayId='string',
              GatewayId='string',
              InstanceId='string',
              NatGatewayId='string',
              TransitGatewayId='string',
              NetworkInterfaceId='string',
              RouteTableId='string',
              VpcPeeringConnectionId='string'
          )
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock:
          The IPv4 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.
        :type DestinationIpv6CidrBlock: string
        :param DestinationIpv6CidrBlock:
          The IPv6 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EgressOnlyInternetGatewayId: string
        :param EgressOnlyInternetGatewayId:
          [IPv6 traffic only] The ID of an egress-only internet gateway.
        :type GatewayId: string
        :param GatewayId:
          The ID of an internet gateway or virtual private gateway.
        :type InstanceId: string
        :param InstanceId:
          The ID of a NAT instance in your VPC.
        :type NatGatewayId: string
        :param NatGatewayId:
          [IPv4 traffic only] The ID of a NAT gateway.
        :type TransitGatewayId: string
        :param TransitGatewayId:
          The ID of a transit gateway.
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId:
          The ID of a network interface.
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the route table.
        :type VpcPeeringConnectionId: string
        :param VpcPeeringConnectionId:
          The ID of a VPC peering connection.
        :returns: None
        """
        pass

    def replace_route_table_association(self, AssociationId: str, RouteTableId: str, DryRun: bool = None) -> Dict:
        """
        Changes the route table associated with a given subnet in a VPC. After the operation completes, the subnet uses the routes in the new route table it's associated with. For more information about route tables, see `Route Tables <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        You can also use ReplaceRouteTableAssociation to change which table is the main route table in the VPC. You just specify the main route table's association ID and the route table to be the new main route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReplaceRouteTableAssociation>`_
        
        **Request Syntax**
        ::
          response = client.replace_route_table_association(
              AssociationId='string',
              DryRun=True|False,
              RouteTableId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NewAssociationId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NewAssociationId** *(string) --* 
              The ID of the new association.
        :type AssociationId: string
        :param AssociationId: **[REQUIRED]**
          The association ID.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type RouteTableId: string
        :param RouteTableId: **[REQUIRED]**
          The ID of the new route table to associate with the subnet.
        :rtype: dict
        :returns:
        """
        pass

    def replace_transit_gateway_route(self, DestinationCidrBlock: str, TransitGatewayRouteTableId: str, TransitGatewayAttachmentId: str = None, Blackhole: bool = None, DryRun: bool = None) -> Dict:
        """
        Replaces the specified route in the specified transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReplaceTransitGatewayRoute>`_
        
        **Request Syntax**
        ::
          response = client.replace_transit_gateway_route(
              DestinationCidrBlock='string',
              TransitGatewayRouteTableId='string',
              TransitGatewayAttachmentId='string',
              Blackhole=True|False,
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Route': {
                    'DestinationCidrBlock': 'string',
                    'TransitGatewayAttachments': [
                        {
                            'ResourceId': 'string',
                            'TransitGatewayAttachmentId': 'string',
                            'ResourceType': 'vpc'|'vpn'
                        },
                    ],
                    'Type': 'static'|'propagated',
                    'State': 'pending'|'active'|'blackhole'|'deleting'|'deleted'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Route** *(dict) --* 
              Information about the modified route.
              - **DestinationCidrBlock** *(string) --* 
                The CIDR block used for destination matches.
              - **TransitGatewayAttachments** *(list) --* 
                The attachments.
                - *(dict) --* 
                  Describes a route attachment.
                  - **ResourceId** *(string) --* 
                    The ID of the resource.
                  - **TransitGatewayAttachmentId** *(string) --* 
                    The ID of the attachment.
                  - **ResourceType** *(string) --* 
                    The resource type.
              - **Type** *(string) --* 
                The route type.
              - **State** *(string) --* 
                The state of the route.
        :type DestinationCidrBlock: string
        :param DestinationCidrBlock: **[REQUIRED]**
          The CIDR range used for the destination match. Routing decisions are based on the most specific match.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the route table.
        :type TransitGatewayAttachmentId: string
        :param TransitGatewayAttachmentId:
          The ID of the attachment.
        :type Blackhole: boolean
        :param Blackhole:
          Indicates whether traffic matching this route is to be dropped.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def report_instance_status(self, Instances: List, ReasonCodes: List, Status: str, Description: str = None, DryRun: bool = None, EndTime: datetime = None, StartTime: datetime = None):
        """
        Submits feedback about the status of an instance. The instance must be in the ``running`` state. If your experience with the instance differs from the instance status returned by  DescribeInstanceStatus , use  ReportInstanceStatus to report your experience with the instance. Amazon EC2 collects this information to improve the accuracy of status checks.
        Use of this action does not change the value returned by  DescribeInstanceStatus .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ReportInstanceStatus>`_
        
        **Request Syntax**
        ::
          response = client.report_instance_status(
              Description='string',
              DryRun=True|False,
              EndTime=datetime(2015, 1, 1),
              Instances=[
                  'string',
              ],
              ReasonCodes=[
                  'instance-stuck-in-state'|'unresponsive'|'not-accepting-credentials'|'password-not-available'|'performance-network'|'performance-instance-store'|'performance-ebs-volume'|'performance-other'|'other',
              ],
              StartTime=datetime(2015, 1, 1),
              Status='ok'|'impaired'
          )
        :type Description: string
        :param Description:
          Descriptive text about the health state of your instance.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EndTime: datetime
        :param EndTime:
          The time at which the reported instance health state ended.
        :type Instances: list
        :param Instances: **[REQUIRED]**
          The instances.
          - *(string) --*
        :type ReasonCodes: list
        :param ReasonCodes: **[REQUIRED]**
          The reason codes that describe the health state of your instance.
          * ``instance-stuck-in-state`` : My instance is stuck in a state.
          * ``unresponsive`` : My instance is unresponsive.
          * ``not-accepting-credentials`` : My instance is not accepting my credentials.
          * ``password-not-available`` : A password is not available for my instance.
          * ``performance-network`` : My instance is experiencing performance problems that I believe are network related.
          * ``performance-instance-store`` : My instance is experiencing performance problems that I believe are related to the instance stores.
          * ``performance-ebs-volume`` : My instance is experiencing performance problems that I believe are related to an EBS volume.
          * ``performance-other`` : My instance is experiencing performance problems.
          * ``other`` : [explain using the description parameter]
          - *(string) --*
        :type StartTime: datetime
        :param StartTime:
          The time at which the reported instance health state began.
        :type Status: string
        :param Status: **[REQUIRED]**
          The status of all instances listed.
        :returns: None
        """
        pass

    def request_spot_fleet(self, SpotFleetRequestConfig: Dict, DryRun: bool = None) -> Dict:
        """
        Creates a Spot Fleet request.
        The Spot Fleet request specifies the total target capacity and the On-Demand target capacity. Amazon EC2 calculates the difference between the total capacity and On-Demand capacity, and launches the difference as Spot capacity.
        You can submit a single request that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet.
        By default, the Spot Fleet requests Spot Instances in the Spot pool where the price per unit is the lowest. Each launch specification can include its own instance weighting that reflects the value of the instance type to your application workload.
        Alternatively, you can specify that the Spot Fleet distribute the target capacity across the Spot pools included in its launch specifications. By ensuring that the Spot Instances in your Spot Fleet are in different Spot pools, you can improve the availability of your fleet.
        You can specify tags for the Spot Instances. You cannot tag other resource types in a Spot Fleet request because only the ``instance`` resource type is supported.
        For more information, see `Spot Fleet Requests <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RequestSpotFleet>`_
        
        **Request Syntax**
        ::
          response = client.request_spot_fleet(
              DryRun=True|False,
              SpotFleetRequestConfig={
                  'AllocationStrategy': 'lowestPrice'|'diversified',
                  'OnDemandAllocationStrategy': 'lowestPrice'|'prioritized',
                  'ClientToken': 'string',
                  'ExcessCapacityTerminationPolicy': 'noTermination'|'default',
                  'FulfilledCapacity': 123.0,
                  'OnDemandFulfilledCapacity': 123.0,
                  'IamFleetRole': 'string',
                  'LaunchSpecifications': [
                      {
                          'SecurityGroups': [
                              {
                                  'GroupName': 'string',
                                  'GroupId': 'string'
                              },
                          ],
                          'AddressingType': 'string',
                          'BlockDeviceMappings': [
                              {
                                  'DeviceName': 'string',
                                  'VirtualName': 'string',
                                  'Ebs': {
                                      'DeleteOnTermination': True|False,
                                      'Iops': 123,
                                      'SnapshotId': 'string',
                                      'VolumeSize': 123,
                                      'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                                      'Encrypted': True|False,
                                      'KmsKeyId': 'string'
                                  },
                                  'NoDevice': 'string'
                              },
                          ],
                          'EbsOptimized': True|False,
                          'IamInstanceProfile': {
                              'Arn': 'string',
                              'Name': 'string'
                          },
                          'ImageId': 'string',
                          'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                          'KernelId': 'string',
                          'KeyName': 'string',
                          'Monitoring': {
                              'Enabled': True|False
                          },
                          'NetworkInterfaces': [
                              {
                                  'AssociatePublicIpAddress': True|False,
                                  'DeleteOnTermination': True|False,
                                  'Description': 'string',
                                  'DeviceIndex': 123,
                                  'Groups': [
                                      'string',
                                  ],
                                  'Ipv6AddressCount': 123,
                                  'Ipv6Addresses': [
                                      {
                                          'Ipv6Address': 'string'
                                      },
                                  ],
                                  'NetworkInterfaceId': 'string',
                                  'PrivateIpAddress': 'string',
                                  'PrivateIpAddresses': [
                                      {
                                          'Primary': True|False,
                                          'PrivateIpAddress': 'string'
                                      },
                                  ],
                                  'SecondaryPrivateIpAddressCount': 123,
                                  'SubnetId': 'string',
                                  'InterfaceType': 'string'
                              },
                          ],
                          'Placement': {
                              'AvailabilityZone': 'string',
                              'GroupName': 'string',
                              'Tenancy': 'default'|'dedicated'|'host'
                          },
                          'RamdiskId': 'string',
                          'SpotPrice': 'string',
                          'SubnetId': 'string',
                          'UserData': 'string',
                          'WeightedCapacity': 123.0,
                          'TagSpecifications': [
                              {
                                  'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                                  'Tags': [
                                      {
                                          'Key': 'string',
                                          'Value': 'string'
                                      },
                                  ]
                              },
                          ]
                      },
                  ],
                  'LaunchTemplateConfigs': [
                      {
                          'LaunchTemplateSpecification': {
                              'LaunchTemplateId': 'string',
                              'LaunchTemplateName': 'string',
                              'Version': 'string'
                          },
                          'Overrides': [
                              {
                                  'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                                  'SpotPrice': 'string',
                                  'SubnetId': 'string',
                                  'AvailabilityZone': 'string',
                                  'WeightedCapacity': 123.0,
                                  'Priority': 123.0
                              },
                          ]
                      },
                  ],
                  'SpotPrice': 'string',
                  'TargetCapacity': 123,
                  'OnDemandTargetCapacity': 123,
                  'TerminateInstancesWithExpiration': True|False,
                  'Type': 'request'|'maintain'|'instant',
                  'ValidFrom': datetime(2015, 1, 1),
                  'ValidUntil': datetime(2015, 1, 1),
                  'ReplaceUnhealthyInstances': True|False,
                  'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate',
                  'LoadBalancersConfig': {
                      'ClassicLoadBalancersConfig': {
                          'ClassicLoadBalancers': [
                              {
                                  'Name': 'string'
                              },
                          ]
                      },
                      'TargetGroupsConfig': {
                          'TargetGroups': [
                              {
                                  'Arn': 'string'
                              },
                          ]
                      }
                  },
                  'InstancePoolsToUseCount': 123
              }
          )
        
        **Response Syntax**
        ::
            {
                'SpotFleetRequestId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of RequestSpotFleet.
            - **SpotFleetRequestId** *(string) --* 
              The ID of the Spot Fleet request.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type SpotFleetRequestConfig: dict
        :param SpotFleetRequestConfig: **[REQUIRED]**
          The configuration for the Spot Fleet request.
          - **AllocationStrategy** *(string) --*
            Indicates how to allocate the target capacity across the Spot pools specified by the Spot Fleet request. The default is ``lowestPrice`` .
          - **OnDemandAllocationStrategy** *(string) --*
            The order of the launch template overrides to use in fulfilling On-Demand capacity. If you specify ``lowestPrice`` , Spot Fleet uses price to determine the order, launching the lowest price first. If you specify ``prioritized`` , Spot Fleet uses the priority that you assign to each Spot Fleet launch template override, launching the highest priority first. If you do not specify a value, Spot Fleet defaults to ``lowestPrice`` .
          - **ClientToken** *(string) --*
            A unique, case-sensitive identifier that you provide to ensure the idempotency of your listings. This helps to avoid duplicate listings. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          - **ExcessCapacityTerminationPolicy** *(string) --*
            Indicates whether running Spot Instances should be terminated if the target capacity of the Spot Fleet request is decreased below the current size of the Spot Fleet.
          - **FulfilledCapacity** *(float) --*
            The number of units fulfilled by this request compared to the set target capacity. You cannot set this value.
          - **OnDemandFulfilledCapacity** *(float) --*
            The number of On-Demand units fulfilled by this request compared to the set target On-Demand capacity.
          - **IamFleetRole** *(string) --* **[REQUIRED]**
            Grants the Spot Fleet permission to terminate Spot Instances on your behalf when you cancel its Spot Fleet request using  CancelSpotFleetRequests or when the Spot Fleet request expires, if you set ``terminateInstancesWithExpiration`` .
          - **LaunchSpecifications** *(list) --*
            The launch specifications for the Spot Fleet request. If you specify ``LaunchSpecifications`` , you can\'t specify ``LaunchTemplateConfigs`` .
            - *(dict) --*
              Describes the launch specification for one or more Spot Instances.
              - **SecurityGroups** *(list) --*
                One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
                - *(dict) --*
                  Describes a security group.
                  - **GroupName** *(string) --*
                    The name of the security group.
                  - **GroupId** *(string) --*
                    The ID of the security group.
              - **AddressingType** *(string) --*
                Deprecated.
              - **BlockDeviceMappings** *(list) --*
                One or more block device mapping entries. You can\'t specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
                - *(dict) --*
                  Describes a block device mapping.
                  - **DeviceName** *(string) --*
                    The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                  - **VirtualName** *(string) --*
                    The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                    NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
                    Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
                  - **Ebs** *(dict) --*
                    Parameters used to automatically set up EBS volumes when the instance is launched.
                    - **DeleteOnTermination** *(boolean) --*
                      Indicates whether the EBS volume is deleted on instance termination.
                    - **Iops** *(integer) --*
                      The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                      Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                      Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                    - **SnapshotId** *(string) --*
                      The ID of the snapshot.
                    - **VolumeSize** *(integer) --*
                      The size of the volume, in GiB.
                      Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                      Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
                    - **VolumeType** *(string) --*
                      The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                      Default: ``standard``
                    - **Encrypted** *(boolean) --*
                      Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                      If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
                    - **KmsKeyId** *(string) --*
                      Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                      This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
                  - **NoDevice** *(string) --*
                    Suppresses the specified device included in the block device mapping of the AMI.
              - **EbsOptimized** *(boolean) --*
                Indicates whether the instances are optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
                Default: ``false``
              - **IamInstanceProfile** *(dict) --*
                The IAM instance profile.
                - **Arn** *(string) --*
                  The Amazon Resource Name (ARN) of the instance profile.
                - **Name** *(string) --*
                  The name of the instance profile.
              - **ImageId** *(string) --*
                The ID of the AMI.
              - **InstanceType** *(string) --*
                The instance type.
              - **KernelId** *(string) --*
                The ID of the kernel.
              - **KeyName** *(string) --*
                The name of the key pair.
              - **Monitoring** *(dict) --*
                Enable or disable monitoring for the instances.
                - **Enabled** *(boolean) --*
                  Enables monitoring for the instance.
                  Default: ``false``
              - **NetworkInterfaces** *(list) --*
                One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
                - *(dict) --*
                  Describes a network interface.
                  - **AssociatePublicIpAddress** *(boolean) --*
                    Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ``true`` .
                  - **DeleteOnTermination** *(boolean) --*
                    If set to ``true`` , the interface is deleted when the instance is terminated. You can specify ``true`` only if creating a new network interface when launching an instance.
                  - **Description** *(string) --*
                    The description of the network interface. Applies only if creating a network interface when launching an instance.
                  - **DeviceIndex** *(integer) --*
                    The index of the device on the instance for the network interface attachment. If you are specifying a network interface in a  RunInstances request, you must provide the device index.
                  - **Groups** *(list) --*
                    The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
                    - *(string) --*
                  - **Ipv6AddressCount** *(integer) --*
                    A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you\'ve specified a minimum number of instances to launch.
                  - **Ipv6Addresses** *(list) --*
                    One or more IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you\'ve specified a minimum number of instances to launch.
                    - *(dict) --*
                      Describes an IPv6 address.
                      - **Ipv6Address** *(string) --*
                        The IPv6 address.
                  - **NetworkInterfaceId** *(string) --*
                    The ID of the network interface.
                  - **PrivateIpAddress** *(string) --*
                    The private IPv4 address of the network interface. Applies only if creating a network interface when launching an instance. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
                  - **PrivateIpAddresses** *(list) --*
                    One or more private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
                    - *(dict) --*
                      Describes a secondary private IPv4 address for a network interface.
                      - **Primary** *(boolean) --*
                        Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                      - **PrivateIpAddress** *(string) --*
                        The private IPv4 addresses.
                  - **SecondaryPrivateIpAddressCount** *(integer) --*
                    The number of secondary private IPv4 addresses. You can\'t specify this option and specify more than one private IP address using the private IP addresses option. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
                  - **SubnetId** *(string) --*
                    The ID of the subnet associated with the network string. Applies only if creating a network interface when launching an instance.
                  - **InterfaceType** *(string) --*
                    The type of interface.
              - **Placement** *(dict) --*
                The placement information.
                - **AvailabilityZone** *(string) --*
                  The Availability Zone.
                  [Spot Fleet only] To specify multiple Availability Zones, separate them using commas; for example, \"us-west-2a, us-west-2b\".
                - **GroupName** *(string) --*
                  The name of the placement group.
                - **Tenancy** *(string) --*
                  The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for Spot Instances.
              - **RamdiskId** *(string) --*
                The ID of the RAM disk.
              - **SpotPrice** *(string) --*
                The maximum price per unit hour that you are willing to pay for a Spot Instance. If this value is not specified, the default is the Spot price specified for the fleet. To determine the Spot price per unit hour, divide the Spot price by the value of ``WeightedCapacity`` .
              - **SubnetId** *(string) --*
                The ID of the subnet in which to launch the instances. To specify multiple subnets, separate them using commas; for example, \"subnet-a61dafcf, subnet-65ea5f08\".
              - **UserData** *(string) --*
                The Base64-encoded user data to make available to the instances.
              - **WeightedCapacity** *(float) --*
                The number of units provided by the specified instance type. These are the same units that you chose to set the target capacity in terms (instances or a performance characteristic such as vCPUs, memory, or I/O).
                If the target capacity divided by this value is not a whole number, we round the number of instances to the next whole number. If this value is not specified, the default is 1.
              - **TagSpecifications** *(list) --*
                The tags to apply during creation.
                - *(dict) --*
                  The tags for a Spot Fleet resource.
                  - **ResourceType** *(string) --*
                    The type of resource. Currently, the only resource type that is supported is ``instance`` .
                  - **Tags** *(list) --*
                    The tags.
                    - *(dict) --*
                      Describes a tag.
                      - **Key** *(string) --*
                        The key of the tag.
                        Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                      - **Value** *(string) --*
                        The value of the tag.
                        Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
          - **LaunchTemplateConfigs** *(list) --*
            The launch template and overrides. If you specify ``LaunchTemplateConfigs`` , you can\'t specify ``LaunchSpecifications`` .
            - *(dict) --*
              Describes a launch template and overrides.
              - **LaunchTemplateSpecification** *(dict) --*
                The launch template.
                - **LaunchTemplateId** *(string) --*
                  The ID of the launch template. You must specify either a template ID or a template name.
                - **LaunchTemplateName** *(string) --*
                  The name of the launch template. You must specify either a template name or a template ID.
                - **Version** *(string) --*
                  The version number of the launch template. You must specify a version number.
              - **Overrides** *(list) --*
                Any parameters that you specify override the same parameters in the launch template.
                - *(dict) --*
                  Describes overrides for a launch template.
                  - **InstanceType** *(string) --*
                    The instance type.
                  - **SpotPrice** *(string) --*
                    The maximum price per unit hour that you are willing to pay for a Spot Instance.
                  - **SubnetId** *(string) --*
                    The ID of the subnet in which to launch the instances.
                  - **AvailabilityZone** *(string) --*
                    The Availability Zone in which to launch the instances.
                  - **WeightedCapacity** *(float) --*
                    The number of units provided by the specified instance type.
                  - **Priority** *(float) --*
                    The priority for the launch template override. If **OnDemandAllocationStrategy** is set to ``prioritized`` , Spot Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. Valid values are whole numbers starting at ``0`` . The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority.
          - **SpotPrice** *(string) --*
            The maximum price per unit hour that you are willing to pay for a Spot Instance. The default is the On-Demand price.
          - **TargetCapacity** *(integer) --* **[REQUIRED]**
            The number of units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is ``maintain`` , you can specify a target capacity of 0 and add capacity later.
          - **OnDemandTargetCapacity** *(integer) --*
            The number of On-Demand units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is ``maintain`` , you can specify a target capacity of 0 and add capacity later.
          - **TerminateInstancesWithExpiration** *(boolean) --*
            Indicates whether running Spot Instances should be terminated when the Spot Fleet request expires.
          - **Type** *(string) --*
            The type of request. Indicates whether the Spot Fleet only requests the target capacity or also attempts to maintain it. When this value is ``request`` , the Spot Fleet only places the required requests. It does not attempt to replenish Spot Instances if capacity is diminished, nor does it submit requests in alternative Spot pools if capacity is not available. When this value is ``maintain`` , the Spot Fleet maintains the target capacity. The Spot Fleet places the required requests to meet capacity and automatically replenishes any interrupted instances. Default: ``maintain`` . ``instant`` is listed but is not used by Spot Fleet.
          - **ValidFrom** *(datetime) --*
            The start date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). The default is to start fulfilling the request immediately.
          - **ValidUntil** *(datetime) --*
            The end date and time of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). At this point, no new Spot Instance requests are placed or able to fulfill the request. If no value is specified, the Spot Fleet request remains until you cancel it.
          - **ReplaceUnhealthyInstances** *(boolean) --*
            Indicates whether Spot Fleet should replace unhealthy instances.
          - **InstanceInterruptionBehavior** *(string) --*
            The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
          - **LoadBalancersConfig** *(dict) --*
            One or more Classic Load Balancers and target groups to attach to the Spot Fleet request. Spot Fleet registers the running Spot Instances with the specified Classic Load Balancers and target groups.
            With Network Load Balancers, Spot Fleet cannot register instances that have the following instance types: C1, CC1, CC2, CG1, CG2, CR1, CS1, G1, G2, HI1, HS1, M1, M2, M3, and T1.
            - **ClassicLoadBalancersConfig** *(dict) --*
              The Classic Load Balancers.
              - **ClassicLoadBalancers** *(list) --*
                One or more Classic Load Balancers.
                - *(dict) --*
                  Describes a Classic Load Balancer.
                  - **Name** *(string) --*
                    The name of the load balancer.
            - **TargetGroupsConfig** *(dict) --*
              The target groups.
              - **TargetGroups** *(list) --*
                One or more target groups.
                - *(dict) --*
                  Describes a load balancer target group.
                  - **Arn** *(string) --*
                    The Amazon Resource Name (ARN) of the target group.
          - **InstancePoolsToUseCount** *(integer) --*
            The number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot **AllocationStrategy** is set to ``lowest-price`` . Spot Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify.
        :rtype: dict
        :returns:
        """
        pass

    def request_spot_instances(self, AvailabilityZoneGroup: str = None, BlockDurationMinutes: int = None, ClientToken: str = None, DryRun: bool = None, InstanceCount: int = None, LaunchGroup: str = None, LaunchSpecification: Dict = None, SpotPrice: str = None, Type: str = None, ValidFrom: datetime = None, ValidUntil: datetime = None, InstanceInterruptionBehavior: str = None) -> Dict:
        """
        Creates a Spot Instance request.
        For more information, see `Spot Instance Requests <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-requests.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RequestSpotInstances>`_
        
        **Request Syntax**
        ::
          response = client.request_spot_instances(
              AvailabilityZoneGroup='string',
              BlockDurationMinutes=123,
              ClientToken='string',
              DryRun=True|False,
              InstanceCount=123,
              LaunchGroup='string',
              LaunchSpecification={
                  'SecurityGroupIds': [
                      'string',
                  ],
                  'SecurityGroups': [
                      'string',
                  ],
                  'AddressingType': 'string',
                  'BlockDeviceMappings': [
                      {
                          'DeviceName': 'string',
                          'VirtualName': 'string',
                          'Ebs': {
                              'DeleteOnTermination': True|False,
                              'Iops': 123,
                              'SnapshotId': 'string',
                              'VolumeSize': 123,
                              'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                              'Encrypted': True|False,
                              'KmsKeyId': 'string'
                          },
                          'NoDevice': 'string'
                      },
                  ],
                  'EbsOptimized': True|False,
                  'IamInstanceProfile': {
                      'Arn': 'string',
                      'Name': 'string'
                  },
                  'ImageId': 'string',
                  'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                  'KernelId': 'string',
                  'KeyName': 'string',
                  'Monitoring': {
                      'Enabled': True|False
                  },
                  'NetworkInterfaces': [
                      {
                          'AssociatePublicIpAddress': True|False,
                          'DeleteOnTermination': True|False,
                          'Description': 'string',
                          'DeviceIndex': 123,
                          'Groups': [
                              'string',
                          ],
                          'Ipv6AddressCount': 123,
                          'Ipv6Addresses': [
                              {
                                  'Ipv6Address': 'string'
                              },
                          ],
                          'NetworkInterfaceId': 'string',
                          'PrivateIpAddress': 'string',
                          'PrivateIpAddresses': [
                              {
                                  'Primary': True|False,
                                  'PrivateIpAddress': 'string'
                              },
                          ],
                          'SecondaryPrivateIpAddressCount': 123,
                          'SubnetId': 'string',
                          'InterfaceType': 'string'
                      },
                  ],
                  'Placement': {
                      'AvailabilityZone': 'string',
                      'GroupName': 'string',
                      'Tenancy': 'default'|'dedicated'|'host'
                  },
                  'RamdiskId': 'string',
                  'SubnetId': 'string',
                  'UserData': 'string'
              },
              SpotPrice='string',
              Type='one-time'|'persistent',
              ValidFrom=datetime(2015, 1, 1),
              ValidUntil=datetime(2015, 1, 1),
              InstanceInterruptionBehavior='hibernate'|'stop'|'terminate'
          )
        
        **Response Syntax**
        ::
            {
                'SpotInstanceRequests': [
                    {
                        'ActualBlockHourlyPrice': 'string',
                        'AvailabilityZoneGroup': 'string',
                        'BlockDurationMinutes': 123,
                        'CreateTime': datetime(2015, 1, 1),
                        'Fault': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'InstanceId': 'string',
                        'LaunchGroup': 'string',
                        'LaunchSpecification': {
                            'UserData': 'string',
                            'SecurityGroups': [
                                {
                                    'GroupName': 'string',
                                    'GroupId': 'string'
                                },
                            ],
                            'AddressingType': 'string',
                            'BlockDeviceMappings': [
                                {
                                    'DeviceName': 'string',
                                    'VirtualName': 'string',
                                    'Ebs': {
                                        'DeleteOnTermination': True|False,
                                        'Iops': 123,
                                        'SnapshotId': 'string',
                                        'VolumeSize': 123,
                                        'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                                        'Encrypted': True|False,
                                        'KmsKeyId': 'string'
                                    },
                                    'NoDevice': 'string'
                                },
                            ],
                            'EbsOptimized': True|False,
                            'IamInstanceProfile': {
                                'Arn': 'string',
                                'Name': 'string'
                            },
                            'ImageId': 'string',
                            'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                            'KernelId': 'string',
                            'KeyName': 'string',
                            'NetworkInterfaces': [
                                {
                                    'AssociatePublicIpAddress': True|False,
                                    'DeleteOnTermination': True|False,
                                    'Description': 'string',
                                    'DeviceIndex': 123,
                                    'Groups': [
                                        'string',
                                    ],
                                    'Ipv6AddressCount': 123,
                                    'Ipv6Addresses': [
                                        {
                                            'Ipv6Address': 'string'
                                        },
                                    ],
                                    'NetworkInterfaceId': 'string',
                                    'PrivateIpAddress': 'string',
                                    'PrivateIpAddresses': [
                                        {
                                            'Primary': True|False,
                                            'PrivateIpAddress': 'string'
                                        },
                                    ],
                                    'SecondaryPrivateIpAddressCount': 123,
                                    'SubnetId': 'string',
                                    'InterfaceType': 'string'
                                },
                            ],
                            'Placement': {
                                'AvailabilityZone': 'string',
                                'GroupName': 'string',
                                'Tenancy': 'default'|'dedicated'|'host'
                            },
                            'RamdiskId': 'string',
                            'SubnetId': 'string',
                            'Monitoring': {
                                'Enabled': True|False
                            }
                        },
                        'LaunchedAvailabilityZone': 'string',
                        'ProductDescription': 'Linux/UNIX'|'Linux/UNIX (Amazon VPC)'|'Windows'|'Windows (Amazon VPC)',
                        'SpotInstanceRequestId': 'string',
                        'SpotPrice': 'string',
                        'State': 'open'|'active'|'closed'|'cancelled'|'failed',
                        'Status': {
                            'Code': 'string',
                            'Message': 'string',
                            'UpdateTime': datetime(2015, 1, 1)
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'Type': 'one-time'|'persistent',
                        'ValidFrom': datetime(2015, 1, 1),
                        'ValidUntil': datetime(2015, 1, 1),
                        'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of RequestSpotInstances.
            - **SpotInstanceRequests** *(list) --* 
              One or more Spot Instance requests.
              - *(dict) --* 
                Describes a Spot Instance request.
                - **ActualBlockHourlyPrice** *(string) --* 
                  If you specified a duration and your Spot Instance request was fulfilled, this is the fixed hourly price in effect for the Spot Instance while it runs.
                - **AvailabilityZoneGroup** *(string) --* 
                  The Availability Zone group. If you specify the same Availability Zone group for all Spot Instance requests, all Spot Instances are launched in the same Availability Zone.
                - **BlockDurationMinutes** *(integer) --* 
                  The duration for the Spot Instance, in minutes.
                - **CreateTime** *(datetime) --* 
                  The date and time when the Spot Instance request was created, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
                - **Fault** *(dict) --* 
                  The fault codes for the Spot Instance request, if any.
                  - **Code** *(string) --* 
                    The reason code for the Spot Instance state change.
                  - **Message** *(string) --* 
                    The message for the Spot Instance state change.
                - **InstanceId** *(string) --* 
                  The instance ID, if an instance has been launched to fulfill the Spot Instance request.
                - **LaunchGroup** *(string) --* 
                  The instance launch group. Launch groups are Spot Instances that launch together and terminate together.
                - **LaunchSpecification** *(dict) --* 
                  Additional information for launching instances.
                  - **UserData** *(string) --* 
                    The Base64-encoded user data for the instance.
                  - **SecurityGroups** *(list) --* 
                    One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
                    - *(dict) --* 
                      Describes a security group.
                      - **GroupName** *(string) --* 
                        The name of the security group.
                      - **GroupId** *(string) --* 
                        The ID of the security group.
                  - **AddressingType** *(string) --* 
                    Deprecated.
                  - **BlockDeviceMappings** *(list) --* 
                    One or more block device mapping entries.
                    - *(dict) --* 
                      Describes a block device mapping.
                      - **DeviceName** *(string) --* 
                        The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                      - **VirtualName** *(string) --* 
                        The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                        NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
                        Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
                      - **Ebs** *(dict) --* 
                        Parameters used to automatically set up EBS volumes when the instance is launched.
                        - **DeleteOnTermination** *(boolean) --* 
                          Indicates whether the EBS volume is deleted on instance termination.
                        - **Iops** *(integer) --* 
                          The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                          Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                          Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                        - **SnapshotId** *(string) --* 
                          The ID of the snapshot.
                        - **VolumeSize** *(integer) --* 
                          The size of the volume, in GiB.
                          Default: If you're creating the volume from a snapshot and don't specify a volume size, the default is the snapshot size.
                          Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
                        - **VolumeType** *(string) --* 
                          The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                          Default: ``standard``  
                        - **Encrypted** *(boolean) --* 
                          Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                          If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
                        - **KmsKeyId** *(string) --* 
                          Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                          This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
                      - **NoDevice** *(string) --* 
                        Suppresses the specified device included in the block device mapping of the AMI.
                  - **EbsOptimized** *(boolean) --* 
                    Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
                    Default: ``false``  
                  - **IamInstanceProfile** *(dict) --* 
                    The IAM instance profile.
                    - **Arn** *(string) --* 
                      The Amazon Resource Name (ARN) of the instance profile.
                    - **Name** *(string) --* 
                      The name of the instance profile.
                  - **ImageId** *(string) --* 
                    The ID of the AMI.
                  - **InstanceType** *(string) --* 
                    The instance type.
                  - **KernelId** *(string) --* 
                    The ID of the kernel.
                  - **KeyName** *(string) --* 
                    The name of the key pair.
                  - **NetworkInterfaces** *(list) --* 
                    One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
                    - *(dict) --* 
                      Describes a network interface.
                      - **AssociatePublicIpAddress** *(boolean) --* 
                        Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ``true`` .
                      - **DeleteOnTermination** *(boolean) --* 
                        If set to ``true`` , the interface is deleted when the instance is terminated. You can specify ``true`` only if creating a new network interface when launching an instance.
                      - **Description** *(string) --* 
                        The description of the network interface. Applies only if creating a network interface when launching an instance.
                      - **DeviceIndex** *(integer) --* 
                        The index of the device on the instance for the network interface attachment. If you are specifying a network interface in a  RunInstances request, you must provide the device index.
                      - **Groups** *(list) --* 
                        The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
                        - *(string) --* 
                      - **Ipv6AddressCount** *(integer) --* 
                        A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you've specified a minimum number of instances to launch.
                      - **Ipv6Addresses** *(list) --* 
                        One or more IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you've specified a minimum number of instances to launch.
                        - *(dict) --* 
                          Describes an IPv6 address.
                          - **Ipv6Address** *(string) --* 
                            The IPv6 address.
                      - **NetworkInterfaceId** *(string) --* 
                        The ID of the network interface.
                      - **PrivateIpAddress** *(string) --* 
                        The private IPv4 address of the network interface. Applies only if creating a network interface when launching an instance. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                      - **PrivateIpAddresses** *(list) --* 
                        One or more private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                        - *(dict) --* 
                          Describes a secondary private IPv4 address for a network interface.
                          - **Primary** *(boolean) --* 
                            Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                          - **PrivateIpAddress** *(string) --* 
                            The private IPv4 addresses.
                      - **SecondaryPrivateIpAddressCount** *(integer) --* 
                        The number of secondary private IPv4 addresses. You can't specify this option and specify more than one private IP address using the private IP addresses option. You cannot specify this option if you're launching more than one instance in a  RunInstances request.
                      - **SubnetId** *(string) --* 
                        The ID of the subnet associated with the network string. Applies only if creating a network interface when launching an instance.
                      - **InterfaceType** *(string) --* 
                        The type of interface.
                  - **Placement** *(dict) --* 
                    The placement information for the instance.
                    - **AvailabilityZone** *(string) --* 
                      The Availability Zone.
                      [Spot Fleet only] To specify multiple Availability Zones, separate them using commas; for example, "us-west-2a, us-west-2b".
                    - **GroupName** *(string) --* 
                      The name of the placement group.
                    - **Tenancy** *(string) --* 
                      The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for Spot Instances.
                  - **RamdiskId** *(string) --* 
                    The ID of the RAM disk.
                  - **SubnetId** *(string) --* 
                    The ID of the subnet in which to launch the instance.
                  - **Monitoring** *(dict) --* 
                    Describes the monitoring of an instance.
                    - **Enabled** *(boolean) --* 
                      Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
                - **LaunchedAvailabilityZone** *(string) --* 
                  The Availability Zone in which the request is launched.
                - **ProductDescription** *(string) --* 
                  The product description associated with the Spot Instance.
                - **SpotInstanceRequestId** *(string) --* 
                  The ID of the Spot Instance request.
                - **SpotPrice** *(string) --* 
                  The maximum price per hour that you are willing to pay for a Spot Instance.
                - **State** *(string) --* 
                  The state of the Spot Instance request. Spot status information helps track your Spot Instance requests. For more information, see `Spot Status <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-bid-status.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
                - **Status** *(dict) --* 
                  The status code and status message describing the Spot Instance request.
                  - **Code** *(string) --* 
                    The status code. For a list of status codes, see `Spot Status Codes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-bid-status.html#spot-instance-bid-status-understand>`__ in the *Amazon EC2 User Guide for Linux Instances* .
                  - **Message** *(string) --* 
                    The description for the status code.
                  - **UpdateTime** *(datetime) --* 
                    The date and time of the most recent status update, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z).
                - **Tags** *(list) --* 
                  Any tags assigned to the resource.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **Type** *(string) --* 
                  The Spot Instance request type.
                - **ValidFrom** *(datetime) --* 
                  The start date of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). The request becomes active at this date and time.
                - **ValidUntil** *(datetime) --* 
                  The end date of the request, in UTC format (for example, *YYYY* -*MM* -*DD* T*HH* :*MM* :*SS* Z). If this is a one-time request, it remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date is reached. The default end date is 7 days from the current date.
                - **InstanceInterruptionBehavior** *(string) --* 
                  The behavior when a Spot Instance is interrupted.
        :type AvailabilityZoneGroup: string
        :param AvailabilityZoneGroup:
          The user-specified name for a logical grouping of requests.
          When you specify an Availability Zone group in a Spot Instance request, all Spot Instances in the request are launched in the same Availability Zone. Instance proximity is maintained with this parameter, but the choice of Availability Zone is not. The group applies only to requests for Spot Instances of the same instance type. Any additional Spot Instance requests that are specified with the same Availability Zone group name are launched in that same Availability Zone, as long as at least one instance from the group is still active.
          If there is no active instance running in the Availability Zone group that you specify for a new Spot Instance request (all instances are terminated, the request is expired, or the maximum price you specified falls below current Spot price), then Amazon EC2 launches the instance in any Availability Zone where the constraint can be met. Consequently, the subsequent set of Spot Instances could be placed in a different zone from the original request, even if you specified the same Availability Zone group.
          Default: Instances are launched in any available Availability Zone.
        :type BlockDurationMinutes: integer
        :param BlockDurationMinutes:
          The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
          The duration period starts as soon as your Spot Instance receives its instance ID. At the end of the duration period, Amazon EC2 marks the Spot Instance for termination and provides a Spot Instance termination notice, which gives the instance a two-minute warning before it terminates.
          You can\'t specify an Availability Zone group or a launch group if you specify a duration.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see `How to Ensure Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html>`__ in the *Amazon EC2 User Guide for Linux Instances* .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceCount: integer
        :param InstanceCount:
          The maximum number of Spot Instances to launch.
          Default: 1
        :type LaunchGroup: string
        :param LaunchGroup:
          The instance launch group. Launch groups are Spot Instances that launch together and terminate together.
          Default: Instances are launched and terminated individually
        :type LaunchSpecification: dict
        :param LaunchSpecification:
          The launch specification.
          - **SecurityGroupIds** *(list) --*
            One or more security group IDs.
            - *(string) --*
          - **SecurityGroups** *(list) --*
            One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
            - *(string) --*
          - **AddressingType** *(string) --*
            Deprecated.
          - **BlockDeviceMappings** *(list) --*
            One or more block device mapping entries. You can\'t specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
            - *(dict) --*
              Describes a block device mapping.
              - **DeviceName** *(string) --*
                The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
              - **VirtualName** *(string) --*
                The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
                Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
              - **Ebs** *(dict) --*
                Parameters used to automatically set up EBS volumes when the instance is launched.
                - **DeleteOnTermination** *(boolean) --*
                  Indicates whether the EBS volume is deleted on instance termination.
                - **Iops** *(integer) --*
                  The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                  Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                  Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                - **SnapshotId** *(string) --*
                  The ID of the snapshot.
                - **VolumeSize** *(integer) --*
                  The size of the volume, in GiB.
                  Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                  Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
                - **VolumeType** *(string) --*
                  The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                  Default: ``standard``
                - **Encrypted** *(boolean) --*
                  Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                  If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
                - **KmsKeyId** *(string) --*
                  Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                  This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
              - **NoDevice** *(string) --*
                Suppresses the specified device included in the block device mapping of the AMI.
          - **EbsOptimized** *(boolean) --*
            Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
            Default: ``false``
          - **IamInstanceProfile** *(dict) --*
            The IAM instance profile.
            - **Arn** *(string) --*
              The Amazon Resource Name (ARN) of the instance profile.
            - **Name** *(string) --*
              The name of the instance profile.
          - **ImageId** *(string) --*
            The ID of the AMI.
          - **InstanceType** *(string) --*
            The instance type.
          - **KernelId** *(string) --*
            The ID of the kernel.
          - **KeyName** *(string) --*
            The name of the key pair.
          - **Monitoring** *(dict) --*
            Indicates whether basic or detailed monitoring is enabled for the instance.
            Default: Disabled
            - **Enabled** *(boolean) --* **[REQUIRED]**
              Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
          - **NetworkInterfaces** *(list) --*
            One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
            - *(dict) --*
              Describes a network interface.
              - **AssociatePublicIpAddress** *(boolean) --*
                Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ``true`` .
              - **DeleteOnTermination** *(boolean) --*
                If set to ``true`` , the interface is deleted when the instance is terminated. You can specify ``true`` only if creating a new network interface when launching an instance.
              - **Description** *(string) --*
                The description of the network interface. Applies only if creating a network interface when launching an instance.
              - **DeviceIndex** *(integer) --*
                The index of the device on the instance for the network interface attachment. If you are specifying a network interface in a  RunInstances request, you must provide the device index.
              - **Groups** *(list) --*
                The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
                - *(string) --*
              - **Ipv6AddressCount** *(integer) --*
                A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you\'ve specified a minimum number of instances to launch.
              - **Ipv6Addresses** *(list) --*
                One or more IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you\'ve specified a minimum number of instances to launch.
                - *(dict) --*
                  Describes an IPv6 address.
                  - **Ipv6Address** *(string) --*
                    The IPv6 address.
              - **NetworkInterfaceId** *(string) --*
                The ID of the network interface.
              - **PrivateIpAddress** *(string) --*
                The private IPv4 address of the network interface. Applies only if creating a network interface when launching an instance. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
              - **PrivateIpAddresses** *(list) --*
                One or more private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
                - *(dict) --*
                  Describes a secondary private IPv4 address for a network interface.
                  - **Primary** *(boolean) --*
                    Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                  - **PrivateIpAddress** *(string) --*
                    The private IPv4 addresses.
              - **SecondaryPrivateIpAddressCount** *(integer) --*
                The number of secondary private IPv4 addresses. You can\'t specify this option and specify more than one private IP address using the private IP addresses option. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
              - **SubnetId** *(string) --*
                The ID of the subnet associated with the network string. Applies only if creating a network interface when launching an instance.
              - **InterfaceType** *(string) --*
                The type of interface.
          - **Placement** *(dict) --*
            The placement information for the instance.
            - **AvailabilityZone** *(string) --*
              The Availability Zone.
              [Spot Fleet only] To specify multiple Availability Zones, separate them using commas; for example, \"us-west-2a, us-west-2b\".
            - **GroupName** *(string) --*
              The name of the placement group.
            - **Tenancy** *(string) --*
              The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for Spot Instances.
          - **RamdiskId** *(string) --*
            The ID of the RAM disk.
          - **SubnetId** *(string) --*
            The ID of the subnet in which to launch the instance.
          - **UserData** *(string) --*
            The Base64-encoded user data for the instance. User data is limited to 16 KB.
        :type SpotPrice: string
        :param SpotPrice:
          The maximum price per hour that you are willing to pay for a Spot Instance. The default is the On-Demand price.
        :type Type: string
        :param Type:
          The Spot Instance request type.
          Default: ``one-time``
        :type ValidFrom: datetime
        :param ValidFrom:
          The start date of the request. If this is a one-time request, the request becomes active at this date and time and remains active until all instances launch, the request expires, or the request is canceled. If the request is persistent, the request becomes active at this date and time and remains active until it expires or is canceled.
        :type ValidUntil: datetime
        :param ValidUntil:
          The end date of the request. If this is a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date is reached. The default end date is 7 days from the current date.
        :type InstanceInterruptionBehavior: string
        :param InstanceInterruptionBehavior:
          The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
        :rtype: dict
        :returns:
        """
        pass

    def reset_fpga_image_attribute(self, FpgaImageId: str, DryRun: bool = None, Attribute: str = None) -> Dict:
        """
        Resets the specified attribute of the specified Amazon FPGA Image (AFI) to its default value. You can only reset the load permission attribute.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ResetFpgaImageAttribute>`_
        
        **Request Syntax**
        ::
          response = client.reset_fpga_image_attribute(
              DryRun=True|False,
              FpgaImageId='string',
              Attribute='loadPermission'
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Is ``true`` if the request succeeds, and an error otherwise.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type FpgaImageId: string
        :param FpgaImageId: **[REQUIRED]**
          The ID of the AFI.
        :type Attribute: string
        :param Attribute:
          The attribute.
        :rtype: dict
        :returns:
        """
        pass

    def reset_image_attribute(self, Attribute: str, ImageId: str, DryRun: bool = None):
        """
        Resets an attribute of an AMI to its default value.
        .. note::
          The productCodes attribute can't be reset.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ResetImageAttribute>`_
        
        **Request Syntax**
        ::
          response = client.reset_image_attribute(
              Attribute='launchPermission',
              ImageId='string',
              DryRun=True|False
          )
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The attribute to reset (currently you can only reset the launch permission attribute).
        :type ImageId: string
        :param ImageId: **[REQUIRED]**
          The ID of the AMI.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def reset_instance_attribute(self, Attribute: str, InstanceId: str, DryRun: bool = None):
        """
        Resets an attribute of an instance to its default value. To reset the ``kernel`` or ``ramdisk`` , the instance must be in a stopped state. To reset the ``sourceDestCheck`` , the instance can be either running or stopped.
        The ``sourceDestCheck`` attribute controls whether source/destination checking is enabled. The default value is ``true`` , which means checking is enabled. This value must be ``false`` for a NAT instance to perform NAT. For more information, see `NAT Instances <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_NAT_Instance.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ResetInstanceAttribute>`_
        
        **Request Syntax**
        ::
          response = client.reset_instance_attribute(
              Attribute='instanceType'|'kernel'|'ramdisk'|'userData'|'disableApiTermination'|'instanceInitiatedShutdownBehavior'|'rootDeviceName'|'blockDeviceMapping'|'productCodes'|'sourceDestCheck'|'groupSet'|'ebsOptimized'|'sriovNetSupport'|'enaSupport',
              DryRun=True|False,
              InstanceId='string'
          )
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The attribute to reset.
          .. warning::
            You can only reset the following attributes: ``kernel`` | ``ramdisk`` | ``sourceDestCheck`` . To change an instance attribute, use  ModifyInstanceAttribute .
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceId: string
        :param InstanceId: **[REQUIRED]**
          The ID of the instance.
        :returns: None
        """
        pass

    def reset_network_interface_attribute(self, NetworkInterfaceId: str, DryRun: bool = None, SourceDestCheck: str = None):
        """
        Resets a network interface attribute. You can specify only one attribute at a time.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ResetNetworkInterfaceAttribute>`_
        
        **Request Syntax**
        ::
          response = client.reset_network_interface_attribute(
              DryRun=True|False,
              NetworkInterfaceId='string',
              SourceDestCheck='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :type SourceDestCheck: string
        :param SourceDestCheck:
          The source/destination checking attribute. Resets the value to ``true`` .
        :returns: None
        """
        pass

    def reset_snapshot_attribute(self, Attribute: str, SnapshotId: str, DryRun: bool = None):
        """
        Resets permission settings for the specified snapshot.
        For more information about modifying snapshot permissions, see `Sharing Snapshots <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-modifying-snapshot-permissions.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ResetSnapshotAttribute>`_
        
        **Request Syntax**
        ::
          response = client.reset_snapshot_attribute(
              Attribute='productCodes'|'createVolumePermission',
              SnapshotId='string',
              DryRun=True|False
          )
        :type Attribute: string
        :param Attribute: **[REQUIRED]**
          The attribute to reset. Currently, only the attribute for permission to create volumes can be reset.
        :type SnapshotId: string
        :param SnapshotId: **[REQUIRED]**
          The ID of the snapshot.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def restore_address_to_classic(self, PublicIp: str, DryRun: bool = None) -> Dict:
        """
        Restores an Elastic IP address that was previously moved to the EC2-VPC platform back to the EC2-Classic platform. You cannot move an Elastic IP address that was originally allocated for use in EC2-VPC. The Elastic IP address must not be associated with an instance or network interface.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RestoreAddressToClassic>`_
        
        **Request Syntax**
        ::
          response = client.restore_address_to_classic(
              DryRun=True|False,
              PublicIp='string'
          )
        
        **Response Syntax**
        ::
            {
                'PublicIp': 'string',
                'Status': 'MoveInProgress'|'InVpc'|'InClassic'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **PublicIp** *(string) --* 
              The Elastic IP address.
            - **Status** *(string) --* 
              The move status for the IP address.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type PublicIp: string
        :param PublicIp: **[REQUIRED]**
          The Elastic IP address.
        :rtype: dict
        :returns:
        """
        pass

    def revoke_client_vpn_ingress(self, ClientVpnEndpointId: str, TargetNetworkCidr: str, AccessGroupId: str = None, RevokeAllGroups: bool = None, DryRun: bool = None) -> Dict:
        """
        Removes an ingress authorization rule from a Client VPN endpoint. 
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RevokeClientVpnIngress>`_
        
        **Request Syntax**
        ::
          response = client.revoke_client_vpn_ingress(
              ClientVpnEndpointId='string',
              TargetNetworkCidr='string',
              AccessGroupId='string',
              RevokeAllGroups=True|False,
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Status': {
                    'Code': 'authorizing'|'active'|'failed'|'revoking',
                    'Message': 'string'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Status** *(dict) --* 
              The current state of the authorization rule.
              - **Code** *(string) --* 
                The state of the authorization rule.
              - **Message** *(string) --* 
                A message about the status of the authorization rule, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint with which the authorization rule is associated.
        :type TargetNetworkCidr: string
        :param TargetNetworkCidr: **[REQUIRED]**
          The IPv4 address range, in CIDR notation, of the network for which access is being removed.
        :type AccessGroupId: string
        :param AccessGroupId:
          The ID of the Active Directory group for which to revoke access.
        :type RevokeAllGroups: boolean
        :param RevokeAllGroups:
          Indicates whether access should be revoked for all clients.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def revoke_security_group_egress(self, GroupId: str, DryRun: bool = None, IpPermissions: List = None, CidrIp: str = None, FromPort: int = None, IpProtocol: str = None, ToPort: int = None, SourceSecurityGroupName: str = None, SourceSecurityGroupOwnerId: str = None):
        """
        [VPC only] Removes the specified egress rules from a security group for EC2-VPC. This action doesn't apply to security groups for use in EC2-Classic. To remove a rule, the values that you specify (for example, ports) must match the existing rule's values exactly.
        Each rule consists of the protocol and the IPv4 or IPv6 CIDR range or source security group. For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not have to specify the description to revoke the rule.
        Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RevokeSecurityGroupEgress>`_
        
        **Request Syntax**
        ::
          response = client.revoke_security_group_egress(
              DryRun=True|False,
              GroupId='string',
              IpPermissions=[
                  {
                      'FromPort': 123,
                      'IpProtocol': 'string',
                      'IpRanges': [
                          {
                              'CidrIp': 'string',
                              'Description': 'string'
                          },
                      ],
                      'Ipv6Ranges': [
                          {
                              'CidrIpv6': 'string',
                              'Description': 'string'
                          },
                      ],
                      'PrefixListIds': [
                          {
                              'Description': 'string',
                              'PrefixListId': 'string'
                          },
                      ],
                      'ToPort': 123,
                      'UserIdGroupPairs': [
                          {
                              'Description': 'string',
                              'GroupId': 'string',
                              'GroupName': 'string',
                              'PeeringStatus': 'string',
                              'UserId': 'string',
                              'VpcId': 'string',
                              'VpcPeeringConnectionId': 'string'
                          },
                      ]
                  },
              ],
              CidrIp='string',
              FromPort=123,
              IpProtocol='string',
              ToPort=123,
              SourceSecurityGroupName='string',
              SourceSecurityGroupOwnerId='string'
          )
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupId: string
        :param GroupId: **[REQUIRED]**
          The ID of the security group.
        :type IpPermissions: list
        :param IpPermissions:
          The sets of IP permissions. You can\'t specify a destination security group and a CIDR IP address range in the same set of permissions.
          - *(dict) --*
            Describes a set of permissions for a security group rule.
            - **FromPort** *(integer) --*
              The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **IpProtocol** *(string) --*
              The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
              [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
            - **IpRanges** *(list) --*
              The IPv4 ranges.
              - *(dict) --*
                Describes an IPv4 range.
                - **CidrIp** *(string) --*
                  The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv4 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **Ipv6Ranges** *(list) --*
              [VPC only] The IPv6 ranges.
              - *(dict) --*
                [EC2-VPC only] Describes an IPv6 range.
                - **CidrIpv6** *(string) --*
                  The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv6 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **PrefixListIds** *(list) --*
              [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
              - *(dict) --*
                Describes a prefix list ID.
                - **Description** *(string) --*
                  A description for the security group rule that references this prefix list ID.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **PrefixListId** *(string) --*
                  The ID of the prefix.
            - **ToPort** *(integer) --*
              The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **UserIdGroupPairs** *(list) --*
              The security group and AWS account ID pairs.
              - *(dict) --*
                Describes a security group and AWS account ID pair.
                - **Description** *(string) --*
                  A description for the security group rule that references this user ID group pair.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **GroupId** *(string) --*
                  The ID of the security group.
                - **GroupName** *(string) --*
                  The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID.
                  For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                - **PeeringStatus** *(string) --*
                  The status of a VPC peering connection, if applicable.
                - **UserId** *(string) --*
                  The ID of an AWS account.
                  For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                  [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                - **VpcId** *(string) --*
                  The ID of the VPC for the referenced security group, if applicable.
                - **VpcPeeringConnectionId** *(string) --*
                  The ID of the VPC peering connection, if applicable.
        :type CidrIp: string
        :param CidrIp:
          Not supported. Use a set of IP permissions to specify the CIDR.
        :type FromPort: integer
        :param FromPort:
          Not supported. Use a set of IP permissions to specify the port.
        :type IpProtocol: string
        :param IpProtocol:
          Not supported. Use a set of IP permissions to specify the protocol name or number.
        :type ToPort: integer
        :param ToPort:
          Not supported. Use a set of IP permissions to specify the port.
        :type SourceSecurityGroupName: string
        :param SourceSecurityGroupName:
          Not supported. Use a set of IP permissions to specify a destination security group.
        :type SourceSecurityGroupOwnerId: string
        :param SourceSecurityGroupOwnerId:
          Not supported. Use a set of IP permissions to specify a destination security group.
        :returns: None
        """
        pass

    def revoke_security_group_ingress(self, CidrIp: str = None, FromPort: int = None, GroupId: str = None, GroupName: str = None, IpPermissions: List = None, IpProtocol: str = None, SourceSecurityGroupName: str = None, SourceSecurityGroupOwnerId: str = None, ToPort: int = None, DryRun: bool = None):
        """
        Removes the specified ingress rules from a security group. To remove a rule, the values that you specify (for example, ports) must match the existing rule's values exactly.
        .. note::
          [EC2-Classic only] If the values you specify do not match the existing rule's values, no error is returned. Use  DescribeSecurityGroups to verify that the rule has been removed.
        Each rule consists of the protocol and the CIDR range or source security group. For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not have to specify the description to revoke the rule.
        Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RevokeSecurityGroupIngress>`_
        
        **Request Syntax**
        ::
          response = client.revoke_security_group_ingress(
              CidrIp='string',
              FromPort=123,
              GroupId='string',
              GroupName='string',
              IpPermissions=[
                  {
                      'FromPort': 123,
                      'IpProtocol': 'string',
                      'IpRanges': [
                          {
                              'CidrIp': 'string',
                              'Description': 'string'
                          },
                      ],
                      'Ipv6Ranges': [
                          {
                              'CidrIpv6': 'string',
                              'Description': 'string'
                          },
                      ],
                      'PrefixListIds': [
                          {
                              'Description': 'string',
                              'PrefixListId': 'string'
                          },
                      ],
                      'ToPort': 123,
                      'UserIdGroupPairs': [
                          {
                              'Description': 'string',
                              'GroupId': 'string',
                              'GroupName': 'string',
                              'PeeringStatus': 'string',
                              'UserId': 'string',
                              'VpcId': 'string',
                              'VpcPeeringConnectionId': 'string'
                          },
                      ]
                  },
              ],
              IpProtocol='string',
              SourceSecurityGroupName='string',
              SourceSecurityGroupOwnerId='string',
              ToPort=123,
              DryRun=True|False
          )
        :type CidrIp: string
        :param CidrIp:
          The CIDR IP address range. You can\'t specify this parameter when specifying a source security group.
        :type FromPort: integer
        :param FromPort:
          The start of port range for the TCP and UDP protocols, or an ICMP type number. For the ICMP type number, use ``-1`` to specify all ICMP types.
        :type GroupId: string
        :param GroupId:
          The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
        :type GroupName: string
        :param GroupName:
          [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request.
        :type IpPermissions: list
        :param IpPermissions:
          The sets of IP permissions. You can\'t specify a source security group and a CIDR IP address range in the same set of permissions.
          - *(dict) --*
            Describes a set of permissions for a security group rule.
            - **FromPort** *(integer) --*
              The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **IpProtocol** *(string) --*
              The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
              [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
            - **IpRanges** *(list) --*
              The IPv4 ranges.
              - *(dict) --*
                Describes an IPv4 range.
                - **CidrIp** *(string) --*
                  The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv4 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **Ipv6Ranges** *(list) --*
              [VPC only] The IPv6 ranges.
              - *(dict) --*
                [EC2-VPC only] Describes an IPv6 range.
                - **CidrIpv6** *(string) --*
                  The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv6 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **PrefixListIds** *(list) --*
              [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
              - *(dict) --*
                Describes a prefix list ID.
                - **Description** *(string) --*
                  A description for the security group rule that references this prefix list ID.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **PrefixListId** *(string) --*
                  The ID of the prefix.
            - **ToPort** *(integer) --*
              The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **UserIdGroupPairs** *(list) --*
              The security group and AWS account ID pairs.
              - *(dict) --*
                Describes a security group and AWS account ID pair.
                - **Description** *(string) --*
                  A description for the security group rule that references this user ID group pair.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **GroupId** *(string) --*
                  The ID of the security group.
                - **GroupName** *(string) --*
                  The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID.
                  For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                - **PeeringStatus** *(string) --*
                  The status of a VPC peering connection, if applicable.
                - **UserId** *(string) --*
                  The ID of an AWS account.
                  For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                  [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                - **VpcId** *(string) --*
                  The ID of the VPC for the referenced security group, if applicable.
                - **VpcPeeringConnectionId** *(string) --*
                  The ID of the VPC peering connection, if applicable.
        :type IpProtocol: string
        :param IpProtocol:
          The IP protocol name (``tcp`` , ``udp`` , ``icmp`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ). Use ``-1`` to specify all.
        :type SourceSecurityGroupName: string
        :param SourceSecurityGroupName:
          [EC2-Classic, default VPC] The name of the source security group. You can\'t specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. For EC2-VPC, the source security group must be in the same VPC. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead.
        :type SourceSecurityGroupOwnerId: string
        :param SourceSecurityGroupOwnerId:
          [EC2-Classic] The AWS account ID of the source security group, if the source security group is in a different account. You can\'t specify this parameter in combination with the following parameters: the CIDR IP address range, the IP protocol, the start of the port range, and the end of the port range. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead.
        :type ToPort: integer
        :param ToPort:
          The end of port range for the TCP and UDP protocols, or an ICMP code number. For the ICMP code number, use ``-1`` to specify all ICMP codes for the ICMP type.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :returns: None
        """
        pass

    def run_instances(self, MaxCount: int, MinCount: int, BlockDeviceMappings: List = None, ImageId: str = None, InstanceType: str = None, Ipv6AddressCount: int = None, Ipv6Addresses: List = None, KernelId: str = None, KeyName: str = None, Monitoring: Dict = None, Placement: Dict = None, RamdiskId: str = None, SecurityGroupIds: List = None, SecurityGroups: List = None, SubnetId: str = None, UserData: str = None, AdditionalInfo: str = None, ClientToken: str = None, DisableApiTermination: bool = None, DryRun: bool = None, EbsOptimized: bool = None, IamInstanceProfile: Dict = None, InstanceInitiatedShutdownBehavior: str = None, NetworkInterfaces: List = None, PrivateIpAddress: str = None, ElasticGpuSpecification: List = None, ElasticInferenceAccelerators: List = None, TagSpecifications: List = None, LaunchTemplate: Dict = None, InstanceMarketOptions: Dict = None, CreditSpecification: Dict = None, CpuOptions: Dict = None, CapacityReservationSpecification: Dict = None, HibernationOptions: Dict = None, LicenseSpecifications: List = None) -> Dict:
        """
        Launches the specified number of instances using an AMI for which you have permissions. 
        You can specify a number of options, or leave the default options. The following rules apply:
        * [EC2-VPC] If you don't specify a subnet ID, we choose a default subnet from your default VPC for you. If you don't have a default VPC, you must specify a subnet ID in the request. 
        * [EC2-Classic] If don't specify an Availability Zone, we choose one for you. 
        * Some instance types must be launched into a VPC. If you do not have a default VPC, or if you do not specify a subnet ID, the request fails. For more information, see `Instance Types Available Only in a VPC <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-vpc.html#vpc-only-instance-types>`__ . 
        * [EC2-VPC] All instances have a network interface with a primary private IPv4 address. If you don't specify this address, we choose one from the IPv4 range of your subnet. 
        * Not all instance types support IPv6 addresses. For more information, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ . 
        * If you don't specify a security group ID, we use the default security group. For more information, see `Security Groups <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-network-security.html>`__ . 
        * If any of the AMIs have a product code attached for which the user has not subscribed, the request fails. 
        You can create a `launch template <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html>`__ , which is a resource that contains the parameters to launch an instance. When you launch an instance using  RunInstances , you can specify the launch template instead of specifying the launch parameters.
        To ensure faster instance launches, break up large requests into smaller batches. For example, create five separate launch requests for 100 instances each instead of one launch request for 500 instances.
        An instance is ready for you to use when it's in the ``running`` state. You can check the state of your instance using  DescribeInstances . You can tag instances and EBS volumes during launch, after launch, or both. For more information, see  CreateTags and `Tagging Your Amazon EC2 Resources <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html>`__ .
        Linux instances have access to the public key of the key pair at boot. You can use this key to provide secure access to the instance. Amazon EC2 public images use this feature to provide secure access without passwords. For more information, see `Key Pairs <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        For troubleshooting, see `What To Do If An Instance Immediately Terminates <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_InstanceStraightToTerminated.html>`__ , and `Troubleshooting Connecting to Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstancesConnecting.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RunInstances>`_
        
        **Request Syntax**
        ::
          response = client.run_instances(
              BlockDeviceMappings=[
                  {
                      'DeviceName': 'string',
                      'VirtualName': 'string',
                      'Ebs': {
                          'DeleteOnTermination': True|False,
                          'Iops': 123,
                          'SnapshotId': 'string',
                          'VolumeSize': 123,
                          'VolumeType': 'standard'|'io1'|'gp2'|'sc1'|'st1',
                          'Encrypted': True|False,
                          'KmsKeyId': 'string'
                      },
                      'NoDevice': 'string'
                  },
              ],
              ImageId='string',
              InstanceType='t1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
              Ipv6AddressCount=123,
              Ipv6Addresses=[
                  {
                      'Ipv6Address': 'string'
                  },
              ],
              KernelId='string',
              KeyName='string',
              MaxCount=123,
              MinCount=123,
              Monitoring={
                  'Enabled': True|False
              },
              Placement={
                  'AvailabilityZone': 'string',
                  'Affinity': 'string',
                  'GroupName': 'string',
                  'PartitionNumber': 123,
                  'HostId': 'string',
                  'Tenancy': 'default'|'dedicated'|'host',
                  'SpreadDomain': 'string'
              },
              RamdiskId='string',
              SecurityGroupIds=[
                  'string',
              ],
              SecurityGroups=[
                  'string',
              ],
              SubnetId='string',
              UserData='string',
              AdditionalInfo='string',
              ClientToken='string',
              DisableApiTermination=True|False,
              DryRun=True|False,
              EbsOptimized=True|False,
              IamInstanceProfile={
                  'Arn': 'string',
                  'Name': 'string'
              },
              InstanceInitiatedShutdownBehavior='stop'|'terminate',
              NetworkInterfaces=[
                  {
                      'AssociatePublicIpAddress': True|False,
                      'DeleteOnTermination': True|False,
                      'Description': 'string',
                      'DeviceIndex': 123,
                      'Groups': [
                          'string',
                      ],
                      'Ipv6AddressCount': 123,
                      'Ipv6Addresses': [
                          {
                              'Ipv6Address': 'string'
                          },
                      ],
                      'NetworkInterfaceId': 'string',
                      'PrivateIpAddress': 'string',
                      'PrivateIpAddresses': [
                          {
                              'Primary': True|False,
                              'PrivateIpAddress': 'string'
                          },
                      ],
                      'SecondaryPrivateIpAddressCount': 123,
                      'SubnetId': 'string',
                      'InterfaceType': 'string'
                  },
              ],
              PrivateIpAddress='string',
              ElasticGpuSpecification=[
                  {
                      'Type': 'string'
                  },
              ],
              ElasticInferenceAccelerators=[
                  {
                      'Type': 'string'
                  },
              ],
              TagSpecifications=[
                  {
                      'ResourceType': 'client-vpn-endpoint'|'customer-gateway'|'dedicated-host'|'dhcp-options'|'elastic-ip'|'fleet'|'fpga-image'|'host-reservation'|'image'|'instance'|'internet-gateway'|'launch-template'|'natgateway'|'network-acl'|'network-interface'|'reserved-instances'|'route-table'|'security-group'|'snapshot'|'spot-instances-request'|'subnet'|'transit-gateway'|'transit-gateway-attachment'|'transit-gateway-route-table'|'volume'|'vpc'|'vpc-peering-connection'|'vpn-connection'|'vpn-gateway',
                      'Tags': [
                          {
                              'Key': 'string',
                              'Value': 'string'
                          },
                      ]
                  },
              ],
              LaunchTemplate={
                  'LaunchTemplateId': 'string',
                  'LaunchTemplateName': 'string',
                  'Version': 'string'
              },
              InstanceMarketOptions={
                  'MarketType': 'spot',
                  'SpotOptions': {
                      'MaxPrice': 'string',
                      'SpotInstanceType': 'one-time'|'persistent',
                      'BlockDurationMinutes': 123,
                      'ValidUntil': datetime(2015, 1, 1),
                      'InstanceInterruptionBehavior': 'hibernate'|'stop'|'terminate'
                  }
              },
              CreditSpecification={
                  'CpuCredits': 'string'
              },
              CpuOptions={
                  'CoreCount': 123,
                  'ThreadsPerCore': 123
              },
              CapacityReservationSpecification={
                  'CapacityReservationPreference': 'open'|'none',
                  'CapacityReservationTarget': {
                      'CapacityReservationId': 'string'
                  }
              },
              HibernationOptions={
                  'Configured': True|False
              },
              LicenseSpecifications=[
                  {
                      'LicenseConfigurationArn': 'string'
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Groups': [
                    {
                        'GroupName': 'string',
                        'GroupId': 'string'
                    },
                ],
                'Instances': [
                    {
                        'AmiLaunchIndex': 123,
                        'ImageId': 'string',
                        'InstanceId': 'string',
                        'InstanceType': 't1.micro'|'t2.nano'|'t2.micro'|'t2.small'|'t2.medium'|'t2.large'|'t2.xlarge'|'t2.2xlarge'|'t3.nano'|'t3.micro'|'t3.small'|'t3.medium'|'t3.large'|'t3.xlarge'|'t3.2xlarge'|'t3a.nano'|'t3a.micro'|'t3a.small'|'t3a.medium'|'t3a.large'|'t3a.xlarge'|'t3a.2xlarge'|'m1.small'|'m1.medium'|'m1.large'|'m1.xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge'|'m4.16xlarge'|'m2.xlarge'|'m2.2xlarge'|'m2.4xlarge'|'cr1.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'r4.large'|'r4.xlarge'|'r4.2xlarge'|'r4.4xlarge'|'r4.8xlarge'|'r4.16xlarge'|'r5.large'|'r5.xlarge'|'r5.2xlarge'|'r5.4xlarge'|'r5.12xlarge'|'r5.24xlarge'|'r5.metal'|'r5a.large'|'r5a.xlarge'|'r5a.2xlarge'|'r5a.4xlarge'|'r5a.12xlarge'|'r5a.24xlarge'|'r5d.large'|'r5d.xlarge'|'r5d.2xlarge'|'r5d.4xlarge'|'r5d.12xlarge'|'r5d.24xlarge'|'r5d.metal'|'r5ad.large'|'r5ad.xlarge'|'r5ad.2xlarge'|'r5ad.4xlarge'|'r5ad.8xlarge'|'r5ad.12xlarge'|'r5ad.16xlarge'|'r5ad.24xlarge'|'x1.16xlarge'|'x1.32xlarge'|'x1e.xlarge'|'x1e.2xlarge'|'x1e.4xlarge'|'x1e.8xlarge'|'x1e.16xlarge'|'x1e.32xlarge'|'i2.xlarge'|'i2.2xlarge'|'i2.4xlarge'|'i2.8xlarge'|'i3.large'|'i3.xlarge'|'i3.2xlarge'|'i3.4xlarge'|'i3.8xlarge'|'i3.16xlarge'|'i3.metal'|'hi1.4xlarge'|'hs1.8xlarge'|'c1.medium'|'c1.xlarge'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'c5.large'|'c5.xlarge'|'c5.2xlarge'|'c5.4xlarge'|'c5.9xlarge'|'c5.18xlarge'|'c5d.large'|'c5d.xlarge'|'c5d.2xlarge'|'c5d.4xlarge'|'c5d.9xlarge'|'c5d.18xlarge'|'c5n.large'|'c5n.xlarge'|'c5n.2xlarge'|'c5n.4xlarge'|'c5n.9xlarge'|'c5n.18xlarge'|'cc1.4xlarge'|'cc2.8xlarge'|'g2.2xlarge'|'g2.8xlarge'|'g3.4xlarge'|'g3.8xlarge'|'g3.16xlarge'|'g3s.xlarge'|'cg1.4xlarge'|'p2.xlarge'|'p2.8xlarge'|'p2.16xlarge'|'p3.2xlarge'|'p3.8xlarge'|'p3.16xlarge'|'p3dn.24xlarge'|'d2.xlarge'|'d2.2xlarge'|'d2.4xlarge'|'d2.8xlarge'|'f1.2xlarge'|'f1.4xlarge'|'f1.16xlarge'|'m5.large'|'m5.xlarge'|'m5.2xlarge'|'m5.4xlarge'|'m5.12xlarge'|'m5.24xlarge'|'m5.metal'|'m5a.large'|'m5a.xlarge'|'m5a.2xlarge'|'m5a.4xlarge'|'m5a.12xlarge'|'m5a.24xlarge'|'m5d.large'|'m5d.xlarge'|'m5d.2xlarge'|'m5d.4xlarge'|'m5d.12xlarge'|'m5d.24xlarge'|'m5d.metal'|'m5ad.large'|'m5ad.xlarge'|'m5ad.2xlarge'|'m5ad.4xlarge'|'m5ad.8xlarge'|'m5ad.12xlarge'|'m5ad.16xlarge'|'m5ad.24xlarge'|'h1.2xlarge'|'h1.4xlarge'|'h1.8xlarge'|'h1.16xlarge'|'z1d.large'|'z1d.xlarge'|'z1d.2xlarge'|'z1d.3xlarge'|'z1d.6xlarge'|'z1d.12xlarge'|'z1d.metal'|'u-6tb1.metal'|'u-9tb1.metal'|'u-12tb1.metal'|'a1.medium'|'a1.large'|'a1.xlarge'|'a1.2xlarge'|'a1.4xlarge',
                        'KernelId': 'string',
                        'KeyName': 'string',
                        'LaunchTime': datetime(2015, 1, 1),
                        'Monitoring': {
                            'State': 'disabled'|'disabling'|'enabled'|'pending'
                        },
                        'Placement': {
                            'AvailabilityZone': 'string',
                            'Affinity': 'string',
                            'GroupName': 'string',
                            'PartitionNumber': 123,
                            'HostId': 'string',
                            'Tenancy': 'default'|'dedicated'|'host',
                            'SpreadDomain': 'string'
                        },
                        'Platform': 'Windows',
                        'PrivateDnsName': 'string',
                        'PrivateIpAddress': 'string',
                        'ProductCodes': [
                            {
                                'ProductCodeId': 'string',
                                'ProductCodeType': 'devpay'|'marketplace'
                            },
                        ],
                        'PublicDnsName': 'string',
                        'PublicIpAddress': 'string',
                        'RamdiskId': 'string',
                        'State': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        },
                        'StateTransitionReason': 'string',
                        'SubnetId': 'string',
                        'VpcId': 'string',
                        'Architecture': 'i386'|'x86_64'|'arm64',
                        'BlockDeviceMappings': [
                            {
                                'DeviceName': 'string',
                                'Ebs': {
                                    'AttachTime': datetime(2015, 1, 1),
                                    'DeleteOnTermination': True|False,
                                    'Status': 'attaching'|'attached'|'detaching'|'detached',
                                    'VolumeId': 'string'
                                }
                            },
                        ],
                        'ClientToken': 'string',
                        'EbsOptimized': True|False,
                        'EnaSupport': True|False,
                        'Hypervisor': 'ovm'|'xen',
                        'IamInstanceProfile': {
                            'Arn': 'string',
                            'Id': 'string'
                        },
                        'InstanceLifecycle': 'spot'|'scheduled',
                        'ElasticGpuAssociations': [
                            {
                                'ElasticGpuId': 'string',
                                'ElasticGpuAssociationId': 'string',
                                'ElasticGpuAssociationState': 'string',
                                'ElasticGpuAssociationTime': 'string'
                            },
                        ],
                        'ElasticInferenceAcceleratorAssociations': [
                            {
                                'ElasticInferenceAcceleratorArn': 'string',
                                'ElasticInferenceAcceleratorAssociationId': 'string',
                                'ElasticInferenceAcceleratorAssociationState': 'string',
                                'ElasticInferenceAcceleratorAssociationTime': datetime(2015, 1, 1)
                            },
                        ],
                        'NetworkInterfaces': [
                            {
                                'Association': {
                                    'IpOwnerId': 'string',
                                    'PublicDnsName': 'string',
                                    'PublicIp': 'string'
                                },
                                'Attachment': {
                                    'AttachTime': datetime(2015, 1, 1),
                                    'AttachmentId': 'string',
                                    'DeleteOnTermination': True|False,
                                    'DeviceIndex': 123,
                                    'Status': 'attaching'|'attached'|'detaching'|'detached'
                                },
                                'Description': 'string',
                                'Groups': [
                                    {
                                        'GroupName': 'string',
                                        'GroupId': 'string'
                                    },
                                ],
                                'Ipv6Addresses': [
                                    {
                                        'Ipv6Address': 'string'
                                    },
                                ],
                                'MacAddress': 'string',
                                'NetworkInterfaceId': 'string',
                                'OwnerId': 'string',
                                'PrivateDnsName': 'string',
                                'PrivateIpAddress': 'string',
                                'PrivateIpAddresses': [
                                    {
                                        'Association': {
                                            'IpOwnerId': 'string',
                                            'PublicDnsName': 'string',
                                            'PublicIp': 'string'
                                        },
                                        'Primary': True|False,
                                        'PrivateDnsName': 'string',
                                        'PrivateIpAddress': 'string'
                                    },
                                ],
                                'SourceDestCheck': True|False,
                                'Status': 'available'|'associated'|'attaching'|'in-use'|'detaching',
                                'SubnetId': 'string',
                                'VpcId': 'string',
                                'InterfaceType': 'string'
                            },
                        ],
                        'RootDeviceName': 'string',
                        'RootDeviceType': 'ebs'|'instance-store',
                        'SecurityGroups': [
                            {
                                'GroupName': 'string',
                                'GroupId': 'string'
                            },
                        ],
                        'SourceDestCheck': True|False,
                        'SpotInstanceRequestId': 'string',
                        'SriovNetSupport': 'string',
                        'StateReason': {
                            'Code': 'string',
                            'Message': 'string'
                        },
                        'Tags': [
                            {
                                'Key': 'string',
                                'Value': 'string'
                            },
                        ],
                        'VirtualizationType': 'hvm'|'paravirtual',
                        'CpuOptions': {
                            'CoreCount': 123,
                            'ThreadsPerCore': 123
                        },
                        'CapacityReservationId': 'string',
                        'CapacityReservationSpecification': {
                            'CapacityReservationPreference': 'open'|'none',
                            'CapacityReservationTarget': {
                                'CapacityReservationId': 'string'
                            }
                        },
                        'HibernationOptions': {
                            'Configured': True|False
                        },
                        'Licenses': [
                            {
                                'LicenseConfigurationArn': 'string'
                            },
                        ]
                    },
                ],
                'OwnerId': 'string',
                'RequesterId': 'string',
                'ReservationId': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            Describes a reservation.
            - **Groups** *(list) --* 
              [EC2-Classic only] The security groups.
              - *(dict) --* 
                Describes a security group.
                - **GroupName** *(string) --* 
                  The name of the security group.
                - **GroupId** *(string) --* 
                  The ID of the security group.
            - **Instances** *(list) --* 
              The instances.
              - *(dict) --* 
                Describes an instance.
                - **AmiLaunchIndex** *(integer) --* 
                  The AMI launch index, which can be used to find this instance in the launch group.
                - **ImageId** *(string) --* 
                  The ID of the AMI used to launch the instance.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **InstanceType** *(string) --* 
                  The instance type.
                - **KernelId** *(string) --* 
                  The kernel associated with this instance, if applicable.
                - **KeyName** *(string) --* 
                  The name of the key pair, if this instance was launched with an associated key pair.
                - **LaunchTime** *(datetime) --* 
                  The time the instance was launched.
                - **Monitoring** *(dict) --* 
                  The monitoring for the instance.
                  - **State** *(string) --* 
                    Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
                - **Placement** *(dict) --* 
                  The location where the instance launched, if applicable.
                  - **AvailabilityZone** *(string) --* 
                    The Availability Zone of the instance.
                    If not specified, an Availability Zone will be automatically chosen for you based on the load balancing criteria for the region.
                  - **Affinity** *(string) --* 
                    The affinity setting for the instance on the Dedicated Host. This parameter is not supported for the  ImportInstance command.
                  - **GroupName** *(string) --* 
                    The name of the placement group the instance is in.
                  - **PartitionNumber** *(integer) --* 
                    The number of the partition the instance is in. Valid only if the placement group strategy is set to ``partition`` .
                  - **HostId** *(string) --* 
                    The ID of the Dedicated Host on which the instance resides. This parameter is not supported for the  ImportInstance command.
                  - **Tenancy** *(string) --* 
                    The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for the  ImportInstance command.
                  - **SpreadDomain** *(string) --* 
                    Reserved for future use.
                - **Platform** *(string) --* 
                  The value is ``Windows`` for Windows instances; otherwise blank.
                - **PrivateDnsName** *(string) --* 
                  (IPv4 only) The private DNS hostname name assigned to the instance. This DNS hostname can only be used inside the Amazon EC2 network. This name is not available until the instance enters the ``running`` state. 
                  [EC2-VPC] The Amazon-provided DNS server resolves Amazon-provided private DNS hostnames if you've enabled DNS resolution and DNS hostnames in your VPC. If you are not using the Amazon-provided DNS server in your VPC, your custom domain name servers must resolve the hostname as appropriate.
                - **PrivateIpAddress** *(string) --* 
                  The private IPv4 address assigned to the instance.
                - **ProductCodes** *(list) --* 
                  The product codes attached to this instance, if applicable.
                  - *(dict) --* 
                    Describes a product code.
                    - **ProductCodeId** *(string) --* 
                      The product code.
                    - **ProductCodeType** *(string) --* 
                      The type of product code.
                - **PublicDnsName** *(string) --* 
                  (IPv4 only) The public DNS name assigned to the instance. This name is not available until the instance enters the ``running`` state. For EC2-VPC, this name is only available if you've enabled DNS hostnames for your VPC.
                - **PublicIpAddress** *(string) --* 
                  The public IPv4 address assigned to the instance, if applicable.
                - **RamdiskId** *(string) --* 
                  The RAM disk associated with this instance, if applicable.
                - **State** *(dict) --* 
                  The current state of the instance.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
                - **StateTransitionReason** *(string) --* 
                  The reason for the most recent state transition. This might be an empty string.
                - **SubnetId** *(string) --* 
                  [EC2-VPC] The ID of the subnet in which the instance is running.
                - **VpcId** *(string) --* 
                  [EC2-VPC] The ID of the VPC in which the instance is running.
                - **Architecture** *(string) --* 
                  The architecture of the image.
                - **BlockDeviceMappings** *(list) --* 
                  Any block device mapping entries for the instance.
                  - *(dict) --* 
                    Describes a block device mapping.
                    - **DeviceName** *(string) --* 
                      The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
                    - **Ebs** *(dict) --* 
                      Parameters used to automatically set up EBS volumes when the instance is launched.
                      - **AttachTime** *(datetime) --* 
                        The time stamp when the attachment initiated.
                      - **DeleteOnTermination** *(boolean) --* 
                        Indicates whether the volume is deleted on instance termination.
                      - **Status** *(string) --* 
                        The attachment state.
                      - **VolumeId** *(string) --* 
                        The ID of the EBS volume.
                - **ClientToken** *(string) --* 
                  The idempotency token you provided when you launched the instance, if applicable.
                - **EbsOptimized** *(boolean) --* 
                  Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
                - **EnaSupport** *(boolean) --* 
                  Specifies whether enhanced networking with ENA is enabled.
                - **Hypervisor** *(string) --* 
                  The hypervisor type of the instance.
                - **IamInstanceProfile** *(dict) --* 
                  The IAM instance profile associated with the instance, if applicable.
                  - **Arn** *(string) --* 
                    The Amazon Resource Name (ARN) of the instance profile.
                  - **Id** *(string) --* 
                    The ID of the instance profile.
                - **InstanceLifecycle** *(string) --* 
                  Indicates whether this is a Spot Instance or a Scheduled Instance.
                - **ElasticGpuAssociations** *(list) --* 
                  The Elastic GPU associated with the instance.
                  - *(dict) --* 
                    Describes the association between an instance and an Elastic Graphics accelerator.
                    - **ElasticGpuId** *(string) --* 
                      The ID of the Elastic Graphics accelerator.
                    - **ElasticGpuAssociationId** *(string) --* 
                      The ID of the association.
                    - **ElasticGpuAssociationState** *(string) --* 
                      The state of the association between the instance and the Elastic Graphics accelerator.
                    - **ElasticGpuAssociationTime** *(string) --* 
                      The time the Elastic Graphics accelerator was associated with the instance.
                - **ElasticInferenceAcceleratorAssociations** *(list) --* 
                  The elastic inference accelerator associated with the instance. 
                  - *(dict) --* 
                    Describes the association between an instance and an elastic inference accelerator. 
                    - **ElasticInferenceAcceleratorArn** *(string) --* 
                      The Amazon Resource Name (ARN) of the elastic inference accelerator. 
                    - **ElasticInferenceAcceleratorAssociationId** *(string) --* 
                      The ID of the association. 
                    - **ElasticInferenceAcceleratorAssociationState** *(string) --* 
                      The state of the elastic inference accelerator. 
                    - **ElasticInferenceAcceleratorAssociationTime** *(datetime) --* 
                      The time at which the elastic inference accelerator is associated with an instance. 
                - **NetworkInterfaces** *(list) --* 
                  [EC2-VPC] The network interfaces for the instance.
                  - *(dict) --* 
                    Describes a network interface.
                    - **Association** *(dict) --* 
                      The association information for an Elastic IPv4 associated with the network interface.
                      - **IpOwnerId** *(string) --* 
                        The ID of the owner of the Elastic IP address.
                      - **PublicDnsName** *(string) --* 
                        The public DNS name.
                      - **PublicIp** *(string) --* 
                        The public IP address or Elastic IP address bound to the network interface.
                    - **Attachment** *(dict) --* 
                      The network interface attachment.
                      - **AttachTime** *(datetime) --* 
                        The time stamp when the attachment initiated.
                      - **AttachmentId** *(string) --* 
                        The ID of the network interface attachment.
                      - **DeleteOnTermination** *(boolean) --* 
                        Indicates whether the network interface is deleted when the instance is terminated.
                      - **DeviceIndex** *(integer) --* 
                        The index of the device on the instance for the network interface attachment.
                      - **Status** *(string) --* 
                        The attachment state.
                    - **Description** *(string) --* 
                      The description.
                    - **Groups** *(list) --* 
                      One or more security groups.
                      - *(dict) --* 
                        Describes a security group.
                        - **GroupName** *(string) --* 
                          The name of the security group.
                        - **GroupId** *(string) --* 
                          The ID of the security group.
                    - **Ipv6Addresses** *(list) --* 
                      One or more IPv6 addresses associated with the network interface.
                      - *(dict) --* 
                        Describes an IPv6 address.
                        - **Ipv6Address** *(string) --* 
                          The IPv6 address.
                    - **MacAddress** *(string) --* 
                      The MAC address.
                    - **NetworkInterfaceId** *(string) --* 
                      The ID of the network interface.
                    - **OwnerId** *(string) --* 
                      The ID of the AWS account that created the network interface.
                    - **PrivateDnsName** *(string) --* 
                      The private DNS name.
                    - **PrivateIpAddress** *(string) --* 
                      The IPv4 address of the network interface within the subnet.
                    - **PrivateIpAddresses** *(list) --* 
                      One or more private IPv4 addresses associated with the network interface.
                      - *(dict) --* 
                        Describes a private IPv4 address.
                        - **Association** *(dict) --* 
                          The association information for an Elastic IP address for the network interface.
                          - **IpOwnerId** *(string) --* 
                            The ID of the owner of the Elastic IP address.
                          - **PublicDnsName** *(string) --* 
                            The public DNS name.
                          - **PublicIp** *(string) --* 
                            The public IP address or Elastic IP address bound to the network interface.
                        - **Primary** *(boolean) --* 
                          Indicates whether this IPv4 address is the primary private IP address of the network interface.
                        - **PrivateDnsName** *(string) --* 
                          The private IPv4 DNS name.
                        - **PrivateIpAddress** *(string) --* 
                          The private IPv4 address of the network interface.
                    - **SourceDestCheck** *(boolean) --* 
                      Indicates whether to validate network traffic to or from this network interface.
                    - **Status** *(string) --* 
                      The status of the network interface.
                    - **SubnetId** *(string) --* 
                      The ID of the subnet.
                    - **VpcId** *(string) --* 
                      The ID of the VPC.
                    - **InterfaceType** *(string) --* 
                      Describes the type of network interface.
                - **RootDeviceName** *(string) --* 
                  The device name of the root device volume (for example, ``/dev/sda1`` ).
                - **RootDeviceType** *(string) --* 
                  The root device type used by the AMI. The AMI can use an EBS volume or an instance store volume.
                - **SecurityGroups** *(list) --* 
                  The security groups for the instance.
                  - *(dict) --* 
                    Describes a security group.
                    - **GroupName** *(string) --* 
                      The name of the security group.
                    - **GroupId** *(string) --* 
                      The ID of the security group.
                - **SourceDestCheck** *(boolean) --* 
                  Specifies whether to enable an instance launched in a VPC to perform NAT. This controls whether source/destination checking is enabled on the instance. A value of ``true`` means that checking is enabled, and ``false`` means that checking is disabled. The value must be ``false`` for the instance to perform NAT. For more information, see `NAT Instances <https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_NAT_Instance.html>`__ in the *Amazon Virtual Private Cloud User Guide* .
                - **SpotInstanceRequestId** *(string) --* 
                  If the request is a Spot Instance request, the ID of the request.
                - **SriovNetSupport** *(string) --* 
                  Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
                - **StateReason** *(dict) --* 
                  The reason for the most recent state transition.
                  - **Code** *(string) --* 
                    The reason code for the state change.
                  - **Message** *(string) --* 
                    The message for the state change.
                    * ``Server.InsufficientInstanceCapacity`` : There was insufficient capacity available to satisfy the launch request. 
                    * ``Server.InternalError`` : An internal error caused the instance to terminate during launch. 
                    * ``Server.ScheduledStop`` : The instance was stopped due to a scheduled retirement. 
                    * ``Server.SpotInstanceShutdown`` : The instance was stopped because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. 
                    * ``Server.SpotInstanceTermination`` : The instance was terminated because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. 
                    * ``Client.InstanceInitiatedShutdown`` : The instance was shut down using the ``shutdown -h`` command from the instance. 
                    * ``Client.InstanceTerminated`` : The instance was terminated or rebooted during AMI creation. 
                    * ``Client.InternalError`` : A client error caused the instance to terminate during launch. 
                    * ``Client.InvalidSnapshot.NotFound`` : The specified snapshot was not found. 
                    * ``Client.UserInitiatedHibernate`` : Hibernation was initiated on the instance. 
                    * ``Client.UserInitiatedShutdown`` : The instance was shut down using the Amazon EC2 API. 
                    * ``Client.VolumeLimitExceeded`` : The limit on the number of EBS volumes or total storage was exceeded. Decrease usage or request an increase in your account limits. 
                - **Tags** *(list) --* 
                  Any tags assigned to the instance.
                  - *(dict) --* 
                    Describes a tag.
                    - **Key** *(string) --* 
                      The key of the tag.
                      Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                    - **Value** *(string) --* 
                      The value of the tag.
                      Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
                - **VirtualizationType** *(string) --* 
                  The virtualization type of the instance.
                - **CpuOptions** *(dict) --* 
                  The CPU options for the instance.
                  - **CoreCount** *(integer) --* 
                    The number of CPU cores for the instance.
                  - **ThreadsPerCore** *(integer) --* 
                    The number of threads per CPU core.
                - **CapacityReservationId** *(string) --* 
                  The ID of the Capacity Reservation.
                - **CapacityReservationSpecification** *(dict) --* 
                  Information about the Capacity Reservation targeting option.
                  - **CapacityReservationPreference** *(string) --* 
                    Describes the instance's Capacity Reservation preferences. Possible preferences include:
                    * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone). 
                    * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity. 
                  - **CapacityReservationTarget** *(dict) --* 
                    Information about the targeted Capacity Reservation.
                    - **CapacityReservationId** *(string) --* 
                      The ID of the Capacity Reservation.
                - **HibernationOptions** *(dict) --* 
                  Indicates whether the instance is enabled for hibernation.
                  - **Configured** *(boolean) --* 
                    If this parameter is set to ``true`` , your instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
                - **Licenses** *(list) --* 
                  The license configurations.
                  - *(dict) --* 
                    Describes a license configuration.
                    - **LicenseConfigurationArn** *(string) --* 
                      The Amazon Resource Name (ARN) of the license configuration.
            - **OwnerId** *(string) --* 
              The ID of the AWS account that owns the reservation.
            - **RequesterId** *(string) --* 
              The ID of the requester that launched the instances on your behalf (for example, AWS Management Console or Auto Scaling).
            - **ReservationId** *(string) --* 
              The ID of the reservation.
        :type BlockDeviceMappings: list
        :param BlockDeviceMappings:
          The block device mapping entries. You can\'t specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
          - *(dict) --*
            Describes a block device mapping.
            - **DeviceName** *(string) --*
              The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
            - **VirtualName** *(string) --*
              The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
              NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
              Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
            - **Ebs** *(dict) --*
              Parameters used to automatically set up EBS volumes when the instance is launched.
              - **DeleteOnTermination** *(boolean) --*
                Indicates whether the EBS volume is deleted on instance termination.
              - **Iops** *(integer) --*
                The number of I/O operations per second (IOPS) that the volume supports. For ``io1`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                Constraints: Range is 100-16,000 IOPS for ``gp2`` volumes and 100 to 64,000IOPS for ``io1`` volumes, in most Regions. The maximum IOPS for ``io1`` of 64,000 is guaranteed only on `Nitro-based instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances>`__ . Other instance families guarantee performance up to 32,000 IOPS.
                Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
              - **SnapshotId** *(string) --*
                The ID of the snapshot.
              - **VolumeSize** *(integer) --*
                The size of the volume, in GiB.
                Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                Constraints: 1-16384 for General Purpose SSD (``gp2`` ), 4-16384 for Provisioned IOPS SSD (``io1`` ), 500-16384 for Throughput Optimized HDD (``st1`` ), 500-16384 for Cold HDD (``sc1`` ), and 1-1024 for Magnetic (``standard`` ) volumes. If you specify a snapshot, the volume size must be equal to or larger than the snapshot size.
              - **VolumeType** *(string) --*
                The volume type. If you set the type to ``io1`` , you must also set the **Iops** property.
                Default: ``standard``
              - **Encrypted** *(boolean) --*
                Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption.
                If you are creating a volume from a snapshot, you cannot specify an encryption value. This is because only blank volumes can be encrypted on creation. If you are creating a snapshot from an existing EBS volume, you cannot specify an encryption value that differs from that of the EBS volume. We recommend that you omit the encryption value from the block device mappings when creating an image from an instance.
              - **KmsKeyId** *(string) --*
                Identifier (key ID, key alias, ID ARN, or alias ARN) for a user-managed CMK under which the EBS volume is encrypted.
                This parameter is only supported on ``BlockDeviceMapping`` objects called by `RunInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html>`__ , `RequestSpotFleet <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html>`__ , and `RequestSpotInstances <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html>`__ .
            - **NoDevice** *(string) --*
              Suppresses the specified device included in the block device mapping of the AMI.
        :type ImageId: string
        :param ImageId:
          The ID of the AMI. An AMI is required to launch an instance and must be specified here or in a launch template.
        :type InstanceType: string
        :param InstanceType:
          The instance type. For more information, see `Instance Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          Default: ``m1.small``
        :type Ipv6AddressCount: integer
        :param Ipv6AddressCount:
          [EC2-VPC] The number of IPv6 addresses to associate with the primary network interface. Amazon EC2 chooses the IPv6 addresses from the range of your subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you\'ve specified a minimum number of instances to launch.
          You cannot specify this option and the network interfaces option in the same request.
        :type Ipv6Addresses: list
        :param Ipv6Addresses:
          [EC2-VPC] The IPv6 addresses from the range of the subnet to associate with the primary network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you\'ve specified a minimum number of instances to launch.
          You cannot specify this option and the network interfaces option in the same request.
          - *(dict) --*
            Describes an IPv6 address.
            - **Ipv6Address** *(string) --*
              The IPv6 address.
        :type KernelId: string
        :param KernelId:
          The ID of the kernel.
          .. warning::
            We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `PV-GRUB <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type KeyName: string
        :param KeyName:
          The name of the key pair. You can create a key pair using  CreateKeyPair or  ImportKeyPair .
          .. warning::
            If you do not specify a key pair, you can\'t connect to the instance unless you choose an AMI that is configured to allow users another way to log in.
        :type MaxCount: integer
        :param MaxCount: **[REQUIRED]**
          The maximum number of instances to launch. If you specify more instances than Amazon EC2 can launch in the target Availability Zone, Amazon EC2 launches the largest possible number of instances above ``MinCount`` .
          Constraints: Between 1 and the maximum number you\'re allowed for the specified instance type. For more information about the default limits, and how to request an increase, see `How many instances can I run in Amazon EC2 <http://aws.amazon.com/ec2/faqs/#How_many_instances_can_I_run_in_Amazon_EC2>`__ in the Amazon EC2 FAQ.
        :type MinCount: integer
        :param MinCount: **[REQUIRED]**
          The minimum number of instances to launch. If you specify a minimum that is more instances than Amazon EC2 can launch in the target Availability Zone, Amazon EC2 launches no instances.
          Constraints: Between 1 and the maximum number you\'re allowed for the specified instance type. For more information about the default limits, and how to request an increase, see `How many instances can I run in Amazon EC2 <http://aws.amazon.com/ec2/faqs/#How_many_instances_can_I_run_in_Amazon_EC2>`__ in the Amazon EC2 General FAQ.
        :type Monitoring: dict
        :param Monitoring:
          Specifies whether detailed monitoring is enabled for the instance.
          - **Enabled** *(boolean) --* **[REQUIRED]**
            Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
        :type Placement: dict
        :param Placement:
          The placement for the instance.
          - **AvailabilityZone** *(string) --*
            The Availability Zone of the instance.
            If not specified, an Availability Zone will be automatically chosen for you based on the load balancing criteria for the region.
          - **Affinity** *(string) --*
            The affinity setting for the instance on the Dedicated Host. This parameter is not supported for the  ImportInstance command.
          - **GroupName** *(string) --*
            The name of the placement group the instance is in.
          - **PartitionNumber** *(integer) --*
            The number of the partition the instance is in. Valid only if the placement group strategy is set to ``partition`` .
          - **HostId** *(string) --*
            The ID of the Dedicated Host on which the instance resides. This parameter is not supported for the  ImportInstance command.
          - **Tenancy** *(string) --*
            The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of ``dedicated`` runs on single-tenant hardware. The ``host`` tenancy is not supported for the  ImportInstance command.
          - **SpreadDomain** *(string) --*
            Reserved for future use.
        :type RamdiskId: string
        :param RamdiskId:
          The ID of the RAM disk to select. Some kernels require additional drivers at launch. Check the kernel requirements for information about whether you need to specify a RAM disk. To find kernel requirements, go to the AWS Resource Center and search for the kernel ID.
          .. warning::
            We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see `PV-GRUB <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        :type SecurityGroupIds: list
        :param SecurityGroupIds:
          The IDs of the security groups. You can create a security group using  CreateSecurityGroup .
          Default: Amazon EC2 uses the default security group.
          You cannot specify this option and the network interfaces option in the same request.
          - *(string) --*
        :type SecurityGroups: list
        :param SecurityGroups:
          [EC2-Classic, default VPC] The names of the security groups. For a nondefault VPC, you must use security group IDs instead.
          You cannot specify this option and the network interfaces option in the same request.
          Default: Amazon EC2 uses the default security group.
          - *(string) --*
        :type SubnetId: string
        :param SubnetId:
          [EC2-VPC] The ID of the subnet to launch the instance into.
          You cannot specify this option and the network interfaces option in the same request.
        :type UserData: string
        :param UserData:
          The user data to make available to the instance. For more information, see `Running Commands on Your Linux Instance at Launch <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/user-data.html>`__ (Linux) and `Adding User Data <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2-instance-metadata.html#instancedata-add-user-data>`__ (Windows). If you are using a command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text. User data is limited to 16 KB.
            **This value will be base64 encoded automatically. Do not base64 encode this value prior to performing the operation.**
        :type AdditionalInfo: string
        :param AdditionalInfo:
          Reserved.
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          Constraints: Maximum 64 ASCII characters
        :type DisableApiTermination: boolean
        :param DisableApiTermination:
          If you set this parameter to ``true`` , you can\'t terminate the instance using the Amazon EC2 console, CLI, or API; otherwise, you can. To change this attribute to ``false`` after launch, use  ModifyInstanceAttribute . Alternatively, if you set ``InstanceInitiatedShutdownBehavior`` to ``terminate`` , you can terminate the instance by running the shutdown command from the instance.
          Default: ``false``
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type EbsOptimized: boolean
        :param EbsOptimized:
          Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal Amazon EBS I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS-optimized instance.
          Default: ``false``
        :type IamInstanceProfile: dict
        :param IamInstanceProfile:
          The IAM instance profile.
          - **Arn** *(string) --*
            The Amazon Resource Name (ARN) of the instance profile.
          - **Name** *(string) --*
            The name of the instance profile.
        :type InstanceInitiatedShutdownBehavior: string
        :param InstanceInitiatedShutdownBehavior:
          Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
          Default: ``stop``
        :type NetworkInterfaces: list
        :param NetworkInterfaces:
          The network interfaces to associate with the instance.
          - *(dict) --*
            Describes a network interface.
            - **AssociatePublicIpAddress** *(boolean) --*
              Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ``true`` .
            - **DeleteOnTermination** *(boolean) --*
              If set to ``true`` , the interface is deleted when the instance is terminated. You can specify ``true`` only if creating a new network interface when launching an instance.
            - **Description** *(string) --*
              The description of the network interface. Applies only if creating a network interface when launching an instance.
            - **DeviceIndex** *(integer) --*
              The index of the device on the instance for the network interface attachment. If you are specifying a network interface in a  RunInstances request, you must provide the device index.
            - **Groups** *(list) --*
              The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
              - *(string) --*
            - **Ipv6AddressCount** *(integer) --*
              A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you\'ve specified a minimum number of instances to launch.
            - **Ipv6Addresses** *(list) --*
              One or more IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you\'ve specified a minimum number of instances to launch.
              - *(dict) --*
                Describes an IPv6 address.
                - **Ipv6Address** *(string) --*
                  The IPv6 address.
            - **NetworkInterfaceId** *(string) --*
              The ID of the network interface.
            - **PrivateIpAddress** *(string) --*
              The private IPv4 address of the network interface. Applies only if creating a network interface when launching an instance. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
            - **PrivateIpAddresses** *(list) --*
              One or more private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
              - *(dict) --*
                Describes a secondary private IPv4 address for a network interface.
                - **Primary** *(boolean) --*
                  Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
                - **PrivateIpAddress** *(string) --*
                  The private IPv4 addresses.
            - **SecondaryPrivateIpAddressCount** *(integer) --*
              The number of secondary private IPv4 addresses. You can\'t specify this option and specify more than one private IP address using the private IP addresses option. You cannot specify this option if you\'re launching more than one instance in a  RunInstances request.
            - **SubnetId** *(string) --*
              The ID of the subnet associated with the network string. Applies only if creating a network interface when launching an instance.
            - **InterfaceType** *(string) --*
              The type of interface.
        :type PrivateIpAddress: string
        :param PrivateIpAddress:
          [EC2-VPC] The primary IPv4 address. You must specify a value from the IPv4 address range of the subnet.
          Only one private IP address can be designated as primary. You can\'t specify this option if you\'ve specified the option to designate a private IP address as the primary IP address in a network interface specification. You cannot specify this option if you\'re launching more than one instance in the request.
          You cannot specify this option and the network interfaces option in the same request.
        :type ElasticGpuSpecification: list
        :param ElasticGpuSpecification:
          An elastic GPU to associate with the instance. An Elastic GPU is a GPU resource that you can attach to your Windows instance to accelerate the graphics performance of your applications. For more information, see `Amazon EC2 Elastic GPUs <https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/elastic-graphics.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - *(dict) --*
            A specification for an Elastic Graphics accelerator.
            - **Type** *(string) --* **[REQUIRED]**
              The type of Elastic Graphics accelerator.
        :type ElasticInferenceAccelerators: list
        :param ElasticInferenceAccelerators:
          An elastic inference accelerator to associate with the instance. Elastic inference accelerators are a resource you can attach to your Amazon EC2 instances to accelerate your Deep Learning (DL) inference workloads.
          - *(dict) --*
            Describes an elastic inference accelerator.
            - **Type** *(string) --* **[REQUIRED]**
              The type of elastic inference accelerator. The possible values are ``eia1.small`` , ``eia1.medium`` , and ``eia1.large`` .
        :type TagSpecifications: list
        :param TagSpecifications:
          The tags to apply to the resources during launch. You can only tag instances and volumes on launch. The specified tags are applied to all instances or volumes that are created during launch. To tag a resource after it has been created, see  CreateTags .
          - *(dict) --*
            The tags to apply to a resource when the resource is being created.
            - **ResourceType** *(string) --*
              The type of resource to tag. Currently, the resource types that support tagging on creation are ``fleet`` , ``dedicated-host`` , ``instance`` , ``snapshot`` , and ``volume`` . To tag a resource after it has been created, see  CreateTags .
            - **Tags** *(list) --*
              The tags to apply to the resource.
              - *(dict) --*
                Describes a tag.
                - **Key** *(string) --*
                  The key of the tag.
                  Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with ``aws:`` .
                - **Value** *(string) --*
                  The value of the tag.
                  Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
        :type LaunchTemplate: dict
        :param LaunchTemplate:
          The launch template to use to launch the instances. Any parameters that you specify in  RunInstances override the same parameters in the launch template. You can specify either the name or ID of a launch template, but not both.
          - **LaunchTemplateId** *(string) --*
            The ID of the launch template.
          - **LaunchTemplateName** *(string) --*
            The name of the launch template.
          - **Version** *(string) --*
            The version number of the launch template.
            Default: The default version for the launch template.
        :type InstanceMarketOptions: dict
        :param InstanceMarketOptions:
          The market (purchasing) option for the instances.
          For  RunInstances , persistent Spot Instance requests are only supported when **InstanceInterruptionBehavior** is set to either ``hibernate`` or ``stop`` .
          - **MarketType** *(string) --*
            The market type.
          - **SpotOptions** *(dict) --*
            The options for Spot Instances.
            - **MaxPrice** *(string) --*
              The maximum hourly price you\'re willing to pay for the Spot Instances. The default is the On-Demand price.
            - **SpotInstanceType** *(string) --*
              The Spot Instance request type. For  RunInstances , persistent Spot Instance requests are only supported when **InstanceInterruptionBehavior** is set to either ``hibernate`` or ``stop`` .
            - **BlockDurationMinutes** *(integer) --*
              The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
            - **ValidUntil** *(datetime) --*
              The end date of the request. For a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date and time is reached. The default end date is 7 days from the current date.
            - **InstanceInterruptionBehavior** *(string) --*
              The behavior when a Spot Instance is interrupted. The default is ``terminate`` .
        :type CreditSpecification: dict
        :param CreditSpecification:
          The credit option for CPU usage of the T2 or T3 instance. Valid values are ``standard`` and ``unlimited`` . To change this attribute after launch, use  ModifyInstanceCreditSpecification . For more information, see `Burstable Performance Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          Default: ``standard`` (T2 instances) or ``unlimited`` (T3 instances)
          - **CpuCredits** *(string) --* **[REQUIRED]**
            The credit option for CPU usage of a T2 or T3 instance. Valid values are ``standard`` and ``unlimited`` .
        :type CpuOptions: dict
        :param CpuOptions:
          The CPU options for the instance. For more information, see `Optimizing CPU Options <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **CoreCount** *(integer) --*
            The number of CPU cores for the instance.
          - **ThreadsPerCore** *(integer) --*
            The number of threads per CPU core. To disable Intel Hyper-Threading Technology for the instance, specify a value of ``1`` . Otherwise, specify the default value of ``2`` .
        :type CapacityReservationSpecification: dict
        :param CapacityReservationSpecification:
          Information about the Capacity Reservation targeting option. If you do not specify this parameter, the instance\'s Capacity Reservation preference defaults to ``open`` , which enables it to run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
          - **CapacityReservationPreference** *(string) --*
            Indicates the instance\'s Capacity Reservation preferences. Possible preferences include:
            * ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
            * ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs as an On-Demand Instance.
          - **CapacityReservationTarget** *(dict) --*
            Information about the target Capacity Reservation.
            - **CapacityReservationId** *(string) --*
              The ID of the Capacity Reservation.
        :type HibernationOptions: dict
        :param HibernationOptions:
          Indicates whether an instance is enabled for hibernation. For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          - **Configured** *(boolean) --*
            If you set this parameter to ``true`` , your instance is enabled for hibernation.
            Default: ``false``
        :type LicenseSpecifications: list
        :param LicenseSpecifications:
          The license configurations.
          - *(dict) --*
            Describes a license configuration.
            - **LicenseConfigurationArn** *(string) --*
              The Amazon Resource Name (ARN) of the license configuration.
        :rtype: dict
        :returns:
        """
        pass

    def run_scheduled_instances(self, LaunchSpecification: Dict, ScheduledInstanceId: str, ClientToken: str = None, DryRun: bool = None, InstanceCount: int = None) -> Dict:
        """
        Launches the specified Scheduled Instances.
        Before you can launch a Scheduled Instance, you must purchase it and obtain an identifier using  PurchaseScheduledInstances .
        You must launch a Scheduled Instance during its scheduled time period. You can't stop or reboot a Scheduled Instance, but you can terminate it as needed. If you terminate a Scheduled Instance before the current scheduled time period ends, you can launch it again after a few minutes. For more information, see `Scheduled Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-scheduled-instances.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/RunScheduledInstances>`_
        
        **Request Syntax**
        ::
          response = client.run_scheduled_instances(
              ClientToken='string',
              DryRun=True|False,
              InstanceCount=123,
              LaunchSpecification={
                  'BlockDeviceMappings': [
                      {
                          'DeviceName': 'string',
                          'Ebs': {
                              'DeleteOnTermination': True|False,
                              'Encrypted': True|False,
                              'Iops': 123,
                              'SnapshotId': 'string',
                              'VolumeSize': 123,
                              'VolumeType': 'string'
                          },
                          'NoDevice': 'string',
                          'VirtualName': 'string'
                      },
                  ],
                  'EbsOptimized': True|False,
                  'IamInstanceProfile': {
                      'Arn': 'string',
                      'Name': 'string'
                  },
                  'ImageId': 'string',
                  'InstanceType': 'string',
                  'KernelId': 'string',
                  'KeyName': 'string',
                  'Monitoring': {
                      'Enabled': True|False
                  },
                  'NetworkInterfaces': [
                      {
                          'AssociatePublicIpAddress': True|False,
                          'DeleteOnTermination': True|False,
                          'Description': 'string',
                          'DeviceIndex': 123,
                          'Groups': [
                              'string',
                          ],
                          'Ipv6AddressCount': 123,
                          'Ipv6Addresses': [
                              {
                                  'Ipv6Address': 'string'
                              },
                          ],
                          'NetworkInterfaceId': 'string',
                          'PrivateIpAddress': 'string',
                          'PrivateIpAddressConfigs': [
                              {
                                  'Primary': True|False,
                                  'PrivateIpAddress': 'string'
                              },
                          ],
                          'SecondaryPrivateIpAddressCount': 123,
                          'SubnetId': 'string'
                      },
                  ],
                  'Placement': {
                      'AvailabilityZone': 'string',
                      'GroupName': 'string'
                  },
                  'RamdiskId': 'string',
                  'SecurityGroupIds': [
                      'string',
                  ],
                  'SubnetId': 'string',
                  'UserData': 'string'
              },
              ScheduledInstanceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'InstanceIdSet': [
                    'string',
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            Contains the output of RunScheduledInstances.
            - **InstanceIdSet** *(list) --* 
              The IDs of the newly launched instances.
              - *(string) --* 
        :type ClientToken: string
        :param ClientToken:
          Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see `Ensuring Idempotency <https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html>`__ .
          This field is autopopulated if not provided.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type InstanceCount: integer
        :param InstanceCount:
          The number of instances.
          Default: 1
        :type LaunchSpecification: dict
        :param LaunchSpecification: **[REQUIRED]**
          The launch specification. You must match the instance type, Availability Zone, network, and platform of the schedule that you purchased.
          - **BlockDeviceMappings** *(list) --*
            The block device mapping entries.
            - *(dict) --*
              Describes a block device mapping for a Scheduled Instance.
              - **DeviceName** *(string) --*
                The device name (for example, ``/dev/sdh`` or ``xvdh`` ).
              - **Ebs** *(dict) --*
                Parameters used to set up EBS volumes automatically when the instance is launched.
                - **DeleteOnTermination** *(boolean) --*
                  Indicates whether the volume is deleted on instance termination.
                - **Encrypted** *(boolean) --*
                  Indicates whether the volume is encrypted. You can attached encrypted volumes only to instances that support them.
                - **Iops** *(integer) --*
                  The number of I/O operations per second (IOPS) that the volume supports. For io1 volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. For more information about ``gp2`` baseline performance, I/O credits, and bursting, see `Amazon EBS Volume Types <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
                  Constraint: Range is 100-20000 IOPS for ``io1`` volumes and 100-10000 IOPS for ``gp2`` volumes.
                  Condition: This parameter is required for requests to create ``io1`` volumes; it is not used in requests to create ``gp2`` , ``st1`` , ``sc1`` , or ``standard`` volumes.
                - **SnapshotId** *(string) --*
                  The ID of the snapshot.
                - **VolumeSize** *(integer) --*
                  The size of the volume, in GiB.
                  Default: If you\'re creating the volume from a snapshot and don\'t specify a volume size, the default is the snapshot size.
                - **VolumeType** *(string) --*
                  The volume type. ``gp2`` for General Purpose SSD, ``io1`` for Provisioned IOPS SSD, Throughput Optimized HDD for ``st1`` , Cold HDD for ``sc1`` , or ``standard`` for Magnetic.
                  Default: ``standard``
              - **NoDevice** *(string) --*
                Suppresses the specified device included in the block device mapping of the AMI.
              - **VirtualName** *(string) --*
                The virtual device name (``ephemeral`` N). Instance store volumes are numbered starting from 0. An instance type with two available instance store volumes can specify mappings for ``ephemeral0`` and ``ephemeral1`` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
                Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
          - **EbsOptimized** *(boolean) --*
            Indicates whether the instances are optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn\'t available with all instance types. Additional usage charges apply when using an EBS-optimized instance.
            Default: ``false``
          - **IamInstanceProfile** *(dict) --*
            The IAM instance profile.
            - **Arn** *(string) --*
              The Amazon Resource Name (ARN).
            - **Name** *(string) --*
              The name.
          - **ImageId** *(string) --* **[REQUIRED]**
            The ID of the Amazon Machine Image (AMI).
          - **InstanceType** *(string) --*
            The instance type.
          - **KernelId** *(string) --*
            The ID of the kernel.
          - **KeyName** *(string) --*
            The name of the key pair.
          - **Monitoring** *(dict) --*
            Enable or disable monitoring for the instances.
            - **Enabled** *(boolean) --*
              Indicates whether monitoring is enabled.
          - **NetworkInterfaces** *(list) --*
            The network interfaces.
            - *(dict) --*
              Describes a network interface for a Scheduled Instance.
              - **AssociatePublicIpAddress** *(boolean) --*
                Indicates whether to assign a public IPv4 address to instances launched in a VPC. The public IPv4 address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ``true`` .
              - **DeleteOnTermination** *(boolean) --*
                Indicates whether to delete the interface when the instance is terminated.
              - **Description** *(string) --*
                The description.
              - **DeviceIndex** *(integer) --*
                The index of the device for the network interface attachment.
              - **Groups** *(list) --*
                The IDs of the security groups.
                - *(string) --*
              - **Ipv6AddressCount** *(integer) --*
                The number of IPv6 addresses to assign to the network interface. The IPv6 addresses are automatically selected from the subnet range.
              - **Ipv6Addresses** *(list) --*
                The specific IPv6 addresses from the subnet range.
                - *(dict) --*
                  Describes an IPv6 address.
                  - **Ipv6Address** *(string) --*
                    The IPv6 address.
              - **NetworkInterfaceId** *(string) --*
                The ID of the network interface.
              - **PrivateIpAddress** *(string) --*
                The IPv4 address of the network interface within the subnet.
              - **PrivateIpAddressConfigs** *(list) --*
                The private IPv4 addresses.
                - *(dict) --*
                  Describes a private IPv4 address for a Scheduled Instance.
                  - **Primary** *(boolean) --*
                    Indicates whether this is a primary IPv4 address. Otherwise, this is a secondary IPv4 address.
                  - **PrivateIpAddress** *(string) --*
                    The IPv4 address.
              - **SecondaryPrivateIpAddressCount** *(integer) --*
                The number of secondary private IPv4 addresses.
              - **SubnetId** *(string) --*
                The ID of the subnet.
          - **Placement** *(dict) --*
            The placement information.
            - **AvailabilityZone** *(string) --*
              The Availability Zone.
            - **GroupName** *(string) --*
              The name of the placement group.
          - **RamdiskId** *(string) --*
            The ID of the RAM disk.
          - **SecurityGroupIds** *(list) --*
            The IDs of the security groups.
            - *(string) --*
          - **SubnetId** *(string) --*
            The ID of the subnet in which to launch the instances.
          - **UserData** *(string) --*
            The base64-encoded MIME user data.
        :type ScheduledInstanceId: string
        :param ScheduledInstanceId: **[REQUIRED]**
          The Scheduled Instance ID.
        :rtype: dict
        :returns:
        """
        pass

    def search_transit_gateway_routes(self, TransitGatewayRouteTableId: str, Filters: List, MaxResults: int = None, DryRun: bool = None) -> Dict:
        """
        Searches for routes in the specified transit gateway route table.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/SearchTransitGatewayRoutes>`_
        
        **Request Syntax**
        ::
          response = client.search_transit_gateway_routes(
              TransitGatewayRouteTableId='string',
              Filters=[
                  {
                      'Name': 'string',
                      'Values': [
                          'string',
                      ]
                  },
              ],
              MaxResults=123,
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'Routes': [
                    {
                        'DestinationCidrBlock': 'string',
                        'TransitGatewayAttachments': [
                            {
                                'ResourceId': 'string',
                                'TransitGatewayAttachmentId': 'string',
                                'ResourceType': 'vpc'|'vpn'
                            },
                        ],
                        'Type': 'static'|'propagated',
                        'State': 'pending'|'active'|'blackhole'|'deleting'|'deleted'
                    },
                ],
                'AdditionalRoutesAvailable': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Routes** *(list) --* 
              Information about the routes.
              - *(dict) --* 
                Describes a route for a transit gateway route table.
                - **DestinationCidrBlock** *(string) --* 
                  The CIDR block used for destination matches.
                - **TransitGatewayAttachments** *(list) --* 
                  The attachments.
                  - *(dict) --* 
                    Describes a route attachment.
                    - **ResourceId** *(string) --* 
                      The ID of the resource.
                    - **TransitGatewayAttachmentId** *(string) --* 
                      The ID of the attachment.
                    - **ResourceType** *(string) --* 
                      The resource type.
                - **Type** *(string) --* 
                  The route type.
                - **State** *(string) --* 
                  The state of the route.
            - **AdditionalRoutesAvailable** *(boolean) --* 
              Indicates whether there are additional routes available.
        :type TransitGatewayRouteTableId: string
        :param TransitGatewayRouteTableId: **[REQUIRED]**
          The ID of the transit gateway route table.
        :type Filters: list
        :param Filters: **[REQUIRED]**
          One or more filters. The possible values are:
          * ``attachment.transit-gateway-attachment-id`` - The id of the transit gateway attachment.
          * ``attachment.resource-id`` - The resource id of the transit gateway attachment.
          * ``attachment.resource-type`` - The attachment resource type (``vpc`` | ``vpn`` ).
          * ``route-search.exact-match`` - The exact match of the specified filter.
          * ``route-search.longest-prefix-match`` - The longest prefix that matches the route.
          * ``route-search.subnet-of-match`` - The routes with a subnet that match the specified CIDR filter.
          * ``route-search.supernet-of-match`` - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify supernet-of-match as 10.0.1.0/30, then the result returns 10.0.1.0/29.
          * ``state`` - The state of the attachment (``available`` | ``deleted`` | ``deleting`` | ``failed`` | ``modifying`` | ``pendingAcceptance`` | ``pending`` | ``rollingBack`` | ``rejected`` | ``rejecting`` ).
          * ``type`` - The type of roue (``active`` | ``blackhole`` ).
          - *(dict) --*
            A filter name and value pair that is used to return a more specific list of results from a describe operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs. The filters supported by a describe operation are documented with the describe operation. For example:
            *  DescribeAvailabilityZones
            *  DescribeImages
            *  DescribeInstances
            *  DescribeKeyPairs
            *  DescribeSecurityGroups
            *  DescribeSnapshots
            *  DescribeSubnets
            *  DescribeTags
            *  DescribeVolumes
            *  DescribeVpcs
            - **Name** *(string) --*
              The name of the filter. Filter names are case-sensitive.
            - **Values** *(list) --*
              The filter values. Filter values are case-sensitive.
              - *(string) --*
        :type MaxResults: integer
        :param MaxResults:
          The maximum number of routes to return.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def start_instances(self, InstanceIds: List, AdditionalInfo: str = None, DryRun: bool = None) -> Dict:
        """
        Starts an Amazon EBS-backed instance that you've previously stopped.
        Instances that use Amazon EBS volumes as their root devices can be quickly stopped and started. When an instance is stopped, the compute resources are released and you are not billed for instance usage. However, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. You can restart your instance at any time. Every time you start your Windows instance, Amazon EC2 charges you for a full instance hour. If you stop and restart your Windows instance, a new instance hour begins and Amazon EC2 charges you for another full instance hour even if you are still within the same 60-minute period when it was stopped. Every time you start your Linux instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage.
        Before stopping an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM.
        Performing this operation on an instance that uses an instance store as its root device returns an error.
        For more information, see `Stopping Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Stop_Start.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/StartInstances>`_
        
        **Request Syntax**
        ::
          response = client.start_instances(
              InstanceIds=[
                  'string',
              ],
              AdditionalInfo='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'StartingInstances': [
                    {
                        'CurrentState': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        },
                        'InstanceId': 'string',
                        'PreviousState': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **StartingInstances** *(list) --* 
              Information about the started instances.
              - *(dict) --* 
                Describes an instance state change.
                - **CurrentState** *(dict) --* 
                  The current state of the instance.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **PreviousState** *(dict) --* 
                  The previous state of the instance.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
        :type InstanceIds: list
        :param InstanceIds: **[REQUIRED]**
          The IDs of the instances.
          - *(string) --*
        :type AdditionalInfo: string
        :param AdditionalInfo:
          Reserved.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def stop_instances(self, InstanceIds: List, Hibernate: bool = None, DryRun: bool = None, Force: bool = None) -> Dict:
        """
        Stops an Amazon EBS-backed instance.
        You can use the Stop action to hibernate an instance if the instance is `enabled for hibernation <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html#enabling-hibernation>`__ and it meets the `hibernation prerequisites <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html#hibernating-prerequisites>`__ . For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        We don't charge usage for a stopped instance, or data transfer fees; however, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. Every time you start your Windows instance, Amazon EC2 charges you for a full instance hour. If you stop and restart your Windows instance, a new instance hour begins and Amazon EC2 charges you for another full instance hour even if you are still within the same 60-minute period when it was stopped. Every time you start your Linux instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage.
        You can't start, stop, or hibernate Spot Instances, and you can't stop or hibernate instance store-backed instances. For information about using hibernation for Spot Instances, see `Hibernating Interrupted Spot Instances <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-interruptions.html#hibernate-spot-instances>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        When you stop or hibernate an instance, we shut it down. You can restart your instance at any time. Before stopping or hibernating an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM, but hibernating an instance does preserve data stored in RAM. If an instance cannot hibernate successfully, a normal shutdown occurs.
        Stopping and hibernating an instance is different to rebooting or terminating it. For example, when you stop or hibernate an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, the root device and any other devices attached during the instance launch are automatically deleted. For more information about the differences between rebooting, stopping, hibernating, and terminating instances, see `Instance Lifecycle <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-lifecycle.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        When you stop an instance, we attempt to shut it down forcibly after a short while. If your instance appears stuck in the stopping state after a period of time, there may be an issue with the underlying host computer. For more information, see `Troubleshooting Stopping Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstancesStopping.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/StopInstances>`_
        
        **Request Syntax**
        ::
          response = client.stop_instances(
              InstanceIds=[
                  'string',
              ],
              Hibernate=True|False,
              DryRun=True|False,
              Force=True|False
          )
        
        **Response Syntax**
        ::
            {
                'StoppingInstances': [
                    {
                        'CurrentState': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        },
                        'InstanceId': 'string',
                        'PreviousState': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **StoppingInstances** *(list) --* 
              Information about the stopped instances.
              - *(dict) --* 
                Describes an instance state change.
                - **CurrentState** *(dict) --* 
                  The current state of the instance.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **PreviousState** *(dict) --* 
                  The previous state of the instance.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
        :type InstanceIds: list
        :param InstanceIds: **[REQUIRED]**
          The IDs of the instances.
          - *(string) --*
        :type Hibernate: boolean
        :param Hibernate:
          Hibernates the instance if the instance was enabled for hibernation at launch. If the instance cannot hibernate successfully, a normal shutdown occurs. For more information, see `Hibernate Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
          Default: ``false``
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type Force: boolean
        :param Force:
          Forces the instances to stop. The instances do not have an opportunity to flush file system caches or file system metadata. If you use this option, you must perform file system check and repair procedures. This option is not recommended for Windows instances.
          Default: ``false``
        :rtype: dict
        :returns:
        """
        pass

    def terminate_client_vpn_connections(self, ClientVpnEndpointId: str, ConnectionId: str = None, Username: str = None, DryRun: bool = None) -> Dict:
        """
        Terminates active Client VPN endpoint connections. This action can be used to terminate a specific client connection, or up to five connections established by a specific user.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/TerminateClientVpnConnections>`_
        
        **Request Syntax**
        ::
          response = client.terminate_client_vpn_connections(
              ClientVpnEndpointId='string',
              ConnectionId='string',
              Username='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ClientVpnEndpointId': 'string',
                'Username': 'string',
                'ConnectionStatuses': [
                    {
                        'ConnectionId': 'string',
                        'PreviousStatus': {
                            'Code': 'active'|'failed-to-terminate'|'terminating'|'terminated',
                            'Message': 'string'
                        },
                        'CurrentStatus': {
                            'Code': 'active'|'failed-to-terminate'|'terminating'|'terminated',
                            'Message': 'string'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ClientVpnEndpointId** *(string) --* 
              The ID of the Client VPN endpoint.
            - **Username** *(string) --* 
              The user who established the terminated client connections.
            - **ConnectionStatuses** *(list) --* 
              The current state of the client connections.
              - *(dict) --* 
                Information about a terminated Client VPN endpoint client connection.
                - **ConnectionId** *(string) --* 
                  The ID of the client connection.
                - **PreviousStatus** *(dict) --* 
                  The state of the client connection.
                  - **Code** *(string) --* 
                    The state of the client connection.
                  - **Message** *(string) --* 
                    A message about the status of the client connection, if applicable.
                - **CurrentStatus** *(dict) --* 
                  A message about the status of the client connection, if applicable.
                  - **Code** *(string) --* 
                    The state of the client connection.
                  - **Message** *(string) --* 
                    A message about the status of the client connection, if applicable.
        :type ClientVpnEndpointId: string
        :param ClientVpnEndpointId: **[REQUIRED]**
          The ID of the Client VPN endpoint to which the client is connected.
        :type ConnectionId: string
        :param ConnectionId:
          The ID of the client connection to be terminated.
        :type Username: string
        :param Username:
          The name of the user who initiated the connection. Use this option to terminate all active connections for the specified user. This option can only be used if the user has established up to five connections.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def terminate_instances(self, InstanceIds: List, DryRun: bool = None) -> Dict:
        """
        Shuts down the specified instances. This operation is idempotent; if you terminate an instance more than once, each call succeeds. 
        If you specify multiple instances and the request fails (for example, because of a single incorrect instance ID), none of the instances are terminated.
        Terminated instances remain visible after termination (for approximately one hour).
        By default, Amazon EC2 deletes all EBS volumes that were attached when the instance launched. Volumes attached after instance launch continue running.
        You can stop, start, and terminate EBS-backed instances. You can only terminate instance store-backed instances. What happens to an instance differs if you stop it or terminate it. For example, when you stop an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, any attached EBS volumes with the ``DeleteOnTermination`` block device mapping parameter set to ``true`` are automatically deleted. For more information about the differences between stopping and terminating instances, see `Instance Lifecycle <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-lifecycle.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        For more information about troubleshooting, see `Troubleshooting Terminating Your Instance <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstancesShuttingDown.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/TerminateInstances>`_
        
        **Request Syntax**
        ::
          response = client.terminate_instances(
              InstanceIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'TerminatingInstances': [
                    {
                        'CurrentState': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        },
                        'InstanceId': 'string',
                        'PreviousState': {
                            'Code': 123,
                            'Name': 'pending'|'running'|'shutting-down'|'terminated'|'stopping'|'stopped'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **TerminatingInstances** *(list) --* 
              Information about the terminated instances.
              - *(dict) --* 
                Describes an instance state change.
                - **CurrentState** *(dict) --* 
                  The current state of the instance.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **PreviousState** *(dict) --* 
                  The previous state of the instance.
                  - **Code** *(integer) --* 
                    The state of the instance as a 16-bit unsigned integer. 
                    The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored.
                    The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255. 
                    The valid values for instance-state-code will all be in the range of the low byte and they are:
                    * ``0`` : ``pending``   
                    * ``16`` : ``running``   
                    * ``32`` : ``shutting-down``   
                    * ``48`` : ``terminated``   
                    * ``64`` : ``stopping``   
                    * ``80`` : ``stopped``   
                    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
                  - **Name** *(string) --* 
                    The current state of the instance.
        :type InstanceIds: list
        :param InstanceIds: **[REQUIRED]**
          The IDs of the instances.
          Constraints: Up to 1000 instance IDs. We recommend breaking up this request into smaller batches.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def unassign_ipv6_addresses(self, Ipv6Addresses: List, NetworkInterfaceId: str) -> Dict:
        """
        Unassigns one or more IPv6 addresses from a network interface.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/UnassignIpv6Addresses>`_
        
        **Request Syntax**
        ::
          response = client.unassign_ipv6_addresses(
              Ipv6Addresses=[
                  'string',
              ],
              NetworkInterfaceId='string'
          )
        
        **Response Syntax**
        ::
            {
                'NetworkInterfaceId': 'string',
                'UnassignedIpv6Addresses': [
                    'string',
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **NetworkInterfaceId** *(string) --* 
              The ID of the network interface.
            - **UnassignedIpv6Addresses** *(list) --* 
              The IPv6 addresses that have been unassigned from the network interface.
              - *(string) --* 
        :type Ipv6Addresses: list
        :param Ipv6Addresses: **[REQUIRED]**
          The IPv6 addresses to unassign from the network interface.
          - *(string) --*
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :rtype: dict
        :returns:
        """
        pass

    def unassign_private_ip_addresses(self, NetworkInterfaceId: str, PrivateIpAddresses: List):
        """
        Unassigns one or more secondary private IP addresses from a network interface.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/UnassignPrivateIpAddresses>`_
        
        **Request Syntax**
        ::
          response = client.unassign_private_ip_addresses(
              NetworkInterfaceId='string',
              PrivateIpAddresses=[
                  'string',
              ]
          )
        :type NetworkInterfaceId: string
        :param NetworkInterfaceId: **[REQUIRED]**
          The ID of the network interface.
        :type PrivateIpAddresses: list
        :param PrivateIpAddresses: **[REQUIRED]**
          The secondary private IP addresses to unassign from the network interface. You can specify this option multiple times to unassign more than one IP address.
          - *(string) --*
        :returns: None
        """
        pass

    def unmonitor_instances(self, InstanceIds: List, DryRun: bool = None) -> Dict:
        """
        Disables detailed monitoring for a running instance. For more information, see `Monitoring Your Instances and Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-cloudwatch.html>`__ in the *Amazon Elastic Compute Cloud User Guide* .
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/UnmonitorInstances>`_
        
        **Request Syntax**
        ::
          response = client.unmonitor_instances(
              InstanceIds=[
                  'string',
              ],
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'InstanceMonitorings': [
                    {
                        'InstanceId': 'string',
                        'Monitoring': {
                            'State': 'disabled'|'disabling'|'enabled'|'pending'
                        }
                    },
                ]
            }
        
        **Response Structure**
          - *(dict) --* 
            - **InstanceMonitorings** *(list) --* 
              The monitoring information.
              - *(dict) --* 
                Describes the monitoring of an instance.
                - **InstanceId** *(string) --* 
                  The ID of the instance.
                - **Monitoring** *(dict) --* 
                  The monitoring for the instance.
                  - **State** *(string) --* 
                    Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
        :type InstanceIds: list
        :param InstanceIds: **[REQUIRED]**
          The IDs of the instances.
          - *(string) --*
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass

    def update_security_group_rule_descriptions_egress(self, IpPermissions: List, DryRun: bool = None, GroupId: str = None, GroupName: str = None) -> Dict:
        """
        [VPC only] Updates the description of an egress (outbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously.
        You specify the description as part of the IP permissions structure. You can remove a description for a security group rule by omitting the description parameter in the request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/UpdateSecurityGroupRuleDescriptionsEgress>`_
        
        **Request Syntax**
        ::
          response = client.update_security_group_rule_descriptions_egress(
              DryRun=True|False,
              GroupId='string',
              GroupName='string',
              IpPermissions=[
                  {
                      'FromPort': 123,
                      'IpProtocol': 'string',
                      'IpRanges': [
                          {
                              'CidrIp': 'string',
                              'Description': 'string'
                          },
                      ],
                      'Ipv6Ranges': [
                          {
                              'CidrIpv6': 'string',
                              'Description': 'string'
                          },
                      ],
                      'PrefixListIds': [
                          {
                              'Description': 'string',
                              'PrefixListId': 'string'
                          },
                      ],
                      'ToPort': 123,
                      'UserIdGroupPairs': [
                          {
                              'Description': 'string',
                              'GroupId': 'string',
                              'GroupName': 'string',
                              'PeeringStatus': 'string',
                              'UserId': 'string',
                              'VpcId': 'string',
                              'VpcPeeringConnectionId': 'string'
                          },
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupId: string
        :param GroupId:
          The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
        :type GroupName: string
        :param GroupName:
          [Default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request.
        :type IpPermissions: list
        :param IpPermissions: **[REQUIRED]**
          The IP permissions for the security group rule.
          - *(dict) --*
            Describes a set of permissions for a security group rule.
            - **FromPort** *(integer) --*
              The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **IpProtocol** *(string) --*
              The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
              [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
            - **IpRanges** *(list) --*
              The IPv4 ranges.
              - *(dict) --*
                Describes an IPv4 range.
                - **CidrIp** *(string) --*
                  The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv4 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **Ipv6Ranges** *(list) --*
              [VPC only] The IPv6 ranges.
              - *(dict) --*
                [EC2-VPC only] Describes an IPv6 range.
                - **CidrIpv6** *(string) --*
                  The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv6 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **PrefixListIds** *(list) --*
              [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
              - *(dict) --*
                Describes a prefix list ID.
                - **Description** *(string) --*
                  A description for the security group rule that references this prefix list ID.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **PrefixListId** *(string) --*
                  The ID of the prefix.
            - **ToPort** *(integer) --*
              The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **UserIdGroupPairs** *(list) --*
              The security group and AWS account ID pairs.
              - *(dict) --*
                Describes a security group and AWS account ID pair.
                - **Description** *(string) --*
                  A description for the security group rule that references this user ID group pair.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **GroupId** *(string) --*
                  The ID of the security group.
                - **GroupName** *(string) --*
                  The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID.
                  For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                - **PeeringStatus** *(string) --*
                  The status of a VPC peering connection, if applicable.
                - **UserId** *(string) --*
                  The ID of an AWS account.
                  For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                  [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                - **VpcId** *(string) --*
                  The ID of the VPC for the referenced security group, if applicable.
                - **VpcPeeringConnectionId** *(string) --*
                  The ID of the VPC peering connection, if applicable.
        :rtype: dict
        :returns:
        """
        pass

    def update_security_group_rule_descriptions_ingress(self, IpPermissions: List, DryRun: bool = None, GroupId: str = None, GroupName: str = None) -> Dict:
        """
        Updates the description of an ingress (inbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously.
        You specify the description as part of the IP permissions structure. You can remove a description for a security group rule by omitting the description parameter in the request.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/UpdateSecurityGroupRuleDescriptionsIngress>`_
        
        **Request Syntax**
        ::
          response = client.update_security_group_rule_descriptions_ingress(
              DryRun=True|False,
              GroupId='string',
              GroupName='string',
              IpPermissions=[
                  {
                      'FromPort': 123,
                      'IpProtocol': 'string',
                      'IpRanges': [
                          {
                              'CidrIp': 'string',
                              'Description': 'string'
                          },
                      ],
                      'Ipv6Ranges': [
                          {
                              'CidrIpv6': 'string',
                              'Description': 'string'
                          },
                      ],
                      'PrefixListIds': [
                          {
                              'Description': 'string',
                              'PrefixListId': 'string'
                          },
                      ],
                      'ToPort': 123,
                      'UserIdGroupPairs': [
                          {
                              'Description': 'string',
                              'GroupId': 'string',
                              'GroupName': 'string',
                              'PeeringStatus': 'string',
                              'UserId': 'string',
                              'VpcId': 'string',
                              'VpcPeeringConnectionId': 'string'
                          },
                      ]
                  },
              ]
          )
        
        **Response Syntax**
        ::
            {
                'Return': True|False
            }
        
        **Response Structure**
          - *(dict) --* 
            - **Return** *(boolean) --* 
              Returns ``true`` if the request succeeds; otherwise, returns an error.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :type GroupId: string
        :param GroupId:
          The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
        :type GroupName: string
        :param GroupName:
          [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request.
        :type IpPermissions: list
        :param IpPermissions: **[REQUIRED]**
          The IP permissions for the security group rule.
          - *(dict) --*
            Describes a set of permissions for a security group rule.
            - **FromPort** *(integer) --*
              The start of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of ``-1`` indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **IpProtocol** *(string) --*
              The IP protocol name (``tcp`` , ``udp`` , ``icmp`` , ``icmpv6`` ) or number (see `Protocol Numbers <http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml>`__ ).
              [VPC only] Use ``-1`` to specify all protocols. When authorizing security group rules, specifying ``-1`` or a protocol number other than ``tcp`` , ``udp`` , ``icmp`` , or ``icmpv6`` allows traffic on all ports, regardless of any port range you specify. For ``tcp`` , ``udp`` , and ``icmp`` , you must specify a port range. For ``icmpv6`` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
            - **IpRanges** *(list) --*
              The IPv4 ranges.
              - *(dict) --*
                Describes an IPv4 range.
                - **CidrIp** *(string) --*
                  The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv4 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **Ipv6Ranges** *(list) --*
              [VPC only] The IPv6 ranges.
              - *(dict) --*
                [EC2-VPC only] Describes an IPv6 range.
                - **CidrIpv6** *(string) --*
                  The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
                - **Description** *(string) --*
                  A description for the security group rule that references this IPv6 address range.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
            - **PrefixListIds** *(list) --*
              [VPC only] The prefix list IDs for an AWS service. With outbound rules, this is the AWS service to access through a VPC endpoint from instances associated with the security group.
              - *(dict) --*
                Describes a prefix list ID.
                - **Description** *(string) --*
                  A description for the security group rule that references this prefix list ID.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **PrefixListId** *(string) --*
                  The ID of the prefix.
            - **ToPort** *(integer) --*
              The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of ``-1`` indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all codes.
            - **UserIdGroupPairs** *(list) --*
              The security group and AWS account ID pairs.
              - *(dict) --*
                Describes a security group and AWS account ID pair.
                - **Description** *(string) --*
                  A description for the security group rule that references this user ID group pair.
                  Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
                - **GroupId** *(string) --*
                  The ID of the security group.
                - **GroupName** *(string) --*
                  The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID.
                  For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
                - **PeeringStatus** *(string) --*
                  The status of a VPC peering connection, if applicable.
                - **UserId** *(string) --*
                  The ID of an AWS account.
                  For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
                  [EC2-Classic] Required when adding or removing rules that reference a security group in another AWS account.
                - **VpcId** *(string) --*
                  The ID of the VPC for the referenced security group, if applicable.
                - **VpcPeeringConnectionId** *(string) --*
                  The ID of the VPC peering connection, if applicable.
        :rtype: dict
        :returns:
        """
        pass

    def withdraw_byoip_cidr(self, Cidr: str, DryRun: bool = None) -> Dict:
        """
        Stops advertising an IPv4 address range that is provisioned as an address pool.
        You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time.
        It can take a few minutes before traffic to the specified addresses stops routing to AWS because of BGP propagation delays.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/WithdrawByoipCidr>`_
        
        **Request Syntax**
        ::
          response = client.withdraw_byoip_cidr(
              Cidr='string',
              DryRun=True|False
          )
        
        **Response Syntax**
        ::
            {
                'ByoipCidr': {
                    'Cidr': 'string',
                    'Description': 'string',
                    'StatusMessage': 'string',
                    'State': 'advertised'|'deprovisioned'|'failed-deprovision'|'failed-provision'|'pending-deprovision'|'pending-provision'|'provisioned'
                }
            }
        
        **Response Structure**
          - *(dict) --* 
            - **ByoipCidr** *(dict) --* 
              Information about the address pool.
              - **Cidr** *(string) --* 
                The public IPv4 address range, in CIDR notation.
              - **Description** *(string) --* 
                The description of the address range.
              - **StatusMessage** *(string) --* 
                Upon success, contains the ID of the address pool. Otherwise, contains an error message.
              - **State** *(string) --* 
                The state of the address pool.
        :type Cidr: string
        :param Cidr: **[REQUIRED]**
          The public IPv4 address range, in CIDR notation.
        :type DryRun: boolean
        :param DryRun:
          Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ``DryRunOperation`` . Otherwise, it is ``UnauthorizedOperation`` .
        :rtype: dict
        :returns:
        """
        pass
